(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    125940,       3051]*)
(*NotebookOutlinePosition[    127020,       3085]*)
(*  CellTagsIndexPosition[    126976,       3081]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["AFM compatibility diagrams at 3 \
kbar",
  FontColor->RGBColor[1, 0, 0]]], "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general compatibility diagram functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Off[General::spell]; Off[General::spell1]; Off[Set::shape];\n\
Off[Interpolation::inhr]; Off[InterpolatingFunction::dmwarn",
    FontWeight->"Plain"],
  StyleBox["]",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0.499992]],
  StyleBox["\nSetOptions[Position, Heads -> False];\n<<Graphics`Animation` (* \
only needed if movies to be made *)",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default value, normally overridden", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["making combinations", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};  \n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                            \
                       gray[n-1,m-1]]}],m];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["creates slider", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[slider];\n",
    FontWeight->"Plain"],
  StyleBox["slider",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v1_, v2_, dv1_, dv2_] := \n    \
{Line[{{x1,y},{x2,y},{x2,y-dy},{x1,y-dy},{x1,y}}],\n          Map[Line[{{x1 + \
(#-v1)(x2-x1)/(v2-v1),y},\n                    {x1 + \
(#-v1)(x2-x1)/(v2-v1),y-dy}}]&, Range[v1,v2,dv1]],\n                    \n    \
      Map[Line[{{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.4},\n                    \
{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.6}}]&, Range[v1,v2,dv2]],\n                \
    \n          If[TrueQ[varyTatP],\n             \
Text[FontForm[\"T(\[Degree]C)\",  {\"Helvetica\",fontsize1}], {x1,y+yplus}],\n\
             Text[FontForm[\"P(kbar)\",{\"Helvetica\",fontsize1}], \
{x1,y+yplus}]],\n          \n          \
Text[FontForm[Round[v1],{\"Helvetica\",fontsize1}], {x1,y+yminus}],\n         \
 Text[FontForm[Round[v2],{\"Helvetica\",fontsize1}], {x2,y+yminus}] };",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["creates bar on slider", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bar];\n",
    FontWeight->"Plain"],
  StyleBox["bar",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v_, v1_, v2_] := \n           Line[{{x1 + (v-v1)(x2-x1)/(v2-v1), \
y-dy-dy1},\n                 {x1 + (v-v1)(x2-x1)/(v2-v1), y+dy1}}];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws background to phase relationships", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background];\n",
    FontWeight->"Plain"],
  StyleBox["background",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[0,0.45,1], Polygon[shape], GrayLevel[0], Line[shape]};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws labels", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] := {};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws all the tie triangles", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tietriangle];\n",
    FontWeight->"Plain"],
  StyleBox["tietriangle",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_]:=\n     {GrayLevel[1], Map[conv[Polygon,#]&, q], \n      \
GrayLevel[0], Map[conv[Line,#]&, q]};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["interpolation of divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[interpolatedi];\n",
    FontWeight->"Plain"],
  StyleBox["interpolatedi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_, info_, v_] :=\n   (    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["info2 is same as info but with names->codes and phases ordered  ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    info1 = Fold[(k = #2; pn = phase[[k]];\n    \
              pp = Position[#1,_?((#==pn)&)];\n                  MapAt[k&, \
#1, pp])&, info, Range[Length[phase]]];\n    info2 = Map[{#[[1]],Map[Sort[#, \
(#1[[1]]<#2[[1]])&]&, Drop[#,1]]}&,info1];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["vv is vector of T (or P)  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t   vv = Map[#[[1,vposi]]&, info];\n    \n    \
(* ",
    FontWeight->"Plain"],
  StyleBox["kki is position in vv if there is exact match with v  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    kki = Flatten[Position[vv, _?((Abs[v - \
#]<diffv)&)]]; \n    If[Length[kki] == 1,  \n        \n       (* ",
    FontWeight->"Plain"],
  StyleBox["returns divariant coordinates from info2 if there is an exact \
match ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       info2[[kki[[1]],2]],\n        \n       \
(* ",
    FontWeight->"Plain"],
  StyleBox["no exact match; {k1,k2} positions in vv bracket v ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       k2 = Flatten[Position[vv, _?((v < \
#)&)]][[1]]; k1 = k2 - 1;\n       \n       If[k1 == 0, \n           \n        \
  (* ",
    FontWeight->"Plain"],
  StyleBox["if v cannot be bracketed, empty list returned ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n          {},\n           \n          (* ",
    FontWeight->"Plain"],
  StyleBox["bracketed; vprop is prop position in bracket ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t         vprop = (v - vv[[k1]])/(vv[[k2]] - \
vv[[k1]]);\n\t\n          (* ",
    FontWeight->"Plain"],
  StyleBox["dic are divariants in {k1,k2} in common ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         di1 = Map[Transpose[#][[1]]&, \
Drop[info2[[k1]],1][[1]]];\n\t         di2 = Map[Transpose[#][[1]]&, \
Drop[info2[[k2]],1][[1]]];\n\t         dic = Intersection[di1,di2];\n\t\n     \
     (* ",
    FontWeight->"Plain"],
  StyleBox["interpolating the divariants in common ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         Map[(idik = #;\n            \t  pk1 = \
Position[di1, _?((#==idik)&)][[1,1]];\n      \t        pk2 = Position[di2, \
_?((#==idik)&)][[1,1]];\n      \t        q1 = info2[[k1,2,pk1]]; q2 = \
info2[[k2,2,pk2]];\n               q1 + vprop (q2 - q1) )&, dic]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["drawing trivariants - no curvature assumed", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tri];\n",
    FontWeight->"Plain"],
  StyleBox["tri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (\t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["using divariant info in allinfo, ic is all phases involved ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n      af = Fold[({equiv1,equiv2} = #2;\n          \
        MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["looks at the phases pairwise, with a being the divariant \
coordinates ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];                       \
        \n      a = Map[({k1,k2} = #; \n                 plc = \
Flatten[Position[Map[Length,\n                               \
Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\n                 cc = \
Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n                           \
              Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\n                 occ \
= Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n                 cocc = \
Map[Map[conv,#]&,occ];\n                 \
Map[Join[cocc[[#[[1]]]],Reverse[cocc[[#[[2]]]]],{cocc[[#[[1]],1]]}]&, \n      \
               Partition[Range[Length[plc]],2]] )&, Map[ic[[#]]&,gr]];        \
             \n     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["drawing the trivariant info in a ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      {Hue[0,0.15,1], \n       \
Map[Map[Polygon[#]&,#]&, a], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, a], \n       GrayLevel[0]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setting up trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setuptri];\n",
    FontWeight->"Plain"],
  StyleBox["setuptri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["ic is list of phases involved in trivariants ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      triinfo1 = Fold[(k = #2; pn = phasef[[k]];\n   \
                    pp = Position[#1,_?((#==pn)&)];\n                       \
MapAt[k&, #1, pp])&, triinfo, Range[Length[phase]]];\n      triinfo2 = \
Map[{#[[1]],Map[Sort[#, (#1[[1]]<#2[[1]])&]&, \n                     \
Drop[Drop[#,-1],1]][[1]]}&,triinfo1];\n      pr = \
Map[{{#[[1,1]],#[[2,1]]},Map[conv,#]}&,Map[Drop[#,1][[1]]&,triinfo2]];\n      \
vr = Map[#[[1,vposi]]&,triinfo2];      \n      c = Map[#[[1]]&,pr];  ic = \
Intersection[Flatten[c]];\n      \n      (* ",
    FontWeight->"Plain"],
  StyleBox["calculates all the interpolation functions for the trivariant \
boundaries ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];         \n      \
Map[({k1,k2} = #; \n           pp = Flatten[Position[c, _?((#=={k1,k2})&)]];\n\
           pr1 = Map[Drop[#,1][[1]]&,pr[[pp]]];\n           vr1 = vr[[pp]];\n \
          ivv = Intersection[vr1];\n           {#, Map[(ivvk = #;\n           \
         pr2 = pr1[[Flatten[Position[vr1,_?((#==ivvk)&)]]]];\n                \
    {ivvk,\n                     \
Interpolation[Map[Reverse,Transpose[pr2][[1]]],\n                             \
      InterpolationOrder->2], \n                     \
Interpolation[Map[Reverse,Transpose[pr2][[2]]],\n                             \
      InterpolationOrder->2]})&,ivv]})&, \n           Map[ic[[#]]&,gr]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["accessing trivariant info", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[getf];\t\t\t\t(* 1,2 are different limbs; a,b are \
interpolants *)\n",
    FontWeight->"Plain"],
  StyleBox["getf",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{k1_,k2_}, vk_] :=\n      (pp = \
Flatten[Position[Map[#[[1]]&,iff], _?((#=={k1,k2})&)]];\n       If[Length[pp] \
== 0, {0,{}}, \n          pp1 = pp[[1]];   \n          ip = iff[[pp1,2]];\n   \
       If[ip === {}, {0,{}}, \n             vv = Transpose[ip][[1]];\n        \
     kkm = Flatten[Position[vv, _?((Abs[vk-#]<0.01)&)]]; \n             \n    \
         If[Length[kkm] == 1,  \n                {ff1,ff2} = \
ip[[kkm[[1]],{2,3}]]; \n                {1,{ {ff1, Apply[List,ff1][[1]]}, \
{ff2, Apply[List,ff2][[1]]} }},\n             \n                kk0 = \
Flatten[Position[vv, _?((vk < #)&)]]; \n                \n                \
If[kk0 == {} || kk0[[1]] == 1, {0,{}},\n                   kk2 = kk0[[1]];  \
kk1 = kk2 - 1;\n                   prop = (vk - vv[[kk1]])/(vv[[kk2]] - \
vv[[kk1]]);\n                   \n                   (* Print[{k1,k2} /. sub, \
{kk1,kk2}]; *)\n             \n                   ff1a = ip[[kk1,2]]; ff1b = \
ip[[kk2,2]];  \n                   {is1a,ie1a} = Apply[List,ff1a][[1]];\n     \
              {is1b,ie1b} = Apply[List,ff1b][[1]];\n                   is1 = \
If[is1a>is1b, is1a, is1b]; ie1 = If[ie1a<ie1b, ie1a, ie1b];\n             \n  \
                 ff2a = ip[[kk1,3]]; ff2b = ip[[kk2,3]];\n                   \
{is2a,ie2a} = Apply[List,ff2a][[1]];\n                   {is2b,ie2b} = \
Apply[List,ff2b][[1]];\n                   is2 = If[is2a>is2b, is2a, is2b]; \
ie2 = If[ie2a<ie2b, ie2a, ie2b];\n             \n                   {2,{ \
{{ff1a,ff1b}, {is1,ie1}}, {{ff2a,ff2b}, {is2,ie2}}, prop}}]]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["drawing proper trivariant", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["del = 0.001;\n\nClear[btri]; Clear[f1]; Clear[f2]; \n",
    FontWeight->"Plain"],
  StyleBox["btri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_]:=\n     (af = Fold[({equiv1,equiv2} = #2;\n                 \
 MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n      gr = gray[Length[ic],2];   icgr = \
Map[ic[[#]]&,gr];  z=.;    \n                      \n      atri = Array[(k = \
#;  {k1,k2} = icgr[[k]];\n                 plc = Flatten[Position[Map[Length,\
\n                           Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\
\n                 cc = Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n   \
                                      Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\
\n                 occ = Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n \
                cocc = Map[Map[conv,#]&,occ];\n                 \n            \
     {code,f} = getf[{k1,k2},vk];\n                 \n                 simple \
= code == 0; match = code == 1;\n                 \n                 \
If[simple, (* do nothing *) ,\n                    If[match,\n                \
       {{f1, {is1,ie1}},{f2, {is2,ie2}}} = f,\n                       \
{{{f1a,f1b}, {is1,ie1}}, {{f2a,f2b}, {is2,ie2}}, prop} = f]];\n               \
        \n                 If[OddQ[Length[plc]], \n                    d = \
Abs[Join[cocc,{{{0,0},{0,0}}}] - Join[{{{0,0},{0,0}}},cocc]];\n               \
     pd = Flatten[Position[Map[Apply[Plus,Flatten[#]]&,d],_?((#<0.01)&)]];\n  \
                  cocc = Drop[cocc,pd];\n                    \
If[OddQ[Length[cocc]],\n                       Print[\"no of tie lines for \
\",{k1,k2} /. sub,\" is still odd \"],\n                       (* \
Print[\"duplicate removed in \",{k1,k2} /. sub] *)   ]];\n                    \
   \n                 Map[(c1 = cocc[[#[[1]]]];\n                      c2 = \
cocc[[#[[2]]]];\n                      \n                      If[simple,  p1 \
= {{}}; p2 = {{}},\n\n                         cy12 = c2[[1,2]]; cy11 = \
c1[[1,2]]; \n                         s1 =  If[is1>cy11+del, is1, cy11+del];  \
\n                         e1 = If[ie1<cy12-del, ie1, cy12-del];\n            \
             dy1 = e1 - s1;\n                         p1 = If[dy1 <= \
2del,{{}},\n                                 kd1 = Floor[dy1/del]; dd = \
dy1/kd1;\n                                 rr1 = s1 + dd Range[0,kd1];\n      \
                           If[match,\n                                    \
Map[{f1[#],#}&, rr1],\n                                    \
Map[{(1-prop)f1a[#]+prop f1b[#],#}&, rr1]]];\n                                \
 \n                         cy22 = c2[[2,2]]; cy21 = c1[[2,2]]; \n            \
             s2 =  If[is2>cy21+del, is2, cy21+del];  \n                       \
  e2 = If[ie2<cy22-del, ie2, cy22-del];\n                         dy2 = e2 - \
s2;\n                         p2 = If[dy2 <= 2del,{{}},\n                     \
            kd2 = Floor[dy2/del]; dd = dy2/kd2;\n                             \
    rr2 = s2 + dd Range[0,kd2];\n                                 If[match,\n \
                                   Map[{f2[#],#}&, rr2],\n                    \
                Map[{(1-prop)f2a[#]+prop f2b[#],#}&, rr2]]] ];\n              \
                      \n                       Which[Dimensions[p1]=={1,0} && \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p1]=={1,0},\n                               \
Join[c1,p2,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],Reverse[p1],{c1[[1]]}],\n                             \
True,\n                               \
Join[c1,p2,Reverse[c2],Reverse[p1],{c1[[1]]}]])&, \n                     \
Partition[Range[Length[cocc]],2]])&, Length[icgr]];\n      {Hue[0,0.15,1], \n \
      Map[Map[Polygon[#]&,#]&, atri], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, atri], \n       GrayLevel[0]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["looking at the divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[show];\n",
    FontWeight->"Plain"],
  StyleBox["show",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := Print[N[allinfo /. sub,3] //ColumnForm]",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["checking data shape", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[datashape]; Clear[datacheck];\n\n",
    FontWeight->"Plain"],
  StyleBox["datashape",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := Map[Map[Dimensions,#]&,info];\n\n",
    FontWeight->"Plain"],
  StyleBox["datacheck",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_, k_] :=\n  (dc = datashape[info];\n   ldc = \
Length[Position[Map[Transpose[Drop[#,1]][[2]]&, dc], _?((#!=k)&)]];\n   \
If[TrueQ[ldc==0],\"data shape OK\",\"data shape stuffed\"])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with slider etc", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontWeight->"Plain"],
  StyleBox["fullmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
tri, \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nfullmake[___] := If[TrueQ[varyTatP],\n        \
            Print[\"T outside range (or T inc on slider not supplied)\"],\n   \
                 Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[make];\n",
    FontWeight->"Plain"],
  StyleBox["make",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   tri, \n                     tietriangle[infok],\n          \
           labelling[vstring],\n                     plotvscale[vk]}],\n      \
               AspectRatio->Automatic,\n                     \
PlotRange->plotrange]) /; vk >= vlow && vk <= vhigh;\n     \nmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
draw compatibility diagram with proper trivariants and with slider \
etc\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bfullmake];\n",
    FontWeight->"Plain"],
  StyleBox["bfullmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
btri[vk], \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nbfullmake[___] := If[TrueQ[varyTatP],\n       \
             Print[\"T outside range (or T inc on slider not supplied)\"],\n  \
                  Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bmake];\n",
    FontWeight->"Plain"],
  StyleBox["bmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   btri[vk], \n                     tietriangle[infok],\n     \
                plotvscale[vk]}],\n          AspectRatio->Automatic,\n        \
  PlotRange->plotrange]) /; vk <= vhigh;\n     \nbmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontWeight->"Plain"],
  StyleBox["partmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, plotrangep_] :=\n    (assemble[vk]; \n     Show[Graphics[ \
{background,\n                     tri,\n                     \
tietriangle[infok],\n                     labelling[vstring],\n               \
      plotvscale[vk]}],\n                    AspectRatio->Automatic, \n       \
             PlotRange->plotrangep])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setup];\n",
    FontWeight->"Plain"],
  StyleBox["setup",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_] :=\n   (vstring = s;\n    If[TrueQ[varyTatP],\n       diffv \
= 0.01;    vposi = 2; \n       vlow = info[[1,1,2]]; vhigh = info[[-1,1,2]],\n\
       diffv = 0.0001;; vposi = 1; \n       vlow = info[[1,1,1]]; vhigh = \
info[[-1,1,1]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["AFM system-specific functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
applies function f to AFM coordinates as provided by THERMOCALC,
after converting them into graphical coordinates\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[conv];\n",
    FontWeight->"Plain"],
  StyleBox["conv",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[f_,t_]:=(p = Map[(Mg = #[[4]]; Fe = #[[3]]; \n                   \
 N[ {(Mg - Fe)/Sqrt[3], -(Mg + Fe)} ] )&, t];\n              \
f[Join[p,{p[[1]]}]]);\n              \n",
    FontWeight->"Plain"],
  StyleBox["conv",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[t_]:= (Mg = t[[4]]; Fe = t[[3]]; N[ {(Mg - Fe)/Sqrt[3], -(Mg + \
Fe)} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default font sizes", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["fontsize1 = 12; fontsize = 16;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
creates AFM triangle (triangle not joined up, so no bottom line on \
triangle)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
third = 1/3;      sqrtthird = 1/Sqrt[3];     twothird = 2/3;

ll = 1.36; lla = ll sqrtthird; 
cll = 1 - ll; clla = 1 - cll;  
dd = 0.03;

{xky,yky} = {0,0}; xbot = lla + dd sqrtthird; ybot = -ll - dd;

shape = N[{{-xbot,ybot}, {0,0}, {xbot,ybot}}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{-0.80251687417358, -1.39}, {0, 0}, \
{0.80251687417358, -1.39}}\
\>", "\<\
{{-0.802517, -1.39}, {0, 0}, {0.802517, \
-1.39}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["plot range info", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
xband = 0.191; yband = 0.05;     (* for AspectRatio -> Automatic *)

xlow0 = -xbot - xband; xhigh0 = xbot + xband; 
ylow0 = ybot - yband; yhigh0 = yband;

plotrange = {{xlow0,xhigh0},{ylow0,yhigh0}};
plotrangef = plotrange;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default slider coordinates", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
y = -1.6; dy = 0.02; dy1 = 0.05;
x1 = -0.8; x2 = 0.8;
yplus = 0.032; yminus = -0.075;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["vscale", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["xsc = -0.77; ysc = -0.32; pl = 1;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["plotvscale",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v_] := Text[FontForm[N[Round[10^pl v]/10^pl],\n                  \
          {\"Helvetica\",fontsize}], {xsc,ysc},{-1,0}]",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws labels", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] :=\n    ({Text[FontForm[p,{\"Helvetica\",fontsize}], \
{-0.7,-0.21}],\n     Text[FontForm[\"AFM\",{\"Times-Bold\",18}], \
{-0.7,-0.1}],\n     Text[FontForm[\"als\",{\"Helvetica\",fontsize}], \
{0.1,-0.05}],\n     Text[FontForm[\"st\",{\"Helvetica\",fontsize}], \
{-0.27,-0.3}],\n     Text[FontForm[\"ctd\",{\"Helvetica\",fontsize}], \
{-0.38,-0.5}],\n     Text[FontForm[\"g\",{\"Helvetica\",fontsize}], \
{-0.52,-0.75}],\n     Text[FontForm[\"chl\",{\"Helvetica\",fontsize}], \
{0.54,-0.80}],\n     Text[FontForm[\"bi\",{\"Helvetica\",fontsize}], \
{0,-1.33}]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["assembly of data", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemble];\n",
    FontWeight->"Plain"],
  StyleBox["assemble",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[tk_] :=\n    (infok = interpolatedi[phase, info, tk];\n     \
infosubfk = Map[Map[Insert[#, 0,-1]&, #]&, interpolatedi[phasesubf, infosubf, \
tk]];\n     infosubmk = Map[Map[Insert[#, 0, 3]&, #]&, \
interpolatedi[phasesubm, infosubm, tk]];\n     allinfo = \
Join[infok,infosubfk,infosubmk]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["coordinates", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["divariants", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KFM coordinates", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phase = {\"chl\",\"bi\",\"g\",\"st\",\"ctd\",\"and\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["equivalence = {};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
info = {
{{3.000, 480.00}, 
         {{\"ctd\", 0.5000, 0.3956, 0.1044}, 
          {\"chl\", 0.2251, 0.4173, 0.3576}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 491.81}, 
         {{\"ctd\", 0.5000, 0.4084, 0.0916}, 
          {\"chl\", 0.2216, 0.4542, 0.3241}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3077, 0.0000}, 
          {\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 510.52}, 
         {{\"st\", 0.6923, 0.2955, 0.0122}, 
          {\"chl\", 0.2163, 0.5169, 0.2669}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2955, 0.0122}, 
          {\"ctd\", 0.5000, 0.4283, 0.0717}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.4283, 0.0717}, 
          {\"chl\", 0.2163, 0.5169, 0.2669}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2955, 0.0122}, 
          {\"ctd\", 0.5000, 0.4283, 0.0717}, 
          {\"chl\", 0.2163, 0.5169, 0.2669}} },

{{3.000, 511.26}, 
         {{\"st\", 0.6923, 0.2954, 0.0123}, 
          {\"chl\", 0.2161, 0.5160, 0.2679}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2959, 0.0118}, 
          {\"ctd\", 0.5000, 0.4305, 0.0695}, 
          {\"chl\", 0.2158, 0.5240, 0.2603}},

         {{\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"chl\", 0.1988, 0.8012, 0.0002}, 
          {\"bi\", -0.2206, 1.2206, 0.0000}} },

{{3.000, 516.45}, 
         {{\"st\", 0.6923, 0.2947, 0.0130}, 
          {\"chl\", 0.2146, 0.5105, 0.2749}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2987, 0.0090}, 
          {\"ctd\", 0.5000, 0.4459, 0.0541}, 
          {\"chl\", 0.2121, 0.5750, 0.2129}},

         {{\"ctd\", 0.5000, 0.4888, 0.0112}, 
          {\"chl\", 0.2017, 0.7462, 0.0521}, 
          {\"bi\", -0.2174, 1.1487, 0.0687}},

         {{\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"g\", 0.2500, 0.7500, 0.0000}, 
          {\"bi\", -0.2171, 1.2171, 0.0000}} },

{{3.000, 523.98}, 
         {{\"st\", 0.6923, 0.2937, 0.0140}, 
          {\"chl\", 0.2126, 0.5024, 0.2850}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3022, 0.0054}, 
          {\"ctd\", 0.5000, 0.4668, 0.0332}, 
          {\"chl\", 0.2069, 0.6531, 0.1400}},

         {{\"st\", 0.6923, 0.3077, 0.0000}, 
          {\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"g\", 0.2500, 0.7500, 0.0000}},

         {{\"ctd\", 0.5000, 0.4876, 0.0124}, 
          {\"g\", 0.2500, 0.7426, 0.0074}, 
          {\"bi\", -0.2123, 1.1379, 0.0744}},

         {{\"ctd\", 0.5000, 0.4716, 0.0284}, 
          {\"chl\", 0.2058, 0.6722, 0.1220}, 
          {\"bi\", -0.2124, 1.0498, 0.1626}} },

{{3.000, 524.91}, 
         {{\"st\", 0.6923, 0.3027, 0.0050}, 
          {\"chl\", 0.2063, 0.6631, 0.1306}, 
          {\"bi\", -0.2117, 1.0373, 0.1744}},

         {{\"st\", 0.6923, 0.3027, 0.0050}, 
          {\"ctd\", 0.5000, 0.4693, 0.0307}, 
          {\"bi\", -0.2117, 1.0373, 0.1744}},

         {{\"ctd\", 0.5000, 0.4693, 0.0307}, 
          {\"chl\", 0.2063, 0.6631, 0.1306}, 
          {\"bi\", -0.2117, 1.0373, 0.1744}},

         {{\"st\", 0.6923, 0.3027, 0.0050}, 
          {\"ctd\", 0.5000, 0.4693, 0.0307}, 
          {\"chl\", 0.2063, 0.6631, 0.1306}},

         {{\"st\", 0.6923, 0.2936, 0.0141}, 
          {\"chl\", 0.2123, 0.5015, 0.2862}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3066, 0.0011}, 
          {\"ctd\", 0.5000, 0.4930, 0.0070}, 
          {\"g\", 0.2500, 0.7458, 0.0042}},

         {{\"ctd\", 0.5000, 0.4861, 0.0139}, 
          {\"g\", 0.2500, 0.7416, 0.0084}, 
          {\"bi\", -0.2117, 1.1285, 0.0832}} },

{{3.000, 526.12}, 
         {{\"st\", 0.6923, 0.3051, 0.0026}, 
          {\"g\", 0.2500, 0.7404, 0.0096}, 
          {\"bi\", -0.2109, 1.1164, 0.0944}},

         {{\"st\", 0.6923, 0.3051, 0.0026}, 
          {\"ctd\", 0.5000, 0.4840, 0.0160}, 
          {\"bi\", -0.2109, 1.1164, 0.0944}},

         {{\"ctd\", 0.5000, 0.4840, 0.0160}, 
          {\"g\", 0.2500, 0.7404, 0.0096}, 
          {\"bi\", -0.2109, 1.1164, 0.0944}},

         {{\"st\", 0.6923, 0.3051, 0.0026}, 
          {\"ctd\", 0.5000, 0.4840, 0.0160}, 
          {\"g\", 0.2500, 0.7404, 0.0096}},

         {{\"st\", 0.6923, 0.2934, 0.0143}, 
          {\"chl\", 0.2120, 0.5002, 0.2878}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3016, 0.0061}, 
          {\"chl\", 0.2067, 0.6400, 0.1532}, 
          {\"bi\", -0.2114, 1.0059, 0.2055}} },

{{3.000, 526.96}, 
         {{\"st\", 0.6923, 0.3051, 0.0026}, 
          {\"g\", 0.2500, 0.7402, 0.0098}, 
          {\"bi\", -0.2106, 1.1150, 0.0956}},

         {{\"st\", 0.6923, 0.3008, 0.0069}, 
          {\"chl\", 0.2070, 0.6242, 0.1688}, 
          {\"bi\", -0.2112, 0.9840, 0.2272}},

         {{\"st\", 0.6923, 0.2933, 0.0144}, 
          {\"chl\", 0.2117, 0.4994, 0.2889}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.0000, 0.5000}, 
          {\"chl\", 0.2118, 0.0000, 0.7882}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 534.75}, 
         {{\"st\", 0.6923, 0.2922, 0.0155}, 
          {\"bi\", -0.2086, 0.7966, 0.4120}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2922, 0.0155}, 
          {\"chl\", 0.2096, 0.4916, 0.2988}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"chl\", 0.2096, 0.4916, 0.2988}, 
          {\"bi\", -0.2086, 0.7966, 0.4120}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2922, 0.0155}, 
          {\"chl\", 0.2096, 0.4916, 0.2988}, 
          {\"bi\", -0.2086, 0.7966, 0.4120}},

         {{\"st\", 0.6923, 0.3047, 0.0030}, 
          {\"g\", 0.2500, 0.7388, 0.0112}, 
          {\"bi\", -0.2078, 1.1019, 0.1060}},

         {{\"cd\", 0.5000, 0.1394, 0.3606}, 
          {\"chl\", 0.2097, 0.2618, 0.5285}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 537.75}, 
         {{\"cd\", 0.5000, 0.1969, 0.3031}, 
          {\"bi\", -0.2119, 0.5992, 0.6127}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.1969, 0.3031}, 
          {\"chl\", 0.2088, 0.3596, 0.4316}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"chl\", 0.2088, 0.3596, 0.4316}, 
          {\"bi\", -0.2119, 0.5992, 0.6127}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.1969, 0.3031}, 
          {\"chl\", 0.2088, 0.3596, 0.4316}, 
          {\"bi\", -0.2119, 0.5992, 0.6127}},

         {{\"st\", 0.6923, 0.3045, 0.0032}, 
          {\"g\", 0.2500, 0.7382, 0.0118}, 
          {\"bi\", -0.2068, 1.0967, 0.1101}},

         {{\"st\", 0.6923, 0.2931, 0.0146}, 
          {\"bi\", -0.2075, 0.8150, 0.3925}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 538.50}, 
         {{\"st\", 0.6923, 0.3045, 0.0032}, 
          {\"g\", 0.2500, 0.7380, 0.0120}, 
          {\"bi\", -0.2065, 1.0953, 0.1112}},

         {{\"st\", 0.6923, 0.2933, 0.0144}, 
          {\"bi\", -0.2072, 0.8195, 0.3877}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.1973, 0.3027}, 
          {\"bi\", -0.2117, 0.6003, 0.6113}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.0000, 0.5000}, 
          {\"chl\", 0.2018, 0.0000, 0.7988}, 
          {\"bi\", -0.2311, 0.0000, 1.3525}} },

{{3.000, 572.28}, 
         {{\"st\", 0.6923, 0.3026, 0.0051}, 
          {\"bi\", -0.1950, 1.0426, 0.1525}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3026, 0.0051}, 
          {\"g\", 0.2500, 0.7313, 0.0187}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"g\", 0.2500, 0.7313, 0.0187}, 
          {\"bi\", -0.1950, 1.0426, 0.1525}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3026, 0.0051}, 
          {\"g\", 0.2500, 0.7313, 0.0187}, 
          {\"bi\", -0.1950, 1.0426, 0.1525}},

         {{\"cd\", 0.5000, 0.2367, 0.2633}, 
          {\"bi\", -0.2020, 0.6923, 0.5097}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 573.79}, 
         {{\"g\", 0.2500, 0.7314, 0.0186}, 
          {\"bi\", -0.1947, 1.0433, 0.1514}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.2383, 0.2617}, 
          {\"bi\", -0.2015, 0.6959, 0.5057}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.3077, 0.0000}, 
          {\"g\", 0.2500, 0.7500, 0.0000}, 
          {\"and\", 1.0000, 0, 0}} },

{{3.000, 580.00}, 
         {{\"g\", 0.2500, 0.7317, 0.0183}, 
          {\"bi\", -0.1932, 1.0465, 0.1468}, 
          {\"and\", 1.0000, 0, 0}},

         {{\"cd\", 0.5000, 0.2450, 0.2550}, 
          {\"bi\", -0.1999, 0.7108, 0.4890}, 
          {\"and\", 1.0000, 0, 0}} }};         \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KF coordinates (zero column to be added)-LEFT", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phasesubf = {\"chl\",\"bi\",\"alm\",\"fst\",\"fctd\",\"and\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
infosubf = {
{{3.000, 480.00}, 
         {{\"chl\", 0.1737, 0.8263}, 
          {\"bi\", -0.2476, 1.2476}},

         {{\"chl\", 0.1994, 0.8006}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 491.81}, 
         {{\"fctd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"chl\", 0.1833, 0.8167}, 
          {\"bi\", -0.2385, 1.2385}},

         {{\"chl\", 0.1991, 0.8009}, 
          {\"fctd\", 0.5000, 0.5000}} },

{{3.000, 510.52}, 
         {{\"chl\", 0.1982, 0.8018}, 
          {\"bi\", -0.2213, 1.2213}},

         {{\"chl\", 0.1988, 0.8012}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 511.23}, 
         {{\"chl\", 0.1988, 0.8012}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"bi\", -0.2206, 1.2206}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"chl\", 0.1988, 0.8012}, 
          {\"bi\", -0.2206, 1.2206}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 516.50}, 
         {{\"bi\", -0.2171, 1.2171}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"bi\", -0.2171, 1.2171}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"bi\", -0.2171, 1.2171}, 
          {\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 523.99}, 
         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"bi\", -0.2149, 1.2149}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 524.91}, 
         {{\"bi\", -0.2146, 1.2146}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 526.12}, 
         {{\"bi\", -0.2142, 1.2142}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 526.96}, 
         {{\"bi\", -0.2140, 1.2140}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 534.67}, 
         {{\"bi\", -0.2118, 1.2118}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 537.75}, 
         {{\"bi\", -0.2109, 1.2109}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 538.50}, 
         {{\"bi\", -0.2107, 1.2107}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 572.28}, 
         {{\"bi\", -0.2013, 1.2013}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 573.79}, 
         {{\"fst\", 0.6923, 0.3077}, 
          {\"and\", 1.0000, 0}},

         {{\"alm\", 0.2500, 0.7500}, 
          {\"and\", 1.0000, 0}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"bi\", -0.2009, 1.2009}, 
          {\"alm\", 0.2500, 0.7500}} },

{{3.000, 580.00}, 
         {{\"bi\", -0.1992, 1.1992}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"alm\", 0.2500, 0.7500}, 
          {\"and\", 1.0000, 0}} }};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KM coordinates (zero column to be added) - RIGHT", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phasesubm = {\"chl\",\"bi\",\"py\",\"mst\",\"mctd\",\"and\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
infosubm ={
{{3.000, 480.00}, 
         {{\"bi\", -0.3722, 1.3722}, 
          {\"chl\", 0.1580, 0.8420}},

         {{\"chl\", 0.2251, 0.7749}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 491.81}, 
         {{\"bi\", -0.3700, 1.3700}, 
          {\"chl\", 0.1670, 0.8330}},

         {{\"chl\", 0.2216, 0.7784}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 510.52}, 
         {{\"bi\", -0.3644, 1.3644}, 
          {\"chl\", 0.1810, 0.8190}},

         {{\"chl\", 0.2163, 0.7837}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 511.26}, 
         {{\"bi\", -0.3641, 1.3641}, 
          {\"chl\", 0.1816, 0.8184}},

         {{\"chl\", 0.2161, 0.7839}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 516.45}, 
         {{\"bi\", -0.3622, 1.3622}, 
          {\"chl\", 0.1853, 0.8147}},

         {{\"chl\", 0.2146, 0.7854}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 523.98}, 
         {{\"bi\", -0.3591, 1.3591}, 
          {\"chl\", 0.1907, 0.8093}},

         {{\"chl\", 0.2126, 0.7874}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 524.91}, 
         {{\"bi\", -0.3587, 1.3587}, 
          {\"chl\", 0.1914, 0.8086}},

         {{\"chl\", 0.2123, 0.7877}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 526.12}, 
         {{\"bi\", -0.3582, 1.3582}, 
          {\"chl\", 0.1923, 0.8077}},

         {{\"chl\", 0.2120, 0.7880}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 526.96}, 
         {{\"chl\", 0.2118, 0.7882}, 
          {\"and\", 1.0000, 0}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}},

         {{\"chl\", 0.2118, 0.7882}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"bi\", -0.3578, 1.3578}, 
          {\"chl\", 0.1929, 0.8071}} },

{{3.000, 534.67}, 
         {{\"bi\", -0.3543, 1.3543}, 
          {\"chl\", 0.1983, 0.8017}},

         {{\"chl\", 0.2046, 0.7954}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 537.75}, 
         {{\"bi\", -0.3528, 1.3528}, 
          {\"chl\", 0.2008, 0.7992}},

         {{\"chl\", 0.2018, 0.7982}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 538.50}, 
         {{\"bi\", -0.3525, 1.3525}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"chl\", 0.2012, 0.7988}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"bi\", -0.3525, 1.3525}, 
          {\"chl\", 0.2012, 0.7988}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 572.28}, 
         {{\"bi\", -0.3482, 1.3482}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 573.79}, 
         {{\"bi\", -0.3480, 1.3480}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} },

{{3.000, 580.00}, 
         {{\"bi\", -0.3472, 1.3472}, 
          {\"cd\", 0.5000, 0.5000}},

         {{\"cd\", 0.5000, 0.5000}, 
          {\"and\", 1.0000, 0}} }};                   \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["setting up", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setup[\"3.0 kbar\"];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["doing it", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["make[524.8];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74986 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.503263 0.724698 0.503263 [
[ 0 0 0 0 ]
[ 1 .74986 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .74986 L
0 .74986 L
closepath
clip
newpath
p
p
1 .55 .55 r
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
F
0 g
.004 w
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
s
P
p
1 .85 .85 r
p
p
.73497 .31772 m
.8948 .04089 L
.24844 .11485 L
.34467 .32523 L
.73497 .31772 L
F
P
p
P
p
.14708 .11342 m
.28208 .34725 L
.28689 .34725 L
.19565 .11486 L
.14708 .11342 L
F
P
p
.34594 .32529 m
.41353 .56985 L
.41878 .56984 L
.43737 .3283 L
.34594 .32529 L
F
P
p
P
p
.28423 .34725 m
.41116 .56984 L
.4106 .56984 L
.28208 .34725 L
.28423 .34725 L
F
P
p
.34467 .32523 m
.3724 .47307 L
.37273 .47307 L
.34594 .32529 L
.34467 .32523 L
F
P
p
.24844 .11485 m
.3724 .47307 L
.3627 .47307 L
.19565 .11486 L
.24844 .11485 L
F
P
p
.28689 .34725 m
.3627 .47307 L
.35831 .47307 L
.28423 .34725 L
.28689 .34725 L
F
P
p
.41353 .56985 m
.37273 .47307 L
.35831 .47307 L
.41116 .56984 L
.41353 .56985 L
F
P
p
.72886 .3283 m
.5 .7247 L
.5 .7247 L
.43737 .3283 L
.72886 .3283 L
F
P
p
P
p
P
p
.41878 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.41878 .56984 L
F
P
p
P
P
0 g
p
p
.004 w
.73497 .31772 m
.8948 .04089 L
.24844 .11485 L
.34467 .32523 L
.73497 .31772 L
s
P
p
P
p
.004 w
.14708 .11342 m
.28208 .34725 L
.28689 .34725 L
.19565 .11486 L
.14708 .11342 L
s
P
p
.004 w
.34594 .32529 m
.41353 .56985 L
.41878 .56984 L
.43737 .3283 L
.34594 .32529 L
s
P
p
P
p
.004 w
.28423 .34725 m
.41116 .56984 L
.4106 .56984 L
.28208 .34725 L
.28423 .34725 L
s
P
p
.004 w
.34467 .32523 m
.3724 .47307 L
.37273 .47307 L
.34594 .32529 L
.34467 .32523 L
s
P
p
.004 w
.24844 .11485 m
.3724 .47307 L
.3627 .47307 L
.19565 .11486 L
.24844 .11485 L
s
P
p
.004 w
.28689 .34725 m
.3627 .47307 L
.35831 .47307 L
.28423 .34725 L
.28689 .34725 L
s
P
p
.004 w
.41353 .56985 m
.37273 .47307 L
.35831 .47307 L
.41116 .56984 L
.41353 .56985 L
s
P
p
.004 w
.72886 .3283 m
.5 .7247 L
.5 .7247 L
.43737 .3283 L
.72886 .3283 L
s
P
p
P
p
P
p
.004 w
.41878 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.41878 .56984 L
s
P
p
P
P
P
p
1 g
p
.34467 .32523 m
.24844 .11485 L
.3724 .47307 L
.34467 .32523 L
F
.34594 .32529 m
.41353 .56985 L
.37273 .47307 L
.34594 .32529 L
F
.43737 .3283 m
.41878 .56984 L
.5 .7247 L
.43737 .3283 L
F
.19565 .11486 m
.28689 .34725 L
.3627 .47307 L
.19565 .11486 L
F
.28423 .34725 m
.41116 .56984 L
.35831 .47307 L
.28423 .34725 L
F
P
0 g
p
.004 w
.34467 .32523 m
.24844 .11485 L
.3724 .47307 L
.34467 .32523 L
s
.34594 .32529 m
.41353 .56985 L
.37273 .47307 L
.34594 .32529 L
s
.43737 .3283 m
.41878 .56984 L
.5 .7247 L
.43737 .3283 L
s
.19565 .11486 m
.28689 .34725 L
.3627 .47307 L
.19565 .11486 L
s
.28423 .34725 m
.41116 .56984 L
.35831 .47307 L
.28423 .34725 L
s
P
P
p
p
/Helvetica findfont 16 scalefont setfont
[(3.0 kbar)] .14772 .61901 0 0 Mshowa
P
p
/Times-Bold findfont 18 scalefont setfont
[(AFM)] .14772 .67437 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(als)] .55033 .69954 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(st)] .36412 .57372 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(ctd)] .30876 .47307 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(g)] .2383 .34725 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(chl)] .77176 .32209 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(bi)] .5 .05536 0 0 Mshowa
P
P
p
/Helvetica findfont 16 scalefont setfont
[(524.8)] .11249 .56365 -1 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 299},
  ImageMargins->{{35, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001:a000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo000VOol00`00Oomoo`3oOom0Ool00`00Oomoo`0UOol002Ioo`03001n<Gha0?mn<D1n<@03
001oogoo02Eoo`009goo00<007haOS40ogha?Wha00<007ooOol09Woo000WOol00`00OS5n<@3oOS4n
OS400`00Oomoo`0VOol002Qoo`03001n<Gha0?mn<Can<@03001oogoo02Moo`00:Goo00<007haOS40
ogha>Wha00<007ooOol0:7oo000YOol00`00OS5n<@3oOS4jOS400`00Oomoo`0XOol002Yoo`03001n
<Gha0?mn<CAn<@D002]oo`00:Woo00<007haOS40ogha:gha2@0017mk00<007ooOol0:Goo000[Ool0
0`00OS5n<@2DOS400`00BDX88@0200001DU:OS5n<Gha0000PWha2@0037mk00<007ooOol0:Woo000/
Ool00`00OS5n<@2COS4200001EV<OS59BP00BDX00Wha00<007haOS40Mgha2@005Gmk00<007ooOol0
:Woo000/Ool00`00OS5n<@2COS400`00BDYn<@02OS401DU:001n<Gha0000L7ha2@007Gmk00<007oo
Ool0:goo000]Ool00`00OS5n<@2BOS400`00LNmn<@03OS401000OS5n<@00Igha2@009Gmk00<007oo
Ool0;7oo000]Ool00`00OS5n<@2BOS400`00OS5n<@03OS401000OS5n<@00GWha2@00;Wmk00<007oo
Ool0;7oo000^Ool00`00OS5n<@2AOS400`00OS5n<@03OS401000OS5n<@00EWha2000=Wmk00<007oo
Ool0;Goo000^Ool00`00OS5n<@2AOS400`00DF]n<@02OS401DU:001n<Gha0000CGha2@00?Wmk00<0
07ooOol0;Goo000_Ool00`00OS5n<@2@OS4200001EV<OS59BP00BDX00Wha00<007haOS40@Wha2@00
AWmk00<007ooOol0;Woo000`Ool00`00OS5n<@2?OS400`00@BT88@0200001DU:OS5n<Gha0000>gha
2@00CWmk00<007ooOol0;goo000`Ool00`00OS5n<@2?OS400`00OS5n<@0iOS49001GOg/00`00Oomo
o`0_Ool0035oo`03001n<Gha08in<@03001n<Gha031n<@T005moN`03001oogoo031oo`00<Goo00<0
07haOS40SWha00<007haOS401Wha00<007haOS407Wha2@00J7mk00<007ooOol0<7oo000bOol00`00
OS5n<@2^OS49001`Og/00`00Oomoo`0aOol0039oo`03001n<Gha0:In<@P007UoN`03001oogoo035o
o`00<goo00<007haOS40W7ha2@00P7mk00<007ooOol0<Woo000dOol00`00OS5n<@2BOS490028Og/0
0`00Oomoo`0cOol003Aoo`03001n<Gha08Un<@T0095oN`03001oogoo03=oo`00=Goo00<007haOS40
Ogha2@00VGmk00<007ooOol0=7oo000eOol00`00OS5n<@1fOS49002ROg/00`00Oomoo`0dOol003Io
o`03001n<Gha06an<@T00:YoN`03001oogoo03Eoo`00=goo00<007haOS40Hgha2000/Wmk00<007oo
Ool0=Woo000gOol00`00OS5n<@1JOS49002jOg/00`00Oomoo`0fOol003Qoo`03001n<Gha051n<@T0
0<9oN`03001oogoo03Moo`00>7oo00<007haOS40Agha2@00bgmk00<007ooOol0=goo000iOol00`00
OS5n<@0mOS49003COg/00`00Oomoo`0hOol003Uoo`03001n<Gha03An<@T00=aoN`03001oogoo03Qo
o`00>Woo00<007haOS40:Wha2@00i7mk00<007ooOol0>Goo000kOol/003/Og/00`00Oomoo`0jOol0
03]oo`03001oNgmk011oN`03001oNgmk019oN`03001oNgmk0>eoN`03001oogoo03Yoo`00?7oo00<0
07mkOg/047mk00<007mkOg/04Wmk00<007mkOg/0jgmk00<007ooOol0>goo000lOol00`00Og]oN`0@
Og/00`00Og]oN`0BOg/00`00Og]oN`3[Og/00`00Oomoo`0kOol003eoo`03001oNgmk00moN`8001=o
N`800>]oN`03001oogoo03aoo`00?Goo0P004Gmk00<007mkOg/04Wmk00<007mkOg/0jGmk00<007oo
Ool0?7oo000nOol00`00Og]oN`0?Og/2000COg/00`00Og]oN`3XOg/00`00Oomoo`0mOol003moo`03
001oNgmk00moN`03001oNgmk015oN`800>QoN`03001oogoo03ioo`00?goo00<007mkOg/03gmk00<0
07mkOg/04Wmk00<007mkOg/0iWmk00<007ooOol0?Woo0010Ool00`00Og]oN`0>Og/2000COg/2003V
Og/00`00Oomoo`0oOol0041oo`03001oNgmk00moN`03001oNgmk015oN`800>IoN`03001oogoo03mo
o`00@Goo00<007mkOg/03Wmk0P004gmk0P00i7mk00<007ooOol0@7oo0012Ool00`00Og]oN`0>Og/0
0`00Og]oN`0AOg/2003SOg/00`00Oomoo`11Ool0049oo`03001oNgmk00ioN`80019oN`03001oo`00
0>9oN`03001oogoo045oo`00@goo00<007mkOg/03Gmk0P004gmk0P00hGmk00<007ooOol0@Woo0013
Ool00`00Og]oN`0>Og/2000BOg/00`00Ool0003POg/00`00Oomoo`12Ool004Aoo`03001oNgmk00eo
N`80019oN`03001oo`000=moN`03001oogoo04=oo`00A7oo0P003Wmk00<007oo00004Wmk0P00ggmk
00<007ooOol0@goo0015Ool00`00Og]oN`0=Og/2000BOg/00`00Ool0003MOg/00`00Oomoo`14Ool0
04Ioo`03001oNgmk00aoN`03001oo`00015oN`03001oo`000=aoN`03001oogoo04Eoo`00AWoo00<0
07mkOg/03Gmk0P004Wmk00<007oo0000fgmk00<007ooOol0AGoo0017Ool00`00Og]oN`0<Og/00`00
Ool0000AOg/00`00Ool0003JOg/00`00Oomoo`16Ool004Moo`03001oNgmk00aoN`03001oo`00015o
N`04001oogoo003IOg/00`00Oomoo`16Ool004Qoo`03001oNgmk00aoN`80019oN`03001oo`000=Qo
N`03001oogoo04Moo`00B7oo0P003Gmk00<007oo00004Gmk00@007ooOol00=IoN`8004Uoo`00BGoo
00<007mkOg/037mk0P004Gmk00@007ooOol00=IoN`03001oogoo04Qoo`00BWoo00<007mkOg/02gmk
00<007oo00004Gmk00@007ooOol00=AoN`03001oogoo04Uoo`00BWoo00<007mkOg/02gmk00<007oo
00004Gmk00@007ooOol00=AoN`03001oogoo04Uoo`00Bgoo00<007mkOg/02gmk00<007oo000047mk
00@007ooOol00==oN`03001oogoo04Yoo`00Bgoo00<007mkOg/02gmk00<007oo00004Gmk00@007oo
Ool00=9oN`03001oogoo04Yoo`00C7oo00<007mkOg/02gmk00<007oo000047mk00@007ooOol00=5o
N`03001oogoo04]oo`00CGoo00<007mkOg/02Wmk00<007oo00004Gmk00@007ooOol00<moN`03001o
ogoo04aoo`00CGoo00<007mkOg/02Wmk00@007ooOol0011oN`04001oogoo003?Og/00`00Oomoo`1<
Ool004ioo`03001oNgmk00YoN`03001oo`00011oN`05001oogooOol0003=Og/00`00Oomoo`1=Ool0
04ioo`03001oNgmk00YoN`04001oogoo000@Og/01000Oomoo`00cGmk00<007ooOol0CGoo001?Ool0
0`00Og]oN`0:Og/00`00Ool0000@Og/01@00Oomoogoo0000bgmk00<007ooOol0CWoo001?Ool00`00
Og]oN`0:Og/01000Oomoo`003gmk00D007ooOomoo`000<YoN`80051oo`00D7oo00<007mkOg/02Gmk
00@007ooOol0011oN`05001oogooOol00039Og/00`00Oomoo`1?Ool0055oo`03001oNgmk00UoN`03
001oo`00011oN`05001oogooOol00038Og/00`00Oomoo`1@Ool0055oo`03001oNgmk00UoN`04001o
ogoo000?Og/01@00Oomoogoo0000b7mk00<007ooOol0D7oo001BOol00`00Og]oN`08Og/01000Oomo
o`0047mk00D007ooOomoo`000<IoN`03001oogoo055oo`00DWoo00<007mkOg/02Gmk00@007ooOol0
00moN`05001oogooOol00036Og/00`00Oomoo`1AOol005=oo`03001oNgmk00QoN`04001oogoo000?
Og/00`00Oomoo`02Ool00`00Og]oN`32Og/00`00Oomoo`1BOol005=oo`03001oNgmk00UoN`04001o
ogoo000?Og/01@00Oomoogoo0000`gmk0P00E7oo001DOol00`00Og]oN`08Og/01000Oomoo`003gmk
00<007ooOol00Woo00<007mkOg/0`7mk00<007ooOol0Dgoo001EOol00`00Og]oN`07Og/01@00Oomo
ogoo00003Wmk00<007ooOol00Woo00<007mkOg/0_gmk00<007ooOol0E7oo001EOol00`00Og]oN`08
Og/01000Oomoo`003gmk00<007ooOol00Woo00<007mkOg/0_Wmk00<007ooOol0E7oo001FOol00`00
Og]oN`07Og/01@00Oomoogoo00003Wmk00<007ooOol00Woo00<007mkOg/0_Gmk00<007ooOol0EGoo
001FOol00`00Og]oN`08Og/01000Oomoo`003Wmk00<007ooOol00Woo00<007mkOg/0_7mk0P00Egoo
001GOol00`00Og]oN`07Og/01@00Oomoogoo00003Wmk00<007ooOol00Woo00<007mkOg/0^gmk00<0
07ooOol0EWoo001HOol00`00Og]oN`06Og/01@00Oomoogoo00003Wmk00<007ooOol00Woo00<007mk
Og/0^Wmk00<007ooOol0Egoo001HOol00`00Og]oN`07Og/01000Oomoo`003Wmk00<007ooOol00goo
00<007mkOg/0^Gmk00<007ooOol0Egoo001IOol00`00Og]oN`06Og/01@00Oomoogoo00003Wmk00<0
07ooOol00Woo00<007mkOg/0^7mk00<007ooOol0F7oo001IOol00`00Og]oN`07Og/01000Oomoo`00
3Wmk00<007ooOol00goo00<007mkOg/0]gmk00<007ooOol0F7oo001JOol00`00Og]oN`06Og/01@00
Oomoogoo00003Gmk00<007ooOol00goo00<007mkOg/0]Wmk00<007ooOol0FGoo001JOol00`00Og]o
N`06Og/01@00Oomoogoo00003Wmk00<007ooOol00goo00<007mkOg/0]7mk0P00Fgoo001KOol00`00
Og]oN`06Og/01@00Oomoogoo00003Gmk00<007ooOol00goo00<007mkOg/0]7mk00<007ooOol0FWoo
001LOol00`00Og]oN`05Og/01@00Oomoogoo00003Gmk00<007ooOol017oo00<007mkOg/0/Wmk00<0
07ooOol0Fgoo001LOol00`00Og]oN`06Og/01@00Oomoogoo00003Gmk00<007ooOol00goo00<007mk
Og/0/Wmk00<007ooOol0Fgoo001MOol00`00Og]oN`05Og/01@00Oomoogoo00003Gmk00<007ooOol0
0goo00<007mkOg/0/Gmk00<007ooOol0G7oo001MOol00`00Og]oN`05Og/00`00Oomoo`02Ool00`00
Og]oN`0;Og/00`00Oomoo`03Ool00`00Og]oN`2`Og/00`00Oomoo`1LOol005ioo`03001oNgmk00Eo
N`05001oogooOol0000=Og/00`00Oomoo`03Ool00`00Og]oN`2_Og/00`00Oomoo`1MOol005ioo`03
001oNgmk00EoN`03001oogoo009oo`03001oNgmk00YoN`03001oogoo00Aoo`03001oNgmk0:eoN`80
05moo`00Ggoo00<007mkOg/017mk00<007ooOol00Woo00<007mkOg/02gmk00<007ooOol00goo00<0
07mkOg/0[Gmk00<007ooOol0GWoo001POol00`00Og]oN`04Og/00`00Oomoo`02Ool00`00Og]oN`0:
Og/00`00Oomoo`04Ool00`00Og]oN`2[Og/00`00Oomoo`1OOol0061oo`03001oNgmk00AoN`03001o
ogoo009oo`03001oNgmk00YoN`03001oogoo00Aoo`03001oNgmk0:]oN`03001oogoo05moo`00HGoo
00<007mkOg/017mk00D007ooOomoo`0000eoN`03001oogoo00Aoo`03001oNgmk0:UoN`03001oogoo
061oo`00HGoo00<007mkOg/017mk00<007ooOol00Woo00<007mkOg/02Wmk00<007ooOol017oo00<0
07mkOg/0Z7mk0P00HWoo001ROol00`00Og]oN`03Og/00`00Oomoo`02Ool00`00Og]oN`0:Og/00`00
Oomoo`05Ool00`00Og]oN`2WOg/00`00Oomoo`1QOol0069oo`03001oNgmk00AoN`03001oogoo009o
o`03001oNgmk00YoN`03001oogoo00Aoo`03001oNgmk0:IoN`03001oogoo069oo`00Hgoo00<007mk
Og/00gmk00<007ooOol00Woo00<007mkOg/02Wmk00<007ooOol017oo00<007mkOg/0YWmk00<007oo
Ool0HWoo001TOol00`00Og]oN`03Og/00`00Oomoo`02Ool00`00Og]oN`09Og/00`00Oomoo`05Ool0
0`00Og]oN`2TOg/00`00Oomoo`1SOol006Aoo`03001oNgmk00=oN`03001oogoo009oo`03001oNgmk
00YoN`03001oogoo00Aoo`03001oNgmk0:AoN`03001oogoo06=oo`00IGoo00<007mkOg/00Wmk00<0
07ooOol00goo00<007mkOg/02Gmk00<007ooOol01Goo00<007mkOg/0XWmk00<007ooOol0I7oo001U
Ool00`00Og]oN`03Og/00`00Oomoo`02Ool00`00Og]oN`09Og/00`00Oomoo`05Ool00`00Og]oN`2Q
Og/2001VOol006Ioo`03001oNgmk009oN`03001oogoo00=oo`03001oNgmk00UoN`03001oogoo00Eo
o`03001oNgmk0:1oN`03001oogoo06Eoo`00IWoo00<007mkOg/00gmk00<007ooOol00Woo00<007mk
Og/02Gmk00<007ooOol01Goo00<007mkOg/0Wgmk00<007ooOol0IWoo001WOol00`00Og]oN`02Og/0
0`00Oomoo`03Ool00`00Og]oN`08Og/00`00Oomoo`06Ool00`00Og]oN`2NOg/00`00Oomoo`1VOol0
06Qoo`05001oNgmkOg/00005Ool00`00Og]oN`09Og/00`00Oomoo`05Ool00`00Og]oN`2MOg/00`00
Oomoo`1WOol006Qoo`03001oNgmk009oN`03001oogoo009oo`03001oNgmk00UoN`03001oogoo00Io
o`03001oNgmk09]oN`8000Aoo`05BU800000001:DP02Ool00`00Oomoo`03Ool01000Oomoo`00E7oo
001YOol01@00Og]oNgmk00001Goo00<007mkOg/027mk00<007ooOol01Woo00<007mkOg/0Vgmk00<0
07ooOol00Woo00U:DP00BU9oodYB001:DWoo00001Goo00@007ooOol005Aoo`00JGoo00<007mkOg/0
0Wmk00<007ooOol00Woo00<007mkOg/02Gmk00<007ooOol01Goo00<007mkOg/0P7mk700017oo00<0
04YBOol00Woo00A:DP00Ool000Eoo`04001oogoo001DOol006Yoo`05001oNgmkOg/00005Ool00`00
Og]oN`08Og/00`00Oomoo`06Ool00`00Og]oN`1;Og/d000JOS400`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool01000Oomoo`00E7oo001[Ool01000Og]oN`001Goo00<007mkOg/027mk00<0
07ooOol01Woo00<007mkOg/067mk<`00CGha00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
0goo00@007ooOol005Aoo`00Jgoo00D007mkOg]oN`0000Eoo`03001oNgmk00QoN`03001oogoo00Io
oaX0081n<@03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo001DOol006ao
o`04001oNgmk0005Ool00`00Og]oN`08Og/00`00Oomoo`06Ool2000BOg^60007Ool00`00BU9oo`03
Ool01000Ool005:D0goo00EcW000Oomoo`0005Aoo`00G7oo00I:DP00000000Q2@Q0:Ool01000Og]o
N`001Woo00<007mkOg/027mk00<007ooOol01Goo0P008gmk00<007mkOg/0LGmk00<007ooOol01Goo
00=:DP00BU800Woo00=:DP00Ool00P0000EBU7ooLi`YBSW>009oo`03001oogoo059oo`00G7oo00L0
04YBOomoof<H6<I:DP0:Ool01000Og]oN`001Goo00<007mkOg/027mk00<007ooOol01Goo0`008Wmk
00<007mkOg/0L7mk00<007ooOol01goo00=:DP0000000P0000Q:DWoo001BU1240008@TYB0goo00<0
07ooOol0DWoo001QOol00f]J48Aoo`09Ool01000Og]oN`001Woo00<007mkOg/01gmk00<007ooOol0
1Woo0P008Wmk00<007mkOg/0L7mk00<007ooOol03Woo00<007ooOol01Woo00<007ooOol0DWoo001M
Ool01TYB000000Q2BU8000]oo`04001oNgmk0005Ool00`00Og]oN`08Og/00`00Oomoo`05Ool2000R
Og/2001`Og/00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomoo`1BOol005aoo`05BU8004YBOomJ
eP02000<Ool00`00Og/00006Ool00`00Og]oN`07Og/00`00Oomoo`05Ool3000QOg/2001_Og/00`00
Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`1BOol005aoo`03001:DWoo009oo`03BU8007oo00]o
o`03001oN`0000Ioo`03001oNgmk00MoN`03001oogoo00Eoo`<0025oN`8006moN`03001oogoo06io
o`00G7oo00<007ooOol00Woo00=cW000Ool037oo0`001Woo00<007mkOg/01gmk00<007ooOol017oo
0`008Gmk0P00KWmk00<007ooOol0Kgoo001LOol00`00Oomoo`03Ool00`00Oomoo`0;Ool30006Ool0
0`00Og]oN`07Og/00`00Oomoo`05Ool2000POg/00`00Ool0001^Og/00`00Oomoo`1_Ool005aoo`03
001oogoo009oo`03Li`007oo00eoo`<000Eoo`03001oNgmk00MoN`03001oogoo00Eoo`<001moN`03
001oo`0006eoN`03001oogoo071oo`00G7oo00<004YBOol00Woo00=BU000Ool03Goo10001Goo00<0
07mkOg/01gmk00<007ooOol017oo0`007gmk00@007ooOol006]oN`03001oogoo075oo`00G7oo00E:
DP00BU9ooe[F008000moo`<000Eoo`03001oNgmk00MoN`03001oogoo00Aoo`<001moN`04001oogoo
001[Og/00`00Oomoo`1aOol005eoo`06BU800000249:DP0047oo0`001Goo00<007mkOg/01Wmk00<0
07ooOol017oo0`007gmk00@007ooOol006YoN`03001oogoo079oo`00Lgoo0`001Goo00<007mkOg/0
1gmk00<007ooOol017oo00<007oo00007Wmk00@007ooOol006YoN`03001oogoo079oo`00M7oo0`00
1Goo00<007mkOg/01Wmk00<007ooOol017oo0`007Wmk00@007ooOol006UoN`03001oogoo07=oo`00
M7oo100017oo00<007mkOg/01Wmk00<007ooOol017oo0`007Wmk00@007ooOol006UoN`03001oogoo
07=oo`00MGoo0`001Goo00<007mkOg/01Wmk00<007ooOol00goo0P0000=oo`00Og/077mk00@007oo
Ool006QoN`03001oogoo07Aoo`00MGoo100017oo00<007mkOg/01Wmk00<007ooOol00goo0P0000=o
o`00Og/077mk00D007ooOomoo`0006IoN`03001oogoo07Eoo`00MWoo0`001Goo00<007mkOg/01Gmk
00<007ooOol017oo00<007oo00007Gmk00D007ooOomoo`0006IoN`03001oogoo07Eoo`00Mgoo0`00
17oo00<007mkOg/01Wmk00<007ooOol00goo00<007oo00007Gmk00D007ooOomoo`0006EoN`03001o
ogoo07Ioo`00Mgoo100017oo00<007mkOg/01Gmk00<007ooOol00goo0P0000=oo`00Og/06gmk00D0
07ooOomoo`0006EoN`03001oogoo07Ioo`00N7oo0`0017oo00<007mkOg/01Gmk00<007ooOol00goo
0P0000=oo`00Og/06gmk00D007ooOomoo`0006AoN`03001oogoo07Moo`00N7oo100017oo00<007mk
Og/01Gmk00<007ooOol00Woo0P0000=oo`00Og/06Wmk00<007ooOol00Woo00<007mkOg/0HWmk00<0
07ooOol0Mgoo001iOol30004Ool00`00Og]oN`05Og/00`00Oomoo`02Ool20002Ool00`00Og]oN`0H
Og/00`00Oomoo`03Ool00`00Og]oN`1POg/00`00Oomoo`1hOol007Uoo`@000=oo`03001oNgmk00Eo
N`03001oogoo00=oo`04001oogoo000JOg/00`00Oomoo`03Ool00`00Og]oN`1OOg/00`00Oomoo`1i
Ool007Yoo`@000=oo`03001oNgmk00EoN`03001oogoo009oo`04001oogoo000JOg/00`00Oomoo`03
Ool00`00Og]oN`1OOg/00`00Oomoo`1iOol007]oo`<000=oo`03001oNgmk00EoN`03001oogoo009o
o`800003Ool007mk01UoN`03001oogoo00=oo`03001oNgmk05ioN`03001oogoo07Yoo`00Ngoo1000
0goo00<007mkOg/017mk00<007ooOol00Woo0P000Woo00<007mkOg/05gmk00<007ooOol00goo00<0
07mkOg/0GWmk00<007ooOol0NWoo001lOol30003Ool00`00Og]oN`05Og/01000Oomoogoo0P000Woo
00<007mkOg/05gmk00<007ooOol00goo00<007mkOg/0GGmk00<007ooOol0Ngoo001lOol40003Ool0
0`00Og]oN`04Og/00`00Oomoo`02Ool01000Oomoo`006Gmk00<007ooOol017oo00<007mkOg/0Fgmk
00<007ooOol0O7oo001mOol40002Ool00`00Og]oN`05Og/01@00Oomoogoo00000Woo00<007mkOg/0
5gmk00<007ooOol017oo00<007mkOg/0Fgmk00<007ooOol0O7oo001mOol40003Ool00`00Og]oN`04
Og/01@00Oomoogoo00000goo00<007mkOg/05Wmk00<007ooOol017oo00<007mkOg/0FWmk00<007oo
Ool0OGoo001nOol40002Ool00`00Og]oN`04Og/01000Oomoogoo0P000Woo00<007mkOg/05Wmk00<0
07ooOol017oo00<007mkOg/0FWmk00<007ooOol0OGoo001oOol30003Ool00`00Og]oN`04Og/00`00
Oomoo`020002Ool00`00Og]oN`0FOg/00`00Oomoo`04Ool00`00Og]oN`1IOg/00`00Oomoo`1nOol0
07moo`@0009oo`03001oNgmk00AoN`05001oogooOol00003Ool00`00Og]oN`0EOg/00`00Oomoo`04
Ool00`00Og]oN`1IOg/00`00Oomoo`1nOol0081oo`@0009oo`03001oNgmk00=oN`05001oogooOol0
0003Ool00`00Og]oN`0DOg/00`00Oomoo`05Ool00`00Og]oN`1HOg/00`00Oomoo`1oOol0081oo`@0
009oo`03001oNgmk00AoN`04001oogoo0003Ool00`00Og]oN`0DOg/00`00Oomoo`06Ool00`00Og]o
N`1FOg/00`00Oomoo`20Ool0085oo`@00003Ool007mk00EoN`04001oogoo0003Ool00`00Og]oN`0D
Og/00`00Oomoo`06Ool00`00Og]oN`1FOg/00`00Oomoo`20Ool0085oo`@0009oo`03001oNgmk00=o
N`03001oogoo008000=oo`03001oNgmk01=oN`03001oogoo00Ioo`03001oNgmk05EoN`03001oogoo
085oo`00PWoo100000=oo`00Og/01Gmk00@007oo000000=oo`03001oNgmk01=oN`03001oogoo00Io
o`03001oNgmk05EoN`03001oogoo085oo`00Pgoo100000=oo`00Og/017mk00@007ooOol000=oo`03
001oNgmk01=oN`03001oogoo00Ioo`03001oNgmk05AoN`03001oogoo089oo`00Pgoo100000=oo`00
Og/017mk00@007ooOol000Aoo`03001oNgmk019oN`03001oogoo00Ioo`03001oNgmk05AoN`03001o
ogoo089oo`00Q7oo100000=oo`00Og/017mk00<007oo000017oo00<007mkOg/04Wmk00<007ooOol0
1goo00<007mkOg/0DWmk00<007ooOol0Pgoo0024Ool400000goo001oN`04Og/01000Ool000000goo
00<007mkOg/04Wmk00<007ooOol01goo00<007mkOg/0DGmk00<007ooOol0Q7oo0025Ool400000goo
001oN`03Og/01000Ool000000goo00<007mkOg/04Wmk00<007ooOol01goo00<007mkOg/0DGmk00<0
07ooOol0Q7oo0025Ool2000017oo000000001Gmk00<007oo000017oo00<007mkOg/04Gmk00<007oo
Ool01goo00<007mkOg/0D7mk00<007ooOol0QGoo0026Ool400000goo001oN`03Og/00`00Ool00004
Ool00`00Og]oN`0AOg/00`00Oomoo`07Ool00`00Og]oN`1@Og/00`00Oomoo`25Ool008Moo`D000Ao
N`03001oo`0000Aoo`03001oNgmk015oN`03001oogoo00Moo`03001oNgmk04moN`03001oogoo08Io
o`00Qgoo100000=oo`00Og/00gmk0P001Goo00<007mkOg/047mk00<007ooOol027oo00<007mkOg/0
CGmk00<007ooOol0Qgoo0028Ool50004Og/30004Ool00`00Og]oN`0?Og/00`00Oomoo`09Ool00`00
Og]oN`1=Og/00`00Oomoo`27Ool008Qoo`800004Ool000000003Og/00`00Ool00004Ool00`00Og]o
N`0?Og/00`00Oomoo`09Ool00`00Og]oN`1<Og/00`00Oomoo`28Ool008Uoo`D000AoN`8000Aoo`03
001oNgmk00moN`03001oogoo00Uoo`03001oNgmk04aoN`03001oogoo08Qoo`00RWoo100017mk0P00
1Goo00<007mkOg/03Wmk00<007ooOol02Goo00<007mkOg/0Bgmk00<007ooOol0RGoo002:Ool50003
Og/20005Ool00`00Og]oN`0>Og/00`00Oomoo`09Ool00`00Og]oN`1;Og/00`00Oomoo`29Ool0079o
o`05BU800000001:DP02Ool00cW>00000003Ool01TYB00000124DY@000Ioo`@000AoN`03001oogoo
00=oo`03001oNgmk00ioN`03001oogoo00Yoo`03001oNgmk04UoN`03001oogoo08Yoo`00LGoo00Y:
DP00BU9oodYB001:DWoo001[FP=oo`05BU8004YBOomJeP020006Ool200000goo00000003Og/20004
Ool00`00Og]oN`0>Og/00`00Oomoo`0:Ool00`00Og]oN`18Og/00`00Oomoo`2;Ool0075oo`03001:
DWoo009oo`04BU8007oo0004Ool00`00BU9oo`02Ool00dYB001oo`06Ool40003Og/20005Ool00`00
Og]oN`0=Og/00`00Oomoo`0:Ool00`00Og]oN`18Og/00`00Oomoo`2;Ool0075oo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo009oo`03Li`007oo00Ioo`800003Ool0000000@000Eoo`03001o
Ngmk00eoN`03001oogoo00Yoo`03001oNgmk04MoN`03001oogoo08aoo`00LGoo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo0`0017mk00<007ooOol00goo00<007mk
Og/03Gmk00<007ooOol02Woo00<007mkOg/0Agmk00<007ooOol0S7oo001aOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool30004Og/00`00Oomoo`03Ool00`00Og]o
N`0<Og/00`00Oomoo`0:Ool00`00Og]oN`16Og/00`00Oomoo`2=Ool0075oo`03001:DWoo00=oo`03
001oo`0000Aoo`03001:DWoo009oo`03DY@007oo00Qoo`<000AoN`03001oogoo00=oo`03001oNgmk
00aoN`03001oogoo00Yoo`03001oNgmk04IoN`03001oogoo08eoo`00LGoo00=:DP00BU800Woo00A:
DP00Ool000Aoo`05BU8004YBOomJeP02000:Ool30004Og/00`00Oomoo`02Ool00`00Og]oN`0<Og/0
0`00Oomoo`0;Ool00`00Og]oN`14Og/00`00Oomoo`2>Ool0079oo`03BU80000000800003BU800000
008000=oo`06BU800000249:DP002Woo0`0017mk00<007ooOol00Woo00<007mkOg/037mk00<007oo
Ool02goo00<007mkOg/0@gmk00<007ooOol0Sgoo001iOol00`00Oomoo`08Ool00`00Oomoo`09Ool3
0003Og/00`00Oomoo`03Ool00`00Og]oN`0:Og/00`00Oomoo`0<Ool00`00Og]oN`13Og/00`00Oomo
o`2?Ool007Uoo`03001oogoo00Qoo`03001oogoo00Uoo`800003Ool007mk009oN`03001oogoo009o
o`03001oNgmk00YoN`03001oogoo00aoo`03001oNgmk049oN`03001oogoo091oo`00Q7oo00<007oo
Ool02Woo0`000gmk00<007ooOol00Woo00<007mkOg/02Wmk00<007ooOol037oo00<007mkOg/0@Wmk
00<007ooOol0T7oo002BOol30003Og/00`00Oomoo`02Ool00`00Og]oN`09Og/00`00Oomoo`0<Ool0
0`00Og]oN`11Og/00`00Oomoo`2AOol0099oo`<000=oN`03001oogoo009oo`03001oNgmk00UoN`03
001oogoo00eoo`03001oNgmk03moN`03001oogoo099oo`00Tgoo0`000gmk00D007ooOomoo`0000]o
N`03001oogoo00eoo`03001oNgmk03moN`03001oogoo099oo`00Tgoo0`000gmk00D007ooOomoo`00
00]oN`03001oogoo00eoo`03001oNgmk03ioN`03001oogoo09=oo`00U7oo0`000Wmk00<007ooOol0
0Woo00<007mkOg/027mk00<007ooOol03Goo00<007mkOg/0?Wmk00<007ooOol0Tgoo002DOol30003
Og/01@00Oomoogoo00002Wmk00<007ooOol03Goo00<007mkOg/0?Gmk00<007ooOol0U7oo002EOol3
0002Og/01@00Oomoogoo00002Wmk00<007ooOol03Goo00<007mkOg/0?Gmk00<007ooOol0U7oo002F
Ool20003Og/01000Oomoo`002Wmk00<007ooOol03Woo00<007mkOg/0>gmk00<007ooOol0UGoo002F
Ool30002Og/01@00Oomoogoo00002Gmk00<007ooOol03Woo00<007mkOg/0>Wmk00<007ooOol0UWoo
002GOol20003Og/01000Oomoo`002Gmk00<007ooOol03Woo00<007mkOg/0>Wmk00<007ooOol0UWoo
002GOol30002Og/01000Oomoo`0027mk00<007ooOol03goo00<007mkOg/0>Gmk00<007ooOol0Ugoo
002HOol30002Og/01000Oomoo`001gmk00<007ooOol03goo00<007mkOg/0>Gmk00<007ooOol0Ugoo
002HOol30002Og/01000Oomoo`001gmk00<007ooOol03goo00<007mkOg/0>7mk00<007ooOol0V7oo
002IOol300001Gmk001oogoo00001gmk00<007ooOol047oo00<007mkOg/0=Wmk00<007ooOol0VGoo
002JOol20002Og/00`00Ool00007Og/00`00Oomoo`0@Ool00`00Og]oN`0fOg/00`00Oomoo`2IOol0
09Yoo`<00005Og/007ooOol00006Og/00`00Oomoo`0@Ool00`00Og]oN`0eOg/00`00Oomoo`2JOol0
09]oo`80009oN`03001oo`0000IoN`03001oogoo011oo`03001oNgmk03EoN`03001oogoo09Yoo`00
Vgoo0`0000AoN`00Ool000IoN`03001oogoo011oo`03001oNgmk03AoN`03001oogoo09]oo`00W7oo
0P000Wmk00<007oo00001Gmk00<007ooOol047oo00<007mkOg/0=7mk00<007ooOol0Vgoo002LOol3
000017mk001oo`001Gmk00<007ooOol047oo00<007mkOg/0<gmk00<007ooOol0W7oo002MOol20000
17mk001oo`001Gmk00<007ooOol04Goo00<007mkOg/0<Gmk00<007ooOol0WGoo002NOol200000gmk
00000005Og/00`00Oomoo`0AOol00`00Og]oN`0aOg/00`00Oomoo`2MOol009ioo`800004Og/007oo
0004Og/00`00Oomoo`0AOol00`00Og]oN`0`Og/00`00Oomoo`2NOol009moo`800003Og/0000000Ao
N`03001oogoo015oo`03001oNgmk031oN`03001oogoo09ioo`00;goo00=:DP0000000P0000=:DWoo
Ool020001Goo00<007ooOol00Woo00<007ooOol00Woo00=:DP0000000P0000=:DWooOol0BGoo1@00
0gmk00<007ooOol04Woo00<007mkOg/0;gmk00<007ooOol0Wgoo000^Ool00dYB001:DP02Ool01TYB
001:DWoo249[FP]oo`03001oogoo00Ioo`03BU8004YB009oo`03BU8004YB04]oo`800003Og/007mk
009oN`03001oogoo019oo`03001oNgmk02moN`03001oogoo09moo`00;Woo00<004YBOol00goo00E:
DP00OolQ23W>00]oo`03001oogoo00Ioo`03001:DWoo00=oo`03BU8007oo04Yoo`D0009oN`03001o
ogoo01=oo`03001oNgmk02eoN`03001oogoo0:1oo`00=Goo00D007ooHaP0048@00Eoo`P000Ioo`03
001oogoo00Aoo`03001oogoo04Yoo`@0009oN`03001oogoo01=oo`03001oNgmk02aoN`03001oogoo
0:5oo`00=Goo00@007ooOom[FP8HaP06F]IoogooOolHaU[F0goo00<007ooOol01Woo00<8@W>LOol0
0goo00=JePQ2Ool0=Goo00=:DP0000000`0000A:DWooOolicP8000]oo`<0009oN`03001oogoo01=o
o`03001oNgmk02aoN`03001oogoo0:5oo`00=7oo00=:DP00Ool00goo00QJePQ26<IJeWooJeX@Q7>L
0Woo00<007ooOol01Woo00=BU1S6Ool00Woo00=BU0Q2DY@0=Woo00<004YBOol00Woo00I:DP00Oomo
o`00JeX<Ool400000gmk001oo`0DOol00`00Og]oN`0[Og/00`00Oomoo`2ROol002ioo`8HaP06F]Io
ogooBU8004YB1Woo00I24000DYAoocW><H`2Ool00`00Oomoo`07Ool00b480000000200000a24Oomo
o`0eOol00`00Oomoo`03Ool01000Oomoo`003Woo1@005Goo00<007mkOg/0:gmk00<007ooOol0XWoo
000^Ool00cW>48@8@P0300000dYBOomoo`06Ool026<H001oogoo48AJeWoo0008Ool00dYB6<IS6002
Ool00e:D48@icP0jOol00e[F8@P@Q002Ool00`00Oomoo`0<Ool01@00Og]oNgmk00005Goo00<007mk
Og/0:Wmk00<007ooOol0Xgoo000^Ool00dYB8@Qoo`06Ool00`00Oomoo`04Ool01`00Oomoof<H249c
W00000Qoo`03001oogoo00=oo`03JeX007oo03Ioo`05DY@aS1S6<Ha:DP03Ool00`00Oomoo`0=Ool0
1@00Og]oNgmk00005Goo00<007mkOg/0:7mk00<007ooOol0Y7oo000^Ool00e[F48Aoo`06Ool00`00
BU9oo`03Ool00dYB001oo`02Ool00cW><H`00008Ool00`00BU9oo`03Ool00dYB001oo`0eOol00bU:
48A:DP06Ool00`00Oomoo`0=Ool01@00Og]oNgmk00005Goo00<007mkOg/0:7mk00<007ooOol0Y7oo
000_Ool00`00Oomoo`05Ool00dYB001:DP02Ool00dYB001:DP04Ool00a24001oo`07Ool00dYB001:
DP02Ool00dYB001:DP0fOol00`00Liaoo`03Ool01000Oomoo`0047oo00D007mkOg]oN`0001Aoo`03
001oNgmk02MoN`03001oogoo0:Eoo`00;goo00<8@P0000000`000goo00=:DP0000000P0000=:DWoo
Ool00goo00=S6000Ool027oo00=:DP0000000P0000=:DWooOol0=Goo00<004YBOol00Woo00E:DP00
Oomoo`00015oo`04001oNgmk000DOol00`00Og]oN`0WOg/00`00Oomoo`2UOol008]oo`03BU800000
00<00003BU9oo`0000<000moo`05001oNgmkOg/0000COol00`00Og]oN`0VOg/00`00Oomoo`2VOol0
09Aoo`03001oogoo011oo`04001oNgmk000COol00`00Og]oN`0VOg/00`00Oomoo`2VOol009Aoo`03
001oogoo011oo`05001oNgmkOg/0000BOol00`00Og]oN`0UOg/00`00Oomoo`2WOol00:Qoo`04001o
Ngmk000COol00`00Og]oN`0SOg/00`00Oomoo`2XOol00:Uoo`04001oNgmk000BOol00`00Og]oN`0S
Og/00`00Oomoo`2XOol00:Uoo`05001oNgmkOg/0000AOol00`00Og]oN`0ROg/00`00Oomoo`2YOol0
0:Yoo`04001oNgmk000AOol00`00Og]oN`0ROg/00`00Oomoo`2YOol00:Yoo`05001oNgmkOg/0000@
Ool00`00Og]oN`0QOg/00`00Oomoo`2ZOol00:]oo`04001oNgmk000@Ool00`00Og]oN`0QOg/00`00
Oomoo`2ZOol00:aoo`04001oNgmk000@Ool00`00Og]oN`0OOg/00`00Oomoo`2[Ool0021oo`03BU80
000000800005BU9oogooOol00004Ool00dYB0000000200000dYBOomoo`04Ool01P00Oomoogoo@Q0Q
209oo`03001:DPQ200800005BU9oogooOom:DP0300001R48F]HHaP00Ool005Moo`04001oNgmk000@
Ool00`00Og]oN`0NOg/00`00Oomoo`2/Ool001moo`03BU8004YB009oo`03BU8004YB00Ioo`03BU80
04YB009oo`03BU8004YB00Eoo`06001oogooLi`8@V]J0Woo0P0000EJeWooBU8004YB009oo`07001:
DWooLiaBU0Q200000Woo00<007ooOol0EWoo00@007mkOg/000moo`03001oNgmk01ioN`03001oogoo
0:aoo`007goo00<004YBOol00goo00=:DP00Ool01Goo00<004YBOol00goo00=:DP00Ool017oo00D0
07ooOolYBT8@00=oo`03001:DWoo009oo`05BU8007ooOol00004Ool01F]J001oogoo0000F7oo00@0
07mkOg/000moo`03001oNgmk01eoN`03001oogoo0:eoo`007goo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol00goo00@006<HF]HHaPAoo`03001cW7oo00=oo`05001oogoo
6<HicP04Ool01000Oomoo`00FGoo00@007mkOg/000ioo`03001oNgmk01eoN`03001oogoo0:eoo`00
9Goo00=[FQS6Ool01Goo00<007ooOol017oo00<007ooOol00goo00@001S66<I[FPAoo`03001oogoo
00=oo`0:001oogooLi`YBP00248HaR480002Ool00`00Oomoo`1HOol00`00Og/0000>Ool00`00Og]o
N`0LOg/00`00Oomoo`2^Ool002Aoo`03DY@@Q4YB00Ioo`03001oogoo00Aoo`03001oogoo00=oo`04
001S60Q2JeX4Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00f<HDY@00002Ool00`00Oomoo`1HOol0
1000Og]oN`003Woo00<007mkOg/06Wmk00<007ooOol0[goo000ROol300000cW>Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool01@00OomS61S6Li`00goo00<005:DOol00Woo00E:DP00Oomoo`00
00Eoo`05001oogoo001JeP1JOol00`00Og/0000>Ool00`00Og]oN`0JOg/00`00Oomoo`2_Ool002=o
o`03Li`YBT8@00Moo`03001oogoo00Aoo`03001oogoo00=oo`06001oogooHaPHaW>L0Woo0P0000EJ
eWooBU8004YB009oo`03001:DWoo009oo`07BU8007ooOol00124JeX0FGoo00@007mkOg/000eoo`03
001oNgmk01UoN`03001oogoo0;1oo`007goo00<007ooOol00Woo00=cW000Ool01Woo00<007ooOol0
17oo00<007ooOol00goo00/007ooOomooe[F48AcW7oo001240Q200800005BU9oogooOom:DP050000
1dYBOomoo`00DY@8@P0005Uoo`03001oN`0000eoo`03001oNgmk01UoN`03001oogoo0;1oo`007goo
00<004YBOol00Woo00=:DP00Ool01Woo00<004YBOol00goo00=:DP00Ool017oo00<007ooOol01Goo
00<007ooOol0K7oo00@007mkOg/000aoo`03001oNgmk01QoN`03001oogoo0;5oo`007goo00M:DP00
BU9oodYB001:DP07Ool00dYB001:DP02Ool00dYB001:DP05Ool00`00Oomoo`05Ool00`00Oomoo`1]
Ool00`00Og/0000<Ool00`00Og]oN`0HOg/00`00Oomoo`2aOol0021oo`05BU800000001:DP09Ool0
0dYB0000000200000dYBOomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`1^Ool00`00Og/0000<Ool0
0`00Og]oN`0FOg/00`00Oomoo`2bOol00;=oo`03001oN`0000aoo`03001oNgmk01EoN`03001oogoo
0;=oo`00]7oo00<007mk00002goo00<007mkOg/05Gmk00<007ooOol0/goo002dOol00`00Og/0000;
Ool00`00Og]oN`0DOg/00`00Oomoo`2dOol00;Eoo`03001oN`0000Yoo`03001oNgmk01AoN`03001o
ogoo0;Aoo`00]Woo00<007mk00002Goo00<007mkOg/04gmk00<007ooOol0]Goo002fOol00`00Og/0
0009Ool00`00Og]oN`0COg/00`00Oomoo`2eOol00;Moo`03001oN`0000Uoo`03001oNgmk015oN`03
001oogoo0;Ioo`00]goo00<007mk00002Goo00<007mkOg/047mk00<007ooOol0]goo000VOol40003
Ool60002Ool60004Ool50002Ool01000Oomoogoo1@00JGoo00<007mk000027oo00<007mkOg/047mk
00<007ooOol0]goo000WOol20005Ool40004Ool30008Ool01000Oomoogoo0P0017oo0`00Jgoo0P00
27oo00<007mkOg/03gmk00<007ooOol0^7oo000XOol00`00Oomoo`03Ool30005Ool30008Ool01000
Oomoogoo0`000goo0`00Jgoo00<007mk00001goo00<007mkOg/03gmk00<007ooOol0^7oo000XOol0
0`00Oomoo`03Ool30005Ool30008Ool00`00Oomoo`040003Ool3001/Ool20007Ool00`00Og]oN`0>
Og/00`00Oomoo`2iOol002Uoo`P000Eoo`<000=oo`03001oogoo009oo`03001oogoo00@000=oo`<0
06aoo`03001oN`0000Moo`03001oNgmk00aoN`03001oogoo0;Yoo`00:Goo00@007ooOomoo`<000Io
o`<000=oo`03001oogoo009oo`03001oogoo00<00004Ool007ooOol3001]Ool20007Ool00`00Og]o
N`0<Og/00`00Oomoo`2jOol002Uoo`03001oogoo00@000Ioo`L000Aoo`03001oo`000080009oo`03
001oogoo00<006eoo`03001oN`0000Ioo`03001oNgmk00]oN`03001oogoo0;]oo`00:Woo00<007oo
00000P001goo0`000goo00<007ooOol00Woo00<007oo00000P000Woo00<007ooOol00`00KWoo0P00
1Woo00<007mkOg/02gmk00<007ooOol0^goo000ZOol00`00Ool000020007Ool30003Ool00`00Oomo
o`02Ool50003Ool00`00Ool00002001_Ool20005Ool00`00Og]oN`0:Og/00`00Oomoo`2lOol002]o
o`<000Qoo`<000Eoo`03001oogoo00@000Aoo`03001oo`00008006moo`8000Eoo`03001oNgmk00Yo
N`03001oogoo0;aoo`00:goo0`0027oo0`001Goo00<007ooOol0100017oo00<007oo00000P00L7oo
0P001Goo00<007mkOg/027mk00<007ooOol0_Goo000[Ool20009Ool30004Ool20002Ool40005Ool4
001`Ool20005Ool00`00Og]oN`07Og/00`00Oomoo`2nOol002aoo`03001oogoo00Ioo`l000Ioo`D0
071oo`8000Aoo`03001oNgmk00MoN`04001oogooBU8300001R48F]HHaP00Ool0009oo`03BU800000
00<00003BU9oogoo0:Uoo`00`7oo00<007ooOol00Woo00<007mkOg/01Wmk00/007ooOomoo`00BU9o
og>LDY@8@P00009oo`05001oogoo001:DP03Ool00dYB001oo`2ZOol00<1oo`8000=oo`03001oNgmk
00IoN`05001oogooOol00004Ool01F]J001oogoo00000Woo00<007ooOol00goo00<007ooOol0ZGoo
0031Ool01@00Oomoogoo00001gmk00<007ooOol00Woo00<HaSW>Ool00goo00@007ooOol000Ioo`03
F]HQ21240:]oo`00`Goo0P000Woo00<007mkOg/01Gmk00<007ooOol00Woo00McW2U:0008@QS68@P0
0002Ool02@00OomoogooDY@aS1S6<Ha:DP2/Ool00<9oo`80009oo`03001oNgmk00=oN`03001oogoo
00Moo`03HaQBU000009oo`06001oogoo:DX@Q4YB[goo0033Ool01000Oomoo`0017mk00<007ooOol0
17oo00<007ooOol00goo00@007ooOol0009oo`03001cW7oo00=oo`03001oogoo0:Uoo`00`goo0P00
00=oo`00Og/00gmk00<007ooOol017oo00<004YBOol00Woo00E:DP00Oomoo`00009oo`03001:DWoo
009oo`03BU8007oo0:Yoo`00a7oo00<007oo00000gmk00<007ooOol01Goo00=:DP0000000`0000A:
DWooOol0009oo`03BU80000000<00003BU9oogoo0:Uoo`00a7oo0`000gmk00<007ooOol03Woo00<0
07ooOol0/Woo0035Ool20002Og/00`00Oomoo`0?Ool00`00Oomoo`2bOol00<Ioo`<0019oo`03001o
ogoo0;9oo`00aWoo0`00agoo0037Ool00`00Oomoo`36Ool00?mooi5oo`00ogooTGoo003oOonAOol0
0?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {298, 0}} -> {-0.997508, -1.44001, 0.00500004, \
0.00500004}}]
}, Open  ]],

Cell["detail around the ctd one-phase field", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["partmake[524.8, {{-0.35,-0.22},{-0.6,-0.45}}];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15385 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.69231 7.69231 4.61538 7.69231 [
[ 0 0 0 0 ]
[ 1 1.15385 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 1.15385 L
0 1.15385 L
closepath
clip
newpath
p
p
1 .55 .55 r
-3.4809 -6.07692 m
2.69231 4.61538 L
8.86551 -6.07692 L
F
0 g
.004 w
s
.02761 0 m
.69379 1.15385 L
s
s
.69379 1.15385 m
.02761 0 L
s
s
s
P
p
1 .85 .85 r
p
p
6.28379 -1.60525 m
8.72672 -5.83652 L
-1.15273 -4.70602 L
.31809 -1.49045 L
6.28379 -1.60525 L
F
P
p
P
p
-2.70208 -4.72797 m
-0.63856 -1.15385 L
-0.565 -1.15385 L
-1.95959 -4.70593 L
-2.70208 -4.72797 L
F
P
p
.33758 -1.48945 m
1.37065 2.24855 L
1.4509 2.24846 L
1.73502 -1.44357 L
.33758 -1.48945 L
F
P
p
P
p
-0.60567 -1.15385 m
1.33438 2.24846 L
1.32576 2.24846 L
-0.63856 -1.15385 L
-0.60567 -1.15385 L
F
P
p
.31809 -1.49045 m
.742 .76923 L
.74704 .76923 L
.33758 -1.48945 L
.31809 -1.49045 L
F
P
p
-1.15273 -4.70602 m
.742 .76923 L
.59362 .76923 L
-1.95959 -4.70593 L
-1.15273 -4.70602 L
F
P
p
-0.565 -1.15385 m
.59362 .76923 L
.52655 .76923 L
-0.60567 -1.15385 L
-0.565 -1.15385 L
F
P
p
1.37065 2.24855 m
.74704 .76923 L
.52655 .76923 L
1.33438 2.24846 L
1.37065 2.24855 L
F
P
p
6.19045 -1.44357 m
2.69231 4.61538 L
2.69231 4.61538 L
1.73502 -1.44357 L
6.19045 -1.44357 L
F
P
p
P
p
P
p
1.4509 2.24846 m
2.69231 4.61538 L
2.69231 4.61538 L
1.32576 2.24846 L
1.4509 2.24846 L
F
P
p
P
P
0 g
p
p
.004 w
s
s
s
s
s
s
P
p
P
p
.004 w
s
s
s
s
s
s
P
p
.004 w
s
.74922 0 m
1 .90741 L
s
s
1 .90741 m
.74922 0 L
s
s
s
s
s
P
p
P
p
.004 w
s
.05227 0 m
.71021 1.15385 L
s
s
.71021 1.15385 m
.05227 0 L
s
s
.69379 1.15385 m
.02761 0 L
s
s
.02761 0 m
.69379 1.15385 L
s
s
s
P
p
.004 w
s
.5977 0 m
.742 .76923 L
s
.742 .76923 m
.74704 .76923 L
s
.6076 0 m
.74704 .76923 L
s
s
s
P
p
.004 w
s
.47581 0 m
.742 .76923 L
s
.742 .76923 m
.59362 .76923 L
s
.23491 0 m
.59362 .76923 L
s
s
s
P
p
.004 w
s
.13017 0 m
.59362 .76923 L
s
.59362 .76923 m
.52655 .76923 L
s
.07366 0 m
.52655 .76923 L
s
s
s
P
p
.004 w
s
.90918 1.15385 m
.74704 .76923 L
s
.74704 .76923 m
.52655 .76923 L
s
.7366 1.15385 m
.52655 .76923 L
s
s
s
P
p
.004 w
s
s
s
s
s
s
P
p
P
p
P
p
.004 w
s
s
s
s
s
s
P
p
P
P
P
p
1 g
p
.31809 -1.49045 m
-1.15273 -4.70602 L
.742 .76923 L
.31809 -1.49045 L
F
.33758 -1.48945 m
1.37065 2.24855 L
.74704 .76923 L
.33758 -1.48945 L
F
1.73502 -1.44357 m
1.4509 2.24846 L
2.69231 4.61538 L
1.73502 -1.44357 L
F
-1.95959 -4.70593 m
-0.565 -1.15385 L
.59362 .76923 L
-1.95959 -4.70593 L
F
-0.60567 -1.15385 m
1.33438 2.24846 L
.52655 .76923 L
-0.60567 -1.15385 L
F
P
0 g
p
.004 w
s
s
.47581 0 m
.742 .76923 L
s
.742 .76923 m
0 0 rlineto
.5977 0 m
.742 .76923 L
s
s
s
.74922 0 m
1 .90741 L
s
s
1 .90741 m
.74922 0 L
s
.90918 1.15385 m
.74704 .76923 L
s
.74704 .76923 m
0 0 rlineto
.6076 0 m
.74704 .76923 L
s
s
s
s
s
s
s
s
s
.13017 0 m
.59362 .76923 L
s
.59362 .76923 m
0 0 rlineto
.23491 0 m
.59362 .76923 L
s
s
s
.05227 0 m
.71021 1.15385 L
s
s
.71021 1.15385 m
.05227 0 L
s
.7366 1.15385 m
.52655 .76923 L
s
.52655 .76923 m
0 0 rlineto
.07366 0 m
.52655 .76923 L
s
s
P
P
p
p
/Helvetica findfont 16 scalefont setfont
[(3.0 kbar)] -2.69231 3 0 0 Mshowa
P
p
/Times-Bold findfont 18 scalefont setfont
[(AFM)] -2.69231 3.84615 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(als)] 3.46154 4.23077 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(st)] .61538 2.30769 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(ctd)] -0.23077 .76923 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(g)] -1.30769 -1.15385 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(chl)] 6.84615 -1.53846 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(bi)] 2.69231 -5.61538 0 0 Mshowa
P
P
p
/Helvetica findfont 16 scalefont setfont
[(524.8)] -3.23077 2.15385 -1 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{321, 370},
  ImageMargins->{{32, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000510001LQ000`40O003h00O27oo00<007mkOg/0
1Gmk00<007ooOol017oo00<007mkOg/03Wmk00=oo`00Ool07goo00=oN`00Og/0Bgmk00<007ooOol0
97oo00@007mkOg/002aoo`03001oNgmk04moN`0027oo00<007mkOg/01Gmk00<007ooOol017oo00<0
07mkOg/03gmk00<007ooOol07goo00<007mkOg/0BWmk00<007ooOol097oo00@007mkOg/002aoo`03
001oNgmk04moN`002Goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00<007ooOol0
7Woo00=oN`00Og/0BWmk00=oo`00Ool097oo00@007mkOg/002aoo`03001oNgmk04moN`002Goo00<0
07mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00=oo`00Ool07Woo00=oN`00Og/0Bgmk00<0
07ooOol08goo00@007mkOg/002eoo`03001oNgmk04ioN`002Woo00<007mkOg/01Gmk00<007ooOol0
17oo00<007mkOg/03gmk00<007ooOol07Woo00=oN`00Og/0BWmk00<007ooOol08goo00EoN`00Og]o
N`0002aoo`03001oNgmk04ioN`002goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/03Wmk
00=oo`00Ool07Woo00=oN`00Og/0BWmk00=oo`00Ool097oo00@007mkOg/002aoo`03001oNgmk04io
N`002goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00<007ooOol07Woo00=oN`00
Og/0BWmk00<007ooOol08goo00@007mkOg/002eoo`03001oNgmk04eoN`0037oo00<007mkOg/01Gmk
00<007ooOol017oo00<007mkOg/03gmk00<007ooOol07Goo00=oN`00Og/0BWmk00<007ooOol08goo
00@007mkOg/002eoo`03001oNgmk04eoN`0037oo00<007mkOg/01Gmk00<007ooOol017oo00<007mk
Og/03gmk00=oo`00Ool07Woo00<007mkOg/0BGmk00=oo`00Ool08goo00@007mkOg/002eoo`03001o
Ngmk04eoN`003Goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00<007ooOol07Goo
00=oN`00Og/0BWmk00<007ooOol08Woo00EoN`00Og]oN`0002aoo`03001oNgmk04eoN`003Goo00<0
07mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03Wmk00=oo`00Ool07Woo00<007mkOg/0BGmk00<0
07ooOol08Woo00EoN`00Og]oN`0002eoo`03001oNgmk04aoN`003Woo00<007mkOg/01Gmk00<007oo
Ool017oo00<007mkOg/03gmk00<007ooOol07Goo00=oN`00Og/0BGmk00=oo`00Ool08goo00@007mk
Og/002eoo`03001oNgmk04aoN`003goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/03gmk
00<007ooOol07Goo00<007mkOg/0BGmk00<007ooOol08Woo00@007mkOg/002eoo`03001oNgmk04ao
N`003goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00=oo`00Ool07Goo00=oN`00
Og/0BGmk00<007ooOol08Woo00@007mkOg/002eoo`03001oNgmk04aoN`0047oo00<007mkOg/01Gmk
00<007ooOol017oo00<007mkOg/03gmk00<007ooOol07Goo00<007mkOg/0B7mk00=oo`00Ool08Woo
00AoN`00Og/002ioo`03001oNgmk04]oN`0047oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mk
Og/03Wmk00=oo`00Ool07Goo00=oN`00Og/0BGmk00<007ooOol08Goo00EoN`00Og]oN`0002eoo`03
001oNgmk04]oN`004Goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00<007ooOol0
7Goo00<007mkOg/0B7mk00<007ooOol08Woo00@007mkOg/002eoo`03001oNgmk04]oN`004Woo00<0
07mkOg/017mk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol077oo00=oN`00Og/0BGmk00<0
07ooOol08Goo00@007mkOg/002ioo`03001oNgmk04YoN`004Woo00<007mkOg/01Gmk00<007ooOol0
17oo00<007mkOg/03gmk00=oo`00Ool077oo00=oN`00Og/0BGmk00<007ooOol08Goo00@007mkOg/0
02ioo`03001oNgmk04YoN`004goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/03gmk00<0
07ooOol077oo00=oN`00Og/0B7mk00<007ooOol08Goo00@007mkOg/002ioo`03001oNgmk04YoN`00
4goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/047mk00<007ooOol06goo00=oN`00Og/0
BGmk00<007ooOol087oo00EoN`00Og]oN`0002eoo`03001oNgmk04YoN`0057oo00<007mkOg/01Gmk
00<007ooOol017oo00<007mkOg/03gmk00<007ooOol077oo00=oN`00Og/0B7mk00<007ooOol08Goo
00@007mkOg/002ioo`03001oNgmk04UoN`0057oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mk
Og/03gmk00<007ooOol06goo00=oN`00Og/0B7mk00<007ooOol08Goo00@007mkOg/002ioo`03001o
Ngmk04UoN`005Goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/03gmk00=oo`00Ool077oo
00<007mkOg/0B7mk00<007ooOol087oo00@007mkOg/002ioo`03001oNgmk04UoN`005Woo00<007mk
Og/017mk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06goo00=oN`00Og/0B7mk00<007oo
Ool087oo00@007mkOg/002ioo`03001oNgmk04UoN`005Woo00<007mkOg/01Gmk00<007ooOol017oo
00<007mkOg/047mk00<007ooOol06goo00<007mkOg/0Agmk00<007ooOol087oo00AoN`00Og/002mo
o`03001oNgmk04QoN`005goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/03gmk00<007oo
Ool06goo00=oN`00Og/0B7mk00<007ooOol07goo00EoN`00Og]oN`0002ioo`03001oNgmk04QoN`00
5goo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06goo00<007mkOg/0
Agmk00<007ooOol087oo00@007mkOg/002ioo`03001oNgmk04QoN`0067oo00<007mkOg/01Gmk00<0
07ooOol017oo00<007mkOg/03gmk00=oo`00Ool06goo00=oN`00Og/0Agmk00=oo`00Ool087oo00@0
07mkOg/002moo`03001oNgmk04MoN`0067oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/0
3gmk00<007ooOol06goo00<007mkOg/0Agmk00<007ooOol07goo00@007mkOg/002moo`03001oNgmk
04MoN`006Goo00<007mkOg/01Gmk00<007ooOol017oo00<007mkOg/047mk00<007ooOol06Woo00=o
N`00Og/0Agmk00<007ooOol07goo00AoN`00Og/002moo`03001oNgmk04MoN`006Woo00<007mkOg/0
17mk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06goo00<007mkOg/0AWmk00=oo`00Ool0
7goo00EoN`00Og]oN`0002ioo`03001oNgmk04MoN`006Woo00<007mkOg/01Gmk00<007ooOol01Goo
00<007mkOg/03gmk00<007ooOol06Woo00=oN`00Og/0Agmk00<007ooOol07goo00@007mkOg/002mo
o`03001oNgmk04IoN`006goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/03gmk00=oo`00
Ool06Woo00=oN`00Og/0Agmk00<007ooOol07goo00@007mkOg/002moo`03001oNgmk04IoN`006goo
00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06Woo00=oN`00Og/0AWmk
00=oo`00Ool07goo00@007mkOg/002moo`03001oNgmk04IoN`0077oo00<007mkOg/01Gmk00<007oo
Ool017oo00<007mkOg/047mk00<007ooOol06Goo00=oN`00Og/0Agmk00<007ooOol07Woo00@007mk
Og/002moo`03001oNgmk04IoN`0077oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk
00<007ooOol06Woo00<007mkOg/0AWmk00<007ooOol07Woo00AoN`00Og/0031oo`03001oNgmk04Eo
N`007Goo00<007mkOg/01Gmk00<007ooOol017oo00=oN`00Og/047mk00<007ooOol06Goo00=oN`00
Og/0AWmk00=oo`00Ool07goo00@007mkOg/002moo`03001oNgmk04EoN`007Woo00<007mkOg/017mk
00<007ooOol01Goo00<007mkOg/03gmk00=oo`00Ool06Woo00<007mkOg/0AWmk00<007ooOol07Woo
00@007mkOg/002moo`03001oNgmk04EoN`007Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mk
Og/03gmk00<007ooOol06Goo00=oN`00Og/0AWmk00<007ooOol07Woo00@007mkOg/0031oo`03001o
Ngmk04AoN`007goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/047mk00<007ooOol06Goo
00<007mkOg/0AGmk00=oo`00Ool07Woo00@007mkOg/0031oo`03001oNgmk04AoN`007goo00<007mk
Og/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06Goo00=oN`00Og/0AWmk00<007oo
Ool07Goo00AoN`00Og/0031oo`03001oNgmk04AoN`0087oo00<007mkOg/01Gmk00<007ooOol017oo
00<007mkOg/047mk00<007ooOol06Goo00<007mkOg/0AGmk00<007ooOol07Goo00EoN`00Og]oN`00
02moo`03001oNgmk04AoN`008Goo00<007mkOg/017mk00<007ooOol01Goo00<007mkOg/03gmk00=o
o`00Ool06Goo00=oN`00Og/0AWmk00<007ooOol07Goo00@007mkOg/0031oo`03001oNgmk04=oN`00
8Goo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol06Goo00<007mkOg/0
AGmk00<007ooOol07Goo00@007mkOg/0031oo`03001oNgmk04=oN`008Woo00<007mkOg/017mk00<0
07ooOol01Goo00<007mkOg/047mk00<007ooOol067oo00=oN`00Og/0AGmk00<007ooOol07Goo00@0
07mkOg/0031oo`03001oNgmk04=oN`008Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/0
3gmk00<007ooOol06Goo00<007mkOg/0AGmk00<007ooOol077oo00AoN`00Og/0035oo`03001oNgmk
049oN`008goo00<007mkOg/017mk00=oo`00Ool01Goo00<007mkOg/047mk00<007ooOol067oo00=o
N`00Og/0AGmk00<007ooOol077oo00EoN`00Og]oN`00031oo`03001oNgmk049oN`008goo00<007mk
Og/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00=oo`00Ool067oo00=oN`00Og/0AGmk00<007oo
Ool07Goo00@007mkOg/0031oo`03001oNgmk049oN`0097oo00<007mkOg/01Gmk00<007ooOol01Goo
00<007mkOg/03gmk00<007ooOol067oo00<007mkOg/0AGmk00<007ooOol077oo00@007mkOg/0031o
o`03001oNgmk049oN`009Goo00<007mkOg/017mk00<007ooOol01Goo00<007mkOg/047mk00<007oo
Ool05goo00=oN`00Og/0AGmk00<007ooOol077oo00@007mkOg/0035oo`03001oNgmk045oN`009Goo
00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00<007ooOol067oo00<007mkOg/0A7mk
00<007ooOol077oo00@007mkOg/0035oo`03001oNgmk045oN`009Woo00<007mkOg/017mk00<007oo
Ool01Goo00<007mkOg/047mk00<007ooOol05goo00=oN`00Og/0AGmk00<007ooOol06goo00AoN`00
Og/0035oo`03001oNgmk045oN`009Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/03gmk
00=oo`00Ool067oo00<007mkOg/0A7mk00<007ooOol077oo00@007mkOg/0031oo`03001oNgmk045o
N`009goo00<007mkOg/017mk00=oo`00Ool01Woo00<007mkOg/03gmk00<007ooOol05goo00=oN`00
Og/0A7mk00<007ooOol077oo00@007mkOg/0035oo`03001oNgmk041oN`009goo00<007mkOg/01Gmk
00<007ooOol01Goo00<007mkOg/047mk00<007ooOol05goo00<007mkOg/0A7mk00<007ooOol06goo
00@007mkOg/0035oo`03001oNgmk041oN`00:7oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mk
Og/03gmk00<007ooOol05goo00=oN`00Og/0A7mk00<007ooOol06goo00@007mkOg/0035oo`03001o
Ngmk041oN`00:Goo00<007mkOg/017mk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol05goo
00<007mkOg/0@gmk00=oo`00Ool06goo00AoN`00Og/0039oo`03001oNgmk03moN`00:Goo00<007mk
Og/01Gmk00<007ooOol01Goo00<007mkOg/03gmk00=oo`00Ool05goo00=oN`00Og/0A7mk00<007oo
Ool06Woo00EoN`00Og]oN`00035oo`03001oNgmk03moN`00:Woo00<007mkOg/017mk00<007ooOol0
1Goo00<007mkOg/047mk00<007ooOol05goo00<007mkOg/0@gmk00<007ooOol06goo00@007mkOg/0
035oo`03001oNgmk03moN`00:Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/047mk00<0
07ooOol05Woo00=oN`00Og/0@gmk00=oo`00Ool06goo00@007mkOg/0035oo`03001oNgmk03moN`00
:goo00<007mkOg/017mk00=oo`00Ool01Woo00<007mkOg/03gmk00<007ooOol05goo00<007mkOg/0
@gmk00<007ooOol06Woo00@007mkOg/0039oo`03001oNgmk03ioN`00;7oo00<007mkOg/017mk00<0
07ooOol01Goo00<007mkOg/047mk00<007ooOol05Woo00=oN`00Og/0@gmk00<007ooOol06Woo00Ao
N`00Og/0039oo`03001oNgmk03ioN`00;7oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/0
3gmk00=oo`00Ool05Woo00=oN`00Og/0@gmk00=oo`00Ool06Woo00AoN`00Og/0039oo`03001oNgmk
03ioN`00;Goo00<007mkOg/017mk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol05Woo00<0
07mkOg/0@gmk00<007ooOol06Woo00@007mkOg/0035oo`03001oNgmk03ioN`00;Goo00<007mkOg/0
1Gmk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol05Goo00=oN`00Og/0@gmk00<007ooOol0
6Woo00@007mkOg/0039oo`03001oNgmk03eoN`00;Woo00<007mkOg/017mk00<007ooOol01Woo00<0
07mkOg/03gmk00<007ooOol05Woo00<007mkOg/0@Wmk00=oo`00Ool06Woo00@007mkOg/0039oo`03
001oNgmk03eoN`00;Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol0
5Goo00=oN`00Og/0@gmk00<007ooOol06Goo00@007mkOg/0039oo`03001oNgmk03eoN`00;goo00<0
07mkOg/017mk00=oo`00Ool01Woo00<007mkOg/03gmk00=oo`00Ool05Woo00<007mkOg/0@Wmk00<0
07ooOol06Goo00AoN`00Og/003=oo`03001oNgmk03aoN`00<7oo00<007mkOg/017mk00<007ooOol0
1Goo00<007mkOg/047mk00<007ooOol05Goo00=oN`00Og/0@gmk00<007ooOol06Goo00@007mkOg/0
039oo`03001oNgmk03aoN`00<7oo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/047mk00<0
07ooOol05Goo00<007mkOg/0@Wmk00<007ooOol06Goo00@007mkOg/0039oo`03001oNgmk03aoN`00
<Goo00<007mkOg/017mk00<007ooOol01Woo00<007mkOg/03gmk00<007ooOol05Goo00=oN`00Og/0
@Wmk00<007ooOol06Goo00@007mkOg/0039oo`03001oNgmk03aoN`00<Goo00<007mkOg/01Gmk00<0
07ooOol01Goo00<007mkOg/047mk00<007ooOol05Goo00<007mkOg/0@Wmk00<007ooOol067oo00@0
07mkOg/003=oo`03001oNgmk03]oN`00<Woo00<007mkOg/017mk00<007ooOol01Woo00<007mkOg/0
3gmk00=oo`00Ool05Goo00=oN`00Og/0@Wmk00<007ooOol067oo00AoN`00Og/003=oo`03001oNgmk
03]oN`00<Woo00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol05Goo00<0
07mkOg/0@Gmk00<007ooOol06Goo00<007mk0000<goo00<007mkOg/0>gmk000cOol00`00Og]oN`04
Og/00goo001oo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0DOol00gmk001oN`12Og/00`00Oomoo`0H
Ool01000Og]oN`00<Woo00<007mkOg/0>gmk000dOol00`00Og]oN`04Og/00`00Oomoo`05Ool00gmk
001oN`0@Og/00`00Oomoo`0DOol00gmk001oN`12Og/00`00Oomoo`0HOol01000Og]oN`00<goo00<0
07mkOg/0>Wmk000dOol00`00Og]oN`05Og/00`00Oomoo`05Ool00`00Og]oN`0@Og/00`00Oomoo`0D
Ool00`00Og]oN`11Og/00`00Oomoo`0HOol01000Og]oN`00<goo00<007mkOg/0>Wmk000eOol00`00
Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0?Og/00goo001oo`0DOol00gmk001oN`12Og/00`00
Oomoo`0GOol01000Og]oN`00<goo00<007mkOg/0>Wmk000eOol00`00Og]oN`05Og/00`00Oomoo`05
Ool00`00Og]oN`0@Og/00`00Oomoo`0DOol00`00Og]oN`11Og/00`00Oomoo`0GOol017mk001oN`00
=7oo00<007mkOg/0>Gmk000fOol00`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00
Oomoo`0COol00gmk001oN`11Og/00`00Oomoo`0HOol01000Og]oN`00<goo00<007mkOg/0>Gmk000f
Ool00`00Og]oN`05Og/00`00Oomoo`05Ool00`00Og]oN`0@Og/00`00Oomoo`0DOol00`00Og]oN`11
Og/00`00Oomoo`0GOol01000Og]oN`00<goo00<007mkOg/0>Gmk000gOol00`00Og]oN`04Og/00goo
001oo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0COol00gmk001oN`11Og/00`00Oomoo`0GOol01000
Og]oN`00<goo00<007mkOg/0>Gmk000hOol00`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0?
Og/00goo001oo`0DOol00`00Og]oN`10Og/00goo001oo`0GOol01000Og]oN`00=7oo00<007mkOg/0
>7mk000hOol00`00Og]oN`05Og/00`00Oomoo`05Ool00`00Og]oN`0@Og/00`00Oomoo`0COol00gmk
001oN`11Og/00`00Oomoo`0FOol017mk001oN`00=7oo00<007mkOg/0>7mk000iOol00`00Og]oN`04
Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0COol00`00Og]oN`10Og/00`00Oomoo`0G
Ool00`00Og/0000dOol00`00Og]oN`0hOg/003Uoo`03001oNgmk00EoN`03001oogoo00Eoo`03001o
Ngmk011oN`03001oogoo01=oo`03Og/007mk041oN`03Ool007oo01Moo`04001oNgmk000dOol00`00
Og]oN`0gOg/003Yoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk011oN`03001oogoo01=o
o`03001oNgmk041oN`03001oogoo01Ioo`04001oNgmk000dOol00`00Og]oN`0gOg/003]oo`03001o
Ngmk00AoN`03001oogoo00Ioo`03001oNgmk00moN`03Ool007oo01=oo`03Og/007mk041oN`03001o
ogoo01Ioo`04001oNgmk000dOol00`00Og]oN`0gOg/003]oo`03001oNgmk00AoN`03Ool007oo00Io
o`03001oNgmk011oN`03001oogoo01=oo`03001oNgmk03moN`03Ool007oo01Ioo`04Og/007mk000d
Ool00`00Og]oN`0gOg/003aoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk011oN`03001o
ogoo019oo`03001oNgmk041oN`03001oogoo01Ioo`03001oN`0003Eoo`03001oNgmk03IoN`00?7oo
00<007mkOg/01Gmk00<007ooOol01Goo00<007mkOg/047mk00<007ooOol04Woo00=oN`00Og/0@7mk
00<007ooOol05Woo00@007mkOg/003Aoo`03001oNgmk03IoN`00?Goo00<007mkOg/017mk00<007oo
Ool01Woo00<007mkOg/047mk00<007ooOol04Woo00<007mkOg/0?gmk00=oo`00Ool05Woo00@007mk
Og/003Aoo`03001oNgmk03IoN`00?Goo00<007mkOg/01Gmk00<007ooOol01Woo00<007mkOg/047mk
00<007ooOol04Goo00=oN`00Og/0@7mk00<007ooOol05Goo00@007mkOg/003Aoo`03001oNgmk03Io
N`00?Woo00<007mkOg/017mk00<007ooOol01Woo00<007mkOg/047mk00<007ooOol04Woo00<007mk
Og/0?gmk00<007ooOol05Goo00@007mkOg/003Eoo`03001oNgmk03EoN`00?goo00<007mkOg/017mk
00<007ooOol01Woo00<007mkOg/047mk00<007ooOol04Goo00=oN`00Og/0@7mk00<007ooOol057oo
00AoN`00Og/003Eoo`03001oNgmk03EoN`00?goo00<007mkOg/017mk00=oo`00Ool01Woo00<007mk
Og/047mk00<007ooOol04Woo00<007mkOg/0?gmk00<007ooOol05Goo00<007mk0000=Goo00<007mk
Og/0=Gmk0010Ool00`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0AOol0
0gmk001oN`0oOg/00`00Oomoo`0EOol01000Og]oN`00=Goo00<007mkOg/0=7mk0010Ool00`00Og]o
N`05Og/00`00Oomoo`05Ool00`00Og]oN`0AOg/00`00Oomoo`0AOol00`00Og]oN`0oOg/00`00Oomo
o`0DOol01000Og]oN`00=Goo00<007mkOg/0=7mk0011Ool00`00Og]oN`04Og/00`00Oomoo`06Ool0
0`00Og]oN`0@Og/00`00Oomoo`0AOol00gmk001oN`0oOg/00`00Oomoo`0DOol01000Og]oN`00=Goo
00<007mkOg/0=7mk0011Ool00`00Og]oN`05Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomo
o`0AOol00`00Og]oN`0nOg/00`00Oomoo`0DOol017mk001oN`00=Goo00<007mkOg/0=7mk0012Ool0
0`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0AOol00gmk001oN`0oOg/0
0`00Oomoo`0DOol00`00Og/0000fOol00`00Og]oN`0cOg/004=oo`03001oNgmk00AoN`03001oogoo
00Ioo`03001oNgmk011oN`03001oogoo015oo`03001oNgmk03ioN`03001oogoo01Aoo`04001oNgmk
000eOol00`00Og]oN`0cOg/004=oo`03001oNgmk00AoN`03Ool007oo00Ioo`03001oNgmk015oN`03
001oogoo011oo`03Og/007mk03ioN`03001oogoo01Aoo`04001oNgmk000eOol00`00Og]oN`0cOg/0
04Aoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk011oN`03001oogoo015oo`03001oNgmk
03ioN`03001oogoo01=oo`04001oNgmk000eOol00`00Og]oN`0cOg/004Aoo`03001oNgmk00EoN`03
001oogoo00Ioo`03001oNgmk011oN`03001oogoo011oo`03001oNgmk03ioN`03001oogoo01=oo`04
Og/007mk000fOol00`00Og]oN`0bOg/004Eoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk
011oN`03001oogoo011oo`03Og/007mk03ioN`03001oogoo01Aoo`03001oN`0003Ioo`03001oNgmk
039oN`00AGoo00<007mkOg/01Gmk00<007ooOol01Woo00<007mkOg/047mk00<007ooOol047oo00<0
07mkOg/0?Wmk00<007ooOol04goo00<007mk0000=Woo00<007mkOg/0<Wmk0016Ool00`00Og]oN`04
Og/00`00Oomoo`06Ool00`00Og]oN`0AOg/00`00Oomoo`0?Ool00gmk001oN`0nOg/00`00Oomoo`0C
Ool01000Og]oN`00=Woo00<007mkOg/0<Gmk0017Ool00`00Og]oN`04Og/00`00Oomoo`06Ool00`00
Og]oN`0@Og/00`00Oomoo`0@Ool00`00Og]oN`0mOg/00`00Oomoo`0COol01000Og]oN`00=Woo00<0
07mkOg/0<Gmk0017Ool00`00Og]oN`04Og/00goo001oo`07Ool00`00Og]oN`0@Og/00`00Oomoo`0?
Ool00gmk001oN`0nOg/00`00Oomoo`0BOol01000Og]oN`00=Woo00<007mkOg/0<Gmk0018Ool00`00
Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0@Ool00`00Og]oN`0mOg/00`00
Oomoo`0BOol017mk001oN`00=Woo00<007mkOg/0<Gmk0018Ool00`00Og]oN`04Og/00goo001oo`07
Ool00`00Og]oN`0@Og/00`00Oomoo`0?Ool00gmk001oN`0mOg/00goo001oo`0COol00`00Og/0000g
Ool00`00Og]oN`0`Og/004Uoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk015oN`03001o
ogoo00moo`03001oNgmk03eoN`03001oogoo019oo`04001oNgmk000fOol00`00Og]oN`0`Og/004Yo
o`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk011oN`03001oogoo00moo`03Og/007mk03eo
N`03001oogoo019oo`04001oNgmk000fOol00`00Og]oN`0`Og/004Yoo`03001oNgmk00AoN`03001o
ogoo00Ioo`03001oNgmk015oN`03001oogoo00moo`03001oNgmk03aoN`03Ool007oo019oo`04001o
Ngmk000fOol00`00Og]oN`0`Og/004]oo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk011o
N`03001oogoo00moo`03Og/007mk03eoN`03001oogoo015oo`04Og/007mk000gOol00`00Og]oN`0_
Og/004]oo`03001oNgmk00AoN`03Ool007oo00Moo`03001oNgmk011oN`03001oogoo00moo`03001o
Ngmk03aoN`03001oogoo019oo`03001oN`0003Moo`03001oNgmk02moN`00C7oo00<007mkOg/017mk
00<007ooOol01Woo00<007mkOg/04Gmk00<007ooOol03Woo00<007mkOg/0?Gmk00<007ooOol04Goo
00<007mk0000=goo00<007mkOg/0;gmk001<Ool00`00Og]oN`04Og/00goo001oo`07Ool00`00Og]o
N`0@Og/00`00Oomoo`0?Ool00`00Og]oN`0lOg/00`00Oomoo`0AOol01000Og]oN`00=goo00<007mk
Og/0;Wmk001=Ool00`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0AOg/00`00Oomoo`0>Ool0
0`00Og]oN`0lOg/00`00Oomoo`0AOol01000Og]oN`00=goo00<007mkOg/0;Wmk001>Ool00`00Og]o
N`04Og/00`00Oomoo`06Ool00`00Og]oN`0@Og/00`00Oomoo`0>Ool00gmk001oN`0mOg/00`00Oomo
o`0@Ool017mk001oN`00=goo00<007mkOg/0;Wmk001>Ool00`00Og]oN`04Og/00`00Oomoo`07Ool0
0`00Og]oN`0@Og/00`00Oomoo`0>Ool00`00Og]oN`0lOg/00`00Oomoo`0AOol00`00Og/0000gOol0
0`00Og]oN`0^Og/004moo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk015oN`03001oogoo
00eoo`03Og/007mk03aoN`03001oogoo015oo`03001oN`0003Qoo`03001oNgmk02eoN`00Cgoo00<0
07mkOg/017mk00=oo`00Ool01goo00<007mkOg/047mk00<007ooOol03Woo00<007mkOg/0?7mk00<0
07ooOol047oo00@007mkOg/003Moo`03001oNgmk02eoN`00D7oo00<007mkOg/017mk00<007ooOol0
1Woo00<007mkOg/04Gmk00<007ooOol03Goo00=oN`00Og/0?7mk00<007ooOol047oo00@007mkOg/0
03Moo`03001oNgmk02eoN`00D7oo00<007mkOg/017mk00=oo`00Ool01goo00<007mkOg/047mk00=o
o`00Ool03Woo00<007mkOg/0>gmk00<007ooOol047oo00@007mkOg/003Qoo`03001oNgmk02aoN`00
DGoo00<007mkOg/017mk00<007ooOol01goo00<007mkOg/047mk00<007ooOol03Goo00=oN`00Og/0
?7mk00<007ooOol03goo00AoN`00Og/003Qoo`03001oNgmk02aoN`00DWoo00<007mkOg/017mk00<0
07ooOol01Woo00<007mkOg/04Gmk00<007ooOol03Goo00<007mkOg/0>gmk00<007ooOol047oo00<0
07mk0000>7oo00<007mkOg/0;7mk001BOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0@
Og/00`00Oomoo`0=Ool00gmk001oN`0kOg/00`00Oomoo`0@Ool01000Og]oN`00=goo00<007mkOg/0
;7mk001COol00`00Og]oN`04Og/00`00Oomoo`06Ool00`00Og]oN`0AOg/00`00Oomoo`0=Ool00`00
Og]oN`0kOg/00`00Oomoo`0?Ool01000Og]oN`00>7oo00<007mkOg/0:gmk001COol00`00Og]oN`04
Og/00goo001oo`07Ool00`00Og]oN`0@Og/00goo001oo`0=Ool00`00Og]oN`0kOg/00`00Oomoo`0?
Ool01000Og]oN`00>7oo00<007mkOg/0:gmk001DOol00`00Og]oN`04Og/00`00Oomoo`06Ool00gmk
001oN`0AOg/00`00Oomoo`0=Ool00`00Og]oN`0jOg/00`00Oomoo`0?Ool017mk001oN`00>7oo00<0
07mkOg/0:gmk001DOol00`00Og]oN`04Og/00goo001oo`07Ool00`00Og]oN`0AOg/00`00Oomoo`0<
Ool00`00Og]oN`0kOg/00`00Oomoo`0?Ool00`00Og/0000hOol00`00Og]oN`0[Og/005Eoo`03001o
Ngmk00AoN`03001oogoo00Moo`03001oNgmk011oN`03001oogoo00eoo`03001oNgmk03YoN`03001o
ogoo00moo`03001oN`0003Uoo`03001oNgmk02YoN`00EWoo00<007mkOg/017mk00<007ooOol01Woo
00<007mkOg/04Gmk00<007ooOol037oo00<007mkOg/0>Wmk00<007ooOol03goo00@007mkOg/003Qo
o`03001oNgmk02YoN`00EWoo00<007mkOg/017mk00<007ooOol01goo00<007mkOg/047mk00=oo`00
Ool037oo00=oN`00Og/0>gmk00<007ooOol03Woo00@007mkOg/003Qoo`03001oNgmk02YoN`00Egoo
00<007mkOg/017mk00<007ooOol01Woo00<007mkOg/04Gmk00<007ooOol037oo00<007mkOg/0>Wmk
00<007ooOol03Woo00AoN`00Og/003Uoo`03001oNgmk02UoN`00Egoo00<007mkOg/017mk00=oo`00
Ool01goo00<007mkOg/04Gmk00<007ooOol02goo00=oN`00Og/0>Wmk00=oo`00Ool03goo00<007mk
0000>Goo00<007mkOg/0:Gmk001HOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0@Og/0
0`00Oomoo`0<Ool00`00Og]oN`0jOg/00`00Oomoo`0>Ool00`00Og/0000iOol00`00Og]oN`0YOg/0
05Uoo`03001oNgmk00=oN`03Ool007oo00Moo`03001oNgmk015oN`03001oogoo00]oo`03Og/007mk
03YoN`03001oogoo00ioo`04001oNgmk000hOol00`00Og]oN`0YOg/005Uoo`03001oNgmk00AoN`03
001oogoo00Moo`03001oNgmk011oN`03Ool007oo00aoo`03001oNgmk03UoN`03Ool007oo00ioo`04
001oNgmk000iOol00`00Og]oN`0XOg/005Yoo`03001oNgmk00AoN`03001oogoo00Ioo`03001oNgmk
015oN`03001oogoo00]oo`03Og/007mk03YoN`03001oogoo00eoo`04001oNgmk000iOol00`00Og]o
N`0XOg/005Yoo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk015oN`03001oogoo00]oo`03
001oNgmk03UoN`03001oogoo00ioo`03001oN`0003Uoo`03001oNgmk02QoN`00Fgoo00<007mkOg/0
17mk00<007ooOol01goo00<007mkOg/047mk00<007ooOol02goo00=oN`00Og/0>Wmk00<007ooOol0
3Goo00<007mk0000>Goo00<007mkOg/0:7mk001KOol00`00Og]oN`04Og/00goo001oo`07Ool00`00
Og]oN`0AOg/00`00Oomoo`0;Ool00`00Og]oN`0iOg/00`00Oomoo`0=Ool00`00Og/0000jOol00`00
Og]oN`0WOg/005aoo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk011oN`03Ool007oo00]o
o`03001oNgmk03UoN`03001oogoo00eoo`04001oNgmk000iOol00`00Og]oN`0WOg/005eoo`03001o
Ngmk00=oN`03Ool007oo00Moo`03001oNgmk015oN`03001oogoo00]oo`03001oNgmk03UoN`03001o
ogoo00aoo`04001oNgmk000iOol00`00Og]oN`0WOg/005eoo`03001oNgmk00AoN`03001oogoo00Mo
o`03001oNgmk015oN`03001oogoo00Yoo`03001oNgmk03UoN`03001oogoo00aoo`04Og/007mk000j
Ool00`00Og]oN`0VOg/005ioo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk011oN`03001o
ogoo00]oo`03001oNgmk03QoN`03001oogoo00eoo`03001oN`0003Yoo`03001oNgmk02IoN`00GWoo
00<007mkOg/017mk00<007ooOol01goo00<007mkOg/04Gmk00<007ooOol02Woo00<007mkOg/0>Gmk
00<007ooOol037oo00<007mk0000>Woo00<007mkOg/09Wmk001OOol00`00Og]oN`04Og/00`00Oomo
o`07Ool00`00Og]oN`0@Og/00goo001oo`0:Ool00gmk001oN`0iOg/00`00Oomoo`0<Ool01000Og]o
N`00>Goo00<007mkOg/09Wmk001OOol00`00Og]oN`04Og/00goo001oo`07Ool00`00Og]oN`0AOg/0
0`00Oomoo`0:Ool00`00Og]oN`0hOg/00`00Oomoo`0<Ool01000Og]oN`00>Woo00<007mkOg/09Gmk
001POol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomoo`09Ool00gmk001o
N`0iOg/00`00Oomoo`0;Ool017mk001oN`00>Woo00<007mkOg/09Gmk001QOol00`00Og]oN`03Og/0
0goo001oo`07Ool00`00Og]oN`0AOg/00`00Oomoo`0:Ool00`00Og]oN`0hOg/00`00Oomoo`0<Ool0
0`00Og/0000jOol00`00Og]oN`0UOg/0065oo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk
015oN`03001oogoo00Uoo`03Og/007mk03QoN`03001oogoo00aoo`03001oN`0003Yoo`03001oNgmk
02EoN`00HWoo00<007mkOg/017mk00<007ooOol01goo00<007mkOg/047mk00=oo`00Ool02Woo00<0
07mkOg/0>7mk00<007ooOol02goo00<007mk0000>goo00<007mkOg/097mk001ROol00`00Og]oN`04
Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomoo`09Ool00gmk001oN`0hOg/00`00Oomoo`0;
Ool01000Og]oN`00>Woo00<007mkOg/097mk001SOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00
Og]oN`0AOg/00`00Oomoo`09Ool00`00Og]oN`0gOg/00`00Oomoo`0;Ool01000Og]oN`00>Woo00<0
07mkOg/097mk001SOol00`00Og]oN`04Og/00goo001oo`07Ool00`00Og]oN`0AOg/00`00Oomoo`09
Ool00`00Og]oN`0hOg/00`00Oomoo`0;Ool00`00Og/0000kOol00`00Og]oN`0SOg/006Aoo`03001o
Ngmk00AoN`03001oogoo00Moo`03001oNgmk015oN`03001oogoo00Uoo`03001oNgmk03MoN`03001o
ogoo00]oo`03001oN`0003]oo`03001oNgmk02=oN`00IGoo00<007mkOg/00gmk00=oo`00Ool027oo
00<007mkOg/047mk00=oo`00Ool02Goo00<007mkOg/0=gmk00<007ooOol02goo00<007mk0000>goo
00<007mkOg/08gmk001UOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomo
o`09Ool00`00Og]oN`0gOg/00`00Oomoo`0:Ool01000Og]oN`00>Woo00<007mkOg/08gmk001VOol0
0`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomoo`08Ool00`00Og]oN`0gOg/0
0`00Oomoo`0:Ool01000Og]oN`00>goo00<007mkOg/08Wmk001VOol00`00Og]oN`04Og/00`00Oomo
o`07Ool00`00Og]oN`0AOg/00`00Oomoo`09Ool00`00Og]oN`0fOg/00`00Oomoo`0:Ool017mk001o
N`00>goo00<007mkOg/08Wmk001WOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/0
0`00Oomoo`08Ool00`00Og]oN`0gOg/00`00Oomoo`0:Ool00`00Og/0000kOol00`00Og]oN`0ROg/0
06Qoo`03001oNgmk00=oN`03Ool007oo00Qoo`03001oNgmk011oN`03Ool007oo00Qoo`03Og/007mk
03MoN`03001oogoo00Yoo`03001oN`0003]oo`03001oNgmk029oN`00J7oo00<007mkOg/017mk00<0
07ooOol01goo00<007mkOg/04Gmk00<007ooOol027oo00<007mkOg/0=Wmk00=oo`00Ool02Woo00<0
07mk0000?7oo00<007mkOg/08Gmk001YOol00`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0A
Og/00`00Oomoo`07Ool00gmk001oN`0gOg/00`00Oomoo`09Ool01000Og]oN`00>goo00<007mkOg/0
8Gmk001YOol00`00Og]oN`04Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomoo`08Ool00`00
Og]oN`0fOg/00`00Oomoo`09Ool017mk001oN`00>goo00<007mkOg/08Gmk001ZOol00`00Og]oN`04
Og/00`00Oomoo`07Ool00`00Og]oN`0AOg/00`00Oomoo`07Ool00gmk001oN`0gOg/00`00Oomoo`09
Ool00`00Og/0000lOol00`00Og]oN`0POg/006Yoo`03001oNgmk00AoN`03001oogoo00Moo`03001o
Ngmk019oN`03001oogoo00Moo`03001oNgmk03IoN`03001oogoo00Uoo`03001oN`0003aoo`03001o
Ngmk021oN`00Jgoo00<007mkOg/017mk00<007ooOol01goo00<007mkOg/04Gmk00<007ooOol01goo
00<007mkOg/0=Wmk00<007ooOol02Goo00<007mk0000?7oo00<007mkOg/087mk001/Ool00`00Og]o
N`03Og/00goo001oo`08Ool00`00Og]oN`0AOg/00`00Oomoo`07Ool00`00Og]oN`0fOg/00`00Oomo
o`08Ool01000Og]oN`00>goo00<007mkOg/087mk001/Ool00`00Og]oN`04Og/00`00Oomoo`07Ool0
0`00Og]oN`0AOg/00`00Oomoo`07Ool00`00Og]oN`0fOg/00`00Oomoo`08Ool01000Og]oN`00?7oo
00<007mkOg/07gmk001]Ool00`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0AOg/00`00Oomo
o`07Ool00`00Og]oN`0eOg/00`00Oomoo`09Ool00`00Og/0000lOol00`00Og]oN`0OOg/006eoo`03
001oNgmk00AoN`03001oogoo00Moo`03001oNgmk019oN`03001oogoo00Ioo`03001oNgmk03IoN`03
001oogoo00Qoo`03001oN`0003aoo`03001oNgmk01moN`00KWoo00<007mkOg/017mk00<007ooOol0
1goo00<007mkOg/04Gmk00<007ooOol01goo00<007mkOg/0=Gmk00<007ooOol027oo00<007mk0000
?Goo00<007mkOg/07Wmk001^Ool00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0AOg/00`00
Oomoo`06Ool00`00Og]oN`0eOg/00`00Oomoo`08Ool00`00Og/0000mOol00`00Og]oN`0NOg/006mo
o`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk015oN`03001oogoo00Moo`03001oNgmk03Eo
N`03001oogoo00Moo`04001oNgmk000lOol00`00Og]oN`0NOg/0071oo`03001oNgmk00=oN`03Ool0
07oo00Qoo`03001oNgmk015oN`03001oogoo00Ioo`03001oNgmk03EoN`03001oogoo00Moo`04Og/0
07mk000lOol00`00Og]oN`0NOg/0071oo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk019o
N`03001oogoo00Eoo`03Og/007mk03EoN`03001oogoo00Qoo`03001oN`0003eoo`03001oNgmk01eo
N`00LGoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/04Gmk00<007ooOol01Woo00<007mk
Og/0=Gmk00<007ooOol01goo00<007mk0000?Goo00<007mkOg/07Gmk001aOol00`00Og]oN`04Og/0
0`00Oomoo`08Ool00`00Og]oN`0AOg/00`00Oomoo`05Ool00gmk001oN`0eOg/00`00Oomoo`07Ool0
0`00Og/0000mOol00`00Og]oN`0MOg/0079oo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk
015oN`03001oogoo00Ioo`03001oNgmk03AoN`03001oogoo00Moo`04001oNgmk000lOol00`00Og]o
N`0MOg/007=oo`03001oNgmk00=oN`03Ool007oo00Qoo`03001oNgmk015oN`03001oogoo00Eoo`03
Og/007mk03EoN`03001oogoo00Ioo`04Og/007mk000mOol00`00Og]oN`0LOg/007=oo`03001oNgmk
00AoN`03001oogoo00Moo`03001oNgmk019oN`03001oogoo00Eoo`03001oNgmk03AoN`03001oogoo
00Moo`03001oN`0003eoo`03001oNgmk01aoN`00M7oo00<007mkOg/00gmk00=oo`00Ool027oo00<0
07mkOg/04Gmk00<007ooOol01Goo00<007mkOg/0=7mk00<007ooOol01goo00<007mk0000?Goo00<0
07mkOg/077mk001dOol00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0AOg/00`00Oomoo`05
Ool00`00Og]oN`0dOg/00`00Oomoo`06Ool00`00Og/0000nOol00`00Og]oN`0KOg/007Eoo`03001o
Ngmk00=oN`03Ool007oo00Qoo`03001oNgmk015oN`03001oogoo00Eoo`03001oNgmk03AoN`03001o
ogoo00Ioo`03001oN`0003ioo`03001oNgmk01]oN`00MGoo00<007mkOg/017mk00<007ooOol027oo
00<007mkOg/04Gmk00<007ooOol01Goo00<007mkOg/0<gmk00<007ooOol01Woo00@007mkOg/003eo
o`03001oNgmk01]oN`00MWoo00<007mkOg/017mk00<007ooOol01goo00<007mkOg/04Wmk00<007oo
Ool017oo00<007mkOg/0=7mk00<007ooOol01Woo00<007mk0000?Goo00<007mkOg/06gmk001gOol0
0`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0AOg/00`00Oomoo`05Ool00`00Og]oN`0cOg/0
0`00Oomoo`06Ool00`00Og/0000nOol00`00Og]oN`0JOg/007Moo`03001oNgmk00AoN`03001oogoo
00Moo`03001oNgmk019oN`03001oogoo00Aoo`03001oNgmk03=oN`03Ool007oo00Ioo`03001oN`00
03ioo`03001oNgmk01YoN`00N7oo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/04Gmk00<0
07ooOol01Goo00<007mkOg/0<gmk00<007ooOol01Goo00<007mk0000?Woo00<007mkOg/06Wmk001h
Ool00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0AOg/00`00Oomoo`04Ool00`00Og]oN`0c
Og/00`00Oomoo`05Ool01000Og]oN`00?Goo00<007mkOg/06Wmk001iOol00`00Og]oN`03Og/00goo
001oo`08Ool00`00Og]oN`0BOg/00`00Oomoo`03Ool00gmk001oN`0dOg/00`00Oomoo`04Ool017mk
001oN`00?Woo00<007mkOg/06Gmk001iOol00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0A
Og/00`00Oomoo`04Ool00`00Og]oN`0cOg/00`00Oomoo`05Ool00`00Og/0000nOol00`00Og]oN`0I
Og/007Yoo`03001oNgmk00AoN`03001oogoo00Moo`03001oNgmk019oN`03001oogoo00=oo`03Og/0
07mk03=oN`03001oogoo00Eoo`03001oN`0003ioo`03001oNgmk01UoN`00Ngoo00<007mkOg/00gmk
00=oo`00Ool027oo00<007mkOg/04Gmk00<007ooOol017oo00<007mkOg/0<gmk00<007ooOol017oo
00<007mk0000?goo00<007mkOg/067mk001kOol00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]o
N`0AOg/00`00Oomoo`03Ool00`00Og]oN`0cOg/00`00Oomoo`04Ool00`00Og/0000oOol00`00Og]o
N`0HOg/007aoo`03001oNgmk00=oN`03Ool007oo00Qoo`03001oNgmk019oN`03001oogoo00=oo`03
001oNgmk039oN`03001oogoo00Aoo`04001oNgmk000nOol00`00Og]oN`0HOg/007aoo`03001oNgmk
00AoN`03001oogoo00Qoo`03001oNgmk015oN`03001oogoo00=oo`03001oNgmk03=oN`03001oogoo
00Aoo`03001oN`0003ioo`03001oNgmk01QoN`00OGoo00<007mkOg/00gmk00=oo`00Ool027oo00<0
07mkOg/04Wmk00<007ooOol00goo00<007mkOg/0<Wmk00<007ooOol017oo00<007mk0000?goo00<0
07mkOg/05gmk001mOol00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0AOg/00`00Oomoo`03
Ool00`00Og]oN`0bOg/00`00Oomoo`04Ool00`00Og/0000oOol00`00Og]oN`0GOg/007ioo`03001o
Ngmk00AoN`03001oogoo00Qoo`03001oNgmk015oN`03001oogoo00=oo`03001oNgmk039oN`03001o
ogoo00=oo`03001oN`0003moo`03001oNgmk01MoN`00Ogoo00<007mkOg/00gmk00=oo`00Ool027oo
00<007mkOg/04Wmk00<007ooOol00Woo00<007mkOg/0<Wmk00<007ooOol00goo00@007mkOg/003io
o`03001oNgmk01MoN`00Ogoo00<007mkOg/017mk00<007ooOol027oo00<007mkOg/04Gmk00<007oo
Ool00goo00<007mkOg/0<Gmk00<007ooOol017oo00<007mk0000?goo00<007mkOg/05Wmk0020Ool0
0`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0BOg/00`00Oomoo`02Ool00`00Og]oN`0bOg/0
0`00Oomoo`03Ool00`00Og/0000oOol00`00Og]oN`0FOg/0081oo`03001oNgmk00AoN`03001oogoo
00Qoo`03001oNgmk015oN`03001oogoo00=oo`03001oNgmk035oN`03001oogoo00=oo`03001oN`00
03moo`03001oNgmk01IoN`00PGoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/04Wmk00<0
07ooOol00Woo00<007mkOg/0<Gmk00<007ooOol00goo00<007mk0000@7oo00<007mkOg/05Gmk0022
Ool00`00Og]oN`03Og/00`00Oomoo`08Ool00`00Og]oN`0BOg/01P00OomoogooOg/003=oN`03001o
ogoo009oo`04001oNgmk000oOol00`00Og]oN`0EOg/0089oo`03001oNgmk00AoN`03001oogoo00Qo
o`03001oNgmk015oN`03001oogoo009oo`03001oNgmk035oN`03001oogoo00=oo`03001oN`0003mo
o`03001oNgmk01EoN`00Pgoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/04Wmk00D007oo
Oomoo`0003=oN`03001oogoo00=oo`03001oN`0003moo`03001oNgmk01EoN`00Pgoo00<007mkOg/0
17mk00<007ooOol027oo00<007mkOg/04Gmk00<007ooOol00Woo00<007mkOg/0<Gmk00<007ooOol0
0Woo00<007mk0000@7oo00<007mkOg/057mk0024Ool00`00Og]oN`03Og/00goo001oo`08Ool00`00
Og]oN`0BOg/01@00Oomoogoo0000<gmk00<007ooOol00Woo00<007mk0000@7oo00<007mkOg/057mk
0024Ool00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0BOg/01@00Oomoogoo0000<Wmk00<0
07ooOol00Woo00<007mk0000@7oo00<007mkOg/057mk0025Ool00`00Og]oN`03Og/00goo001oo`09
Ool00`00Og]oN`0AOg/01@00Oomoogoo0000<gmk00D007ooOomoo`00009oN`03001oogoo03ioo`03
001oNgmk01=oN`00QWoo00<007mkOg/00gmk00<007ooOol027oo00<007mkOg/04Wmk00D007ooOomo
o`00039oN`03001oogoo009oo`03001oN`00041oo`03001oNgmk01=oN`00QWoo00<007mkOg/017mk
00<007ooOol027oo00<007mkOg/04Gmk00D007ooOomoo`00039oN`03001oogoo009oo`03001oN`00
041oo`03001oNgmk01=oN`00Qgoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/04Wmk00D0
07ooOomoo`00039oN`07001oogooOol007mk0000@7oo00<007mkOg/04gmk0027Ool00`00Og]oN`04
Og/00`00Oomoo`08Ool00`00Og]oN`0BOg/01000Oomoo`00<Wmk00L007ooOomoo`00Og/00011Ool0
0`00Og]oN`0BOg/008Qoo`03001oNgmk00=oN`03Ool007oo00Uoo`03001oNgmk015oN`05001oogoo
Ool0000bOg/01000Oomoo`000Wmk00<007ooOol0?Woo00<007mkOg/04Wmk0028Ool00`00Og]oN`04
Og/00`00Oomoo`08Ool00`00Og]oN`0BOg/01000Oomoo`00<Wmk00L007ooOomoo`00Og/00010Ool0
0`00Og]oN`0BOg/008Uoo`03001oNgmk00=oN`03Ool007oo00Uoo`03001oNgmk015oN`05001oogoo
Ool0000aOg/01`00Oomoogoo001oN`00041oo`03001oNgmk019oN`00RWoo00<007mkOg/00gmk00<0
07ooOol027oo00<007mkOg/04Wmk00@007ooOol0039oN`06001oogoo001oN`00@Goo00<007mkOg/0
4Gmk002:Ool00`00Og]oN`04Og/00`00Oomoo`08Ool00`00Og]oN`0BOg/01000OomoN`00<Gmk00H0
07ooOol007mk0011Ool00`00Og]oN`0AOg/008]oo`03001oNgmk00=oN`03Ool007oo00Uoo`03001o
Ngmk015oN`04001oogoo000aOg/01P00Oomoo`00Og/0045oo`03001oNgmk015oN`00Rgoo00<007mk
Og/017mk00<007ooOol027oo00<007mkOg/04Wmk00<007oo0000<Wmk00H007ooOol007mk0011Ool0
0`00Og]oN`0@Og/008aoo`03001oNgmk00=oN`03Ool007oo00Uoo`03001oNgmk015oN`04001oogoo
000aOg/01P00Oomoo`00Og/0045oo`03001oNgmk011oN`00S7oo00<007mkOg/017mk00<007ooOol0
27oo00<007mkOg/04Wmk00<007oo0000<Gmk00H007ooOol007mk0011Ool00`00Og]oN`0@Og/008eo
o`03001oNgmk00=oN`03Ool007oo00Uoo`03001oNgmk019oN`03001oo`00035oN`05001oo`00Og/0
0011Ool00`00Og]oN`0@Og/008ioo`03001oNgmk00=oN`03001oogoo00Qoo`03001oNgmk019oN`03
001oo`00035oN`05001oo`00Og/00012Ool00`00Og]oN`0?Og/008ioo`03001oNgmk00AoN`03001o
ogoo00Qoo`03001oNgmk019oN`03001oo`00031oN`03001oo`00009oN`03001oogoo03moo`03001o
Ngmk00moN`00Sgoo00<007mkOg/00gmk00=oo`00Ool02Goo00<007mkOg/04Gmk00<007oo0000<Gmk
00D007oo001oN`00045oo`03001oNgmk00moN`00Sgoo00<007mkOg/017mk00<007ooOol027oo00<0
07mkOg/04Wmk00<007oo0000<7mk00D007oo001oN`00045oo`03001oNgmk00moN`00T7oo00<007mk
Og/00gmk00=oo`00Ool02Goo00<007mkOg/04Wmk0P00<7mk00D007oo001oN`00049oo`03001oNgmk
00ioN`00TGoo00<007mkOg/00gmk00<007ooOol027oo00<007mkOg/04Wmk00<007oo0000<7mk0P00
00=oN`00Ool0@Goo00<007mkOg/03Wmk002AOol00`00Og]oN`03Og/00goo001oo`09Ool00`00Og]o
N`0BOg/2000`Og/200000gmk001oo`11Ool00`00Og]oN`0>Og/0099oo`03001oNgmk00=oN`03001o
ogoo00Uoo`03001oNgmk015oN`03001oo`0002moN`05001oo`00Og/00012Ool00`00Og]oN`0=Og/0
099oo`03001oNgmk00AoN`03001oogoo00Qoo`03001oNgmk019oN`80031oN`800003Og/007oo045o
o`03001oNgmk00eoN`00Tgoo00<007mkOg/00gmk00=oo`00Ool02Goo00<007mkOg/04Wmk00<007mk
Og/0;Wmk0P0000=oN`00Ool0@Goo00<007mkOg/03Gmk002COol00`00Og]oN`04Og/00`00Oomoo`08
Ool00`00Og]oN`0BOg/2000_Og/200000gmk001oo`11Ool00`00Og]oN`0=Og/009Aoo`03001oNgmk
00=oN`03Ool007oo00Uoo`03001oNgmk019oN`03001oNgmk02ioN`03001oN`0004=oo`03001oNgmk
00aoN`00UGoo00<007mkOg/00gmk00<007ooOol02Goo00<007mkOg/04Gmk0P00;gmk0P0000=oN`00
Ool0@Goo00<007mkOg/037mk002EOol00`00Og]oN`03Og/00goo001oo`09Ool00`00Og]oN`0BOg/0
0`00Og]oN`0]Og/200000gmk001oo`11Ool00`00Og]oN`0<Og/009Ioo`03001oNgmk00=oN`03001o
ogoo00UoodP0049oo`03001oNgmk00aoN`00UWoo00<007mkOg/00gmk00=oo`00Ool02Goo00<007mk
Og/0A7mk00<007ooOol0@Goo00<007mkOg/02gmk002GOol00`00Og]oN`03Og/00goo001oo`09Ool0
0`00Og]oN`14Og/00`00Oomoo`10Ool00`00Og]oN`0;Og/009Moo`03001oNgmk00AoN`03001oogoo
00Qoo`03001oNgmk04AoN`03001oogoo041oo`03001oNgmk00]oN`00V7oo00<007mkOg/00gmk00=o
o`00Ool02Goo00<007mkOg/0@gmk00<007ooOol0@Goo00<007mkOg/02Wmk002IOol00`00Og]oN`03
Og/00`00Oomoo`08Ool00`00Og]oN`14Og/00`00Oomoo`10Ool00`00Og]oN`0:Og/009Uoo`03001o
Ngmk00=oN`03Ool007oo00Uoo`03001oNgmk04=oN`03001oogoo041oo`03001oNgmk00YoN`00VWoo
00<007mkOg/00gmk00<007ooOol02Goo00<007mkOg/0@gmk00<007ooOol0?goo00<007mkOg/02Wmk
002JOol00`00Og]oN`03Og/00goo001oo`09Ool00`00Og]oN`13Og/00`00Oomoo`10Ool00`00Og]o
N`09Og/009]oo`03001oNgmk00=oN`03Ool007oo00Uoo`03001oNgmk04=oN`03001oogoo03moo`03
001oNgmk00UoN`00Vgoo00<007mkOg/017mk00<007ooOol027oo00<007mkOg/0@gmk00<007ooOol0
?goo00<007mkOg/02Gmk002LOol00`00Og]oN`03Og/00goo001oo`09Ool00`00Og]oN`12Og/00`00
Oomoo`10Ool00`00Og]oN`08Og/009eoo`03001oNgmk00=oN`03001oogoo00Qoo`03001oNgmk04=o
N`03001oogoo03moo`03001oNgmk00QoN`00WGoo00<007mkOg/00gmk00=oo`00Ool02Goo00<007mk
Og/0@Wmk00<007ooOol0?goo00<007mkOg/027mk002NOol00`00Og]oN`03Og/00`00Oomoo`08Ool0
0`00Og]oN`13Og/00`00Oomoo`0nOol00`00Og]oN`08Og/009ioo`03001oNgmk00=oN`03Ool007oo
00Uoo`03001oNgmk049oN`03001oogoo03moo`03001oNgmk00MoN`00Wgoo00<007mkOg/00gmk00=o
o`00Ool027oo00<007mkOg/0@Wmk00<007ooOol0?goo00<007mkOg/01gmk002POol00`00Og]oN`03
Og/00`00Oomoo`08Ool00`00Og]oN`12Og/00`00Oomoo`0nOol00`00Og]oN`07Og/00:1oo`03001o
Ngmk00=oN`03Ool007oo00Uoo`03001oNgmk045oN`03001oogoo03ioo`03001oNgmk00MoN`00XGoo
00<007mkOg/00gmk00<007ooOol027oo00<007mkOg/0@Wmk00<007ooOol0?Woo00<007mkOg/01Wmk
002QOol00`00Og]oN`03Og/00goo001oo`09Ool00`00Og]oN`11Og/00`00Oomoo`0nOol00`00Og]o
N`06Og/00:9oo`03001oNgmk00=oN`03001oogoo00Qoo`03001oNgmk049oN`03001oogoo03eoo`03
001oNgmk00IoN`00XWoo00<007mkOg/00gmk00=oo`00Ool02Goo00<007mkOg/0@Gmk00<007ooOol0
?Woo00<007mkOg/01Gmk002SOol00`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`11Og/00`00
Oomoo`0nOol00`00Og]oN`05Og/00:Aoo`03001oNgmk00=oN`03001oogoo00Qoo`03001oNgmk045o
N`03001oogoo03eoo`03001oNgmk00EoN`00Y7oo00<007mkOg/00gmk00=oo`00Ool027oo00<007mk
Og/0@Gmk00<007ooOol0?Goo00<007mkOg/01Gmk002UOol00`00Og]oN`03Og/00`00Oomoo`08Ool0
0`00Og]oN`11Og/00`00Oomoo`0mOol00`00Og]oN`04Og/00:Eoo`03001oNgmk00=oN`03Ool007oo
00Qoo`03001oNgmk045oN`03001oogoo03eoo`03001oNgmk00AoN`00YWoo00<007mkOg/00gmk00<0
07ooOol027oo00<007mkOg/0@7mk00<007ooOol0?Goo00<007mkOg/017mk002VOol00`00Og]oN`03
Og/00goo001oo`09Ool00`00Og]oN`10Og/00`00Oomoo`0lOol00`00Og]oN`04Og/00:Moo`03001o
Ngmk00=oN`03Ool007oo00Qoo`03001oNgmk041oN`03001oogoo03eoo`03001oNgmk00=oN`00Z7oo
00<007mkOg/00gmk00<007ooOol027oo00<007mkOg/0@7mk00<007ooOol0?7oo00<007mkOg/00gmk
002XOol00`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`10Og/00`00Oomoo`0lOol00`00Og]o
N`03Og/00:Uoo`03001oNgmk00=oN`03001oogoo00Qoo`03001oNgmk03moN`03001oogoo03eoo`03
001oNgmk009oN`00ZGoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/0@7mk00<007ooOol0
?7oo00<007mkOg/00Wmk002ZOol00`00Og]oN`03Og/00`00Oomoo`08Ool00`00Og]oN`0oOg/00`00
Oomoo`0lOol00`00Og]oN`02Og/00:Yoo`03001oNgmk00=oN`03Ool007oo00Qoo`03001oNgmk041o
N`03001oogoo03]oo`03001oNgmk009oN`00Zgoo00<007mkOg/00gmk00=oo`00Ool027oo00<007mk
Og/0?gmk00<007ooOol0?7oo00<007mkOg/00Gmk002/Ool00`00Og]oN`03Og/00`00Oomoo`07Ool0
0`00Og]oN`10Og/00`00Oomoo`0kOol00`00Og]oN`01Og/00:aoo`03001oNgmk00=oN`03Ool007oo
00Qoo`03001oNgmk03moN`03001oogoo03]oo`03001oNgmk005oN`00[Goo00<007mkOg/00gmk00<0
07ooOol027oo00<007mkOg/0?Wmk00<007ooOol0>goo00<007mkOg/00Gmk002]Ool00`00Og]oN`03
Og/00goo001oo`08Ool00`00Og]oN`0oOg/00`00Oomoo`0kOol10001Og/1Og/00:ioo`03001oNgmk
00=oN`03001oogoo00Qoo`03001oNgmk03ioN`03001oogoo03]oo`40005oN`5oN`00[goo00<007mk
Og/00Wmk00=oo`00Ool027oo00<007mkOg/0?gmk00<007ooOol0>Woo0@000Gmk0Gmk002_Ool00`00
Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0nOg/00`00Oomoo`0kOol10001Og/00;1oo`03001o
Ngmk00=oN`03001oogoo00Moo`03001oNgmk03ioN`03001oogoo03]oo`40005oN`00/7oo00<007mk
Og/00gmk00=oo`00Ool027oo00<007mkOg/0?Wmk00<007ooOol0>goo0Gmk002aOol00`00Og]oN`03
Og/00`00Oomoo`07Ool00`00Og]oN`0nOg/00`00Oomoo`0kOol1Og/00;5oo`03001oNgmk00=oN`03
Ool007oo00Qoo`03001oNgmk03ioN`03001oogoo03Yoo`5oN`00/Woo00<007mkOg/00gmk00<007oo
Ool01goo00<007mkOg/0?Wmk00<007ooOol0>goo002cOol00`00Og]oN`02Og/00goo001oo`08Ool0
0`00Og]oN`0nOg/00`00Oomoo`0jOol00;=oo`03001oNgmk00=oN`03Ool007oo00Qoo`03001oNgmk
03eoN`03001oogoo03Yoo`00]7oo00<007mkOg/00gmk00<007ooOol01goo00<007mkOg/0?Gmk00<0
07ooOol0>Woo002dOol00`00Og]oN`03Og/00goo001oo`08Ool00`00Og]oN`0mOg/00`00Oomoo`0i
Ool00;Eoo`03001oNgmk00=oN`03001oogoo00Moo`03001oNgmk03eoN`03001oogoo03Uoo`00]Goo
00<007mkOg/00gmk00=oo`00Ool027oo00<007mkOg/0?Gmk00<007ooOol0>7oo002fOol00`00Og]o
N`03Og/00`00Oomoo`07Ool00`00Og]oN`0mOg/00`00Oomoo`0hOol00;Moo`03001oNgmk009oN`03
Ool007oo00Qoo`03001oNgmk03aoN`03001oogoo03Qoo`00]goo00<007mkOg/00gmk00=oo`00Ool0
1goo00<007mkOg/0?Gmk00<007ooOol0=goo002hOol00`00Og]oN`03Og/00`00Oomoo`07Ool00`00
Og]oN`0lOg/00`00Oomoo`0gOol00;Qoo`03001oNgmk00=oN`03Ool007oo00Moo`03001oNgmk03eo
N`03001oogoo03Ioo`00^Goo00<007mkOg/00gmk00<007ooOol01goo00<007mkOg/0?7mk00<007oo
Ool0=Woo002jOol00`00Og]oN`02Og/00goo001oo`08Ool00`00Og]oN`0lOg/00`00Oomoo`0eOol0
0;Yoo`03001oNgmk00=oN`03001oogoo00Moo`03001oNgmk03aoN`03001oogoo03Eoo`00^goo00<0
07mkOg/00Wmk00=oo`00Ool027oo00<007mkOg/0>gmk00<007ooOol0=Goo002kOol00`00Og]oN`03
Og/00goo001oo`07Ool00`00Og]oN`0lOg/00`00Oomoo`0dOol00;aoo`03001oNgmk00=oN`03001o
ogoo00Moo`03001oNgmk03]oN`03001oogoo03Aoo`00_7oo00<007mkOg/00gmk00=oo`00Ool01goo
00<007mkOg/0?7mk00<007ooOol0<goo002mOol00`00Og]oN`03Og/00`00Oomoo`07Ool00`00Og]o
N`0kOg/00`00Oomoo`0cOol00;ioo`03001oNgmk009oN`03Ool007oo00Moo`03001oNgmk03]oN`03
001oogoo03=oo`00_Woo00<007mkOg/00gmk00<007ooOol01goo00<007mkOg/0>gmk00<007ooOol0
<Woo002oOol00`00Og]oN`02Og/00goo001oo`07Ool00`00Og]oN`0kOg/00`00Oomoo`0bOol00;mo
o`03001oNgmk00=oN`03Ool007oo00Moo`03001oNgmk03]oN`03001oogoo035oo`00`7oo00<007mk
Og/00gmk00<007ooOol01Woo00<007mkOg/0>gmk00<007ooOol0<Goo0030Ool00`00Og]oN`03Og/0
0goo001oo`07Ool00`00Og]oN`0jOg/00`00Oomoo`0aOol00<5oo`03001oNgmk00=oN`03001oogoo
00Moo`03001oNgmk03YoN`03001oogoo031oo`00`Woo00<007mkOg/00Wmk00=oo`00Ool01goo00<0
07mkOg/0>Wmk00<007ooOol0<7oo0032Ool00`00Og]oN`03Og/00`00Oomoo`07Ool00`00Og]oN`0j
Og/00`00Oomoo`0_Ool00<=oo`03001oNgmk009oN`03Ool007oo00Moo`03001oNgmk03YoN`03001o
ogoo02moo`00`goo00<007mkOg/00gmk00=oo`00Ool01goo00<007mkOg/0>Wmk00<007ooOol0;Woo
0034Ool00`00Og]oN`03Og/00`00Oomoo`06Ool00`00Og]oN`0jOg/00`00Oomoo`0^Ool00<Aoo`03
001oNgmk00=oN`03Ool007oo00Moo`03001oNgmk03UoN`03001oogoo02ioo`00aGoo00<007mkOg/0
0gmk00<007ooOol01Woo00<007mkOg/0>Wmk00<007ooOol0;Goo0036Ool00`00Og]oN`02Og/00goo
001oo`07Ool00`00Og]oN`0iOg/00`00Oomoo`0]Ool00<Ioo`03001oNgmk00=oN`03001oogoo00Io
o`03001oNgmk03YoN`03001oogoo02aoo`00agoo00<007mkOg/00Wmk00=oo`00Ool01goo00<007mk
Og/0>Gmk00<007ooOol0;7oo0037Ool00`00Og]oN`03Og/00goo001oo`07Ool00`00Og]oN`0hOg/0
0`00Oomoo`0/Ool00<Qoo`03001oNgmk00=oN`03001oogoo00Ioo`03001oNgmk03UoN`03001oogoo
02]oo`00bGoo00<007mkOg/00Wmk00=oo`00Ool01goo00<007mkOg/0>7mk00<007ooOol0:goo0039
Ool00`00Og]oN`03Og/00`00Oomoo`06Ool00`00Og]oN`0iOg/00`00Oomoo`0ZOol00<Yoo`03001o
Ngmk009oN`03Ool007oo00Moo`03001oNgmk03QoN`03001oogoo02Yoo`00bWoo00<007mkOg/00gmk
00<007ooOol01Woo00<007mkOg/0>Gmk00<007ooOol0:Goo003;Ool00`00Og]oN`02Og/00goo001o
o`07Ool00`00Og]oN`0hOg/00`00Oomoo`0YOol00<]oo`03001oNgmk00=oN`03Ool007oo00Ioo`03
001oNgmk03QoN`03001oogoo02Uoo`00c7oo00<007mkOg/00gmk00<007ooOol01Woo00<007mkOg/0
>7mk00<007ooOol0:7oo003=Ool00`00Og]oN`02Og/00goo001oo`06Ool00`00Og]oN`0hOg/00`00
Oomoo`0XOol00<eoo`03001oNgmk00=oN`03001oogoo00Ioo`03001oNgmk03QoN`03001oogoo02Mo
o`00cWoo00<007mkOg/00Wmk00=oo`00Ool01goo00<007mkOg/0=gmk00<007ooOol09goo003>Ool0
0`00Og]oN`03Og/00`00Oomoo`06Ool00`00Og]oN`0gOg/00`00Oomoo`0WOol00<moo`03001oNgmk
009oN`03Ool007oo00Moo`03001oNgmk03MoN`03001oogoo02Ioo`00cgoo00<007mkOg/00gmk00=o
o`00Ool01Woo00<007mkOg/0=gmk00<007ooOol09Woo003@Ool00`00Og]oN`03Og/00`00Oomoo`06
Ool00`00Og]oN`0gOg/00`00Oomoo`0UOol00=5oo`03001oNgmk009oN`03Ool007oo00Ioo`03001o
Ngmk03MoN`03001oogoo02Eoo`00dGoo00<007mkOg/00gmk00<007ooOol01Woo00<007mkOg/0=gmk
00<007ooOol097oo003BOol00`00Og]oN`02Og/00goo001oo`06Ool00`00Og]oN`0gOg/00`00Oomo
o`0TOol00=9oo`03001oNgmk00=oN`03001oogoo00Ioo`03001oNgmk03IoN`03001oogoo02Aoo`00
dgoo00<007mkOg/00Wmk00=oo`00Ool01Woo00<007mkOg/0=gmk00<007ooOol08goo003COol00`00
Og]oN`03Og/00goo001oo`06Ool00`00Og]oN`0fOg/00`00Oomoo`0SOol00=Aoo`03001oNgmk00=o
N`03001oogoo00Ioo`03001oNgmk03IoN`03001oogoo029oo`00eGoo00<007mkOg/00Wmk00=oo`00
Ool01Woo00<007mkOg/0=Wmk00<007ooOol08Woo003EOol00`00Og]oN`03Og/00`00Oomoo`06Ool0
0`00Og]oN`0eOg/00`00Oomoo`0ROol00=Ioo`03001oNgmk009oN`03Ool007oo00Ioo`03001oNgmk
03IoN`03001oogoo025oo`00eWoo00<007mkOg/00gmk00<007ooOol01Woo00<007mkOg/0=Gmk00<0
07ooOol08Goo003GOol00`00Og]oN`02Og/00goo001oo`06Ool00`00Og]oN`0fOg/00`00Oomoo`0P
Ool00=Qoo`03001oNgmk009oN`03Ool007oo00Ioo`03001oNgmk03EoN`03001oogoo021oo`00f7oo
00<007mkOg/00gmk00<007ooOol01Goo00<007mkOg/0=Gmk00<007ooOol087oo003IOol00`00Og]o
N`02Og/00goo001oo`06Ool00`00Og]oN`0eOg/00`00Oomoo`0OOol00=Uoo`03001oNgmk00=oN`03
001oogoo00Eoo`03001oNgmk03EoN`03001oogoo01moo`00fWoo00<007mkOg/00Wmk00=oo`00Ool0
1Woo00<007mkOg/0=Gmk00<007ooOol07Woo003JOol00`00Og]oN`03Og/00`00Oomoo`06Ool00`00
Og]oN`0dOg/00`00Oomoo`0NOol00=]oo`03001oNgmk009oN`03Ool007oo00Ioo`03001oNgmk03Eo
N`03001oogoo01eoo`00g7oo00<007mkOg/00Wmk00=oo`00Ool01Woo00<007mkOg/0=7mk00<007oo
Ool07Goo003LOol00`00Og]oN`03Og/00`00Oomoo`05Ool00`00Og]oN`0dOg/00`00Oomoo`0MOol0
0=eoo`03001oNgmk009oN`03Ool007oo00Ioo`03001oNgmk03AoN`03001oogoo01aoo`00\
\>"],
  ImageRangeCache->{{{0, 320}, {369, 0}} -> {-0.350042, -0.6, 0.000406509, \
0.000406509}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{659, 723},
WindowMargins->{{157, Automatic}, {Automatic, 43}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Gd000400@0000000000000004P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 143, 3, 67, "Section"],

Cell[CellGroupData[{
Cell[1895, 59, 95, 1, 63, "Subsection"],
Cell[1993, 62, 464, 12, 68, "Input"],
Cell[2460, 76, 84, 1, 46, "Text"],
Cell[2547, 79, 67, 1, 25, "Input"],
Cell[2617, 82, 69, 1, 46, "Text"],
Cell[2689, 85, 693, 19, 77, "Input"],
Cell[3385, 106, 64, 1, 46, "Text"],
Cell[3452, 109, 1039, 20, 207, "Input"],
Cell[4494, 131, 71, 1, 46, "Text"],
Cell[4568, 134, 369, 10, 64, "Input"],
Cell[4940, 146, 89, 1, 46, "Text"],
Cell[5032, 149, 311, 9, 38, "Input"],
Cell[5346, 160, 62, 1, 46, "Text"],
Cell[5411, 163, 257, 9, 38, "Input"],
Cell[5671, 174, 77, 1, 46, "Text"],
Cell[5751, 177, 351, 10, 64, "Input"],
Cell[6105, 189, 77, 1, 46, "Text"],
Cell[6185, 192, 3128, 71, 662, "Input"],
Cell[9316, 265, 92, 1, 46, "Text"],
Cell[9411, 268, 1934, 40, 402, "Input"],
Cell[11348, 310, 72, 1, 46, "Text"],
Cell[11423, 313, 1872, 36, 402, "Input"],
Cell[13298, 351, 75, 1, 46, "Text"],
Cell[13376, 354, 1858, 30, 441, "Input"],
Cell[15237, 386, 75, 1, 46, "Text"],
Cell[15315, 389, 4269, 62, 1000, "Input"],
Cell[19587, 453, 75, 1, 46, "Text"],
Cell[19665, 456, 279, 9, 38, "Input"],
Cell[19947, 467, 69, 1, 46, "Text"],
Cell[20019, 470, 621, 16, 116, "Input"],
Cell[20643, 488, 92, 1, 46, "Text"],
Cell[20738, 491, 864, 17, 194, "Input"],
Cell[21605, 510, 76, 1, 46, "Text"],
Cell[21684, 513, 715, 15, 194, "Input"],
Cell[22402, 530, 130, 4, 62, "Text"],
Cell[22535, 536, 872, 17, 194, "Input"],
Cell[23410, 555, 100, 1, 46, "Text"],
Cell[23513, 558, 643, 14, 181, "Input"],
Cell[24159, 574, 570, 13, 142, "Input"],
Cell[24732, 589, 100, 1, 46, "Text"],
Cell[24835, 592, 478, 12, 116, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25350, 609, 85, 1, 47, "Subsection"],
Cell[25438, 612, 171, 4, 62, "Text"],
Cell[25612, 618, 600, 17, 90, "Input"],
Cell[26215, 637, 68, 1, 46, "Text"],
Cell[26286, 640, 81, 1, 25, "Input"],
Cell[26370, 643, 67, 1, 25, "Input"],
Cell[26440, 646, 136, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[26601, 654, 306, 11, 129, "Input"],
Cell[26910, 667, 202, 7, 24, "Output"]
}, Open  ]],
Cell[27127, 677, 65, 1, 46, "Text"],
Cell[27195, 680, 282, 9, 103, "Input"],
Cell[27480, 691, 76, 1, 46, "Text"],
Cell[27559, 694, 144, 5, 51, "Input"],
Cell[27706, 701, 56, 1, 46, "Text"],
Cell[27765, 704, 84, 1, 25, "Input"],
Cell[27852, 707, 309, 8, 38, "Input"],
Cell[28164, 717, 62, 1, 46, "Text"],
Cell[28229, 720, 813, 17, 142, "Input"],
Cell[29045, 739, 66, 1, 46, "Text"],
Cell[29114, 742, 536, 13, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29687, 760, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[29779, 765, 69, 1, 61, "Subsubsection"],
Cell[29851, 768, 65, 1, 46, "Text"],
Cell[29919, 771, 105, 1, 25, "Input"],
Cell[30027, 774, 68, 1, 25, "Input"],
Cell[30098, 777, 8607, 265, 3431, "Input"],
Cell[38708, 1044, 95, 1, 70, "Text"],
Cell[38806, 1047, 113, 1, 70, "Input"],
Cell[38922, 1050, 4590, 183, 70, "Input"],
Cell[43515, 1235, 98, 1, 70, "Text"],
Cell[43616, 1238, 112, 1, 70, "Input"],
Cell[43731, 1241, 3081, 125, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[46849, 1371, 69, 1, 47, "Subsubsection"],
Cell[46921, 1374, 71, 1, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[47041, 1381, 64, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[47130, 1386, 63, 1, 25, "Input"],
Cell[47196, 1389, 31495, 687, 307, 3731, 340, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[78706, 2079, 87, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[78818, 2084, 97, 1, 25, "Input"],
Cell[78918, 2087, 46982, 959, 378, 3996, 424, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

