(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    105890,       2565]*)
(*NotebookOutlinePosition[    106970,       2599]*)
(*  CellTagsIndexPosition[    106926,       2595]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["AFM compatibility diagrams at 6 kbar",
  FontColor->RGBColor[1, 0, 0]]], "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general compatibility diagram functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Off[General::spell]; Off[General::spell1]; Off[Set::shape];\n\
Off[Interpolation::inhr]; Off[InterpolatingFunction::dmwarn",
    FontWeight->"Plain"],
  StyleBox["]",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0.499992]],
  StyleBox["\nSetOptions[Position, Heads -> False];\n<<Graphics`Animation` (* \
only needed if movies to be made *)",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default value, normally overridden", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["making combinations", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};  \n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                            \
                       gray[n-1,m-1]]}],m];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["creates slider", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[slider];\n",
    FontWeight->"Plain"],
  StyleBox["slider",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v1_, v2_, dv1_, dv2_] := \n    \
{Line[{{x1,y},{x2,y},{x2,y-dy},{x1,y-dy},{x1,y}}],\n          Map[Line[{{x1 + \
(#-v1)(x2-x1)/(v2-v1),y},\n                    {x1 + \
(#-v1)(x2-x1)/(v2-v1),y-dy}}]&, Range[v1,v2,dv1]],\n                    \n    \
      Map[Line[{{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.4},\n                    \
{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.6}}]&, Range[v1,v2,dv2]],\n                \
    \n          If[TrueQ[varyTatP],\n             \
Text[FontForm[\"T(\[Degree]C)\",  {\"Helvetica\",fontsize1}], {x1,y+yplus}],\n\
             Text[FontForm[\"P(kbar)\",{\"Helvetica\",fontsize1}], \
{x1,y+yplus}]],\n          \n          \
Text[FontForm[Round[v1],{\"Helvetica\",fontsize1}], {x1,y+yminus}],\n         \
 Text[FontForm[Round[v2],{\"Helvetica\",fontsize1}], {x2,y+yminus}] };",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["creates bar on slider", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bar];\n",
    FontWeight->"Plain"],
  StyleBox["bar",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v_, v1_, v2_] := \n           Line[{{x1 + (v-v1)(x2-x1)/(v2-v1), \
y-dy-dy1},\n                 {x1 + (v-v1)(x2-x1)/(v2-v1), y+dy1}}];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws background to phase relationships", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background];\n",
    FontWeight->"Plain"],
  StyleBox["background",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[0,0.45,1], Polygon[shape], GrayLevel[0], Line[shape]};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws labels", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] := {};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws all the tie triangles", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tietriangle];\n",
    FontWeight->"Plain"],
  StyleBox["tietriangle",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_]:=\n     {GrayLevel[1], Map[conv[Polygon,#]&, q], \n      \
GrayLevel[0], Map[conv[Line,#]&, q]};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["interpolation of divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[interpolatedi];\n",
    FontWeight->"Plain"],
  StyleBox["interpolatedi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_, info_, v_] :=\n   (    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["info2 is same as info but with names->codes and phases ordered  ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    info1 = Fold[(k = #2; pn = phase[[k]];\n    \
              pp = Position[#1,_?((#==pn)&)];\n                  MapAt[k&, \
#1, pp])&, info, Range[Length[phase]]];\n    info2 = Map[{#[[1]],Map[Sort[#, \
(#1[[1]]<#2[[1]])&]&, Drop[#,1]]}&,info1];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["vv is vector of T (or P)  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t   vv = Map[#[[1,vposi]]&, info];\n    \n    \
(* ",
    FontWeight->"Plain"],
  StyleBox["kki is position in vv if there is exact match with v  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    kki = Flatten[Position[vv, _?((Abs[v - \
#]<diffv)&)]]; \n    If[Length[kki] == 1,  \n        \n       (* ",
    FontWeight->"Plain"],
  StyleBox["returns divariant coordinates from info2 if there is an exact \
match ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       info2[[kki[[1]],2]],\n        \n       \
(* ",
    FontWeight->"Plain"],
  StyleBox["no exact match; {k1,k2} positions in vv bracket v ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       k2 = Flatten[Position[vv, _?((v < \
#)&)]][[1]]; k1 = k2 - 1;\n       \n       If[k1 == 0, \n           \n        \
  (* ",
    FontWeight->"Plain"],
  StyleBox["if v cannot be bracketed, empty list returned ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n          {},\n           \n          (* ",
    FontWeight->"Plain"],
  StyleBox["bracketed; vprop is prop position in bracket ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t         vprop = (v - vv[[k1]])/(vv[[k2]] - \
vv[[k1]]);\n\t\n          (* ",
    FontWeight->"Plain"],
  StyleBox["dic are divariants in {k1,k2} in common ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         di1 = Map[Transpose[#][[1]]&, \
Drop[info2[[k1]],1][[1]]];\n\t         di2 = Map[Transpose[#][[1]]&, \
Drop[info2[[k2]],1][[1]]];\n\t         dic = Intersection[di1,di2];\n\t\n     \
     (* ",
    FontWeight->"Plain"],
  StyleBox["interpolating the divariants in common ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         Map[(idik = #;\n            \t  pk1 = \
Position[di1, _?((#==idik)&)][[1,1]];\n      \t        pk2 = Position[di2, \
_?((#==idik)&)][[1,1]];\n      \t        q1 = info2[[k1,2,pk1]]; q2 = \
info2[[k2,2,pk2]];\n               q1 + vprop (q2 - q1) )&, dic]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["drawing trivariants - no curvature assumed", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tri];\n",
    FontWeight->"Plain"],
  StyleBox["tri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (\t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["using divariant info in allinfo, ic is all phases involved ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n      af = Fold[({equiv1,equiv2} = #2;\n          \
        MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["looks at the phases pairwise, with a being the divariant \
coordinates ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];                       \
        \n      a = Map[({k1,k2} = #; \n                 plc = \
Flatten[Position[Map[Length,\n                               \
Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\n                 cc = \
Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n                           \
              Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\n                 occ \
= Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n                 cocc = \
Map[Map[conv,#]&,occ];\n                 \
Map[Join[cocc[[#[[1]]]],Reverse[cocc[[#[[2]]]]],{cocc[[#[[1]],1]]}]&, \n      \
               Partition[Range[Length[plc]],2]] )&, Map[ic[[#]]&,gr]];        \
             \n     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["drawing the trivariant info in a ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      {Hue[0,0.15,1], \n       \
Map[Map[Polygon[#]&,#]&, a], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, a], \n       GrayLevel[0]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setting up trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setuptri];\n",
    FontWeight->"Plain"],
  StyleBox["setuptri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (     \t\n      (* ",
    FontWeight->"Plain"],
  StyleBox["ic is list of phases involved in trivariants ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      triinfo1 = Fold[(k = #2; pn = phasef[[k]];\n   \
                    pp = Position[#1,_?((#==pn)&)];\n                       \
MapAt[k&, #1, pp])&, triinfo, Range[Length[phase]]];\n      triinfo2 = \
Map[{#[[1]],Map[Sort[#, (#1[[1]]<#2[[1]])&]&, \n                     \
Drop[Drop[#,-1],1]][[1]]}&,triinfo1];\n      pr = \
Map[{{#[[1,1]],#[[2,1]]},Map[conv,#]}&,Map[Drop[#,1][[1]]&,triinfo2]];\n      \
vr = Map[#[[1,vposi]]&,triinfo2];      \n      c = Map[#[[1]]&,pr];  ic = \
Intersection[Flatten[c]];\n      \n      (* ",
    FontWeight->"Plain"],
  StyleBox["calculates all the interpolation functions for the trivariant \
boundaries ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];         \n      \
Map[({k1,k2} = #; \n           pp = Flatten[Position[c, _?((#=={k1,k2})&)]];\n\
           pr1 = Map[Drop[#,1][[1]]&,pr[[pp]]];\n           vr1 = vr[[pp]];\n \
          ivv = Intersection[vr1];\n           {#, Map[(ivvk = #;\n           \
         pr2 = pr1[[Flatten[Position[vr1,_?((#==ivvk)&)]]]];\n                \
    {ivvk,\n                     \
Interpolation[Map[Reverse,Transpose[pr2][[1]]],\n                             \
      InterpolationOrder->2], \n                     \
Interpolation[Map[Reverse,Transpose[pr2][[2]]],\n                             \
      InterpolationOrder->2]})&,ivv]})&, \n           Map[ic[[#]]&,gr]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["accessing trivariant info", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[getf];\t\t\t\t(* 1,2 are different limbs; a,b are \
interpolants *)\n",
    FontWeight->"Plain"],
  StyleBox["getf",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{k1_,k2_}, vk_] :=\n      (pp = \
Flatten[Position[Map[#[[1]]&,iff], _?((#=={k1,k2})&)]];\n       If[Length[pp] \
== 0, {0,{}}, \n          pp1 = pp[[1]];   \n          ip = iff[[pp1,2]];\n   \
       If[ip === {}, {0,{}}, \n             vv = Transpose[ip][[1]];\n        \
     kkm = Flatten[Position[vv, _?((Abs[vk-#]<0.01)&)]]; \n             \n    \
         If[Length[kkm] == 1,  \n                {ff1,ff2} = \
ip[[kkm[[1]],{2,3}]]; \n                {1,{ {ff1, Apply[List,ff1][[1]]}, \
{ff2, Apply[List,ff2][[1]]} }},\n             \n                kk0 = \
Flatten[Position[vv, _?((vk < #)&)]]; \n                \n                \
If[kk0 == {} || kk0[[1]] == 1, {0,{}},\n                   kk2 = kk0[[1]];  \
kk1 = kk2 - 1;\n                   prop = (vk - vv[[kk1]])/(vv[[kk2]] - \
vv[[kk1]]);\n                   \n                   (* Print[{k1,k2} /. sub, \
{kk1,kk2}]; *)\n             \n                   ff1a = ip[[kk1,2]]; ff1b = \
ip[[kk2,2]];  \n                   {is1a,ie1a} = Apply[List,ff1a][[1]];\n     \
              {is1b,ie1b} = Apply[List,ff1b][[1]];\n                   is1 = \
If[is1a>is1b, is1a, is1b]; ie1 = If[ie1a<ie1b, ie1a, ie1b];\n             \n  \
                 ff2a = ip[[kk1,3]]; ff2b = ip[[kk2,3]];\n                   \
{is2a,ie2a} = Apply[List,ff2a][[1]];\n                   {is2b,ie2b} = \
Apply[List,ff2b][[1]];\n                   is2 = If[is2a>is2b, is2a, is2b]; \
ie2 = If[ie2a<ie2b, ie2a, ie2b];\n             \n                   {2,{ \
{{ff1a,ff1b}, {is1,ie1}}, {{ff2a,ff2b}, {is2,ie2}}, prop}}]]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["drawing proper trivariant", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["del = 0.001;\n\nClear[btri]; Clear[f1]; Clear[f2]; \n",
    FontWeight->"Plain"],
  StyleBox["btri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_]:=\n     (af = Fold[({equiv1,equiv2} = #2;\n                 \
 MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n      gr = gray[Length[ic],2];   icgr = \
Map[ic[[#]]&,gr];  z=.;    \n                      \n      atri = Array[(k = \
#;  {k1,k2} = icgr[[k]];\n                 plc = Flatten[Position[Map[Length,\
\n                           Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\
\n                 cc = Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n   \
                                      Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\
\n                 occ = Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n \
                cocc = Map[Map[conv,#]&,occ];\n                 \n            \
     {code,f} = getf[{k1,k2},vk];\n                 \n                 simple \
= code == 0; match = code == 1;\n                 \n                 \
If[simple, (* do nothing *) ,\n                    If[match,\n                \
       {{f1, {is1,ie1}},{f2, {is2,ie2}}} = f,\n                       \
{{{f1a,f1b}, {is1,ie1}}, {{f2a,f2b}, {is2,ie2}}, prop} = f]];\n               \
        \n                 If[OddQ[Length[plc]], \n                    d = \
Abs[Join[cocc,{{{0,0},{0,0}}}] - Join[{{{0,0},{0,0}}},cocc]];\n               \
     pd = Flatten[Position[Map[Apply[Plus,Flatten[#]]&,d],_?((#<0.01)&)]];\n  \
                  cocc = Drop[cocc,pd];\n                    \
If[OddQ[Length[cocc]],\n                       Print[\"no of tie lines for \
\",{k1,k2} /. sub,\" is still odd \"],\n                       (* \
Print[\"duplicate removed in \",{k1,k2} /. sub] *)   ]];\n                    \
   \n                 Map[(c1 = cocc[[#[[1]]]];\n                      c2 = \
cocc[[#[[2]]]];\n                      \n                      If[simple,  p1 \
= {{}}; p2 = {{}},\n\n                         cy12 = c2[[1,2]]; cy11 = \
c1[[1,2]]; \n                         s1 =  If[is1>cy11+del, is1, cy11+del];  \
\n                         e1 = If[ie1<cy12-del, ie1, cy12-del];\n            \
             dy1 = e1 - s1;\n                         p1 = If[dy1 <= \
2del,{{}},\n                                 kd1 = Floor[dy1/del]; dd = \
dy1/kd1;\n                                 rr1 = s1 + dd Range[0,kd1];\n      \
                           If[match,\n                                    \
Map[{f1[#],#}&, rr1],\n                                    \
Map[{(1-prop)f1a[#]+prop f1b[#],#}&, rr1]]];\n                                \
 \n                         cy22 = c2[[2,2]]; cy21 = c1[[2,2]]; \n            \
             s2 =  If[is2>cy21+del, is2, cy21+del];  \n                       \
  e2 = If[ie2<cy22-del, ie2, cy22-del];\n                         dy2 = e2 - \
s2;\n                         p2 = If[dy2 <= 2del,{{}},\n                     \
            kd2 = Floor[dy2/del]; dd = dy2/kd2;\n                             \
    rr2 = s2 + dd Range[0,kd2];\n                                 If[match,\n \
                                   Map[{f2[#],#}&, rr2],\n                    \
                Map[{(1-prop)f2a[#]+prop f2b[#],#}&, rr2]]] ];\n              \
                      \n                       Which[Dimensions[p1]=={1,0} && \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p1]=={1,0},\n                               \
Join[c1,p2,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],Reverse[p1],{c1[[1]]}],\n                             \
True,\n                               \
Join[c1,p2,Reverse[c2],Reverse[p1],{c1[[1]]}]])&, \n                     \
Partition[Range[Length[cocc]],2]])&, Length[icgr]];\n      {Hue[0,0.15,1], \n \
      Map[Map[Polygon[#]&,#]&, atri], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, atri], \n       GrayLevel[0]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["looking at the divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[show];\n",
    FontWeight->"Plain"],
  StyleBox["show",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := Print[N[allinfo /. sub,3] //ColumnForm]",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["checking data shape", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[datashape]; Clear[datacheck];\n\n",
    FontWeight->"Plain"],
  StyleBox["datashape",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := Map[Map[Dimensions,#]&,info];\n\n",
    FontWeight->"Plain"],
  StyleBox["datacheck",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_, k_] :=\n  (dc = datashape[info];\n   ldc = \
Length[Position[Map[Transpose[Drop[#,1]][[2]]&, dc], _?((#!=k)&)]];\n   \
If[TrueQ[ldc==0],\"data shape OK\",\"data shape stuffed\"])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with slider etc", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontWeight->"Plain"],
  StyleBox["fullmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
tri, \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nfullmake[___] := If[TrueQ[varyTatP],\n        \
            Print[\"T outside range (or T inc on slider not supplied)\"],\n   \
                 Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[make];\n",
    FontWeight->"Plain"],
  StyleBox["make",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   tri, \n                     tietriangle[infok],\n          \
           labelling[vstring],\n                     plotvscale[vk]}],\n      \
               AspectRatio->Automatic,\n                     \
PlotRange->plotrange]) /; vk >= vlow && vk <= vhigh;\n     \nmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
draw compatibility diagram with proper trivariants and with slider \
etc\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bfullmake];\n",
    FontWeight->"Plain"],
  StyleBox["bfullmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
btri[vk], \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nbfullmake[___] := If[TrueQ[varyTatP],\n       \
             Print[\"T outside range (or T inc on slider not supplied)\"],\n  \
                  Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bmake];\n",
    FontWeight->"Plain"],
  StyleBox["bmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   btri[vk], \n                     tietriangle[infok],\n     \
                plotvscale[vk]}],\n          AspectRatio->Automatic,\n        \
  PlotRange->plotrange]) /; vk <= vhigh;\n     \nbmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontWeight->"Plain"],
  StyleBox["partmake",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, plotrangep_] :=\n    (assemble[vk]; \n     Show[Graphics[ \
{background,\n                     tri,\n                     \
tietriangle[infok],\n                     labelling[vstring],\n               \
      plotvscale[vk]}],\n                    AspectRatio->Automatic, \n       \
             PlotRange->plotrangep])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setup];\n",
    FontWeight->"Plain"],
  StyleBox["setup",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_] :=\n   (vstring = s;\n    If[TrueQ[varyTatP],\n       diffv \
= 0.01;    vposi = 2; \n       vlow = info[[1,1,2]]; vhigh = info[[-1,1,2]],\n\
       diffv = 0.0001;; vposi = 1; \n       vlow = info[[1,1,1]]; vhigh = \
info[[-1,1,1]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["AFM system-specific functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
applies function f to AFM coordinates as provided by THERMOCALC,
after converting them into graphical coordinates\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[conv];\n",
    FontWeight->"Plain"],
  StyleBox["conv",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[f_,t_]:=(p = Map[(Mg = #[[4]]; Fe = #[[3]]; \n                   \
 N[ {(Mg - Fe)/Sqrt[3], -(Mg + Fe)} ] )&, t];\n              \
f[Join[p,{p[[1]]}]]);\n              \n",
    FontWeight->"Plain"],
  StyleBox["conv",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[t_]:= (Mg = t[[4]]; Fe = t[[3]]; N[ {(Mg - Fe)/Sqrt[3], -(Mg + \
Fe)} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default font sizes", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["fontsize1 = 12; fontsize = 16;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
creates AFM triangle (triangle not joined up, so no bottom line on \
triangle)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
third = 1/3;      sqrtthird = 1/Sqrt[3];     twothird = 2/3;

ll = 1.36; lla = ll sqrtthird; 
cll = 1 - ll; clla = 1 - cll;  
dd = 0.03;

{xky,yky} = {0,0}; xbot = lla + dd sqrtthird; ybot = -ll - dd;

shape = N[{{-xbot,ybot}, {0,0}, {xbot,ybot}}]\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{{-0.80251687417358, -1.39}, {0, 0}, \
{0.80251687417358, -1.39}}\
\>", "\<\
{{-0.802517, -1.39}, {0, 0}, {0.802517, \
-1.39}}\
\>"], "Output",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]],

Cell["plot range info", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
xband = 0.191; yband = 0.05;     (* for AspectRatio -> Automatic *)

xlow0 = -xbot - xband; xhigh0 = xbot + xband; 
ylow0 = ybot - yband; yhigh0 = yband;

plotrange = {{xlow0,xhigh0},{ylow0,yhigh0}};
plotrangef = plotrange;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default slider coordinates", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
y = -1.6; dy = 0.02; dy1 = 0.05;
x1 = -0.8; x2 = 0.8;
yplus = 0.032; yminus = -0.075;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["vscale", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["xsc = -0.77; ysc = -0.32; pl = 1;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["plotvscale",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v_] := Text[FontForm[N[Round[10^pl v]/10^pl],\n                  \
          {\"Helvetica\",fontsize}], {xsc,ysc},{-1,0}]",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draws labels", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] :=\n    ({Text[FontForm[p,{\"Helvetica\",fontsize}], \
{-0.7,-0.21}],\n     Text[FontForm[\"AFM\",{\"Times-Bold\",18}], \
{-0.7,-0.1}],\n     Text[FontForm[\"als\",{\"Helvetica\",fontsize}], \
{0.1,-0.05}],\n     Text[FontForm[\"st\",{\"Helvetica\",fontsize}], \
{-0.27,-0.3}],\n     Text[FontForm[\"ctd\",{\"Helvetica\",fontsize}], \
{-0.38,-0.5}],\n     Text[FontForm[\"g\",{\"Helvetica\",fontsize}], \
{-0.52,-0.75}],\n     Text[FontForm[\"chl\",{\"Helvetica\",fontsize}], \
{0.54,-0.80}],\n     Text[FontForm[\"bi\",{\"Helvetica\",fontsize}], \
{0,-1.33}]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["assembly of data", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemble];\n",
    FontWeight->"Plain"],
  StyleBox["assemble",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[tk_] :=\n    (infok = interpolatedi[phase, info, tk];\n     \
infosubfk = Map[Map[Insert[#, 0,-1]&, #]&, interpolatedi[phasesubf, infosubf, \
tk]];\n     infosubmk = Map[Map[Insert[#, 0, 3]&, #]&, \
interpolatedi[phasesubm, infosubm, tk]];\n     allinfo = \
Join[infok,infosubfk,infosubmk]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["coordinates", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["divariants", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KFM coordinates", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phase = {\"chl\",\"bi\",\"g\",\"st\",\"ctd\",\"ky\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["equivalence = {};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
info = {
{{6.000, 500.00}, 
         {{\"ctd\", 0.5000, 0.3392, 0.1608}, 
          {\"chl\", 0.2180, 0.3193, 0.4627}, 
          {\"ky\", 1.0000, 0, 0}} },
          
{{6.000, 509.50},  (* at kfash univariant *)
         {{\"st\", 0.6923, 0.3077, 0.0000}, 
          {\"ctd\", 0.5000, 0.4999, 0.0001}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.3476, 0.1524}, 
          {\"chl\", 0.2162, 0.3380, 0.4458}, 
          {\"ky\", 1.0000, 0, 0}} },
          
{{6.000, 521.40},  (* at kfash univariant *)
         {{\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"g\", 0.2500, 0.7500, 0.0000}, 
          {\"chl\", 0.1847, 0.8151, 0.0002}},

         {{\"st\", 0.6923, 0.2978, 0.0099}, 
          {\"ctd\", 0.5000, 0.4427, 0.0573}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.3579, 0.1421}, 
          {\"chl\", 0.2140, 0.3618, 0.4242}, 
          {\"ky\", 1.0000, 0, 0}} }, 
          
 {{6.000, 526.04},  (* at kfash univariant *)
         {{\"g\", 0.2500, 0.7500, 0.0000}, 
          {\"chl\", 0.1688, 0.8312, 0.0000}, 
          {\"bi\", -0.2329, 1.2329, 0.0000}},

         {{\"ctd\", 0.5000, 0.4917, 0.0083}, 
          {\"g\", 0.2500, 0.7451, 0.0049}, 
          {\"chl\", 0.1868, 0.7748, 0.0384}},

         {{\"st\", 0.6923, 0.2936, 0.0141}, 
          {\"ctd\", 0.5000, 0.4220, 0.0780}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.3619, 0.1381}, 
          {\"chl\", 0.2131, 0.3714, 0.4154}, 
          {\"ky\", 1.0000, 0, 0}} },   
          
  {{6.000, 538.03},  (* at kfmash univariant *)
         {{\"st\", 0.6923, 0.2819, 0.0258}, 
          {\"ctd\", 0.5000, 0.3719, 0.1281}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.3722, 0.1278}, 
          {\"chl\", 0.2110, 0.3970, 0.3921}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2821, 0.0256}, 
          {\"ctd\", 0.5000, 0.3728, 0.1272}, 
          {\"chl\", 0.2109, 0.3982, 0.3909}},

         {{\"st\", 0.6923, 0.2820, 0.0257}, 
          {\"chl\", 0.2109, 0.3970, 0.3920}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.4694, 0.0306}, 
          {\"g\", 0.2500, 0.7313, 0.0187}, 
          {\"chl\", 0.1921, 0.6806, 0.1274}},

         {{\"g\", 0.2500, 0.7357, 0.0143}, 
          {\"chl\", 0.1767, 0.7208, 0.1025}, 
          {\"bi\", -0.2331, 1.0904, 0.1427}} },                         

 {{6.000, 545.38}, 
         {{\"st\", 0.6923, 0.3077, 0.0000}, 
          {\"ctd\", 0.5000, 0.5000, 0.0000}, 
          {\"g\", 0.2500, 0.7500, 0.0000}},

         {{\"st\", 0.6923, 0.2888, 0.0189}, 
          {\"ctd\", 0.5000, 0.4025, 0.0975}, 
          {\"chl\", 0.2054, 0.4703, 0.3242}},

         {{\"st\", 0.6923, 0.2795, 0.0282}, 
          {\"chl\", 0.2096, 0.3825, 0.4079}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"ctd\", 0.5000, 0.4553, 0.0447}, 
          {\"g\", 0.2500, 0.7219, 0.0281}, 
          {\"chl\", 0.1951, 0.6291, 0.1758}},

         {{\"g\", 0.2500, 0.7259, 0.0241}, 
          {\"chl\", 0.1815, 0.6611, 0.1574}, 
          {\"bi\", -0.2321, 1.0112, 0.2209}} },
 
 {{6.000, 554.93}, 
         {{\"st\", 0.6923, 0.2959, 0.0118}, 
          {\"g\", 0.2500, 0.7086, 0.0414}, 
          {\"chl\", 0.1989, 0.5684, 0.2327}},

         {{\"st\", 0.6923, 0.2959, 0.0118}, 
          {\"ctd\", 0.5000, 0.4363, 0.0637}, 
          {\"chl\", 0.1989, 0.5684, 0.2327}},

         {{\"ctd\", 0.5000, 0.4363, 0.0637}, 
          {\"g\", 0.2500, 0.7086, 0.0414}, 
          {\"chl\", 0.1989, 0.5684, 0.2327}},

         {{\"st\", 0.6923, 0.2959, 0.0118}, 
          {\"ctd\", 0.5000, 0.4363, 0.0637}, 
          {\"g\", 0.2500, 0.7086, 0.0414}},

         {{\"st\", 0.6923, 0.2761, 0.0316}, 
          {\"chl\", 0.2080, 0.3648, 0.4272}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"g\", 0.2500, 0.7121, 0.0379}, 
          {\"chl\", 0.1873, 0.5922, 0.2205}, 
          {\"bi\", -0.2294, 0.9178, 0.3116}} },

{{6.000, 572.42}, 
         {{\"st\", 0.6923, 0.2882, 0.0195}, 
          {\"chl\", 0.1976, 0.4845, 0.3178}, 
          {\"bi\", -0.2216, 0.7670, 0.4547}},

         {{\"st\", 0.6923, 0.2882, 0.0195}, 
          {\"g\", 0.2500, 0.6831, 0.0669}, 
          {\"bi\", -0.2216, 0.7670, 0.4547}},

         {{\"g\", 0.2500, 0.6831, 0.0669}, 
          {\"chl\", 0.1976, 0.4845, 0.3178}, 
          {\"bi\", -0.2216, 0.7670, 0.4547}},

         {{\"st\", 0.6923, 0.2882, 0.0195}, 
          {\"g\", 0.2500, 0.6831, 0.0669}, 
          {\"chl\", 0.1976, 0.4845, 0.3178}},

         {{\"st\", 0.6923, 0.2695, 0.0382}, 
          {\"chl\", 0.2050, 0.3343, 0.4607}, 
          {\"ky\", 1.0000, 0, 0}} },

{{6.000, 584.82}, 
         {{\"st\", 0.6923, 0.2642, 0.0435}, 
          {\"bi\", -0.2203, 0.5119, 0.7084}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2642, 0.0435}, 
          {\"chl\", 0.2030, 0.3140, 0.4830}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"chl\", 0.2030, 0.3140, 0.4830}, 
          {\"bi\", -0.2203, 0.5119, 0.7084}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2642, 0.0435}, 
          {\"chl\", 0.2030, 0.3140, 0.4830}, 
          {\"bi\", -0.2203, 0.5119, 0.7084}},

         {{\"st\", 0.6923, 0.2868, 0.0209}, 
          {\"g\", 0.2500, 0.6789, 0.0711}, 
          {\"bi\", -0.2178, 0.7537, 0.4641}} },

{{6.000, 591.04}, 
         {{\"st\", 0.6923, 0.2860, 0.0217}, 
          {\"g\", 0.2500, 0.6766, 0.0734}, 
          {\"bi\", -0.2159, 0.7474, 0.4685}},

         {{\"st\", 0.6923, 0.2650, 0.0427}, 
          {\"bi\", -0.2182, 0.5231, 0.6951}, 
          {\"ky\", 1.0000, 0, 0}},
          
         {{\"bi\", -0.2353, 0.000, 1.2353}, 
          {\"chl\", 0.2021, 0.000, 0.7979}, 
          {\"ky\", 1.0000, 0.000, 0}} },

{{6.000, 645.06}, 
         {{\"st\", 0.6923, 0.2790, 0.0287}, 
          {\"bi\", -0.2000, 0.6960, 0.5040}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2790, 0.0287}, 
          {\"g\", 0.2500, 0.6562, 0.0938}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"g\", 0.2500, 0.6562, 0.0938}, 
          {\"bi\", -0.2000, 0.6960, 0.5040}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"st\", 0.6923, 0.2790, 0.0287}, 
          {\"g\", 0.2500, 0.6562, 0.0938}, 
          {\"bi\", -0.2000, 0.6960, 0.5040}} },

 {{6.000, 650.00}, 
         {{\"st\", 0.6923, 0.3012, 0.0065}, 
          {\"g\", 0.2500, 0.7282, 0.0218}, 
          {\"ky\", 1.0000, 0, 0}},

         {{\"g\", 0.2500, 0.6563, 0.0937}, 
          {\"bi\", -0.1990, 0.6990, 0.5000}, 
          {\"ky\", 1.0000, 0, 0}} }};         \
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KF coordinates (zero column to be added)-LEFT", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phasesubf = {\"chl\",\"bi\",\"alm\",\"fst\",\"fctd\",\"ky\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
infosubf = {
{{6.000, 500.00}, 
         {{\"chl\", 0.1477, 0.8523}, 
          {\"bi\", -0.2368, 1.2368}},

         {{\"chl\", 0.1843, 0.8157}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 509.50}, 
         {{\"fctd\", 0.5000, 0.5000}, 
          {\"ky\", 1.0000, 0}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"chl\", 0.1556, 0.8444}, 
          {\"bi\", -0.2366, 1.2366}},

         {{\"chl\", 0.1844, 0.8156}, 
          {\"fctd\", 0.5000, 0.5000}} },

{{6.000, 521.40}, 
         {{\"chl\", 0.1847, 0.8153}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"chl\", 0.1847, 0.8153}, 
          {\"fctd\", 0.5000, 0.5000}},

         {{\"chl\", 0.1652, 0.8348}, 
          {\"bi\", -0.2344, 1.2344}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 526.04}, 
         {{\"chl\", 0.1688, 0.8312}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"bi\", -0.2330, 1.2330}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"chl\", 0.1688, 0.8312}, 
          {\"bi\", -0.2330, 1.2330}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}} ,

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 538.03}, 
         {{\"bi\", -0.2300, 1.2300}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 545.38}, 
         {{\"fctd\", 0.5000, 0.5000}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fctd\", 0.5000, 0.5000}, 
          {\"fst\", 0.6923, 0.3077}},

         {{\"bi\", -0.2282, 1.2282}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 554.93}, 
         {{\"bi\", -0.2258, 1.2258}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 572.42}, 
         {{\"bi\", -0.2217, 1.2217}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 584.82}, 
         {{\"bi\", -0.2188, 1.2188}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 591.04}, 
         {{\"bi\", -0.2173, 1.2173}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 645.06}, 
         {{\"bi\", -0.2055, 1.2055}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} },
          
 {{6.000, 650.00}, 
         {{\"bi\", -0.2044, 1.2044}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"alm\", 0.2500, 0.7500}},

         {{\"fst\", 0.6923, 0.3077}, 
          {\"ky\", 1.0000, 0}} }};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["KM coordinates (zero column to be added) - RIGHT", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["phasesubm = {\"chl\",\"bi\",\"py\",\"mst\",\"mctd\",\"ky\"};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
infosubm ={
{{6.000, 500.00}, 
         {{\"bi\", -0.3074, 1.3074}, 
          {\"chl\", 0.1427, 0.8573}},

         {{\"chl\", 0.2180, 0.7820}, 
          {\"ky\", 1.0000, 0}} },
          
{{6.000, 509.50}, 
         {{\"bi\", -0.3033, 1.3033}, 
          {\"chl\", 0.1494, 0.8506}},

         {{\"chl\", 0.2162, 0.7838}, 
          {\"ky\", 1.0000, 0}} },
          
{{6.000, 521.40}, 
         {{\"bi\", -0.2964, 1.2964}, 
          {\"chl\", 0.1577, 0.8423}},

         {{\"chl\", 0.2140, 0.7860}, 
          {\"ky\", 1.0000, 0}} },
          
{{6.000, 526.04}, 
         {{\"bi\", -0.2933, 1.2933}, 
          {\"chl\", 0.1608, 0.8392}},

         {{\"chl\", 0.2131, 0.7869}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 538.03}, 
         {{\"bi\", -0.2846, 1.2846}, 
          {\"chl\", 0.1688, 0.8312}},

         {{\"chl\", 0.2109, 0.7891}, 
          {\"ky\", 1.0000, 0}} },
          
{{6.000, 545.38}, 
         {{\"bi\", -0.2787, 1.2787}, 
          {\"chl\", 0.1736, 0.8264}},

         {{\"chl\", 0.2096, 0.7904}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 554.93}, 
         {{\"bi\", -0.2705, 1.2705}, 
          {\"chl\", 0.1798, 0.8202}},

         {{\"chl\", 0.2080, 0.7920}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 572.42}, 
         {{\"bi\", -0.2541, 1.2541}, 
          {\"chl\", 0.1907, 0.8093}},

         {{\"chl\", 0.2050, 0.7950}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 584.82}, 
         {{\"bi\", -0.2417, 1.2417}, 
          {\"chl\", 0.1982, 0.8018}},

         {{\"chl\", 0.2030, 0.7970}, 
          {\"ky\", 1.0000, 0}} },

{{6.000, 591.04}, 
         {{\"bi\", -0.2353, 1.2353}, 
          {\"ky\", 1.0000, 0}},

         {{\"chl\", 0.2021, 0.7979}, 
          {\"ky\", 1.0000, 0}},

         {{\"bi\", -0.2353, 1.2353}, 
          {\"chl\", 0.2021, 0.7979}} },

{{6.000, 645.06}, 
         {{\"bi\", -0.2214, 1.2214}, 
          {\"ky\", 1.0000, 0}} },
                    
{{6.000, 650.00}, 
         {{\"bi\", -0.2205, 1.2205}, 
          {\"ky\", 1.0000, 0}} }};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["setting up", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setup[\"6.0 kbar\"];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["doing it", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["make[554.91];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74986 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.503263 0.724698 0.503263 [
[ 0 0 0 0 ]
[ 1 .74986 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .74986 L
0 .74986 L
closepath
clip
newpath
p
p
1 .55 .55 r
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
F
0 g
.004 w
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
s
P
p
1 .85 .85 r
p
p
.73832 .31192 m
.86916 .08529 L
.32375 .10598 L
.39192 .31569 L
.73832 .31192 L
F
P
p
.39192 .31569 m
.30409 .34725 L
.30612 .34725 L
.40239 .32153 L
.39192 .31569 L
F
P
p
.32375 .10598 m
.30409 .34725 L
.28208 .34725 L
.14383 .1078 L
.32375 .10598 L
F
P
p
.40257 .32154 m
.41746 .56984 L
.42895 .56984 L
.51811 .32612 L
.40257 .32154 L
F
P
p
P
p
.30609 .34725 m
.41744 .56984 L
.4106 .56984 L
.28208 .34725 L
.30609 .34725 L
F
P
p
.40239 .32153 m
.39171 .47307 L
.39178 .47307 L
.40257 .32154 L
.40239 .32153 L
F
P
p
P
p
.30612 .34725 m
.39171 .47307 L
.39166 .47307 L
.30609 .34725 L
.30612 .34725 L
F
P
p
.41746 .56984 m
.39178 .47307 L
.39166 .47307 L
.41744 .56984 L
.41746 .56984 L
F
P
p
.73012 .32612 m
.5 .7247 L
.5 .7247 L
.51811 .32612 L
.73012 .32612 L
F
P
p
P
p
P
p
.42895 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.42895 .56984 L
F
P
p
P
P
0 g
p
p
.004 w
.73832 .31192 m
.86916 .08529 L
.32375 .10598 L
.39192 .31569 L
.73832 .31192 L
s
P
p
.004 w
.39192 .31569 m
.30409 .34725 L
.30612 .34725 L
.40239 .32153 L
.39192 .31569 L
s
P
p
.004 w
.32375 .10598 m
.30409 .34725 L
.28208 .34725 L
.14383 .1078 L
.32375 .10598 L
s
P
p
.004 w
.40257 .32154 m
.41746 .56984 L
.42895 .56984 L
.51811 .32612 L
.40257 .32154 L
s
P
p
P
p
.004 w
.30609 .34725 m
.41744 .56984 L
.4106 .56984 L
.28208 .34725 L
.30609 .34725 L
s
P
p
.004 w
.40239 .32153 m
.39171 .47307 L
.39178 .47307 L
.40257 .32154 L
.40239 .32153 L
s
P
p
P
p
.004 w
.30612 .34725 m
.39171 .47307 L
.39166 .47307 L
.30609 .34725 L
.30612 .34725 L
s
P
p
.004 w
.41746 .56984 m
.39178 .47307 L
.39166 .47307 L
.41744 .56984 L
.41746 .56984 L
s
P
p
.004 w
.73012 .32612 m
.5 .7247 L
.5 .7247 L
.51811 .32612 L
.73012 .32612 L
s
P
p
P
p
P
p
.004 w
.42895 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.42895 .56984 L
s
P
p
P
P
P
p
1 g
p
.39192 .31569 m
.32375 .10598 L
.30409 .34725 L
.39192 .31569 L
F
.40239 .32153 m
.30612 .34725 L
.39171 .47307 L
.40239 .32153 L
F
.40257 .32154 m
.41746 .56984 L
.39178 .47307 L
.40257 .32154 L
F
.51811 .32612 m
.42895 .56984 L
.5 .7247 L
.51811 .32612 L
F
.30609 .34725 m
.41744 .56984 L
.39166 .47307 L
.30609 .34725 L
F
P
0 g
p
.004 w
.39192 .31569 m
.32375 .10598 L
.30409 .34725 L
.39192 .31569 L
s
.40239 .32153 m
.30612 .34725 L
.39171 .47307 L
.40239 .32153 L
s
.40257 .32154 m
.41746 .56984 L
.39178 .47307 L
.40257 .32154 L
s
.51811 .32612 m
.42895 .56984 L
.5 .7247 L
.51811 .32612 L
s
.30609 .34725 m
.41744 .56984 L
.39166 .47307 L
.30609 .34725 L
s
P
P
p
p
/Helvetica findfont 16 scalefont setfont
[(6.0 kbar)] .14772 .61901 0 0 Mshowa
P
p
/Times-Bold findfont 18 scalefont setfont
[(AFM)] .14772 .67437 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(als)] .55033 .69954 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(st)] .36412 .57372 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(ctd)] .30876 .47307 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(g)] .2383 .34725 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(chl)] .77176 .32209 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(bi)] .5 .05536 0 0 Mshowa
P
P
p
/Helvetica findfont 16 scalefont setfont
[(554.9)] .11249 .56365 -1 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 299},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001:a000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo000VOol00`00Oomoo`3oOom0Ool00`00Oomoo`0UOol002Ioo`03001n<Gha0?mn<D1n<@03
001oogoo02Eoo`009goo00<007haOS40ogha?Wha00<007ooOol09Woo000WOol00`00OS5n<@3oOS4n
OS400`00Oomoo`0VOol002Qoo`03001n<Gha0?mn<Can<@03001oogoo02Moo`00:Goo00<007haOS40
ogha>Wha00<007ooOol0:7oo000YOol00`00OS5n<@3oOS4jOS400`00Oomoo`0XOol002Yoo`03001n
<Gha0?mn<CQn<@03001oogoo02Uoo`00:Woo00<007haOS40ogha>7ha00<007ooOol0:Goo000[Ool0
0`00OS5n<@2DOS400`00BDX88@0200001DU:OS5n<Gha0000Ugha00<007ooOol0:Woo000/Ool00`00
OS5n<@2COS4200001EV<OS59BP00BDX00Wha00<007haOS40U7ha00<007ooOol0:goo000/Ool00`00
OS5n<@2COS400`00BDYn<@02OS401DU:001n<Gha0000UWha00<007ooOol0:goo000]Ool00`00OS5n
<@2BOS400`00LNmn<@03OS401000OS5n<@00UGha00<007ooOol0;7oo000]Ool00`00OS5n<@2BOS40
0`00OS5n<@03OS401000OS5n<@00UGha00<007ooOol0;7oo000^Ool00`00OS5n<@2AOS400`00OS5n
<@03OS401000OS5n<@00U7ha00<007ooOol0;Goo000^Ool00`00OS5n<@2AOS400`00DF]n<@02OS40
1DU:001n<Gha0000U7ha00<007ooOol0;Goo000_Ool00`00OS5n<@2@OS4200001EV<OS59BP00BDX0
0Wha00<007haOS40TGha00<007ooOol0;Woo000`Ool00`00OS5n<@2?OS400`00@BT88@0200001DU:
OS5n<Gha0000TWha00<007ooOol0;goo000`Ool00`00OS5n<@2?OS400`00OS5n<@2IOS400`00Oomo
o`0_Ool0035oo`03001n<Gha08in<@03001n<Gha09Qn<@03001oogoo031oo`00<Goo00<007haOS40
SWha00<007haOS401Wha00<007haOS40Sgha00<007ooOol0<7oo000bOol00`00OS5n<@3oOS4XOS40
0`00Oomoo`0aOol0039oo`03001n<Gha0?mn<BQn<@03001oogoo035oo`00<goo00<007haOS40ogha
9Wha00<007ooOol0<Woo000dOol00`00OS5n<@3oOS4HOS4=000eOol003Aoo`03001n<Gha0?mn<AP0
00aoN`03001oogoo03=oo`00=Goo00<007haOS40iWha60008gmk00<007ooOol0=7oo000eOol00`00
OS5n<@3>OS4H000kOg/00`00Oomoo`0dOol003Ioo`03001n<Gha0;An<AT0059oN`03001oogoo03Eo
o`00=goo00<007haOS40Vgha6000JWmk00<007ooOol0=Woo000gOol00`00OS5n<@23OS4H0022Og/0
0`00Oomoo`0fOol003Qoo`03001n<Gha06Yn<AP009UoN`03001oogoo03Moo`00>7oo00<007haOS40
DWha6000/Gmk00<007ooOol0=goo000iOomD0038Og/00`00Oomoo`0hOol003Uoo`03001oNgmk04Eo
N`03001oNgmk0=5oN`03001oogoo03Qoo`00>Woo00<007mkOg/0A7mk00<007mkOg/0d7mk00<007oo
Ool0>Goo000jOol00`00Og]oN`14Og/2003@Og/00`00Oomoo`0jOol003]oo`03001oNgmk04=oN`80
0=1oN`03001oogoo03Yoo`00?7oo00<007mkOg/0@Wmk0P00cgmk00<007ooOol0>goo000lOol00`00
Og]oN`12Og/00`00Ool0003>Og/00`00Oomoo`0kOol003eoo`03001oNgmk041oN`04001oogoo003=
Og/00`00Oomoo`0lOol003eoo`03001oNgmk041oN`04001oogoo003<Og/2000nOol003ioo`03001o
Ngmk03moN`05001oogooOol0003;Og/00`00Oomoo`0mOol003moo`03001oNgmk03ioN`05001oogoo
Ool0003:Og/00`00Oomoo`0nOol003moo`03001oNgmk03ioN`05001oogooOol0003:Og/00`00Oomo
o`0nOol0041oo`03001oNgmk03eoN`03001oogoo009oo`03001oNgmk0<IoN`03001oogoo03moo`00
@7oo00<007mkOg/0?Gmk00<007ooOol00Woo00<007mkOg/0aWmk00<007ooOol0?goo0011Ool00`00
Og]oN`0lOg/00`00Oomoo`02Ool00`00Og]oN`35Og/00`00Oomoo`10Ool0045oo`03001oNgmk03ao
N`03001oogoo00=oo`03001oNgmk0<=oN`03001oogoo045oo`00@Woo00<007mkOg/0>gmk00<007oo
Ool00goo00<007mkOg/0`gmk00<007ooOol0@Goo0013Ool00`00Og]oN`0jOg/00`00Oomoo`03Ool0
0`00Og]oN`32Og/00`00Oomoo`12Ool004=oo`03001oNgmk03YoN`03001oogoo00Aoo`03001oNgmk
0<5oN`03001oogoo049oo`00A7oo00<007mkOg/0>7mk00<007ooOol01Goo00<007mkOg/0`7mk00<0
07ooOol0@goo0014Ool00`00Og]oN`0hOg/00`00Oomoo`05Ool00`00Og]oN`30Og/00`00Oomoo`13
Ool004Eoo`03001oNgmk03MoN`03001oogoo00Ioo`03001oNgmk0;ioN`03001oogoo04Aoo`00AGoo
00<007mkOg/0=gmk00<007ooOol01Woo00<007mkOg/0_Gmk00<007ooOol0AGoo0016Ool00`00Og]o
N`0fOg/00`00Oomoo`06Ool00`00Og]oN`2mOg/00`00Oomoo`15Ool004Moo`03001oNgmk03EoN`03
001oogoo00Moo`03001oNgmk0;]oN`03001oogoo04Ioo`00Agoo00<007mkOg/0=Gmk00<007ooOol0
1goo00<007mkOg/0^gmk00<007ooOol0AWoo0018Ool00`00Og]oN`0dOg/00`00Oomoo`07Ool00`00
Og]oN`2jOg/00`00Oomoo`17Ool004Qoo`03001oNgmk03AoN`03001oogoo00Qoo`03001oNgmk0;Qo
N`8004Uoo`00BGoo00<007mkOg/0<gmk00<007ooOol027oo00<007mkOg/0^7mk00<007ooOol0B7oo
001:Ool00`00Og]oN`0bOg/00`00Oomoo`08Ool00`00Og]oN`2gOg/00`00Oomoo`19Ool004Yoo`03
001oNgmk039oN`03001oogoo00Uoo`03001oNgmk0;IoN`03001oogoo04Uoo`00Bgoo00<007mkOg/0
<7mk00<007ooOol02Woo00<007mkOg/0]Gmk00<007ooOol0BWoo001;Ool00`00Og]oN`0`Og/00`00
Oomoo`0:Ool00`00Og]oN`2eOg/00`00Oomoo`1:Ool004aoo`03001oNgmk02moN`03001oogoo00]o
o`03001oNgmk0;=oN`03001oogoo04]oo`00C7oo00<007mkOg/0;gmk00<007ooOol02goo00<007mk
Og/0/Wmk00<007ooOol0C7oo001=Ool00`00Og]oN`0^Og/00`00Oomoo`0;Ool00`00Og]oN`2bOg/0
0`00Oomoo`1<Ool004ioo`03001oNgmk02eoN`03001oogoo00aoo`03001oNgmk0;1oN`03001oogoo
04eoo`00CWoo00<007mkOg/0;Gmk00<007ooOol037oo00<007mkOg/0/7mk00<007ooOol0CGoo001?
Ool00`00Og]oN`0/Og/00`00Oomoo`0<Ool00`00Og]oN`2_Og/00`00Oomoo`1>Ool004moo`03001o
Ngmk02aoN`03001oogoo00eoo`03001oNgmk0:ioN`03001oogoo04ioo`00D7oo00<007mkOg/0:gmk
00<007ooOol03Goo00<007mkOg/0[Gmk00<007ooOol0Cgoo001@Ool00`00Og]oN`0[Og/00`00Oomo
o`0=Ool00`00Og]oN`2/Og/00`00Oomoo`1@Ool0055oo`03001oNgmk02YoN`03001oogoo00ioo`03
001oNgmk0:]oN`03001oogoo051oo`00DWoo00<007mkOg/0:7mk00<007ooOol03goo00<007mkOg/0
ZWmk00<007ooOol0DGoo001BOol00`00Og]oN`0XOg/00`00Oomoo`0?Ool00`00Og]oN`2ZOg/00`00
Oomoo`1AOol005=oo`03001oNgmk02MoN`03001oogoo00moo`03001oNgmk0:UoN`03001oogoo059o
o`00Dgoo00<007mkOg/09gmk00<007ooOol047oo00<007mkOg/0Z7mk00<007ooOol0DWoo001DOol0
0`00Og]oN`0VOg/00`00Oomoo`0@Ool00`00Og]oN`2WOg/00`00Oomoo`1COol005Eoo`03001oNgmk
02EoN`03001oogoo011oo`03001oNgmk0:IoN`03001oogoo05Aoo`00EGoo00<007mkOg/09Gmk00<0
07ooOol04Goo00<007mkOg/0YGmk00<007ooOol0E7oo001FOol00`00Og]oN`0TOg/00`00Oomoo`0A
Ool00`00Og]oN`2TOg/00`00Oomoo`1EOol005Ioo`03001oNgmk02AoN`03001oogoo015oo`03001o
Ngmk0:AoN`03001oogoo05Eoo`00Egoo00<007mkOg/08gmk00<007ooOol04Woo00<007mkOg/0XWmk
00<007ooOol0EWoo001GOol00`00Og]oN`0SOg/00`00Oomoo`0BOol00`00Og]oN`2QOg/00`00Oomo
o`1GOol005Qoo`03001oNgmk025oN`03001oogoo01=oo`03001oNgmk0:5oN`03001oogoo05Moo`00
FGoo00<007mkOg/087mk00<007ooOol057oo00<007mkOg/0Wgmk00<007ooOol0F7oo001IOol00`00
Og]oN`0POg/00`00Oomoo`0DOol00`00Og]oN`2OOg/00`00Oomoo`1HOol005Yoo`03001oNgmk01mo
N`03001oogoo01Aoo`03001oNgmk09ioN`03001oogoo05Uoo`00FWoo00<007mkOg/07gmk00<007oo
Ool05Goo00<007mkOg/0WGmk00<007ooOol0FGoo001KOol00`00Og]oN`0NOg/00`00Oomoo`0EOol0
0`00Og]oN`2LOg/00`00Oomoo`1JOol005]oo`03001oNgmk01ioN`03001oogoo01Eoo`03001oNgmk
09]oN`03001oogoo05]oo`00G7oo00<007mkOg/07Gmk00<007ooOol05Woo00<007mkOg/0VWmk00<0
07ooOol0Fgoo001MOol00`00Og]oN`0LOg/00`00Oomoo`0FOol00`00Og]oN`2IOg/00`00Oomoo`1L
Ool005eoo`03001oNgmk01aoN`03001oogoo01Ioo`03001oNgmk09UoN`03001oogoo05aoo`00GWoo
00<007mkOg/06gmk00<007ooOol05goo00<007mkOg/0Ugmk00<007ooOol0GGoo001NOol00`00Og]o
N`0KOg/00`00Oomoo`0GOol00`00Og]oN`2GOg/00`00Oomoo`1MOol005moo`03001oNgmk01UoN`03
001oogoo01Qoo`03001oNgmk09IoN`03001oogoo05ioo`00H7oo00<007mkOg/067mk00<007ooOol0
6Goo00<007mkOg/0U7mk00<007ooOol0Ggoo001POol00`00Og]oN`0HOg/00`00Oomoo`0IOol00`00
Og]oN`2DOg/00`00Oomoo`1OOol0065oo`03001oNgmk01MoN`03001oogoo01Uoo`03001oNgmk09=o
N`03001oogoo061oo`00HGoo00<007mkOg/05gmk00<007ooOol06Woo00<007mkOg/0TWmk00<007oo
Ool0H7oo001ROol00`00Og]oN`0FOg/00`00Oomoo`0JOol00`00Og]oN`2AOg/00`00Oomoo`1QOol0
069oo`03001oNgmk01IoN`03001oogoo01Yoo`03001oNgmk091oN`03001oogoo069oo`00Hgoo00<0
07mkOg/05Gmk00<007ooOol06goo00<007mkOg/0Sgmk00<007ooOol0HWoo001TOol00`00Og]oN`0D
Og/00`00Oomoo`0KOol00`00Og]oN`2>Og/00`00Oomoo`1SOol006Aoo`03001oNgmk01AoN`03001o
ogoo01]oo`03001oNgmk08ioN`03001oogoo06=oo`00IGoo00<007mkOg/04gmk00<007ooOol077oo
00<007mkOg/0S7mk00<007ooOol0I7oo001UOol00`00Og]oN`0COg/00`00Oomoo`0LOol00`00Og]o
N`2<Og/00`00Oomoo`1TOol006Ioo`03001oNgmk015oN`03001oogoo01eoo`03001oNgmk08]oN`03
001oogoo06Eoo`00IWoo00<007mkOg/04Gmk00<007ooOol07Woo00<007mkOg/0RGmk00<007ooOol0
IWoo001WOol00`00Og]oN`0@Og/00`00Oomoo`0NOol00`00Og]oN`29Og/00`00Oomoo`1VOol006Qo
o`03001oNgmk00moN`03001oogoo01ioo`03001oNgmk06IoNb<006Uoo`00J7oo00<007mkOg/03gmk
00<007ooOol07goo00<007mkOg/087mkA@008Wha00<007ooOol00Woo00E:DP00000004YB009oo`03
001oogoo00=oo`04001oogoo001DOol006Uoo`03001oNgmk00ioN`03001oogoo01ioob@006In<@03
001oogoo009oo`09BU8004YBOom:DP00BU9oo`0000Eoo`04001oogoo001DOol006Uoo`03001oNgmk
00ioN`03001oogoo01]oo`<000=oN`8008En<@03001oogoo009oo`03001:DWoo009oo`04BU8007oo
0005Ool01000Oomoo`00E7oo001ZOol00`00Og]oN`0=Og/00`00Oomoo`0HOol30006Og/?001gOS40
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`00E7oo001[Ool00`00Og]o
N`0<Og/00`00Oomoo`0EOol30005Og/40002Ool00`00Og]oN`0:Og/G001OOS400`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`00E7oo001[Ool00`00Og]oN`0<Og/00`00Oomo
o`0BOol30004Og/40006Ool00`00Og]oN`0QOg]P0006Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
1000Oomoo`00E7oo001/Ool00`00Og]oN`0;Og/00`00Oomoo`0?Ool30004Og/3000:Ool00`00Og]o
N`0[Og/00`00Og]oN`1AOg/00`00Oomoo`05Ool00`00BU9oo`03Ool01000Ool005:D0goo00EcW000
Oomoo`0005Aoo`00G7oo00I:DP00000000Q2@Q0:Ool00`00Og]oN`0;Og/00`00Oomoo`0<Ool30003
Og/4000=Ool00`00Og]oN`0ZOg/2001BOg/20007Ool00dYB001:DP02Ool00dYB001oo`0200001E:D
OomcW2U:>Lh00Woo00<007ooOol0DWoo001LOol01`00BU9oogooHaPHaTYB00Yoo`03001oNgmk00Uo
N`03001oogoo00Yoo`<0009oN`@0015oo`03001oNgmk02YoN`80059oN`03001oogoo00Moo`03BU80
000000800008BU9oo`00DY@@Q000249:DP=oo`03001oogoo059oo`00HGoo00=[FQ24Ool02Goo00<0
07mkOg/02Gmk00<007ooOol01goo0`0000=oN`0000000P005Goo00<007mkOg/0:Wmk0P00DGmk00<0
07ooOol03goo00<007ooOol01Woo00<007ooOol0DWoo001MOol01TYB000000Q2BU8000]oo`03001o
Ngmk00QoN`03001oogoo00Aoo`L001Uoo`03001oNgmk02UoN`03001oo`00051oN`80015oo`03001o
ogoo00Ioo`03001oogoo059oo`00G7oo00E:DP00BU9ooe[F008000aoo`03001oNgmk00MoN`04001o
ogooOol6000LOol2000[Og/00`00Ool0001@Og/00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomo
o`1BOol005aoo`03001:DWoo009oo`03BU8007oo00]oo`03001oNgmk00MoN`L001moo`03001oo`00
02YoN`03001oo`0004moN`80071oo`00G7oo00<007ooOol00Woo00=cW000Ool037oo30008goo00<0
07oo0000:Gmk00@007ooOol004moN`03001oogoo06moo`00G7oo00<007ooOol00goo00<007ooOol0
2goo00<007mkOg/01gmk00<007ooOol08Woo00<007oo0000:Gmk00@007ooOol004ioN`80075oo`00
G7oo00<007ooOol00Woo00=cW000Ool03Goo00<007mkOg/01gmk00<007ooOol08Goo00<007oo0000
:Gmk00@007ooOol004ioN`03001oogoo071oo`00G7oo00<004YBOol00Woo00=BU000Ool03Goo00<0
07mkOg/01gmk0P008Woo00<007oo0000:7mk00D007ooOomoo`0004eoN`03001oogoo075oo`00G7oo
00E:DP00BU9ooe[F008000moo`03001oNgmk00MoN`03001oogoo021oo`03001oo`0002QoN`04001o
ogoo001=Og/2001cOol005eoo`06BU800000249:DP0047oo00<007mkOg/01Wmk0P008Goo00<007oo
00009gmk00D007ooOomoo`0004eoN`03001oogoo079oo`00Lgoo00<007mkOg/01gmk0P0087oo00<0
07oo00009gmk00D007ooOomoo`0004aoN`8007Aoo`00M7oo00<007mkOg/01Wmk0P0087oo00<007oo
00009gmk00D007ooOomoo`0004aoN`03001oogoo07=oo`00M7oo00<007mkOg/01gmk0P007goo00<0
07oo00009Wmk00<007ooOol00Woo00<007mkOg/0BGmk0P00MGoo001eOol00`00Og]oN`06Og/00`00
Ool0000NOol00`00Ool0000VOg/00`00Oomoo`02Ool00`00Og]oN`18Og/2001fOol007Eoo`03001o
Ngmk00MoN`8001ioo`03001oo`0002IoN`03001oogoo009oo`03001oNgmk04QoN`03001oogoo07Eo
o`00MWoo00<007mkOg/01Wmk00<007oo00007Goo00<007oo00009Gmk00<007ooOol00goo00<007mk
Og/0Agmk0P00Mgoo001gOol00`00Og]oN`06Og/00`00Ool0000LOol00`00Ool0000UOg/00`00Oomo
o`03Ool00`00Og]oN`17Og/00`00Oomoo`1fOol007Moo`03001oNgmk00IoN`04001oogoo000JOol0
1000Oomoo`009Gmk00<007ooOol00goo00<007mkOg/0AWmk0P00N7oo001hOol00`00Og]oN`06Og/0
0`00Ool0000JOol01000Oomoo`0097mk00<007ooOol017oo00<007mkOg/0AWmk00<007ooOol0Mgoo
001hOol00`00Og]oN`06Og/01000Oomoo`006Goo00@007ooOol002AoN`03001oogoo00Aoo`03001o
Ngmk04EoN`03001oogoo07Qoo`00NGoo00<007mkOg/01Wmk00@007ooOol001Qoo`05001oogooOol0
000SOg/00`00Oomoo`04Ool00`00Og]oN`14Og/2001jOol007Uoo`03001oNgmk00IoN`04001oogoo
000HOol01@00Oomoogoo00008Wmk00<007ooOol01Goo00<007mkOg/0A7mk00<007ooOol0NGoo001j
Ool00`00Og]oN`06Og/01000Oomoo`005goo00D007ooOomoo`00029oN`03001oogoo00Eoo`03001o
Ngmk04=oN`8007]oo`00Ngoo00<007mkOg/01Gmk00D007ooOomoo`0001Ioo`05001oogooOol0000Q
Og/00`00Oomoo`06Ool00`00Og]oN`13Og/00`00Oomoo`1jOol007]oo`03001oNgmk00IoN`04001o
ogoo000FOol01@00Oomoogoo00008Gmk00<007ooOol01Woo00<007mkOg/0@Wmk0P00O7oo001lOol0
0`00Og]oN`05Og/01@00Oomoogoo00005Goo00D007ooOomoo`00025oN`03001oogoo00Ioo`03001o
Ngmk049oN`03001oogoo07]oo`00O7oo00<007mkOg/01Wmk00D007ooOomoo`0001Aoo`05001oogoo
Ool0000POg/00`00Oomoo`07Ool00`00Og]oN`11Og/00`00Oomoo`1lOol007eoo`03001oNgmk00Eo
N`05001oogooOol0000DOol01@00Oomoogoo000087mk00<007ooOol01goo00<007mkOg/0@7mk0P00
OWoo001mOol00`00Og]oN`06Og/01@00Oomoogoo00004goo00D007ooOomoo`00021oN`03001oogoo
00Moo`03001oNgmk041oN`03001oogoo07eoo`00OWoo00<007mkOg/01Gmk00<007ooOol00Woo00<0
07ooOol047oo00D007ooOomoo`0001moN`03001oogoo00Qoo`03001oNgmk03moN`8007moo`00Ogoo
00<007mkOg/01Gmk00D007ooOomoo`00019oo`05001oogooOol0000OOg/00`00Oomoo`08Ool00`00
Og]oN`0oOg/00`00Oomoo`1nOol007moo`03001oNgmk00EoN`03001oogoo009oo`03001oogoo00mo
o`05001oogooOol0000OOg/00`00Oomoo`07Ool00`00Og]oN`0oOg/20020Ool0081oo`03001oNgmk
00EoN`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oNgmk01aoN`03001oogoo
00Qoo`03001oNgmk03moN`03001oogoo07moo`00P7oo00<007mkOg/01Gmk00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol00Woo00<007mkOg/077mk00<007ooOol027oo00<007mkOg/0?Wmk00<0
07ooOol0P7oo0021Ool00`00Og]oN`05Og/00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool00`00Og]oN`0KOg/00`00Oomoo`09Ool00`00Og]oN`0mOg/20022Ool0085oo`03001oNgmk00Eo
N`03001oogoo00=oo`03001oogoo00]oo`03001oogoo009oo`03001oNgmk01]oN`03001oogoo00Uo
o`03001oNgmk03eoN`03001oogoo085oo`00PWoo00<007mkOg/01Gmk00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol00goo00<007mkOg/06Wmk00<007ooOol02Goo00<007mkOg/0?7mk0P00Pgoo
0023Ool00`00Og]oN`04Og/00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Og]o
N`0IOg/00`00Oomoo`0:Ool00`00Og]oN`0lOg/00`00Oomoo`22Ool008=oo`03001oNgmk00EoN`03
001oogoo00=oo`03001oogoo00Uoo`03001oogoo00=oo`03001oNgmk01UoN`03001oogoo00Yoo`03
001oNgmk03]oN`03001oogoo08=oo`00Q7oo00<007mkOg/017mk00<007ooOol00goo00<007ooOol0
2Goo00<007ooOol00goo00<007mkOg/06Gmk00<007ooOol02Woo00<007mkOg/0>gmk00<007ooOol0
Pgoo0024Ool00`00Og]oN`05Og/00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Og]oN`0HOg/00`00Oomoo`0;Ool00`00Og]oN`0jOg/00`00Oomoo`24Ool008Eoo`03001oNgmk00Ao
N`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oNgmk01QoN`03001oogoo00]o
o`03001oNgmk03UoN`8008Ioo`00QGoo00<007mkOg/01Gmk00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo00<007mkOg/067mk00<007ooOol02goo00<007mkOg/0>Gmk00<007ooOol0QGoo
0026Ool00`00Og]oN`04Og/00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Og]o
N`0GOg/00`00Oomoo`0<Ool00`00Og]oN`0hOg/20027Ool008Moo`03001oNgmk00AoN`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oNgmk01MoN`03001oogoo00aoo`03001oNgmk
03QoN`03001oogoo08Ioo`00Qgoo00<007mkOg/017mk00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol00goo00<007mkOg/05Wmk00<007ooOol03Goo00<007mkOg/0=gmk00<007ooOol0Qgoo0028
Ool00`00Og]oN`04Og/00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Og]oN`0F
Og/00`00Oomoo`0=Ool00`00Og]oN`0fOg/20029Ool008Qoo`03001oNgmk00AoN`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00Aoo`03001oNgmk01IoN`03001oogoo00eoo`03001oNgmk03Io
N`03001oogoo08Qoo`00RGoo00<007mkOg/017mk00<007ooOol01Goo00D007ooOomoo`0000Ioo`03
001oNgmk01EoN`03001oogoo00ioo`03001oNgmk03EoN`8008Yoo`00RWoo00<007mkOg/00gmk00<0
07ooOol01Goo00D007ooOomoo`0000Ioo`03001oNgmk01EoN`03001oogoo00ioo`03001oNgmk03Eo
N`03001oogoo08Uoo`00RWoo00<007mkOg/00gmk00<007ooOol01Woo00@007ooOol000Ioo`03001o
Ngmk01EoN`03001oogoo00ioo`03001oNgmk03AoN`8008]oo`00LWoo00E:DP00000004YB009oo`03
>Lh0000000=oo`06BU80000048ABU0001Woo00<007mkOg/00gmk00<007ooOol01Woo00<007oo0000
1Woo00<007mkOg/057mk00<007ooOol03goo00<007mkOg/0=7mk00<007ooOol0RWoo001aOol02TYB
001:DWooBU8004YBOol006]J0goo00E:DP00BU9ooe[F008000Ioo`03001oNgmk00=oN`03001oogoo
00Ioo`03001oo`0000Ioo`03001oNgmk01AoN`03001oogoo00moo`03001oNgmk03=oN`03001oogoo
08]oo`00LGoo00<004YBOol00Woo00A:DP00Ool000Aoo`03001:DWoo009oo`03BU8007oo00Ioo`03
001oNgmk00=oN`03001oogoo00Ioo`8000Moo`03001oNgmk01=oN`03001oogoo00ioo`03001oNgmk
03=oN`8008eoo`00LGoo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00=cW000Ool0
1Woo00<007mkOg/00gmk00<007ooOol01goo00<007ooOol01Goo00<007mkOg/04Wmk00<007ooOol0
3goo00<007mkOg/0<gmk00<007ooOol0S7oo001aOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Og]oN`03Og/00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Og]oN`0BOg/00`00Oomoo`0?Ool00`00Og]oN`0bOg/2002>Ool0075oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oNgmk009oN`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oNgmk019oN`03001oogoo00moo`03001oNgmk039oN`03001oogoo08eoo`00LGoo
00<004YBOol00goo00<007oo000017oo00<004YBOol00Woo00=BU000Ool027oo00<007mkOg/00gmk
00<007ooOol01Woo00<007ooOol017oo00<007mkOg/04Gmk00<007ooOol047oo00<007mkOg/0<Gmk
00<007ooOol0SWoo001aOol00dYB001:DP02Ool014YB001oo`0017oo00E:DP00BU9ooe[F008000Yo
o`03001oNgmk009oN`03001oogoo00Ioo`03001oogoo00Aoo`03001oNgmk015oN`03001oogoo011o
o`03001oNgmk035oN`03001oogoo08ioo`00LWoo00=:DP0000000P0000=:DP0000000P000goo00I:
DP000008@TYB000:Ool00`00Og]oN`03Og/00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Og]oN`0@
Og/00`00Oomoo`0AOol00`00Og]oN`0`Og/00`00Oomoo`2?Ool007Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oNgmk009oN`03001oogoo00Eoo`03001oogoo00Aoo`03001oNgmk011oN`03001o
ogoo015oo`03001oNgmk02moN`80095oo`00NGoo00<007ooOol027oo00<007ooOol02Goo00<007mk
Og/00gmk00<007ooOol01Goo00<007ooOol00goo00<007mkOg/047mk00<007ooOol04Goo00<007mk
Og/0;gmk00<007ooOol0T7oo0024Ool00`00Oomoo`0:Ool00`00Og]oN`02Og/00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Og]oN`0?Og/00`00Oomoo`0BOol00`00Og]oN`0^Og/2002BOol0099oo`03
001oNgmk009oN`03001oogoo00Aoo`03001oogoo00=oo`03001oNgmk00moN`03001oogoo019oo`03
001oNgmk02ioN`03001oogoo095oo`00TWoo00<007mkOg/00Wmk00<007ooOol017oo00<007ooOol0
0goo00<007mkOg/03gmk00<007ooOol04Woo00<007mkOg/0;Gmk00<007ooOol0TWoo002COol00`00
Og]oN`02Og/00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Og]oN`0>Og/00`00Oomoo`0COol00`00
Og]oN`0]Og/00`00Oomoo`2BOol009=oo`03001oNgmk009oN`03001oogoo00Aoo`03001oogoo009o
o`03001oNgmk00ioN`03001oogoo01=oo`03001oNgmk02aoN`03001oogoo09=oo`00U7oo00<007mk
Og/00Wmk00<007ooOol00goo00<007ooOol00Woo00<007mkOg/03Wmk00<007ooOol04goo00<007mk
Og/0:gmk0P00UGoo002DOol00`00Og]oN`02Og/00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Og]o
N`0=Og/00`00Oomoo`0DOol00`00Og]oN`0[Og/00`00Oomoo`2DOol009Eoo`03001oNgmk009oN`03
001oogoo00=oo`03001oogoo009oo`03001oNgmk00aoN`03001oogoo01Aoo`03001oNgmk02YoN`80
09Ioo`00UWoo00D007mkOg]oN`0000Eoo`03001oogoo009oo`03001oNgmk00]oN`03001oogoo01Eo
o`03001oNgmk02YoN`03001oogoo09Eoo`00UWoo00<007mkOg/00Wmk00<007ooOol00Woo00<007oo
Ool00Woo00<007mkOg/02gmk00<007ooOol05Goo00<007mkOg/0:Gmk00<007ooOol0UWoo002GOol0
1@00Og]oNgmk000017oo00<007ooOol00Woo00<007mkOg/02gmk00<007ooOol05Goo00<007mkOg/0
:Gmk00<007ooOol0UWoo002GOol00`00Og]oN`02Og/00`00Oomoo`02Ool01@00Oomoogoo000037mk
00<007ooOol05Woo00<007mkOg/0:7mk00<007ooOol0Ugoo002HOol01@00Og]oNgmk000017oo00D0
07ooOomoo`0000aoN`03001oogoo01Ioo`03001oNgmk02MoN`8009Uoo`00V7oo00<007mkOg/00Wmk
00D007ooOomoo`0000=oo`03001oNgmk00YoN`03001oogoo01Ioo`03001oNgmk02MoN`03001oogoo
09Qoo`00VGoo00D007mkOg]oN`0000Aoo`04001oogoo000;Og/00`00Oomoo`0FOol00`00Og]oN`0W
Og/00`00Oomoo`2IOol009Yoo`05001oNgmkOg/00003Ool01000Oomoo`002gmk00<007ooOol05Woo
00<007mkOg/09gmk00<007ooOol0VGoo002JOol01@00Og]oNgmk00000goo00@007ooOol000]oN`03
001oogoo01Ioo`03001oNgmk02IoN`03001oogoo09Yoo`00Vgoo00D007mkOg]oN`00009oo`04001o
ogoo000:Og/00`00Oomoo`0GOol00`00Og]oN`0UOg/2002LOol009]oo`05001oNgmkOg/00003Ool0
0`00Ool0000:Og/00`00Oomoo`0GOol00`00Og]oN`0UOg/00`00Oomoo`2KOol009aoo`05001oNgmk
Og/00002Ool00`00Ool0000:Og/00`00Oomoo`0GOol00`00Og]oN`0TOg/2002MOol009aoo`05001o
NgmkOg/00002Ool00`00Ool00009Og/00`00Oomoo`0HOol00`00Og]oN`0TOg/00`00Oomoo`2LOol0
09eoo`09001oNgmkOg/007oo001oo`0000UoN`03001oogoo01Qoo`03001oNgmk02=oN`03001oogoo
09eoo`00WWoo00@007mkOg/0009oo`8000QoN`03001oogoo01Uoo`03001oNgmk02=oN`03001oogoo
09eoo`00WWoo00H007mkOg]oN`00Ool20008Og/00`00Oomoo`0IOol00`00Og]oN`0ROg/00`00Oomo
o`2NOol009moo`08001oNgmk001oo`00Ool000MoN`03001oogoo01Uoo`03001oNgmk025oN`800:1o
o`00;goo00=:DP0000000P0000E:DWooOomoodYB00@00003BU9oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05BU800000248icP1<Ool01000Og]oNgmk0P0000=oo`00Og/01Gmk00<007ooOol0
6Woo00<007mkOg/08Gmk00<007ooOol0Wgoo000^Ool00dYB001:DP02Ool01dYB001:DWooBU8004YB
009oo`03BU8004YB00Eoo`03001oogoo00Ioo`07BU8004YBOom[FR48:DX0C7oo00D007mkOg/007oo
008000IoN`03001oogoo01Yoo`03001oNgmk021oN`800:5oo`00;Woo00<004YBOol00goo00E:DP00
Ool004YB00Aoo`03BU8007oo00Aoo`03001oogoo00Ioo`03001:DWoo00=oo`036<IS67oo04Yoo`04
001oNgmkOg/30006Og/00`00Oomoo`0JOol00`00Og]oN`0POg/00`00Oomoo`2POol003Eoo`03001o
ogoo00Ioo`T000aoo`03BU8aS7oo04]oo`03001oNgmk00<000EoN`03001oogoo01]oo`03001oNgmk
01moN`03001oogoo0:5oo`00=Goo00<007ooOol01Woo00<001S6F]H00goo00<007ooOol01goo00M:
DP0000000124@Q0@Q00fOol00dYB00000003000014YBOomoocW>0P002goo00<007mkOg/00P001Gmk
00<007ooOol06goo00<007mkOg/07gmk00<007ooOol0XGoo000dOol00dYB001oo`06Ool01DYB001[
FQ24Li`00Woo00<007ooOol01Woo00=:DP00BU800Woo00=:DP000000=Woo00<004YBOol00Woo00I:
DP00Oomoo`00JeX<Ool00`00Og]oN`020005Og/00`00Oomoo`0KOol00`00Og]oN`0NOg/00`00Oomo
o`2ROol002ioo`8HaP07F]IoogooBU8004YBOol00QS600UJeWooOom:DP00BU9oocW><H`00Woo00<0
07ooOol01Woo00<004YBOol00goo00=BU000Ool0=Goo00<007ooOol00goo00@007ooOol000ioo`T0
01ioo`03001oNgmk01eoN`800:Aoo`00;Woo00<icQ2424800`0000I:DWooOolicQ242483000024YB
Oomoogoo48AJeWoo0008Ool00`00Oomoo`04Ool00`00Oomoo`0hOol00e[F8@P@Q002Ool00`00Oomo
o`0<Ool00`00Og]oN`05Og/00`00Oomoo`0LOol00`00Og]oN`0MOg/00`00Oomoo`2SOol002ioo`03
BU8Q27oo00Ioo`03BU8Q27oo00Moo`04HaP8@W>L0008Ool00`00Oomoo`04Ool00`00Oomoo`0eOol0
1E:D<H`HaS6<BU800goo00<007ooOol03Goo00<007mkOg/01Gmk00<007ooOol06goo00<007mkOg/0
77mk00<007ooOol0Y7oo000^Ool00e[F48Aoo`06Ool00e[F48Aoo`08Ool00cW><H`00008Ool00`00
BU9oo`03Ool00dYB001oo`0eOol00bU:48A:DP06Ool00`00Oomoo`0=Ool00`00Og]oN`05Og/00`00
Oomoo`0KOol00`00Og]oN`0LOg/00`00Oomoo`2TOol002moo`03001oogoo00Ioo`03001oogoo00Qo
o`0348@007oo00Moo`03BU8004YB009oo`03BU8004YB03Ioo`03001cW7oo00=oo`04001oogoo000@
Ool00`00Og]oN`05Og/00`00Oomoo`0JOol00`00Og]oN`0KOg/00`00Oomoo`2UOol002moo`032480
000000<000=oo`032480000000<000Eoo`03HaP007oo00Qoo`03BU80000000800003BU9oogoo03Eo
o`03001:DWoo009oo`05BU8007ooOol0000AOol00`00Og]oN`04Og/00`00Oomoo`0JOol00`00Og]o
N`0KOg/00`00Oomoo`2UOol008]oo`03BU80000000<00003BU9oo`0000<000moo`03001oNgmk00Eo
N`03001oogoo01Qoo`03001oNgmk01]oN`03001oogoo0:Ioo`00U7oo00<007ooOol047oo00<007mk
Og/017mk00<007ooOol067oo00<007mkOg/06Wmk0P00Z7oo002DOol00`00Oomoo`0@Ool00`00Og]o
N`04Og/00`00Oomoo`0HOol00`00Og]oN`0JOg/00`00Oomoo`2WOol00:Qoo`03001oNgmk00AoN`03
001oogoo01Moo`03001oNgmk01UoN`03001oogoo0:Qoo`00ZGoo00<007mkOg/00gmk00<007ooOol0
5goo00<007mkOg/06Gmk00<007ooOol0Z7oo002YOol00`00Og]oN`04Og/00`00Oomoo`0FOol00`00
Og]oN`0HOg/00`00Oomoo`2YOol00:Yoo`03001oNgmk00=oN`03001oogoo01Ioo`03001oNgmk01Qo
N`03001oogoo0:Uoo`00ZWoo00<007mkOg/017mk00<007ooOol05Goo00<007mkOg/05gmk00<007oo
Ool0ZWoo002[Ool00`00Og]oN`03Og/00`00Oomoo`0EOol00`00Og]oN`0FOg/2002/Ool00:aoo`03
001oNgmk00=oN`03001oogoo01Aoo`03001oNgmk01IoN`03001oogoo0:]oo`008Goo00=:DP000000
0P0000A:DWooOol000Aoo`03BU80000000800003BU9oogoo00Aoo`06001oogooOom242480Woo00<0
04YB24800P0000E:DWooOomoodYB00<000068@QJeQS6001oo`00Egoo00<007mkOg/00gmk00<007oo
Ool057oo00<007mkOg/05Gmk00<007ooOol0[7oo000POol00dYB001:DP02Ool00dYB001:DP05Ool0
0dYB001:DP02Ool00dYB001:DP05Ool01P00Oomoog>L249[FP9oo`800005F]IoodYB001:DP02Ool0
1`00BU9oog>LDY@8@P00009oo`03001oogoo05Ioo`03001oNgmk00=oN`03001oogoo01=oo`03001o
Ngmk01EoN`03001oogoo0:aoo`0087oo00<004YBOol00goo00=:DP00Ool017oo00<004YBOol00goo
00=:DP00Ool017oo00D007ooOolYBT8@00=oo`03001:DWoo009oo`05BU8007ooOol00004Ool01F]J
001oogoo0000F7oo00<007mkOg/00gmk00<007ooOol04goo00<007mkOg/057mk00<007ooOol0[Goo
000POol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000HaQJ
eQS617oo00<007>LOol00goo00D007ooOolHaSW>00Aoo`04001oogoo001IOol00`00Og]oN`02Og/0
0`00Oomoo`0COol00`00Og]oN`0COg/2002_Ool0021oo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00=oo`04000HaQS6JeX4Ool00`00Oomoo`03Ool02P00Oomoog>L:DX0
00Q26<HQ20000Woo00<007ooOol0F7oo00<007mkOg/00Wmk00<007ooOol04Woo00<007mkOg/04gmk
00<007ooOol0[Woo000POol00`00DYAoo`03Ool00dYB001oo`04Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool01000HaP8@V]J17oo00<007ooOol00goo00<007ooOol017oo00=S65:D00000Woo00<007oo
Ool0F7oo00<007mkOg/00Wmk00<007ooOol04Woo00<007mkOg/04Wmk00<007ooOol0[goo000POol2
00001TYBOomoodYB001:DPEoo`03001oogoo00Aoo`03001oogoo00=oo`05001oof<H6<IcW003Ool0
0`00DYAoo`02Ool01DYB001oogoo00001Goo00D007ooOol005[F05Yoo`03001oNgmk009oN`03001o
ogoo015oo`03001oNgmk019oN`03001oogoo0:moo`0087oo00<@Q5:D48@00`0000=:DWooOol017oo
00<007ooOol017oo00<007ooOol00goo00H007ooOomS61S6Li`2Ool200001E[FOom:DP00BU800Woo
00<004YBOol00Woo00M:DP00Oomoo`0048A[FP1IOol00`00Og]oN`02Og/00`00Oomoo`0AOol00`00
Og]oN`0AOg/00`00Oomoo`2`Ool0021oo`03:DYBU7oo00Yoo`03001oogoo00Aoo`03001oogoo00=o
o`0;001oogooOomJeQ24Liaoo`00@Q08@P0200001DYBOomoogooBU801@0000M:DWooOol005:D2480
001IOol00`00Og]oN`02Og/00`00Oomoo`0@Ool00`00Og]oN`0AOg/00`00Oomoo`2`Ool0021oo`03
F]HHaWoo00=oo`03BU8007oo00Aoo`03001:DWoo00=oo`03BU8007oo00Aoo`03001oogoo00Eoo`03
001oogoo06aoo`03001oNgmk009oN`03001oogoo011oo`03001oNgmk011oN`03001oogoo0;5oo`00
8Goo0RU:00E[FWooBU8004YB00Eoo`03BU8004YB009oo`03BU8004YB00Eoo`03001oogoo00Eoo`03
001oogoo06eoo`03001oNgmk009oN`03001oogoo00moo`03001oNgmk00moN`800;=oo`008Woo00Di
cPQ2000004YB00Moo`03BU80000000800003BU9oogoo00Aoo`03001oogoo00Eoo`03001oogoo06io
o`05001oNgmkOg/0000AOol00`00Og]oN`0?Og/00`00Oomoo`2bOol00;=oo`03001oNgmk009oN`03
001oogoo00eoo`03001oNgmk00moN`03001oogoo0;=oo`00]7oo00D007mkOg]oN`0000moo`03001o
Ngmk00moN`03001oogoo0;=oo`00]7oo00<007mkOg/00Wmk00<007ooOol037oo00<007mkOg/03Wmk
00<007ooOol0]7oo002eOol01@00Og]oNgmk00003Woo00<007mkOg/03Wmk00<007ooOol0]7oo002f
Ool01000Og]oN`003Woo00<007mkOg/03Gmk00<007ooOol0]Goo002fOol01@00Og]oNgmk00003Goo
00<007mkOg/037mk0P00]goo002gOol01000Og]oN`003Goo00<007mkOg/037mk00<007ooOol0]Woo
002gOol01@00Og]oNgmk000037oo00<007mkOg/02gmk00<007ooOol0]goo000VOol40003Ool60002
Ool60004Ool50002Ool01000Oomoogoo1@00JGoo00@007mkOg/000aoo`03001oNgmk00]oN`03001o
ogoo0;Moo`009goo0P001Goo100017oo0`0027oo00@007ooOomoo`8000Aoo`<006]oo`04001oNgmk
000;Ool00`00Og]oN`0:Og/00`00Oomoo`2hOol002Qoo`03001oogoo00=oo`<000Eoo`<000Qoo`04
001oogooOol30003Ool3001[Ool01000Og]oN`002goo00<007mkOg/02Wmk00<007ooOol0^7oo000X
Ool00`00Oomoo`03Ool30005Ool30008Ool00`00Oomoo`040003Ool3001/Ool01000Og]oN`002Woo
00<007mkOg/02Gmk00<007ooOol0^Goo000YOol80005Ool30003Ool00`00Oomoo`02Ool00`00Oomo
o`040003Ool3001/Ool01000Og]oN`002Woo00<007mkOg/027mk00<007ooOol0^Woo000YOol01000
Oomoogoo0`001Woo0`000goo00<007ooOol00Woo00<007ooOol00`0000Aoo`00Oomoo`<006eoo`04
001oNgmk0009Ool00`00Og]oN`08Og/00`00Oomoo`2jOol002Uoo`03001oogoo00@000Ioo`L000Ao
o`03001oo`000080009oo`03001oogoo00<006eoo`04001oNgmk0009Ool00`00Og]oN`07Og/00`00
Oomoo`2kOol002Yoo`03001oo`00008000Moo`<000=oo`03001oogoo009oo`03001oo`000080009o
o`03001oogoo00<006ioo`04001oNgmk0008Ool00`00Og]oN`07Og/00`00Oomoo`2kOol002Yoo`03
001oo`00008000Moo`<000=oo`03001oogoo009oo`D000=oo`03001oo`00008006moo`03001oN`00
00Qoo`03001oNgmk00IoN`03001oogoo0;aoo`00:goo0`0027oo0`001Goo00<007ooOol0100017oo
00<007oo00000P00Kgoo00<007mk000027oo00<007mkOg/01Wmk00<007ooOol0_7oo000[Ool30008
Ool30005Ool00`00Oomoo`040004Ool00`00Ool00002001`Ool00`00Og/00007Ool00`00Og]oN`05
Og/00`00Oomoo`2mOol002]oo`8000Uoo`<000Aoo`80009oo`@000Eoo`@0071oo`03001oN`0000Mo
o`03001oNgmk00AoN`03001oogoo0;ioo`00;7oo00<007ooOol01Woo3`001Woo1@00L7oo00<007mk
00001Woo00<007mkOg/017mk00@007ooOom:DP<000068@QJeQS6001oo`000Woo00=:DP0000000`00
00=:DWooOol0ZGoo0030Ool20006Ool00`00Og]oN`03Og/02`00Oomoogoo001:DWooLiaBU0Q20000
0Woo00D007ooOol004YB00=oo`03BU8007oo0:Yoo`00`7oo00<007mk00001Goo00<007mkOg/00gmk
00D007ooOomoo`0000Aoo`05JeX007ooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`2YOol00<5o
o`8000Aoo`03001oNgmk00=oN`03001oogoo009oo`036<HicWoo00=oo`04001oogoo0006Ool00e[F
8@P@Q02[Ool00<5oo`03001oN`0000=oo`03001oNgmk009oN`8000Aoo`07Li`YBP00248HaR480000
0Woo00T007ooOomooe:D<H`HaS6<BU80[7oo0032Ool20003Ool00`00Og]oN`02Og/00`00Oomoo`07
Ool00f<HDY@00002Ool01P00OomoobU:48A:DZmoo`00`goo0P000Woo00D007mkOg]oN`0000Ioo`03
001oogoo00=oo`04001oogoo0002Ool00`00Liaoo`03Ool00`00Oomoo`2YOol00<=oo`80009oo`05
001oNgmkOg/00006Ool00`00BU9oo`02Ool01DYB001oogoo00000Woo00<004YBOol00Woo00=:DP00
Ool0ZWoo0034Ool01000Oomoo`000Wmk00<007ooOol01Goo00=:DP0000000`0000A:DWooOol0009o
o`03BU80000000<00003BU9oogoo0:Uoo`00a7oo0P0000Eoo`00Og]oN`00011oo`03001oogoo0;9o
o`00aGoo00D007oo001oN`00015oo`03001oogoo0;9oo`00aWoo0`004Woo00<007ooOol0/Woo0036
Ool30037Ool00<Moo`03001oogoo0<Ioo`00agoo00<007ooOol0aWoo003oOonAOol00?mooi5oo`00
ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {298, 0}} -> {-0.997508, -1.44001, 0.00500004, \
0.00500004}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["make[560];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74986 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.503263 0.724698 0.503263 [
[ 0 0 0 0 ]
[ 1 .74986 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .74986 L
0 .74986 L
closepath
clip
newpath
p
p
1 .55 .55 r
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
F
0 g
.004 w
.09612 .02516 m
.5 .7247 L
.90388 .02516 L
s
P
p
1 .85 .85 r
p
p
.7374 .31351 m
.86777 .0877 L
.34862 .10711 L
.40927 .31721 L
.7374 .31351 L
F
P
p
.40927 .31721 m
.30899 .34725 L
.31043 .34725 L
.41669 .32136 L
.40927 .31721 L
F
P
p
.34862 .10711 m
.30899 .34725 L
.28208 .34725 L
.14418 .1084 L
.34862 .10711 L
F
P
p
.41669 .32136 m
.41875 .56984 L
.43007 .56984 L
.52352 .32568 L
.41669 .32136 L
F
P
p
P
p
.31043 .34725 m
.41875 .56984 L
.4106 .56984 L
.28208 .34725 L
.31043 .34725 L
F
P
p
.73038 .32568 m
.5 .7247 L
.5 .7247 L
.52352 .32568 L
.73038 .32568 L
F
P
p
P
p
P
p
.43007 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.43007 .56984 L
F
P
P
0 g
p
p
.004 w
.7374 .31351 m
.86777 .0877 L
.34862 .10711 L
.40927 .31721 L
.7374 .31351 L
s
P
p
.004 w
.40927 .31721 m
.30899 .34725 L
.31043 .34725 L
.41669 .32136 L
.40927 .31721 L
s
P
p
.004 w
.34862 .10711 m
.30899 .34725 L
.28208 .34725 L
.14418 .1084 L
.34862 .10711 L
s
P
p
.004 w
.41669 .32136 m
.41875 .56984 L
.43007 .56984 L
.52352 .32568 L
.41669 .32136 L
s
P
p
P
p
.004 w
.31043 .34725 m
.41875 .56984 L
.4106 .56984 L
.28208 .34725 L
.31043 .34725 L
s
P
p
.004 w
.73038 .32568 m
.5 .7247 L
.5 .7247 L
.52352 .32568 L
.73038 .32568 L
s
P
p
P
p
P
p
.004 w
.43007 .56984 m
.5 .7247 L
.5 .7247 L
.4106 .56984 L
.43007 .56984 L
s
P
P
P
p
1 g
p
.40927 .31721 m
.34862 .10711 L
.30899 .34725 L
.40927 .31721 L
F
.41669 .32136 m
.31043 .34725 L
.41875 .56984 L
.41669 .32136 L
F
.52352 .32568 m
.43007 .56984 L
.5 .7247 L
.52352 .32568 L
F
P
0 g
p
.004 w
.40927 .31721 m
.34862 .10711 L
.30899 .34725 L
.40927 .31721 L
s
.41669 .32136 m
.31043 .34725 L
.41875 .56984 L
.41669 .32136 L
s
.52352 .32568 m
.43007 .56984 L
.5 .7247 L
.52352 .32568 L
s
P
P
p
p
/Helvetica findfont 16 scalefont setfont
[(6.0 kbar)] .14772 .61901 0 0 Mshowa
P
p
/Times-Bold findfont 18 scalefont setfont
[(AFM)] .14772 .67437 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(als)] .55033 .69954 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(st)] .36412 .57372 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(ctd)] .30876 .47307 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(g)] .2383 .34725 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(chl)] .77176 .32209 0 0 Mshowa
P
p
/Helvetica findfont 16 scalefont setfont
[(bi)] .5 .05536 0 0 Mshowa
P
P
p
/Helvetica findfont 16 scalefont setfont
[(560.)] .11249 .56365 -1 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 299},
  ImageMargins->{{35, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001:a000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo000VOol00`00Oomoo`3oOom0Ool00`00Oomoo`0UOol002Ioo`03001n<Gha0?mn<D1n<@03
001oogoo02Eoo`009goo00<007haOS40ogha?Wha00<007ooOol09Woo000WOol00`00OS5n<@3oOS4n
OS400`00Oomoo`0VOol002Qoo`03001n<Gha0?mn<Can<@03001oogoo02Moo`00:Goo00<007haOS40
ogha>Wha00<007ooOol0:7oo000YOol00`00OS5n<@3oOS4jOS400`00Oomoo`0XOol002Yoo`03001n
<Gha0?mn<CQn<@03001oogoo02Uoo`00:Woo00<007haOS40ogha>7ha00<007ooOol0:Goo000[Ool0
0`00OS5n<@2DOS400`00BDX88@0200001DU:OS5n<Gha0000Ugha00<007ooOol0:Woo000/Ool00`00
OS5n<@2COS4200001EV<OS59BP00BDX00Wha00<007haOS40U7ha00<007ooOol0:goo000/Ool00`00
OS5n<@2COS400`00BDYn<@02OS401DU:001n<Gha0000UWha00<007ooOol0:goo000]Ool00`00OS5n
<@2BOS400`00LNmn<@03OS401000OS5n<@00UGha00<007ooOol0;7oo000]Ool00`00OS5n<@2BOS40
0`00OS5n<@03OS401000OS5n<@00UGha00<007ooOol0;7oo000^Ool00`00OS5n<@2AOS400`00OS5n
<@03OS401000OS5n<@00U7ha00<007ooOol0;Goo000^Ool00`00OS5n<@2AOS400`00DF]n<@02OS40
1DU:001n<Gha0000U7ha00<007ooOol0;Goo000_Ool00`00OS5n<@2@OS4200001EV<OS59BP00BDX0
0Wha00<007haOS40TGha00<007ooOol0;Woo000`Ool00`00OS5n<@2?OS400`00@BT88@0200001DU:
OS5n<Gha0000TWha00<007ooOol0;goo000`Ool00`00OS5n<@2?OS400`00OS5n<@2IOS400`00Oomo
o`0_Ool0035oo`03001n<Gha08in<@03001n<Gha09Qn<@03001oogoo031oo`00<Goo00<007haOS40
SWha00<007haOS401Wha00<007haOS40Sgha00<007ooOol0<7oo000bOol00`00OS5n<@3oOS4XOS40
0`00Oomoo`0aOol0039oo`03001n<Gha0?mn<BQn<@03001oogoo035oo`00<goo00<007haOS40ogha
9Wha00<007ooOol0<Woo000dOol00`00OS5n<@3oOS4TOS400`00Oomoo`0cOol003Aoo`03001n<Gha
0?mn<AIn<@l003Eoo`00=Goo00<007haOS40nWha6P003Gmk00<007ooOol0=7oo000eOol00`00OS5n
<@3QOS4I000VOg/2000fOol003Ioo`03001n<Gha0<In<AX003moN`03001oogoo03Eoo`00=goo00<0
07haOS40Zgha6P00F7mk00<007ooOol0=Woo000gOol00`00OS5n<@2AOS4J001aOg/2000hOol003Qo
o`03001n<Gha07Mn<AT008]oN`03001oogoo03Moo`00>7oo00<007haOS40GGha6P00Xgmk0P00>Goo
000iOol00`00OS5n<@0WOS4e002mOg/00`00Oomoo`0hOol003UoobX002QoN`03001oNgmk0<IoN`80
03Yoo`00>Woo00<007mkOg/0CWmk00<007mkOg/0aWmk00<007ooOol0>Goo000kOol00`00Og]oN`1=
Og/20036Og/00`00Oomoo`0jOol003]oo`03001oNgmk04aoN`03001oo`000<EoN`8003aoo`00?7oo
00<007mkOg/0Bgmk00<007oo0000aGmk00<007ooOol0>goo000lOol2001<Og/01000Oomoo`00`gmk
0P00?Goo000mOol00`00Og]oN`1:Og/01000Oomoo`00`gmk00<007ooOol0?7oo000mOol2001;Og/0
1000Oomoo`00`Wmk0P00?Woo000nOol00`00Og]oN`19Og/01000Oomoo`00`Gmk0P00?goo000oOol0
0`00Og]oN`17Og/00`00Oomoo`02Ool00`00Og]oN`2nOg/00`00Oomoo`0nOol003moo`03001oNgmk
04MoN`03001oogoo009oo`03001oNgmk0;eoN`80041oo`00@7oo00<007mkOg/0AWmk00<007ooOol0
0Woo00<007mkOg/0_Gmk00<007ooOol0?goo0010Ool20017Og/00`00Oomoo`03Ool00`00Og]oN`2k
Og/20011Ool0045oo`03001oNgmk04EoN`03001oogoo00=oo`03001oNgmk0;]oN`03001oogoo041o
o`00@Woo00<007mkOg/0A7mk00<007ooOol00goo00<007mkOg/0^Wmk00<007ooOol0@Goo0012Ool0
0`00Og]oN`13Og/00`00Oomoo`04Ool00`00Og]oN`2iOg/20013Ool004=oo`03001oNgmk049oN`03
001oogoo00Eoo`03001oNgmk0;QoN`03001oogoo049oo`00@goo00<007mkOg/0@Wmk00<007ooOol0
1Goo00<007mkOg/0]gmk0P00A7oo0014Ool00`00Og]oN`11Og/00`00Oomoo`05Ool00`00Og]oN`2g
Og/00`00Oomoo`13Ool004Aoo`80049oN`03001oogoo00Ioo`03001oNgmk0;EoN`8004Eoo`00AGoo
00<007mkOg/0@7mk00<007ooOol01Woo00<007mkOg/0]Gmk00<007ooOol0A7oo0016Ool00`00Og]o
N`0nOg/00`00Oomoo`07Ool00`00Og]oN`2dOg/00`00Oomoo`15Ool004Ioo`03001oNgmk03ioN`03
001oogoo00Moo`03001oNgmk0;=oN`8004Moo`00Agoo00<007mkOg/0?Gmk00<007ooOol027oo00<0
07mkOg/0/Wmk00<007ooOol0AWoo0017Ool2000nOg/00`00Oomoo`08Ool00`00Og]oN`2aOg/20018
Ool004Qoo`03001oNgmk03aoN`03001oogoo00Qoo`03001oNgmk0;5oN`03001oogoo04Moo`00B7oo
0P00?Gmk00<007ooOol02Goo00<007mkOg/0[gmk0P00BGoo0019Ool00`00Og]oN`0jOg/00`00Oomo
o`0:Ool00`00Og]oN`2^Og/2001:Ool004Yoo`03001oNgmk03UoN`03001oogoo00Yoo`03001oNgmk
0:ioN`03001oogoo04Uoo`00BWoo00<007mkOg/0>Gmk00<007ooOol02Woo00<007mkOg/0[Gmk0P00
Bgoo001;Ool00`00Og]oN`0hOg/00`00Oomoo`0;Ool00`00Og]oN`2/Og/00`00Oomoo`1:Ool004]o
o`8003UoN`03001oogoo00]oo`03001oNgmk0:]oN`8004aoo`00C7oo00<007mkOg/0=gmk00<007oo
Ool02goo00<007mkOg/0Zgmk00<007ooOol0Bgoo001=Ool00`00Og]oN`0eOg/00`00Oomoo`0=Ool0
0`00Og]oN`2YOg/00`00Oomoo`1<Ool004eoo`03001oNgmk03EoN`03001oogoo00eoo`03001oNgmk
0:QoN`8004ioo`00CWoo00<007mkOg/0=7mk00<007ooOol03Goo00<007mkOg/0Z7mk00<007ooOol0
CGoo001>Ool00`00Og]oN`0dOg/00`00Oomoo`0=Ool00`00Og]oN`2WOg/2001?Ool004moo`03001o
Ngmk03=oN`03001oogoo00ioo`03001oNgmk0:IoN`03001oogoo04ioo`00Cgoo0P00=7mk00<007oo
Ool03Woo00<007mkOg/0YGmk0P00D7oo001@Ool00`00Og]oN`0aOg/00`00Oomoo`0?Ool00`00Og]o
N`2UOg/00`00Oomoo`1?Ool0055oo`03001oNgmk031oN`03001oogoo011oo`03001oNgmk0:=oN`03
001oogoo051oo`00DGoo00<007mkOg/0<7mk00<007ooOol047oo00<007mkOg/0XWmk0P00DWoo001B
Ool00`00Og]oN`0_Og/00`00Oomoo`0@Ool00`00Og]oN`2ROg/00`00Oomoo`1AOol0059oo`03001o
Ngmk02moN`03001oogoo011oo`03001oNgmk0:5oN`8005=oo`00Dgoo00<007mkOg/0;Wmk00<007oo
Ool04Goo00<007mkOg/0X7mk00<007ooOol0DWoo001COol2000^Og/00`00Oomoo`0BOol00`00Og]o
N`2OOg/2001DOol005Aoo`03001oNgmk02aoN`03001oogoo019oo`03001oNgmk09moN`03001oogoo
05=oo`00EGoo00<007mkOg/0:gmk00<007ooOol04goo00<007mkOg/0WGmk00<007ooOol0E7oo001E
Ool00`00Og]oN`0[Og/00`00Oomoo`0COol00`00Og]oN`2LOg/2001FOol005Ioo`03001oNgmk02Yo
N`03001oogoo01=oo`03001oNgmk09aoN`03001oogoo05Eoo`00EWoo00<007mkOg/0:Gmk00<007oo
Ool057oo00<007mkOg/0Vgmk0P00Egoo001GOol00`00Og]oN`0XOg/00`00Oomoo`0EOol00`00Og]o
N`2JOg/00`00Oomoo`1FOol005Qoo`03001oNgmk02MoN`03001oogoo01Eoo`03001oNgmk09UoN`03
001oogoo05Moo`00F7oo00<007mkOg/09gmk00<007ooOol05Goo00<007mkOg/0V7mk0P00FGoo001I
Ool00`00Og]oN`0VOg/00`00Oomoo`0FOol00`00Og]oN`2GOg/00`00Oomoo`1HOol005Uoo`03001o
Ngmk02IoN`03001oogoo01Ioo`03001oNgmk09IoN`8005Yoo`00FWoo00<007mkOg/097mk00<007oo
Ool05goo00<007mkOg/0UWmk00<007ooOol0FGoo001JOol00`00Og]oN`0TOg/00`00Oomoo`0GOol0
0`00Og]oN`2EOg/2001KOol005]oo`03001oNgmk02=oN`03001oogoo01Qoo`03001oNgmk09AoN`03
001oogoo05Yoo`00G7oo00<007mkOg/08Wmk00<007ooOol067oo00<007mkOg/0Tgmk00<007ooOol0
Fgoo001LOol00`00Og]oN`0ROg/00`00Oomoo`0HOol00`00Og]oN`2BOg/2001MOol005eoo`03001o
Ngmk025oN`03001oogoo01Uoo`03001oNgmk095oN`03001oogoo05aoo`00GGoo00<007mkOg/087mk
00<007ooOol06Woo00<007mkOg/0T7mk0P00GWoo001NOol00`00Og]oN`0OOg/00`00Oomoo`0JOol0
0`00Og]oN`2@Og/00`00Oomoo`1MOol005ioo`03001oNgmk01moN`03001oogoo01Yoo`03001oNgmk
08moN`8005moo`00Ggoo00<007mkOg/07Wmk00<007ooOol06goo00<007mkOg/0SWmk00<007ooOol0
GWoo001POol00`00Og]oN`0MOg/00`00Oomoo`0KOol00`00Og]oN`2=Og/00`00Oomoo`1OOol0061o
o`03001oNgmk01eoN`03001oogoo01]oo`03001oNgmk08aoN`80065oo`00HGoo00<007mkOg/06gmk
00<007ooOol07Goo00<007mkOg/0Rgmk00<007ooOol0H7oo001QOol00`00Og]oN`0KOg/00`00Oomo
o`0MOol00`00Og]oN`2:Og/2001ROol0069oo`03001oNgmk01YoN`03001oogoo01eoo`03001oNgmk
08YoN`03001oogoo065oo`00Hgoo00<007mkOg/06Gmk00<007ooOol07Goo00<007mkOg/0RGmk00<0
07ooOol0HWoo001SOol00`00Og]oN`0IOg/00`00Oomoo`0NOol00`00Og]oN`27Og/2001TOol006Ao
o`03001oNgmk01QoN`03001oogoo01ioo`03001oNgmk08MoN`03001oogoo06=oo`00I7oo00<007mk
Og/05gmk00<007ooOol07goo00<007mkOg/0QWmk0P00IGoo001UOol00`00Og]oN`0FOg/00`00Oomo
o`0POol00`00Og]oN`25Og/00`00Oomoo`1TOol006Eoo`03001oNgmk01IoN`03001oogoo021oo`03
001oNgmk08AoN`8006Ioo`00IWoo00<007mkOg/05Gmk00<007ooOol087oo00<007mkOg/0Q7mk00<0
07ooOol0IGoo001WOol00`00Og]oN`0DOg/00`00Oomoo`0POol00`00Og]oN`23Og/00`00Oomoo`1V
Ool006Moo`03001oNgmk01AoN`03001oogoo025oo`03001oNgmk085oN`8006Qoo`00J7oo00<007mk
Og/04Wmk00<007ooOol08Woo00<007mkOg/0PGmk00<007ooOol0Igoo001XOol00`00Og]oN`0BOg/0
0`00Oomoo`0ROol00`00Og]oN`1POg/R0004Ool01DYB00000000BU800Woo00<007ooOol00goo00@0
07ooOol005Aoo`00JGoo00<007mkOg/04Gmk00<007ooOol08goo00<007mkOg/07Wmk@@0087ha00<0
07ooOol00Woo00U:DP00BU9oodYB001:DWoo00001Goo00@007ooOol005Aoo`00JGoo00<007mkOg/0
4Gmk00<007ooOol08Goo8`00HGha00<007ooOol00Woo00<004YBOol00Woo00A:DP00Ool000Eoo`04
001oogoo001DOol006Yoo`03001oNgmk011oN`03001oogoo01ioo`<000=oN`h0079n<@03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo001DOol006]oo`03001oNgmk00moN`03
001oogoo01Yoo`@0009oN`@0009oo`03001oNgmk00UoNaD005an<@03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00=oo`04001oogoo001DOol006]oo`03001oNgmk00ioN`03001oogoo01Moo`@0
0003Og/0000000<000Ioo`03001oNgmk01ioNed000Ioo`03001oogoo00Eoo`03001oogoo00=oo`04
001oogoo001DOol006aoo`03001oNgmk00eoN`03001oogoo01Aoo`<00003Og/00000008000]oo`03
001oNgmk02MoN`03001oNgmk051oN`03001oogoo00Aoo`03001:DWoo00=oo`04001oo`00DY@3Ool0
1G>L001oogoo0000E7oo001LOol01TYB00000000249240Yoo`03001oNgmk00eoN`03001oogoo011o
o`P000moo`03001oNgmk02IoN`80055oN`03001oogoo00Eoo`03BU8004YB009oo`03BU8007oo0080
0005DYAoog>L:DXicP02Ool00`00Oomoo`1BOol005aoo`07001:DWooOomS61S6BU802Woo00<007mk
Og/037mk00<007ooOol037oo20004goo00<007mkOg/09Wmk0P00DGmk00<007ooOol01Woo00=:DP00
00000P0000Q:DWoo001BU1240008@TYB0goo00<007ooOol0DWoo001QOol00f]J48Aoo`09Ool00`00
Og]oN`0<Og/00`00Oomoo`09Ool7000GOol00`00Og]oN`0VOg/2001@Og/00`00Oomoo`0>Ool00`00
Oomoo`06Ool00`00Oomoo`1BOol005eoo`06BU800000249:DP002goo00<007mkOg/02gmk00<007oo
Ool01Goo1`006goo00<007mkOg/09Gmk00<007oo0000Cgmk00<007ooOol03goo00<007ooOol01Woo
00<007ooOol0DWoo001LOol01DYB001:DWooF]H00P0037oo00<007mkOg/02Gmk00<007ooOol00Woo
1P0087oo00<007mkOg/09Gmk00<007oo0000Cgmk00<007ooOol03goo00<007ooOol01Woo00<007oo
Ool0DWoo001LOol00`00BU9oo`02Ool00dYB001oo`0;Ool00`00Og]oN`09Og/00`00Ool00004000T
Ool00`00Og]oN`0UOg/00`00Ool0001>Og/00`00Oomoo`1^Ool005aoo`03001oogoo009oo`03Li`0
07oo00aoo`h002Qoo`03001oNgmk02AoN`04001oogoo001>Og/00`00Oomoo`1^Ool005aoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oNgmk00UoN`03001oogoo02Moo`03001oNgmk02AoN`04001o
ogoo001=Og/00`00Oomoo`1_Ool005aoo`03001oogoo009oo`03Li`007oo00eoo`03001oNgmk00Uo
N`03001oogoo02Ioo`03001oNgmk02=oN`04001oogoo001=Og/00`00Oomoo`1`Ool005aoo`03001:
DWoo009oo`03DY@007oo00eoo`03001oNgmk00UoN`03001oogoo02Ioo`03001oNgmk02=oN`04001o
ogoo001=Og/00`00Oomoo`1`Ool005aoo`05BU8004YBOomJeP02000?Ool00`00Og]oN`09Og/00`00
Oomoo`0UOol00`00Og]oN`0SOg/01000Oomoo`00C7mk00<007ooOol0LGoo001MOol01TYB000000Q2
BU80011oo`03001oNgmk00QoN`03001oogoo02Eoo`03001oNgmk029oN`05001oogooOol0001<Og/0
0`00Oomoo`1aOol007=oo`03001oNgmk00UoN`03001oogoo02Aoo`03001oNgmk029oN`05001oogoo
Ool0001;Og/00`00Oomoo`1bOol007Aoo`03001oNgmk00QoN`03001oogoo02Aoo`03001oNgmk025o
N`03001oogoo009oo`03001oNgmk04UoN`03001oogoo079oo`00M7oo00<007mkOg/02Gmk00<007oo
Ool08goo00<007mkOg/08Gmk00<007ooOol00Woo00<007mkOg/0B7mk00<007ooOol0Lgoo001eOol0
0`00Og]oN`08Og/00`00Oomoo`0SOol00`00Og]oN`0QOg/00`00Oomoo`02Ool00`00Og]oN`17Og/0
0`00Oomoo`1dOol007Eoo`03001oNgmk00UoN`03001oogoo029oo`03001oNgmk021oN`03001oogoo
00=oo`03001oNgmk04MoN`03001oogoo07Aoo`00MWoo00<007mkOg/027mk00<007ooOol08Woo00<0
07mkOg/087mk00<007ooOol00goo00<007mkOg/0AWmk00<007ooOol0MGoo001gOol00`00Og]oN`08
Og/00`00Oomoo`0QOol00`00Og]oN`0POg/00`00Oomoo`03Ool00`00Og]oN`16Og/00`00Oomoo`1e
Ool007Moo`03001oNgmk00QoN`03001oogoo025oo`03001oNgmk01moN`03001oogoo00Aoo`03001o
Ngmk04EoN`03001oogoo07Ioo`00N7oo00<007mkOg/027mk00<007ooOol087oo00<007mkOg/07gmk
00<007ooOol017oo00<007mkOg/0A7mk00<007ooOol0Mgoo001hOol00`00Og]oN`08Og/00`00Oomo
o`0POol00`00Og]oN`0NOg/00`00Oomoo`05Ool00`00Og]oN`14Og/00`00Oomoo`1gOol007Uoo`03
001oNgmk00MoN`03001oogoo021oo`03001oNgmk01ioN`03001oogoo00Eoo`03001oNgmk04=oN`03
001oogoo07Qoo`00NGoo00<007mkOg/027mk00<007ooOol07goo00<007mkOg/07Wmk00<007ooOol0
1Goo00<007mkOg/0@gmk00<007ooOol0N7oo001jOol00`00Og]oN`07Og/00`00Oomoo`0OOol00`00
Og]oN`0MOg/00`00Oomoo`06Ool00`00Og]oN`12Og/00`00Oomoo`1iOol007]oo`03001oNgmk00Mo
N`03001oogoo01ioo`03001oNgmk01eoN`03001oogoo00Eoo`03001oNgmk04=oN`03001oogoo07Uo
o`00Ngoo00<007mkOg/01gmk00<007ooOol07Woo00<007mkOg/07Gmk00<007ooOol01Goo00<007mk
Og/0@Wmk00<007ooOol0NWoo001lOol00`00Og]oN`07Og/00`00Oomoo`0MOol00`00Og]oN`0LOg/0
0`00Oomoo`06Ool00`00Og]oN`11Og/00`00Oomoo`1kOol007aoo`03001oNgmk00MoN`03001oogoo
01eoo`03001oNgmk01aoN`03001oogoo00Ioo`03001oNgmk045oN`03001oogoo07]oo`00OGoo00<0
07mkOg/01gmk00<007ooOol077oo00<007mkOg/06gmk00<007ooOol01goo00<007mkOg/0@7mk00<0
07ooOol0O7oo001mOol00`00Og]oN`07Og/00`00Oomoo`0LOol00`00Og]oN`0KOg/00`00Oomoo`07
Ool00`00Og]oN`10Og/00`00Oomoo`1lOol007ioo`03001oNgmk00MoN`03001oogoo01]oo`03001o
Ngmk01]oN`03001oogoo00Moo`03001oNgmk03moN`03001oogoo07eoo`00Ogoo00<007mkOg/01Wmk
00<007ooOol06goo00<007mkOg/06Wmk00<007ooOol027oo00<007mkOg/0?Wmk00<007ooOol0OWoo
001oOol00`00Og]oN`07Og/00`00Oomoo`0JOol00`00Og]oN`0JOg/00`00Oomoo`08Ool00`00Og]o
N`0nOg/00`00Oomoo`1nOol0081oo`03001oNgmk00IoN`03001oogoo01Yoo`03001oNgmk01UoN`03
001oogoo00Uoo`03001oNgmk03eoN`03001oogoo07moo`00P7oo00<007mkOg/01gmk00<007ooOol0
6Goo00<007mkOg/06Gmk00<007ooOol02Goo00<007mkOg/0?Gmk00<007ooOol0Ogoo0021Ool00`00
Og]oN`06Og/00`00Oomoo`0IOol00`00Og]oN`0IOg/00`00Oomoo`09Ool00`00Og]oN`0lOg/00`00
Oomoo`20Ool0085oo`03001oNgmk00MoN`03001oogoo01Qoo`03001oNgmk01QoN`03001oogoo00Yo
o`03001oNgmk03aoN`03001oogoo081oo`00PWoo00<007mkOg/01Wmk00<007ooOol067oo00<007mk
Og/067mk00<007ooOol02Woo00<007mkOg/0>gmk00<007ooOol0PGoo0023Ool00`00Og]oN`06Og/0
0`00Oomoo`0GOol00`00Og]oN`0HOg/00`00Oomoo`0:Ool00`00Og]oN`0jOg/00`00Oomoo`22Ool0
08=oo`03001oNgmk00IoN`03001oogoo01Moo`03001oNgmk01MoN`03001oogoo00]oo`03001oNgmk
03YoN`03001oogoo089oo`00Q7oo00<007mkOg/01Wmk00<007ooOol05Woo00<007mkOg/05gmk00<0
07ooOol02goo00<007mkOg/0>Gmk00<007ooOol0Pgoo0024Ool00`00Og]oN`06Og/00`00Oomoo`0F
Ool00`00Og]oN`0FOg/00`00Oomoo`0<Ool00`00Og]oN`0iOg/00`00Oomoo`23Ool008Eoo`03001o
Ngmk00IoN`03001oogoo01Eoo`03001oNgmk01IoN`03001oogoo00]oo`03001oNgmk03UoN`03001o
ogoo08Aoo`00QGoo00<007mkOg/01Wmk00<007ooOol05Goo00<007mkOg/05Wmk00<007ooOol02goo
00<007mkOg/0>Gmk00<007ooOol0Q7oo0026Ool00`00Og]oN`06Og/00`00Oomoo`0DOol00`00Og]o
N`0EOg/00`00Oomoo`0<Ool00`00Og]oN`0hOg/00`00Oomoo`25Ool008Moo`03001oNgmk00EoN`03
001oogoo01Eoo`03001oNgmk01AoN`03001oogoo00aoo`03001oNgmk03MoN`03001oogoo08Ioo`00
Qgoo00<007mkOg/01Wmk00<007ooOol057oo00<007mkOg/04gmk00<007ooOol03Goo00<007mkOg/0
=gmk00<007ooOol0QWoo0028Ool00`00Og]oN`05Og/00`00Oomoo`0DOol00`00Og]oN`0COg/00`00
Oomoo`0=Ool00`00Og]oN`0fOg/00`00Oomoo`27Ool008Qoo`03001oNgmk00IoN`03001oogoo01=o
o`03001oNgmk01=oN`03001oogoo00eoo`03001oNgmk03IoN`03001oogoo08Moo`00RGoo00<007mk
Og/01Gmk00<007ooOol04goo00<007mkOg/04Wmk00<007ooOol03Woo00<007mkOg/0=Gmk00<007oo
Ool0R7oo002:Ool00`00Og]oN`05Og/00`00Oomoo`0BOol00`00Og]oN`0BOg/00`00Oomoo`0>Ool0
0`00Og]oN`0dOg/00`00Oomoo`29Ool008Yoo`03001oNgmk00EoN`03001oogoo019oo`03001oNgmk
019oN`03001oogoo00ioo`03001oNgmk03AoN`03001oogoo08Uoo`00LWoo00E:DP00000004YB009o
o`03>Lh0000000=oo`06BU80000048ABU0001Woo00<007mkOg/017mk00<007ooOol04Woo00<007mk
Og/04Gmk00<007ooOol03goo00<007mkOg/0<gmk00<007ooOol0RWoo001aOol02TYB001:DWooBU80
04YBOol006]J0goo00E:DP00BU9ooe[F008000Ioo`03001oNgmk00EoN`03001oogoo015oo`03001o
Ngmk015oN`03001oogoo00moo`03001oNgmk03=oN`03001oogoo08Yoo`00LGoo00<004YBOol00Woo
00A:DP00Ool000Aoo`03001:DWoo009oo`03BU8007oo00Ioo`03001oNgmk00AoN`03001oogoo015o
o`03001oNgmk011oN`03001oogoo011oo`03001oNgmk039oN`03001oogoo08]oo`00LGoo00<007oo
Ool01Goo00<007ooOol00Woo00<007ooOol00Woo00=cW000Ool01Woo00<007mkOg/01Gmk00<007oo
Ool047oo00<007mkOg/047mk00<007ooOol047oo00<007mkOg/0<Wmk00<007ooOol0Rgoo001aOol0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Og]oN`04Og/0
0`00Oomoo`0@Ool00`00Og]oN`0@Og/00`00Oomoo`0@Ool00`00Og]oN`0aOg/00`00Oomoo`2<Ool0
075oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oNgmk
00AoN`03001oogoo00moo`03001oNgmk00moN`03001oogoo015oo`03001oNgmk031oN`03001oogoo
08eoo`00LGoo00<004YBOol00goo00<007oo000017oo00<004YBOol00Woo00=BU000Ool027oo00<0
07mkOg/017mk00<007ooOol03goo00<007mkOg/03gmk00<007ooOol04Goo00<007mkOg/0<7mk00<0
07ooOol0SGoo001aOol00dYB001:DP02Ool014YB001oo`0017oo00E:DP00BU9ooe[F008000Yoo`03
001oNgmk00AoN`03001oogoo00ioo`03001oNgmk00moN`03001oogoo011oo`03001oNgmk031oN`03
001oogoo08ioo`00LWoo00=:DP0000000P0000=:DP0000000P000goo00I:DP000008@TYB000:Ool0
0`00Og]oN`04Og/00`00Oomoo`0>Ool00`00Og]oN`0>Og/00`00Oomoo`0AOol00`00Og]oN`0`Og/0
0`00Oomoo`2>Ool007Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oNgmk00AoN`03001oogoo
00eoo`03001oNgmk00ioN`03001oogoo015oo`03001oNgmk02moN`03001oogoo08moo`00NGoo00<0
07ooOol027oo00<007ooOol02Goo00<007mkOg/017mk00<007ooOol03Goo00<007mkOg/03Gmk00<0
07ooOol04Woo00<007mkOg/0;Wmk00<007ooOol0T7oo0024Ool00`00Oomoo`0:Ool00`00Og]oN`04
Og/00`00Oomoo`0<Ool00`00Og]oN`0=Og/00`00Oomoo`0BOol00`00Og]oN`0^Og/00`00Oomoo`2@
Ool0099oo`03001oNgmk00=oN`03001oogoo00aoo`03001oNgmk00eoN`03001oogoo019oo`03001o
Ngmk02eoN`03001oogoo095oo`00TWoo00<007mkOg/017mk00<007ooOol02goo00<007mkOg/037mk
00<007ooOol04goo00<007mkOg/0;Gmk00<007ooOol0TGoo002COol00`00Og]oN`03Og/00`00Oomo
o`0;Ool00`00Og]oN`0<Og/00`00Oomoo`0COol00`00Og]oN`0/Og/00`00Oomoo`2BOol009=oo`03
001oNgmk00AoN`03001oogoo00Yoo`03001oNgmk00]oN`03001oogoo01Aoo`03001oNgmk02aoN`03
001oogoo099oo`00U7oo00<007mkOg/00gmk00<007ooOol02Woo00<007mkOg/02gmk00<007ooOol0
57oo00<007mkOg/0:gmk00<007ooOol0Tgoo002DOol00`00Og]oN`04Og/00`00Oomoo`09Ool00`00
Og]oN`0;Og/00`00Oomoo`0DOol00`00Og]oN`0ZOg/00`00Oomoo`2DOol009Eoo`03001oNgmk00=o
N`03001oogoo00Uoo`03001oNgmk00YoN`03001oogoo01Eoo`03001oNgmk02YoN`03001oogoo09Ao
o`00UWoo00<007mkOg/00gmk00<007ooOol027oo00<007mkOg/02Wmk00<007ooOol05Goo00<007mk
Og/0:Gmk00<007ooOol0UGoo002FOol00`00Og]oN`03Og/00`00Oomoo`08Ool00`00Og]oN`0:Og/0
0`00Oomoo`0EOol00`00Og]oN`0YOg/00`00Oomoo`2EOol009Moo`03001oNgmk00=oN`03001oogoo
00Moo`03001oNgmk00UoN`03001oogoo01Ioo`03001oNgmk02QoN`03001oogoo09Ioo`00Ugoo00<0
07mkOg/00gmk00<007ooOol01goo00<007mkOg/02Gmk00<007ooOol05Woo00<007mkOg/09gmk00<0
07ooOol0Ugoo002HOol00`00Og]oN`03Og/00`00Oomoo`06Ool00`00Og]oN`08Og/00`00Oomoo`0G
Ool00`00Og]oN`0WOg/00`00Oomoo`2GOol009Qoo`03001oNgmk00=oN`03001oogoo00Ioo`03001o
Ngmk00QoN`03001oogoo01Moo`03001oNgmk02IoN`03001oogoo09Qoo`00VGoo00<007mkOg/00gmk
00<007ooOol01Goo00<007mkOg/027mk00<007ooOol05Woo00<007mkOg/09gmk00<007ooOol0V7oo
002JOol00`00Og]oN`02Og/00`00Oomoo`05Ool00`00Og]oN`07Og/00`00Oomoo`0GOol00`00Og]o
N`0VOg/00`00Oomoo`2IOol009Yoo`03001oNgmk00=oN`03001oogoo00Aoo`03001oNgmk00MoN`03
001oogoo01Moo`03001oNgmk02IoN`03001oogoo09Uoo`00Vgoo00<007mkOg/00Wmk00<007ooOol0
17oo00<007mkOg/01gmk00<007ooOol05goo00<007mkOg/09Gmk00<007ooOol0VWoo002KOol00`00
Og]oN`02Og/00`00Oomoo`04Ool00`00Og]oN`06Og/00`00Oomoo`0HOol00`00Og]oN`0TOg/00`00
Oomoo`2KOol009aoo`03001oNgmk009oN`03001oogoo00=oo`03001oNgmk00IoN`03001oogoo01Qo
o`03001oNgmk02AoN`03001oogoo09]oo`00W7oo00<007mkOg/00Wmk00<007ooOol00goo00<007mk
Og/01Gmk00<007ooOol06Goo00<007mkOg/08gmk00<007ooOol0W7oo002MOol00`00Og]oN`02Og/0
0`00Oomoo`02Ool00`00Og]oN`05Og/00`00Oomoo`0IOol00`00Og]oN`0SOg/00`00Oomoo`2LOol0
09ioo`05001oNgmkOg/00004Ool00`00Og]oN`05Og/00`00Oomoo`0IOol00`00Og]oN`0ROg/00`00
Oomoo`2MOol009ioo`03001oNgmk009oN`05001oogooOol00006Og/00`00Oomoo`0JOol00`00Og]o
N`0QOg/00`00Oomoo`2NOol009moo`05001oNgmkOg/00003Ool00`00Og]oN`04Og/00`00Oomoo`0J
Ool00`00Og]oN`0QOg/00`00Oomoo`2NOol002moo`03BU80000000800005BU9oogooOom:DP040000
1DYBOomoogooBU80100000A:DWooOol005Eoo`03001oNgmk009oN`04001oogoo0005Og/00`00Oomo
o`0KOol00`00Og]oN`0POg/00`00Oomoo`2OOol002ioo`03BU8004YB009oo`07BU8004YBOom:DP00
BU800Woo00M:DP00BU9oodYB001:DP02Ool00dYB001:DP1HOol01@00Og]oNgmk00000Woo00<007mk
Og/00gmk00<007ooOol06goo00<007mkOg/087mk00<007ooOol0Wgoo000^Ool00`00BU9oo`03Ool0
1DYB001oo`00BU8017oo00E:DP00Ool004YB00Aoo`03BU8007oo05Moo`03001oNgmk009oN`03001o
o`0000EoN`03001oogoo01]oo`03001oNgmk01moN`03001oogoo0:1oo`00=Goo00<007oo00001Woo
00<007oo00001Woo00<007ooOol0Egoo00L007mkOg]oN`00Ool00004Og/00`00Oomoo`0LOol00`00
Og]oN`0OOg/00`00Oomoo`2POol003Eoo`03001oo`0000Ioo`03001oo`0000Ioo`03001oogoo045o
o`03BU80000000<00004BU9oogoo>Lh2000;Ool01000Og]oNgmk0P0017mk00<007ooOol077oo00<0
07mkOg/07Wmk00<007ooOol0XGoo000dOol01DYB001oo`00DY@017oo00A:DP00Ool000Ioo`03001o
ogoo045oo`03001:DWoo009oo`06BU8007ooOol006]J37oo00@007mkOg]oN`8000AoN`03001oogoo
01aoo`03001oNgmk01eoN`03001oogoo0:9oo`00;Woo0QS600MJeWooOom:DP00BU9oo`02000024YB
OomoodYB001:DWoo0006Ool00`00Oomoo`11Ool00`00Oomoo`03Ool01000Oomoo`003Woo2@007goo
00<007mkOg/07Gmk00<007ooOol0XWoo000^Ool00cW>48@8@P0300001TYBOomooa24DY@@Q0<00004
BU9oogoo0006Ool00`00Oomoo`15Ool00e[F8@P@Q002Ool00`00Oomoo`0<Ool00`00Og]oN`05Og/0
0`00Oomoo`0LOol00`00Og]oN`0MOg/00`00Oomoo`2SOol002ioo`03BU8Q27oo00Ioo`03:DYBU7oo
00Ioo`03001oogoo00Aoo`03001oogoo049oo`05DY@aS1S6<Ha:DP03Ool00`00Oomoo`0=Ool00`00
Og]oN`05Og/00`00Oomoo`0KOol00`00Og]oN`0MOg/00`00Oomoo`2SOol002ioo`03F]H@Q7oo00Io
o`03F]HHaWoo00=oo`05BU8007oo001:DP04Ool00dYB001oo`12Ool00bU:48A:DP06Ool00`00Oomo
o`0=Ool00`00Og]oN`05Og/00`00Oomoo`0KOol00`00Og]oN`0LOg/00`00Oomoo`2TOol002moo`03
001oogoo00Ioo`8YBP09JeYoodYB001:DWooBU8004YB009oo`03BU8004YB04=oo`03001cW7oo00=o
o`04001oogoo000@Ool00`00Og]oN`05Og/00`00Oomoo`0JOol00`00Og]oN`0KOg/00`00Oomoo`2U
Ool002moo`032480000000<000Aoo`05>Lh8@P00001:DP03Ool00dYB0000000200000dYBOomoo`12
Ool00`00BU9oo`02Ool01DYB001oogoo00004Goo00<007mkOg/017mk00<007ooOol06Woo00<007mk
Og/06gmk00<007ooOol0YGoo002;Ool00dYB0000000300000dYBOol00003000?Ool00`00Og]oN`05
Og/00`00Oomoo`0IOol00`00Og]oN`0JOg/00`00Oomoo`2VOol009Aoo`03001oogoo011oo`03001o
Ngmk00AoN`03001oogoo01Uoo`03001oNgmk01YoN`03001oogoo0:Ioo`00U7oo00<007ooOol047oo
00<007mkOg/017mk00<007ooOol06Goo00<007mkOg/06Gmk00<007ooOol0Ygoo002XOol00`00Og]o
N`04Og/00`00Oomoo`0HOol00`00Og]oN`0IOg/00`00Oomoo`2WOol00:Uoo`03001oNgmk00=oN`03
001oogoo01Qoo`03001oNgmk01QoN`03001oogoo0:Qoo`00ZGoo00<007mkOg/017mk00<007ooOol0
5goo00<007mkOg/05gmk00<007ooOol0ZGoo002ZOol00`00Og]oN`03Og/00`00Oomoo`0GOol00`00
Og]oN`0GOg/00`00Oomoo`2YOol00:Yoo`03001oNgmk00AoN`03001oogoo01Ioo`03001oNgmk01Io
N`03001oogoo0:Yoo`00Zgoo00<007mkOg/00gmk00<007ooOol05Woo00<007mkOg/05Wmk00<007oo
Ool0ZWoo002/Ool00`00Og]oN`03Og/00`00Oomoo`0EOol00`00Og]oN`0EOg/00`00Oomoo`2[Ool0
025oo`03BU80000000800004BU9oogoo0004Ool00dYB0000000200000dYBOomoo`04Ool01P00Oomo
ogoo@Q0Q209oo`03001:DPQ200800005BU9oogooOom:DP0300001R48F]HHaP00Ool005Moo`03001o
Ngmk00=oN`03001oogoo01Eoo`03001oNgmk01AoN`03001oogoo0:aoo`0087oo00=:DP00BU800Woo
00=:DP00BU801Goo00=:DP00BU800Woo00=:DP00BU801Goo00H007ooOomcW0Q2JeX2Ool200001E[F
Oom:DP00BU800Woo00L004YBOomcW5:D24800002Ool00`00Oomoo`1FOol00`00Og]oN`03Og/00`00
Oomoo`0DOol00`00Og]oN`0DOg/00`00Oomoo`2/Ool0021oo`03001:DWoo00=oo`03BU8007oo00Ao
o`03001:DWoo00=oo`03BU8007oo00Aoo`05001oogoo:DY24003Ool00`00BU9oo`02Ool01DYB001o
ogoo000017oo00E[FP00Oomoo`0005Qoo`03001oNgmk00=oN`03001oogoo01=oo`03001oNgmk01Ao
N`03001oogoo0:eoo`0087oo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool00goo00@006<HF]HHaPAoo`03001cW7oo00=oo`05001oogoo6<HicP04Ool01000Oomoo`00FGoo
00<007mkOg/00Wmk00<007ooOol04goo00<007mkOg/057mk00<007ooOol0[Goo000POol00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool010006<HHaV]J17oo00<007oo
Ool00goo00X007ooOomcW2U:0008@QS68@P0009oo`03001oogoo05Qoo`03001oNgmk009oN`03001o
ogoo019oo`03001oNgmk01=oN`03001oogoo0:ioo`0087oo00<005:DOol00goo00=:DP00Ool017oo
00<007ooOol017oo00<007ooOol00goo00@006<H249[FPAoo`03001oogoo00=oo`03001oogoo00Ao
o`03HaQBU000009oo`03001oogoo05Qoo`03001oNgmk009oN`03001oogoo019oo`03001oNgmk01=o
N`03001oogoo0:ioo`0087oo0P0000I:DWooOom:DP00BU85Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool01@00OomS61S6Li`00goo00<005:DOol00Woo00E:DP00Oomoo`0000Eoo`05001oogoo001JeP1J
Ool00`00Og]oN`02Og/00`00Oomoo`0AOol00`00Og]oN`0BOg/00`00Oomoo`2_Ool0021oo`0348AB
U12400<00003BU9oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`06001oogooHaPHaW>L0Woo
0P0000EJeWooBU8004YB009oo`03001:DWoo009oo`07BU8007ooOol00124JeX0FGoo00<007mkOg/0
0Wmk00<007ooOol04Goo00<007mkOg/04Gmk00<007ooOol0/7oo000POol00bU:DYAoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool02`00OomoogooF]H@Q7>LOol0048@24800P0000E:DWooOomoodYB
00D00007BU9oogoo001BU0Q20000FGoo00<007mkOg/00Wmk00<007ooOol047oo00<007mkOg/04Gmk
00<007ooOol0/7oo000POol00e[F6<Ioo`03Ool00dYB001oo`04Ool00`00BU9oo`03Ool00dYB001o
o`04Ool00`00Oomoo`05Ool00`00Oomoo`1/Ool00`00Og]oN`02Og/00`00Oomoo`0@Ool00`00Og]o
N`0@Og/00`00Oomoo`2aOol0025oo`8YBP05JeYoodYB001:DP05Ool00dYB001:DP02Ool00dYB001:
DP05Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool00`00Og]oN`02Og/00`00Oomoo`0?Ool00`00Og]o
N`0@Og/00`00Oomoo`2aOol0029oo`05>Lh8@P00001:DP07Ool00dYB0000000200000dYBOomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`1^Ool01@00Og]oNgmk00004Goo00<007mkOg/03gmk00<007oo
Ool0/Woo002cOol00`00Og]oN`02Og/00`00Oomoo`0>Ool00`00Og]oN`0?Og/00`00Oomoo`2bOol0
0;Aoo`05001oNgmkOg/0000@Ool00`00Og]oN`0>Og/00`00Oomoo`2cOol00;Aoo`03001oNgmk009o
N`03001oogoo00eoo`03001oNgmk00eoN`03001oogoo0;Aoo`00]Goo00D007mkOg]oN`0000moo`03
001oNgmk00eoN`03001oogoo0;Aoo`00]Woo00@007mkOg/000moo`03001oNgmk00aoN`03001oogoo
0;Eoo`00]Woo00D007mkOg]oN`0000ioo`03001oNgmk00aoN`03001oogoo0;Eoo`00]goo00@007mk
Og/000ioo`03001oNgmk00]oN`03001oogoo0;Ioo`00]goo00D007mkOg]oN`0000eoo`03001oNgmk
00YoN`03001oogoo0;Moo`009Woo10000goo1P000Woo1P0017oo1@000Woo00@007ooOomoo`D006Uo
o`04001oNgmk000<Ool00`00Og]oN`0;Og/00`00Oomoo`2gOol002Moo`8000Eoo`@000Aoo`<000Qo
o`04001oogooOol20004Ool3001[Ool01000Og]oN`002goo00<007mkOg/02Wmk00<007ooOol0^7oo
000XOol00`00Oomoo`03Ool30005Ool30008Ool01000Oomoogoo0`000goo0`00Jgoo00@007mkOg/0
00]oo`03001oNgmk00YoN`03001oogoo0;Qoo`00:7oo00<007ooOol00goo0`001Goo0`0027oo00<0
07ooOol010000goo0`00K7oo00@007mkOg/000Yoo`03001oNgmk00UoN`03001oogoo0;Uoo`00:Goo
20001Goo0`000goo00<007ooOol00Woo00<007ooOol010000goo0`00K7oo00@007mkOg/000Yoo`03
001oNgmk00UoN`03001oogoo0;Uoo`00:Goo00@007ooOomoo`<000Ioo`<000=oo`03001oogoo009o
o`03001oogoo00<00004Ool007ooOol3001]Ool01000Og]oN`002Goo00<007mkOg/027mk00<007oo
Ool0^Woo000YOol00`00Oomoo`040006Ool70004Ool00`00Ool000020002Ool00`00Oomoo`03001]
Ool01000Og]oN`002Goo00<007mkOg/01gmk00<007ooOol0^goo000ZOol00`00Ool000020007Ool3
0003Ool00`00Oomoo`02Ool00`00Ool000020002Ool00`00Oomoo`03001^Ool01000Og]oN`0027oo
00<007mkOg/01gmk00<007ooOol0^goo000ZOol00`00Ool000020007Ool30003Ool00`00Oomoo`02
Ool50003Ool00`00Ool00002001_Ool00`00Og/00008Ool00`00Og]oN`06Og/00`00Oomoo`2lOol0
02]oo`<000Qoo`<000Eoo`03001oogoo00@000Aoo`03001oo`00008006moo`03001oN`0000Qoo`03
001oNgmk00IoN`03001oogoo0;aoo`00:goo0`0027oo0`001Goo00<007ooOol0100017oo00<007oo
00000P00L7oo00<007mk00001goo00<007mkOg/01Gmk00<007ooOol0_Goo000[Ool20009Ool30004
Ool20002Ool40005Ool4001`Ool00`00Og/00007Ool00`00Og]oN`04Og/00`00Oomoo`2nOol002ao
o`03001oogoo00Ioo`l000Ioo`D0071oo`03001oN`0000Ioo`03001oNgmk00AoN`04001oogooBU83
00001R48F]HHaP00Ool0009oo`03BU80000000<00003BU9oogoo0:Uoo`00`7oo0P001Woo00<007mk
Og/00gmk00/007ooOomoo`00BU9oog>LDY@8@P00009oo`05001oogoo001:DP03Ool00dYB001oo`2Z
Ool00<1oo`03001oN`0000Eoo`03001oNgmk00=oN`05001oogooOol00004Ool01F]J001oogoo0000
0Woo00<007ooOol00goo00<007ooOol0ZGoo0031Ool20005Ool00`00Og]oN`02Og/00`00Oomoo`02
Ool00aS6>Lioo`03Ool01000Oomoo`001Woo00=JeR4848@0Zgoo0031Ool00`00Og/00004Ool00`00
Og]oN`02Og/00`00Oomoo`02Ool01g>L:DX000Q26<HQ2000009oo`09001oogooOomBU36<6<HaS4YB
0:aoo`00`Woo0P000goo00<007mkOg/00Wmk00<007ooOol01goo00=S65:D00000Woo00H007ooOolY
BQ24BU:_Ool00<=oo`80009oo`05001oNgmkOg/00006Ool00`00Oomoo`03Ool01000Oomoo`000Woo
00<007>LOol00goo00<007ooOol0ZGoo0033Ool20002Ool01@00Og]oNgmk00001Woo00<004YBOol0
0Woo00E:DP00Oomoo`00009oo`03001:DWoo009oo`03BU8007oo0:Yoo`00a7oo00@007ooOol0009o
N`03001oogoo00Eoo`03BU80000000<00004BU9oogoo0002Ool00dYB0000000300000dYBOomoo`2Y
Ool00<Aoo`800005Ool007mkOg/0000@Ool00`00Oomoo`2bOol00<Eoo`05001oo`00Og/0000AOol0
0`00Oomoo`2bOol00<Ioo`<0019oo`03001oogoo0;9oo`00aWoo0`00agoo0037Ool00`00Oomoo`36
Ool00<Moo`03001oogoo0<Ioo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol0
0?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {298, 0}} -> {-0.997508, -1.44001, 0.00500004, \
0.00500004}}]
}, Open  ]],

Cell["the way to generate a series of diagrams - for animation ...", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Map[make, Range[555,572,0.5]];", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{655, 768},
WindowMargins->{{Automatic, 224}, {Automatic, 19}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Gd000400@0000000000000004P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 141, 2, 67, "Section"],

Cell[CellGroupData[{
Cell[1893, 58, 95, 1, 63, "Subsection"],
Cell[1991, 61, 464, 12, 68, "Input"],
Cell[2458, 75, 84, 1, 46, "Text"],
Cell[2545, 78, 67, 1, 25, "Input"],
Cell[2615, 81, 69, 1, 46, "Text"],
Cell[2687, 84, 693, 19, 77, "Input"],
Cell[3383, 105, 64, 1, 46, "Text"],
Cell[3450, 108, 1039, 20, 207, "Input"],
Cell[4492, 130, 71, 1, 46, "Text"],
Cell[4566, 133, 369, 10, 64, "Input"],
Cell[4938, 145, 89, 1, 46, "Text"],
Cell[5030, 148, 311, 9, 38, "Input"],
Cell[5344, 159, 62, 1, 46, "Text"],
Cell[5409, 162, 257, 9, 38, "Input"],
Cell[5669, 173, 77, 1, 46, "Text"],
Cell[5749, 176, 351, 10, 64, "Input"],
Cell[6103, 188, 77, 1, 46, "Text"],
Cell[6183, 191, 3128, 71, 662, "Input"],
Cell[9314, 264, 92, 1, 46, "Text"],
Cell[9409, 267, 1934, 40, 402, "Input"],
Cell[11346, 309, 72, 1, 46, "Text"],
Cell[11421, 312, 1872, 36, 402, "Input"],
Cell[13296, 350, 75, 1, 46, "Text"],
Cell[13374, 353, 1858, 30, 441, "Input"],
Cell[15235, 385, 75, 1, 46, "Text"],
Cell[15313, 388, 4269, 62, 1000, "Input"],
Cell[19585, 452, 75, 1, 46, "Text"],
Cell[19663, 455, 279, 9, 38, "Input"],
Cell[19945, 466, 69, 1, 46, "Text"],
Cell[20017, 469, 621, 16, 116, "Input"],
Cell[20641, 487, 92, 1, 46, "Text"],
Cell[20736, 490, 864, 17, 194, "Input"],
Cell[21603, 509, 76, 1, 46, "Text"],
Cell[21682, 512, 715, 15, 194, "Input"],
Cell[22400, 529, 130, 4, 62, "Text"],
Cell[22533, 535, 872, 17, 194, "Input"],
Cell[23408, 554, 100, 1, 46, "Text"],
Cell[23511, 557, 643, 14, 181, "Input"],
Cell[24157, 573, 570, 13, 142, "Input"],
Cell[24730, 588, 100, 1, 46, "Text"],
Cell[24833, 591, 478, 12, 116, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25348, 608, 85, 1, 47, "Subsection"],
Cell[25436, 611, 171, 4, 62, "Text"],
Cell[25610, 617, 600, 17, 90, "Input"],
Cell[26213, 636, 68, 1, 46, "Text"],
Cell[26284, 639, 81, 1, 25, "Input"],
Cell[26368, 642, 67, 1, 25, "Input"],
Cell[26438, 645, 136, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[26599, 653, 306, 11, 129, "Input"],
Cell[26908, 666, 202, 7, 24, "Output"]
}, Open  ]],
Cell[27125, 676, 65, 1, 46, "Text"],
Cell[27193, 679, 282, 9, 103, "Input"],
Cell[27478, 690, 76, 1, 46, "Text"],
Cell[27557, 693, 144, 5, 51, "Input"],
Cell[27704, 700, 56, 1, 46, "Text"],
Cell[27763, 703, 84, 1, 25, "Input"],
Cell[27850, 706, 309, 8, 38, "Input"],
Cell[28162, 716, 62, 1, 46, "Text"],
Cell[28227, 719, 813, 17, 142, "Input"],
Cell[29043, 738, 66, 1, 46, "Text"],
Cell[29112, 741, 536, 13, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29685, 759, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[29777, 764, 69, 1, 61, "Subsubsection"],
Cell[29849, 767, 65, 1, 46, "Text"],
Cell[29917, 770, 104, 1, 25, "Input"],
Cell[30024, 773, 68, 1, 25, "Input"],
Cell[30095, 776, 6591, 198, 2560, "Input"],
Cell[36689, 976, 95, 1, 70, "Text"],
Cell[36787, 979, 112, 1, 70, "Input"],
Cell[36902, 982, 3967, 158, 70, "Input"],
Cell[40872, 1142, 98, 1, 70, "Text"],
Cell[40973, 1145, 111, 1, 70, "Input"],
Cell[41087, 1148, 2075, 83, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[43199, 1236, 69, 1, 47, "Subsubsection"],
Cell[43271, 1239, 71, 1, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[43391, 1246, 64, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[43480, 1251, 64, 1, 25, "Input"],
Cell[43547, 1254, 31957, 692, 307, 3755, 340, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75541, 1951, 61, 1, 25, "Input"],
Cell[75605, 1954, 30048, 600, 307, 2931, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[105668, 2557, 110, 1, 46, "Text"],
Cell[105781, 2560, 81, 1, 25, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

