(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    151187,       4986]*)
(*NotebookOutlinePosition[    152266,       5020]*)
(*  CellTagsIndexPosition[    152222,       5016]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["AFM P-x at 600\[Degree]C",
    FontColor->RGBColor[1, 0, 0]],
  ""
}], "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Off[General::spell]; Off[General::spell1]; Off[Set::shape];\n\
Off[Interpolation::inhr]; Off[InterpolatingFunction::dmwarn",
    FontWeight->"Plain"],
  StyleBox["]",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0.499992]],
  StyleBox["\nSetOptions[Position, Heads -> False];\n<<Graphics`Animation`",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["making combinations (used in one phase field)", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};  \n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                            \
                       gray[n-1,m-1]]}],m];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number formatting", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[format]; \n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ, n_Integer, _?TrueQ, w_Integer]:=\n     \
Block[{m=N[10^n], y},\n           y = ToString[Round[m x]/m]; ly = \
StringLength[y];\n           If[ly < w, StringJoin[Apply[StringJoin,Table[\" \
\",{w-ly}]],y],y]]\n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,_?TrueQ]:=Block[{m=N[10^n]},Round[m x]/m];\n\
",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,___]:=N[x,n];\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_,___]:=x;\n\nSetAttributes[format,{Listable}];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["interval halving", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[ih];\n",
    FontWeight->"Plain"],
  StyleBox["ih",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[f__Function, params:{_?NumberQ...}, lim1_Function, \
lim2_Function] := \n   Block[{v1,v2,s1,s2,v,sv},\n          \
v1=N[Apply[lim1,params]]; s1=N[Apply[f,Join[{v1},params]]];            \n     \
     v2=N[Apply[lim2,params]]; s2=N[Apply[f,Join[{v2},params]]];  \n          \
If[ Sign[s1]==Sign[s2],Print[\"same sign - meaningless answer?\"]];           \
   \n          FixedPoint[( v = (v1+v2)/2; sv = N[Apply[f,Join[{v},params]]];\
\n                       If[Sign[s1]==Sign[sv], v1=v; s1=sv, v2=v; s2=sv];\n  \
                     (v1+v2)/2  )&,0.5,15]];\nih[___] = \"something is wrong \
with the input\";",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["linecuts", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[linecuts];\n\n",
    FontWeight->"Plain"],
  StyleBox["linecuts",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{slope_,intercept_},{{xlow_,xhigh_},{ylow_,yhigh_}}]:=\n  \
(y1=intercept+slope xlow; y2=intercept+slope xhigh;\n      {If[slope>0,\n     \
   If[y1<ylow, {(ylow-intercept)/slope,ylow},  {xlow,y1}],\n        \
If[y1>yhigh,{(yhigh-intercept)/slope,yhigh},{xlow,y1}]],\n       If[slope>0,\n\
        If[y2>yhigh,{(yhigh-intercept)/slope,yhigh},{xhigh,y2}],\n        \
If[y2<ylow, {(ylow-intercept)/slope,ylow},  {xhigh,y2}] ]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["T-x/P-x functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default values, normally overridden", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 400; top = 800;
delv = 5; addx = addy = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
varyTatP = True;
debugit = False;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["labelling[p_]:={};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["differentiating an interpolation function", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[dif];\n",
    FontWeight->"Plain"],
  StyleBox["dif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifr_,v_] := \n    ({r1,r2} = ifr;\n     Which[v > \
r2-difdelv,\n             (if[r2]-if[r2-difdelv])/difdelv,\n           v < \
r1,\n             (if[r1+difdelv]-if[r1])/difdelv,\n           True,\n        \
     (if[v+difdelv]-if[v])/difdelv]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
substitute into interpolation function in value (T or P) range v1 \
<-> v2\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[subsif];\n",
    FontWeight->"Plain"],
  StyleBox["subsif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,v1_,v2_] :=\n    (dv = Abs[v2-v1];\n     If[dv <= 2 delv,\n  \
      {{if[v1],v1},{if[v2],v2}},\n        kd = Floor[dv/delv]; \n        \
Map[{if[#],#}&, v1 + dv/kd Range[0,kd]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
make a boundary of the a divariant using the interpolation fn, if;  \
(note that vs < ve  OR  vs > ve)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makeboundary];\n",
    FontWeight->"Plain"],
  StyleBox["makeboundary",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifrange_,vs_,ve_] :=\n    (\n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb is maximum substitution range, with vb > va ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     If[ve > vs, {va,vb} = {vs,ve}, {va,vb} = {ve,vs}];\
\n   \n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb adjusted to be consistent with interpolation function ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     {vr1,vr2} = ifrange;\n     If[va<vr1, va=vr1];  \
If[vb>vr2, vb=vr2];\n     \n",
    FontWeight->"Plain"],
  StyleBox["     If[debugit, Print[\"    \",if]; Print[\"  \",ifrange,\"  \", \
{vs,ve},\"  \",{va,vb}]];\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n     (* ",
    FontWeight->"Plain"],
  StyleBox["xa <-> xb corresponds to va <-> vb ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)     \n     \n     z = Which[(va > top  || vb < bottom) || \
(va>=vb),\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["boundary doesn't appear within diagram ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 {{}},\n                 \n     \
          {xa,xb} = {if[va],if[vb]};  xb > xa,\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["positive slope in v-x ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 Which[xa >= left && xb <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xa > right && xb  >right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[{{left,va}},subsif[if,vsol,vb]],\n                       True,   (* \
ie xb > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[subsif[if,va,vsol],{{right,vb}}] ],\n               True,\n              \
      \n               (* ",
    FontWeight->"Plain"],
  StyleBox["negative slope in v-x",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *) \n             \n                 Which[xb >= left && xa <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xb > right && xb > right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[subsif[if,va,vsol], {{left,vb}}],\n                       True,   (* \
ie xa > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[{{right,va}}, subsif[if,vsol,vb]] ]  ];   \n                             \
  \n     (* ",
    FontWeight->"Plain"],
  StyleBox["reverse info if ve < vs ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n  \n     If[ve > vs, z, Reverse[z]]  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["no of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[diwhich];\n",
    FontWeight->"Plain"],
  StyleBox["diwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points which see s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = nposi[Map[incommon[s,#]&,plines],3];\n    \
muni = nposi[Map[incommon[s,#]&,puni]-Map[Length,puni],-1];\n    mpoints = \
nposi[Map[incommon[s,#]&,ppoints],3];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["which univariants, if any, are in range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       ipuni = \
Flatten[Position[uni[[muni]],\n                          \
_?((#[[vuposi]]>bottom && #[[vuposi]]<top)&),{1}]];\n       muni = \
muni[[ipuni]] ];\n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["duni = degenerate univariants; cduni are the others",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       duni = \
muni[[nposi[Map[Length,puni[[muni]]],2]]];  \n       cduni = \
Complement[muni,duni],\n       duni = {}; cduni = {}];\n           \n    (* ",
    
    FontWeight->"Plain"],
  StyleBox["removing degenerate univariant(s) not relevant to this divariant \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[Length[cduni]>0 && Length[duni] > 0,  \n       \
idel = Map[({v,{react,prod}} = uni[[#,{vuposi,5}]];  \n       ph = \
Flatten[{react,prod}];\n       If[incommon[prod,s] == Length[prod],\n         \
     Position[uni[[duni]],\n                  _?((#[[vuposi]] < v && \
incommon[ph,#[[5,2]]] == 1)&),{1}],\n              Position[uni[[duni]],\n    \
              _?((#[[vuposi]] > v && incommon[ph,#[[5,1]]] == \
1)&),{1}]])&,cduni];\n       muni = \
Complement[muni,duni[[Union[Flatten[idel]]]]]];\n       \n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
{\",plines[[#,{1,2}]],\", \",plines[[#,3]],\"}\"]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no univariants\"],\n             \
Print[\"  univariants\"];\n             Map[Print[\"    \", #,\": \
\",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["does a T-x / P-x divariant field", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doadi];\n",
    FontWeight->"Plain"],
  StyleBox["doadi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points relevant to s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = diwhich[s,False];\n        \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["using any univariants to get the value (ie T or P) range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n\n    Switch[Length[muni],\n       2, {va,vb} = \
uni[[muni,vuposi]]; \n          If[vb>va, {v1,v2} = {va,vb}, {v2,v1} = \
{va,vb}],\n       1, {vuni,{react,prod}} = uni[[muni[[1]],{vuposi,5}]];\n     \
     If[incommon[react,s]==Length[react],\n             v1 = bottom; v2 = \
vuni,\n             v1 = vuni; v2 = top],\n       _, v1 = bottom; v2 = top];\n\
            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iff[[mlines]]; ifrange = iffrange[[mlines]];\n\
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = plines[[mlines,{1,2}]];\n    pp = Map[(ppk = \
#; \n              pos = Position[pm, _?((#==ppk)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,1]]];\n    cpp = \
Complement[Range[Length[mlines]],Flatten[pp]];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["lc = no of lines; lpp = no of points; pcpp = no not connected to \
points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; luni = Length[muni];\n  \n   ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp,\"  \",luni]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n    \n    p = Which[lc == 1,\n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a divariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2], \n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && luni == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries, one point, and one univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            vuni = uni[[muni]][[1,vuposi]];\n                {p1,p2} = \
pp[[1]];                \n                If[vuni>vp, vw = v2, vw = v1];      \
          \n                Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp],\n\
                     makeboundary[if[[p2]],ifrange[[p2]],vp,vw]],\n           \
   \n              lc == 2, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point - ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["logic not complete",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[{d1,d2},\"  \",{vp,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    (* ",
    FontWeight->"Plain"],
  StyleBox["from here down, three boundaries (ie max for 3 phase divariants) \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n              lpp == 1,\n              \n              (* ",
    
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                      \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[ifrange[[{pp1,pp2}]],\"  \",{d1,d2},\"  \
\",{vp,vc,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lpp == 2 \
&& luni == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points: boundaries connected through points, and to a \
univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                vuni = \
uni[[muni]][[1,vuposi]];\n                {pp1,pp2}=pp;\n                p2 = \
Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
If[vuni>vp1, vw = v2, vw = v1];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,vw]],\n              \n              \
(* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** \
geometry for \",s,\" not implemented yet **\"]; {{}} ];\n    Join[p,{p[[1]]}] \
 );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadriwhich];\n",
    FontWeight->"Plain"],
  StyleBox["quadriwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, points, and degenerate univariants which see \
s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = \
Flatten[Position[Map[#[[1]]&,pqlines],_?((#==s)&)]];\n    mpoints = \
Flatten[Position[Map[#[[1]]&,ppoints],_?((#==s)&)]];        \n    muni = \
Flatten[Position[puni,_?((Length[#]==2 && incommon[#,s]==1)&),{1}]];\n       \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
\",{pqlines[[#,1]]},\", \",pqlines[[#,2]]]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no degenerate univariants\"],\n   \
          Print[\"  degenerate univariants\"];\n             Map[Print[\"    \
\", #,\": \",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doaquadri];\n",
    FontWeight->"Plain"],
  StyleBox["doaquadri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_]:=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["qline, points and degenerate univariants for this quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = quadriwhich[s,False];",
    FontWeight->"Plain"],
  StyleBox["\n    ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n    v1 = bottom; v2 = top;           \n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iffq[[mlines]];  ifrange = \
iffqrange[[mlines]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = pqlines[[mlines,2]];\n    pp = Map[(ppk = #; \n\
              pos = Position[pm, _?((incommon[#,ppk]==1)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,{2,3}]]];\n    \
cpp = Complement[Range[Length[mlines]],Flatten[pp]];\n  \n    ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; lu = Length[muni];\n\n    p = Which[lc == 1,\n    \n             \
 (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a quadrivariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0 && lu == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["- assumes lines have same slope",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && lpp == 0 && lu == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points, but one degenerate univariant *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n    \n                vuni = uni[[muni,vuposi]][[1]];\n         \
       If[{s} == puni[[muni]][[1]], vw = v1, vw = v2];\n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw,vuni],\n                     \
makeboundary[if[[2]],ifrange[[2]],vuni,vw]],\n              \n              \
lc == 2 && lpp == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n                vp = points[[mpoints]][[1,vposi]];\n        \
        d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n                ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[{d1,d2},\" \",{vp,vw1,vw2}]]",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[";       \n                      \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    lc == 3 && lpp == 1 && lu == 0,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lc == 3 \
&& lpp == 1 && lu == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, one degenerate univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vuni = uni[[muni,vuposi]][[1]];\n       \
         vp = points[[mpoints]][[1,vposi]];\n                {pp1,pp2} = \
pp[[1]]; cpp1 = cpp[[1]];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],v1,vp],  (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to ky",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vuni],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vuni,v1]],\n  \n              lc == 3 \
&& lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2}=pp;\n              \
  p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],v1,vp1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v1]],\n  \n              lc == 4 && \
lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries, plus one separate boundary ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2} = pp;\n            \
    p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                p4 = \
Complement[Range[4],{p1,p2,p3}][[1]];\n                \
Join[makeboundary[if[[p4]],ifrange[[p4]],v2,v1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p1]],ifrange[[p1]],v1,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v2]],\n  \n              (* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** not \
implemented yet **\"]; {{}} ];\n    If[p[[1]]=={}, \n       \
Join[Drop[p,1],{p[[2]]}], \n       Join[p,{p[[1]]}]]",
    FontWeight->"Plain"],
  StyleBox["   ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[");",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the quadrivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadrvariant];\n",
    FontWeight->"Plain"],
  StyleBox["quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = \
Map[doaquadri,Intersection[Map[#[[1]]&,pqlines]]];\n      ipoly = \
Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > 0)&)]];\n      \
{Hue[1,0.45,1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]\
});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[divariant];\n",
    FontWeight->"Plain"],
  StyleBox["divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = Map[doadi,Intersection[Map[Sort,plines]]];\n    \
  ipoly = Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > \
0)&)]];\n      \
{GrayLevel[1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]}\
);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["makes horizontal lines for degenerate univariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makehor];\n",
    FontWeight->"Plain"],
  StyleBox["makehor",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pluni is position of degenerate reactions in uni ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pluni = nposi[Map[Length[Flatten[#[[5]]]]&,uni],2];\
\n    If[Length[pluni]==0, Line[{{0,top+1},{1,top+1}}], (* ",
    FontWeight->"Plain"],
  StyleBox["dummy line",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n       Map[(            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ph is phases involved in A=B; vuni is T/P  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            ph = Flatten[uni[[#,5]]]; vuni = \
uni[[#,vuposi]];\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["dl2 is positions in lines which involve A or B disappearing  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            dl = plines; (* \
Map[#[[1]][[{6,7}]]&,lines]; *)\n            dl2 = \
Flatten[Position[dl,_?((#[[-1]]==ph[[1]] || #[[-1]]==ph[[2]])&),{1}]];\n      \
      \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ii locates which of the dl2 involve A and B disappearing at A=B ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            gg = gray[Length[dl2],2];\n         \
   dl1 = Map[Drop[#,-1]&,dl[[dl2]]];\n            ii = \
Flatten[Position[Map[incommon[dl1[[#[[1]]]],dl1[[#[[2]]]]]&,gg],\n            \
                       _?((#==2)&)]];\n                                   \n  \
          If[debugit, ",
    FontWeight->"Plain"],
  StyleBox["Print[ph,\"  \",dl2,\"  \",Map[gg[[#]]&,ii]]]; ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["draws horizontal line, length depends on length of ii ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            Switch[Length[ii],\n                \
   0, Line[{{left,vuni},{right,vuni}}],\n                   1, ig = \
dl2[[gg[[ii[[1]],1]]]];\n                      {r1,r2} = \
Apply[List,iff[[ig]]][[1]];\n                      If[vuni<=r1 || vuni>=r2,\n \
                        Line[{{left,vuni},{right,vuni}}],\n                   \
      Line[{{iff[[ig]][vuni],vuni},{right,vuni}}]],\n                   2, \
ig1 = dl2[[gg[[ii[[1]],1]]]];               \n                      {r11,r12} \
= Apply[List,iff[[ig1]]][[1]];\n                      ig2 = \
dl2[[gg[[ii[[2]],1]]]];\n                      {r21,r22} = \
Apply[List,iff[[ig2]]][[1]];\n                      Which[(vuni<=r11 || \
vuni>=r12) && (vuni<=r21 || vuni>=r22),\n                              \
Line[{{left,vuni},{right,vuni}}],\n                            vuni<=r11 || \
vuni>=r12,\n                              \
Line[{{iff[[ig2]][vuni],vuni},{right,vuni}}],\n                            \
vuni<=r21 || vuni>=r22,\n                              \
Line[{{iff[[ig1]][vuni],vuni},{right,vuni}}],\n                            \
True,\n                              Line[{{iff[[ig1]][vuni],vuni},\n         \
                           {iff[[ig2]][vuni],vuni}}]] ] )&,pluni] ] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["generate the outlines of the diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background]; Clear[outline]; Clear[box];\n",
    FontWeight->"Plain"],
  StyleBox["box",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {{left, bottom},{left, top},{right, top},{right, \
bottom},{left, bottom}};\n",
    FontWeight->"Plain"],
  StyleBox["background",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[1,0.3,1], Polygon[box]};\n",
    FontWeight->"Plain"],
  StyleBox["outline",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0], Line",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[box]};",
    FontWeight->"Plain"],
  StyleBox["                                    ",
    FontSize->11,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setting up ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setupvx];\n",
    FontWeight->"Plain"],
  StyleBox["setupvx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (If[TrueQ[varyTatP], \n       vposi = 5; oposi = 4; \
vuposi = 4; ouposi = 3; delv =   5; difdelv =   0.01, \n       vposi = 4; \
oposi = 5; vuposi = 3; ouposi = 4; delv = 0.2; difdelv = 0.0001];\n        \n \
   (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for lines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    rolines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,alllines];\n    alliff = Array[(ak = \
alllines[[#]]; ro = rolines[[#]];\n                    Map[(rok = #;\n        \
                 ii = Flatten[Position[Map[#[[oposi]]&,ak],\n                 \
                              _?((#==rok)&),{1}]];\n                         \
Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                        \
)&,ro])&,Length[alllines]];\n    alliffrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliff];\n                        \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for qlines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    roqlines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,allqlines];\n    alliffq = Array[(ak = \
allqlines[[#]]; ro = roqlines[[#]];\n                     Map[(rok = #;\n     \
                     ii = Flatten[Position[Map[#[[oposi]]&,ak],\n             \
                                   _?((#==rok)&),{1}]];\n                     \
     Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                         \
)&,ro])&,Length[allqlines]]; \n    alliffqrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliffq];\n                            \n    \
(* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffuni = \
Map[Interpolation[Map[#[[{ouposi,vuposi}]]&,#]]&,alluni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffpoints = \
Map[Interpolation[Map[#[[{oposi,vposi}]]&,#]]&,allpoints];\n    iffpointsx = \
Map[Interpolation[Map[#[[{oposi,3}]]&,#]]&,allpoints];  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemblevx];\n",
    FontWeight->"Plain"],
  StyleBox["assemblevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := \n   (    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming uni (ie univariants) at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    iuni = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffuni],\n                           \
 _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    uni = Map[(if = iffuni[[#]];\n   \
            If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = ok; pp = if[tt]];\n  \
             {0,2,pp,tt,alluni[[#]][[1,5]]})&,iuni];       \n    puni =  \
Map[Flatten[#[[5]]]&,uni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants excluded by out of range univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    dels1 = Map[(sp = #[[5]];\n                 \
If[#[[vuposi]]>top,\n                    If[Length[sp[[1]]]==1, {sp[[2]]},\n  \
                     {Flatten[{sp[[1,1]],sp[[2]]}],Flatten[{sp[[1,2]],sp[[2]]}\
]}],\n                    {{\"junk\"}}])&,uni];\n    dels2 = Map[(sp = \
#[[5]];\n                 If[#[[vuposi]]<bottom,\n                    \
If[Length[sp[[2]]]==1, {sp[[1]]},\n                       \
{Flatten[{sp[[1]],sp[[2,1]]}],Flatten[{sp[[1]],sp[[2,1]]}]}],\n               \
     {{\"junk\"}}])&,uni];\n    dels = Flatten[Union[dels1,dels2],1];\n       \
                         \n    cjuni =  Map[(dsk = #; ll = Length[dsk];\n     \
             Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,puni],\n   \
                                _?((#==0)&)]])&, dels];\n    juni = \
Complement[Range[Length[puni]],Intersection[Flatten[cjuni]]];\n               \
                  \n    uni = uni[[juni]];\n    puni =  puni[[juni]];         \
                   \n                                    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants that are excluded by degenerate univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    (* ",
    FontWeight->"Plain"],
  StyleBox["ie does Schreinemakers in this special case",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    dlu = \
Flatten[Position[Map[Length,puni],_?((#==2)&)]];\n    cdlu = \
Complement[Range[Length[puni]],dlu];\n    idel1 = Map[(v = uni[[#,vuposi]]; p \
= puni[[#]];\n                Position[uni[[cdlu]],\n                     \
_?((ll1 = incommon[{p[[1]]},Flatten[#[[5]]]];\n                         \
#[[vuposi]] > v && ll1 == 1)&),{1}])&,dlu];\n    idel2 = Map[(v = \
uni[[#,vuposi]]; p = puni[[#]];\n                Position[uni[[cdlu]],\n      \
               _?((ll2 = incommon[{p[[2]]},Flatten[#[[5]]]];\n                \
         #[[vuposi]] < v && ll2 == 1)&),{1}])&,dlu];\n    idel1 = \
Union[Flatten[idel1]]; idel2 = Union[Flatten[idel2]];\n    \n    udel1 = \
Map[{#[[{1,3,4}]],#[[{2,3,4}]]}&,puni[[idel1]]];\n    udel2 = \
Map[{#[[{1,2,3}]],#[[{1,2,4}]]}&,puni[[idel2]]];\n    udel = \
Partition[Flatten[{udel1,udel2}],3];\n    \n    iuni = \
Complement[Range[Length[puni]],Union[Flatten[{idel1,idel2}]]];\n    uni = \
uni[[iuni]];\n    puni =  puni[[iuni]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming points at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    ip = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffpoints],\n                        \
    _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    points = Map[(if = \
iffpoints[[#]];\n               If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = \
ok; pp = if[tt]];\n               \
{1,2,iffpointsx[[#]][ok],pp,tt,allpoints[[#]][[1,6]],\n                \
allpoints[[#]][[1,7]],allpoints[[#]][[1,8]]})&,ip];       \n    \n    ppoints \
= Map[Flatten[#[[{6,7,8}]]]&,points];\n    \n    cipoints =  Map[(dsk = #; ll \
= Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,ppoints],\n             \
                         _?((#==0)&)]])&, dels];\n    ipoints = \
Complement[Range[Length[ppoints]],Intersection[Flatten[cipoints]]];\n    \
points = points[[ipoints]];\n    ppoints = ppoints[[ipoints]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming lines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    plines = Map[Flatten[#[[1,{6,7}]]]&,alllines];\n    \
ilines1 = Flatten[Position[Map[#[[{1,-1}]]&,rolines],\n                       \
       _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    cilines2 = \
Flatten[Map[(udelk = #;\n                            Flatten[Position[plines,\
\n                                             _?((Length[Intersection[#,\
udelk]]==3)&),\n                                             {1}]])&,udel]];\n\
    ilines2 = Complement[Range[Length[rolines]],cilines2];\n    cilines3 =  \
Map[(dsk = #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,plines],\n              \
                        _?((#==0)&)]])&, dels];\n    ilines3 = \
Complement[Range[Length[plines]],Intersection[Flatten[cilines3]]];\n    \
ilines = Intersection[ilines1,ilines2,ilines3];                          \n   \
                           \n    iff = Map[(ii = #; rok = rolines[[ii]];\n    \
           kkm = Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n           \
    If[Length[kkm] == 1,\n                  alliff[[ii,kkm[[1]]]],\n          \
        kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  \
k1 = kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {f1,f2} = alliff[[ii,{k1,k2}]]; \n                  \
{fr1,fr2} = alliffrange[[ii,{k1,k2}]];\n                  diff1 = \
(fr1[[2]]-fr1[[1]]-2del)/ni;\n                  v1 = Map[{#,f1[#]}&, \
Range[fr1[[1]]+del,fr1[[2]]-del,diff1]];\n                  diff2 = \
(fr2[[2]]-fr2[[1]]-2del)/ni;\n                  v2 = Map[{#,f2[#]}&, \
Range[fr2[[1]]+del,fr2[[2]]-del,diff2]];\n                  \
Interpolation[v1(1-prop) + v2 prop]]\n              )&, ilines];            \n\
              \n    iffrange = Map[Apply[List,#][[1]]&, iff];    \n           \
        \n    plines = plines[[ilines]];\n                 \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming qlines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pqlines = Map[Flatten[#[[1,{6,7}]]]&,allqlines];\n  \
  iqlines1 = Flatten[Position[Map[#[[{1,-1}]]&,roqlines],\n                   \
           _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    ciqlines2 =  Map[(dsk \
= #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,pqlines],\n             \
                         _?((#==0)&)]])&, dels];\n    iqlines2 = \
Complement[Range[Length[pqlines]],Intersection[Flatten[ciqlines2]]];\n    \
iqlines = Intersection[iqlines1,iqlines2];\n              \n    iffq = \
Map[(ii = #; rok = roqlines[[ii]];\n               kkm = \
Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n               \
If[Length[kkm] == 1,\n                  alliffq[[ii,kkm[[1]]]],\n             \
     kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  k1 \
= kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {fq1,fq2} = alliffq[[ii,{k1,k2}]]; \n                  \
{fqr1,fqr2} = alliffqrange[[ii,{k1,k2}]];\n                  diffq1 = \
(fqr1[[2]]-fqr1[[1]]-2del)/ni;\n                  vq1 = Map[{#,fq1[#]}&, \
Range[fqr1[[1]]+del,fqr1[[2]]-del,diffq1]];\n                  diffq2 = \
(fqr2[[2]]-fqr2[[1]]-2del)/ni;\n                  vq2 = Map[{#,fq2[#]}&, \
Range[fqr2[[1]]+del,fqr2[[2]]-del,diffq2]];\n                  \
Interpolation[vq1(1-prop) + vq2 prop]]\n               )&, iqlines];          \
  \n              \n    iffqrange = Map[Apply[List,#][[1]]&, iffq];          \
\n           \n    pqlines = pqlines[[iqlines]]   );\n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makevx];\n",
    FontWeight->"Plain"],
  StyleBox["makevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := (assemblevx[ok];\n                \
Show[Graphics[{background,\n                               quadrivariant,\n   \
                            divariant,\n                               \
makehor,\n                               outline,\n                           \
    labelling[ok]}],\n                     AspectRatio -> 1, Frame -> True,\n \
                    PlotRange -> {{left, right}, {bottom, top}},\n            \
         PlotRegion-> {{addx,1-addx},{addy,1-addy}}])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell["bulk composition line below garnet - chlorite in AFM", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["definitions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 2.0; top = 14.0;
delv = 0.05;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = False;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["coordinates", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["points", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["allpoints = {{{1,  2, 0.1758, 12.34, 600.0, {\"g\"},\"bi\", \"chl\
\"}},   ",
    FontWeight->"Plain"],
  StyleBox["(* corner of g quadri *) \n             ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["{{1,  2, 0.5044, 9.16, 600.0, {\"chl\"},\"g\", \"bi\"}}};",
    FontWeight->"Plain"],
  StyleBox["   (* corner of chl quadri *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["univariants", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
alluni ={
 {{1,  1, 3.55, 600.0,  {{\"and\"}, {\"sill\"}}}},    
 {{1,  1, 3.88, 600.0,  {{\"g\", \"sill\"}, {\"st\", \"bi\"}}}}, 
 {{1,  1, 5.49, 600.0,  {{\"sill\"}, {\"ky\"}}}},    
 {{1,  1, 7.46, 600.0,  {{\"ky\", \"bi\"}, {\"st\", \"chl\"}}}},   
 {{1,  1, 8.04, 600.0,  {{\"st\", \"bi\"}, {\"chl\", \"g\"}}}}};             \
\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
if two di -> tri boundaries (ie lines) meet at a quadri -> di 
(ie a point), then put these in up-temperature (or left->right) order as \
below\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["alllines = {\n{",
    FontWeight->"Plain"],
  StyleBox["(* cd-and-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["bi-and",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.0600, 1.77, 600.0, {\"bi\", \"and\"},\"cd\"}, \
     \n{1,  2, 0.1200, 2.03, 600.0, {\"bi\", \"and\"},\"cd\"},      \n{1,  2, \
0.1800, 2.28, 600.0, {\"bi\", \"and\"},\"cd\"},   \n{1,  2, 0.2400, 2.53, \
600.0, {\"bi\", \"and\"},\"cd\"},     \n{1,  2, 0.3000, 2.77, 600.0, {\"bi\", \
\"and\"},\"cd\"},   \n{1,  2, 0.3600, 3.00, 600.0, {\"bi\", \"and\"},\"cd\"}, \
    \n{1,  2, 0.4200, 3.23, 600.0, {\"bi\", \"and\"},\"cd\"},     \n{1,  2, \
0.4800, 3.46, 600.0, {\"bi\", \"and\"},\"cd\"},     \n{1,  2, 0.5400, 3.68, \
600.0, {\"bi\", \"and\"},\"cd\"}},     \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-cd ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.0600, 1.74, 600.0, {\"cd\", \"bi\"},\"and\"},  \
   \n{1,  2, 0.1200, 1.98, 600.0, {\"cd\", \"bi\"},\"and\"},   \n{1,  2, \
0.1800, 2.21, 600.0, {\"cd\", \"bi\"},\"and\"},     \n{1,  2, 0.2400, 2.45, \
600.0, {\"cd\", \"bi\"},\"and\"},    \n{1,  2, 0.3000, 2.68, 600.0, {\"cd\", \
\"bi\"},\"and\"},    \n{1,  2, 0.3600, 2.91, 600.0, {\"cd\", \
\"bi\"},\"and\"},   \n{1,  2, 0.4200, 3.14, 600.0, {\"cd\", \"bi\"},\"and\"}, \
 \n{1,  2, 0.4800, 3.36, 600.0, {\"cd\", \"bi\"},\"and\"},   \n{1,  2, \
0.5400, 3.58, 600.0, {\"cd\", \"bi\"},\"and\"}},   \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* cd-sill-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["bi-sill",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4000, 3.24, 600.0, {\"bi\", \
\"sill\"},\"cd\"},     \n{1,  2, 0.4600, 3.42, 600.0, {\"bi\", \"sill\"},\"cd\
\"},      \n{1,  2, 0.5200, 3.59, 600.0, {\"bi\", \"sill\"},\"cd\"},    \n{1, \
 2, 0.5800, 3.76, 600.0, {\"bi\", \"sill\"},\"cd\"},     \n{1,  2, 0.6400, \
3.93, 600.0, {\"bi\", \"sill\"},\"cd\"},     \n{1,  2, 0.7000, 4.09, 600.0, {\
\"bi\", \"sill\"},\"cd\"},      \n{1,  2, 0.7600, 4.25, 600.0, {\"bi\", \
\"sill\"},\"cd\"},      \n{1,  2, 0.8200, 4.41, 600.0, {\"bi\", \
\"sill\"},\"cd\"},      \n{1,  2, 0.8800, 4.56, 600.0, {\"bi\", \
\"sill\"},\"cd\"},      \n{1,  2, 0.9400, 4.70, 600.0, {\"bi\", \
\"sill\"},\"cd\"},     \n{1,  2, 1.0000, 4.85, 600.0, {\"bi\", \"sill\"},\"cd\
\"}},     \n\n{(*",
    FontWeight->"Plain"],
  StyleBox["bi-cd",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4000, 3.16, 600.0, {\"cd\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.4600, 3.34, 600.0, {\"cd\", \"bi\"},\"sill\
\"},    \n{1,  2, 0.5200, 3.52, 600.0, {\"cd\", \"bi\"},\"sill\"},     \n{1,  \
2, 0.5800, 3.69, 600.0, {\"cd\", \"bi\"},\"sill\"},     \n{1,  2, 0.6400, \
3.87, 600.0, {\"cd\", \"bi\"},\"sill\"},      \n{1,  2, 0.7000, 4.04, 600.0, \
{\"cd\", \"bi\"},\"sill\"},      \n{1,  2, 0.7600, 4.21, 600.0, {\"cd\", \"bi\
\"},\"sill\"},      \n{1,  2, 0.8200, 4.37, 600.0, {\"cd\", \
\"bi\"},\"sill\"},    \n{1,  2, 0.8800, 4.53, 600.0, {\"cd\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.9400, 4.69, 600.0, {\"cd\", \"bi\"},\"sill\
\"},    \n{1,  2, 1.0000, 4.85, 600.0, {\"cd\", \"bi\"},\"sill\"}},      \n\n\
{",
    FontWeight->"Plain"],
  StyleBox["(* g-and-bi*)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0, 2.29, 600.0, {\"g\", \"bi\"},\"and\"},      \
\n{1,  2, 0.0100, 2.42, 600.0, {\"g\", \"bi\"},\"and\"},      \n{1,  2, \
0.0200, 2.54, 600.0, {\"g\", \"bi\"},\"and\"},     \n{1,  2, 0.0300, 2.67, \
600.0, {\"g\", \"bi\"},\"and\"},     \n{1,  2, 0.0400, 2.81, 600.0, {\"g\", \
\"bi\"},\"and\"},     \n{1,  2, 0.0500, 2.94, 600.0, {\"g\", \
\"bi\"},\"and\"},    \n{1,  2, 0.0600, 3.07, 600.0, {\"g\", \"bi\"},\"and\"}, \
    \n{1,  2, 0.0700, 3.21, 600.0, {\"g\", \"bi\"},\"and\"},    \n{1,  2, \
0.0800, 3.35, 600.0, {\"g\", \"bi\"},\"and\"},   \n{1,  2, 0.0900, 3.49, \
600.0, {\"g\", \"bi\"},\"and\"},   \n{1,  2, 0.1000, 3.63, 600.0, {\"g\", \
\"bi\"},\"and\"}},    \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-and",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0, 2.29, 600.0, {\"bi\", \"and\"},\"g\"},    \n\
{1,  2, 0.0200, 2.42, 600.0, {\"bi\", \"and\"},\"g\"},     \n{1,  2, 0.0400, \
2.55, 600.0, {\"bi\", \"and\"},\"g\"},     \n{1,  2, 0.0600, 2.68, 600.0, \
{\"bi\", \"and\"},\"g\"},      \n{1,  2, 0.0800, 2.81, 600.0, {\"bi\", \
\"and\"},\"g\"},     \n{1,  2, 0.1000, 2.95, 600.0, {\"bi\", \"and\"},\"g\"}, \
     \n{1,  2, 0.1200, 3.09, 600.0, {\"bi\", \"and\"},\"g\"},     \n{1,  2, \
0.1400, 3.23, 600.0, {\"bi\", \"and\"},\"g\"},     \n{1,  2, 0.1600, 3.37, \
600.0, {\"bi\", \"and\"},\"g\"},     \n{1,  2, 0.1800, 3.52, 600.0, {\"bi\", \
\"and\"},\"g\"},     \n{1,  2, 0.2000, 3.67, 600.0, {\"bi\", \
\"and\"},\"g\"}},     \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* g-sill-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.0500, 2.87, 600.0, {\"g\", \"bi\"},\"sill\"}, \
    \n{1,  2, 0.0600, 3.02, 600.0, {\"g\", \"bi\"},\"sill\"},     \n{1,  2, \
0.0700, 3.17, 600.0, {\"g\", \"bi\"},\"sill\"},      \n{1,  2, 0.0800, 3.33, \
600.0, {\"g\", \"bi\"},\"sill\"},   \n{1,  2, 0.0900, 3.48, 600.0, {\"g\", \
\"bi\"},\"sill\"},   \n{1,  2, 0.1000, 3.64, 600.0, {\"g\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.1100, 3.80, 600.0, {\"g\", \
\"bi\"},\"sill\"},    \n{1,  2, 0.1200, 3.96, 600.0, {\"g\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.1300, 4.13, 600.0, {\"g\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.1400, 4.30, 600.0, {\"g\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.1500, 4.47, 600.0, {\"g\", \
\"bi\"},\"sill\"}},   \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-sill",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1500, 3.27, 600.0, {\"bi\", \"sill\"},\"g\"}, \
     \n{1,  2, 0.1600, 3.35, 600.0, {\"bi\", \"sill\"},\"g\"},      \n{1,  2, \
0.1700, 3.44, 600.0, {\"bi\", \"sill\"},\"g\"},     \n{1,  2, 0.1800, 3.52, \
600.0, {\"bi\", \"sill\"},\"g\"},      \n{1,  2, 0.1900, 3.60, 600.0, \
{\"bi\", \"sill\"},\"g\"},      \n{1,  2, 0.2000, 3.69, 600.0, {\"bi\", \
\"sill\"},\"g\"},    \n{1,  2, 0.2100, 3.77, 600.0, {\"bi\", \
\"sill\"},\"g\"},      \n{1,  2, 0.2200, 3.86, 600.0, {\"bi\", \
\"sill\"},\"g\"},      \n{1,  2, 0.2300, 3.94, 600.0, {\"bi\", \
\"sill\"},\"g\"},     \n{1,  2, 0.2400, 4.03, 600.0, {\"bi\", \
\"sill\"},\"g\"},     \n{1,  2, 0.2500, 4.12, 600.0, {\"bi\", \
\"sill\"},\"g\"}},     \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* st-g-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.0300, 1.93, 600.0, {\"g\", \"bi\"},\"st\"},   \
  \n{1,  2, 0.0900, 3.28, 600.0, {\"g\", \"bi\"},\"st\"},     \n{1,  2, \
0.1200, 4.01, 600.0, {\"g\", \"bi\"},\"st\"},      \n{1,  2, 0.1500, 4.79, \
600.0, {\"g\", \"bi\"},\"st\"},      \n{1,  2, 0.1800, 5.62, 600.0, {\"g\", \
\"bi\"},\"st\"},     \n{1,  2, 0.2100, 6.52, 600.0, {\"g\", \"bi\"},\"st\"},  \
   \n{1,  2, 0.2400, 7.47, 600.0, {\"g\", \"bi\"},\"st\"},     \n{1,  2, \
0.2700, 8.48, 600.0, {\"g\", \"bi\"},\"st\"},      \n{1,  2, 0.3000, 9.54, \
600.0, {\"g\", \"bi\"},\"st\"}},      \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1000, 2.56, 600.0, {\"st\", \"bi\"},\"g\"},   \
   \n{1,  2, 0.1800, 3.62, 600.0, {\"st\", \"bi\"},\"g\"},    \n{1,  2, \
0.2200, 4.19, 600.0, {\"st\", \"bi\"},\"g\"},      \n{1,  2, 0.2600, 4.79, \
600.0, {\"st\", \"bi\"},\"g\"},    \n{1,  2, 0.3000, 5.42, 600.0, {\"st\", \
\"bi\"},\"g\"},     \n{1,  2, 0.3400, 6.09, 600.0, {\"st\", \"bi\"},\"g\"},   \
 \n{1,  2, 0.3800, 6.80, 600.0, {\"st\", \"bi\"},\"g\"},     \n{1,  2, \
0.4200, 7.57, 600.0, {\"st\", \"bi\"},\"g\"},     \n{1,  2, 0.4600, 8.40, \
600.0, {\"st\", \"bi\"},\"g\"},      \n{1,  2, 0.5000, 9.30, 600.0, {\"st\", \
\"bi\"},\"g\"}},      \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* st-sill-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1000, 3.44, 600.0, {\"st\", \
\"bi\"},\"sill\"},      \n{1,  2, 0.1500, 3.66, 600.0, {\"st\", \
\"bi\"},\"sill\"},      \n{1,  2, 0.2000, 3.88, 600.0, {\"st\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.2500, 4.13, 600.0, {\"st\", \"bi\"},\"sill\
\"},     \n{1,  2, 0.3000, 4.40, 600.0, {\"st\", \"bi\"},\"sill\"},     \n{1, \
 2, 0.3500, 4.68, 600.0, {\"st\", \"bi\"},\"sill\"},      \n{1,  2, 0.4000, \
4.99, 600.0, {\"st\", \"bi\"},\"sill\"},     \n{1,  2, 0.4500, 5.33, 600.0, {\
\"st\", \"bi\"},\"sill\"},      \n{1,  2, 0.5000, 5.69, 600.0, {\"st\", \
\"bi\"},\"sill\"},      \n{1,  2, 0.5500, 6.09, 600.0, {\"st\", \
\"bi\"},\"sill\"},      \n{1,  2, 0.6000, 6.53, 600.0, {\"st\", \
\"bi\"},\"sill\"}},     \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-sill ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.1000, 3.40, 600.0, {\"bi\", \"sill\"},\"st\"}, \
     \n{1,  2, 0.1500, 3.58, 600.0, {\"bi\", \"sill\"},\"st\"},      \n{1,  \
2, 0.2000, 3.78, 600.0, {\"bi\", \"sill\"},\"st\"},      \n{1,  2, 0.2500, \
4.00, 600.0, {\"bi\", \"sill\"},\"st\"},      \n{1,  2, 0.3000, 4.22, 600.0, \
{\"bi\", \"sill\"},\"st\"},     \n{1,  2, 0.3500, 4.47, 600.0, {\"bi\", \
\"sill\"},\"st\"},      \n{1,  2, 0.4000, 4.73, 600.0, {\"bi\", \
\"sill\"},\"st\"},      \n{1,  2, 0.4500, 5.01, 600.0, {\"bi\", \
\"sill\"},\"st\"},      \n{1,  2, 0.5000, 5.32, 600.0, {\"bi\", \
\"sill\"},\"st\"},     \n{1,  2, 0.5500, 5.66, 600.0, {\"bi\", \"sill\"},\"st\
\"},     \n{1,  2, 0.6000, 6.02, 600.0, {\"bi\", \"sill\"},\"st\"}},    \n\n\
{",
    FontWeight->"Plain"],
  StyleBox["(* st-ky-bi *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.4500, 4.80, 600.0, {\"st\", \"bi\"},\"ky\"},   \
   \n{1,  2, 0.4600, 5.09, 600.0, {\"st\", \"bi\"},\"ky\"},     \n{1,  2, \
0.4700, 5.41, 600.0, {\"st\", \"bi\"},\"ky\"},      \n{1,  2, 0.4800, 5.74, \
600.0, {\"st\", \"bi\"},\"ky\"},     \n{1,  2, 0.4900, 6.10, 600.0, {\"st\", \
\"bi\"},\"ky\"},     \n{1,  2, 0.5000, 6.49, 600.0, {\"st\", \"bi\"},\"ky\"}, \
     \n{1,  2, 0.5100, 6.91, 600.0, {\"st\", \"bi\"},\"ky\"},     \n{1,  2, \
0.5200, 7.36, 600.0, {\"st\", \"bi\"},\"ky\"},      \n{1,  2, 0.5300, 7.86, \
600.0, {\"st\", \"bi\"},\"ky\"},      \n{1,  2, 0.5400, 8.40, 600.0, {\"st\", \
\"bi\"},\"ky\"},      \n{1,  2, 0.5500, 9.00, 600.0, {\"st\", \
\"bi\"},\"ky\"}},    \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-ky ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.5000, 4.82, 600.0, {\"bi\", \"ky\"},\"st\"},   \
   \n{1,  2, 0.5100, 5.07, 600.0, {\"bi\", \"ky\"},\"st\"},      \n{1,  2, \
0.5200, 5.34, 600.0, {\"bi\", \"ky\"},\"st\"},     \n{1,  2, 0.5300, 5.63, \
600.0, {\"bi\", \"ky\"},\"st\"},     \n{1,  2, 0.5400, 5.93, 600.0, {\"bi\", \
\"ky\"},\"st\"},     \n{1,  2, 0.5500, 6.25, 600.0, {\"bi\", \"ky\"},\"st\"}, \
     \n{1,  2, 0.5600, 6.59, 600.0, {\"bi\", \"ky\"},\"st\"},      \n{1,  2, \
0.5700, 6.96, 600.0, {\"bi\", \"ky\"},\"st\"},     \n{1,  2, 0.5800, 7.34, \
600.0, {\"bi\", \"ky\"},\"st\"},     \n{1,  2, 0.5900, 7.76, 600.0, {\"bi\", \
\"ky\"},\"st\"},      \n{1,  2, 0.6000, 8.21, 600.0, {\"bi\", \
\"ky\"},\"st\"}},     \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* ky-bi-chl *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["bi-ky ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.5000, 7.56, 600.0, {\"bi\", \"ky\"},\"chl\"},  \
   \n{1,  2, 0.5500, 7.50, 600.0, {\"bi\", \"ky\"},\"chl\"},      \n{1,  2, \
0.6000, 7.44, 600.0, {\"bi\", \"ky\"},\"chl\"},      \n{1,  2, 0.6500, 7.38, \
600.0, {\"bi\", \"ky\"},\"chl\"},     \n{1,  2, 0.7000, 7.32, 600.0, {\"bi\", \
\"ky\"},\"chl\"},      \n{1,  2, 0.7500, 7.26, 600.0, {\"bi\", \
\"ky\"},\"chl\"},      \n{1,  2, 0.8000, 7.19, 600.0, {\"bi\", \
\"ky\"},\"chl\"},     \n{1,  2, 0.8500, 7.13, 600.0, {\"bi\", \
\"ky\"},\"chl\"},     \n{1,  2, 0.9000, 7.07, 600.0, {\"bi\", \
\"ky\"},\"chl\"},    \n{1,  2, 0.9500, 7.00, 600.0, {\"bi\", \
\"ky\"},\"chl\"},     \n{1,  2, 1.0000, 6.94, 600.0, {\"bi\", \
\"ky\"},\"chl\"}},     \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5000, 7.58, 600.0, {\"chl\", \"bi\"},\"ky\"}, \
     \n{1,  2, 0.5500, 7.52, 600.0, {\"chl\", \"bi\"},\"ky\"},     \n{1,  2, \
0.6000, 7.46, 600.0, {\"chl\", \"bi\"},\"ky\"},     \n{1,  2, 0.6500, 7.40, \
600.0, {\"chl\", \"bi\"},\"ky\"},     \n{1,  2, 0.7000, 7.33, 600.0, \
{\"chl\", \"bi\"},\"ky\"},     \n{1,  2, 0.7500, 7.27, 600.0, {\"chl\", \
\"bi\"},\"ky\"},     \n{1,  2, 0.8000, 7.21, 600.0, {\"chl\", \
\"bi\"},\"ky\"},     \n{1,  2, 0.8500, 7.14, 600.0, {\"chl\", \
\"bi\"},\"ky\"},     \n{1,  2, 0.9000, 7.07, 600.0, {\"chl\", \
\"bi\"},\"ky\"},     \n{1,  2, 0.9500, 7.01, 600.0, {\"chl\", \
\"bi\"},\"ky\"},     \n{1,  2, 1.0000, 6.94, 600.0, {\"chl\", \
\"bi\"},\"ky\"}},    \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* st-bi-chl *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4000, 8.32, 600.0, {\"st\", \"bi\"},\"chl\"}, \
    \n{1,  2, 0.4200, 8.19, 600.0, {\"st\", \"bi\"},\"chl\"},    \n{1,  2, \
0.4400, 8.05, 600.0, {\"st\", \"bi\"},\"chl\"},    \n{1,  2, 0.4600, 7.91, \
600.0, {\"st\", \"bi\"},\"chl\"},     \n{1,  2, 0.4800, 7.77, 600.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5000, 7.63, 600.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5200, 7.48, 600.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5400, 7.32, 600.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5600, 7.17, 600.0, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.5800, 7.01, 600.0, {\"st\", \
\"bi\"},\"chl\"},      \n{1,  2, 0.6000, 6.85, 600.0, {\"st\", \
\"bi\"},\"chl\"}},    \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4000, 8.69, 600.0, {\"chl\", \"bi\"},\"st\"}, \
   \n{1,  2, 0.4200, 8.58, 600.0, {\"chl\", \"bi\"},\"st\"},      \n{1,  2, \
0.4400, 8.47, 600.0, {\"chl\", \"bi\"},\"st\"},     \n{1,  2, 0.4600, 8.36, \
600.0, {\"chl\", \"bi\"},\"st\"},   \n{1,  2, 0.4800, 8.24, 600.0, {\"chl\", \
\"bi\"},\"st\"},     \n{1,  2, 0.5000, 8.11, 600.0, {\"chl\", \
\"bi\"},\"st\"},    \n{1,  2, 0.5200, 7.99, 600.0, {\"chl\", \"bi\"},\"st\"}, \
  \n{1,  2, 0.5400, 7.86, 600.0, {\"chl\", \"bi\"},\"st\"},     \n{1,  2, \
0.5600, 7.72, 600.0, {\"chl\", \"bi\"},\"st\"},    \n{1,  2, 0.5800, 7.58, \
600.0, {\"chl\", \"bi\"},\"st\"},    \n{1,  2, 0.6000, 7.44, 600.0, {\"chl\", \
\"bi\"},\"st\"}},   \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* g-bi-chl *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.1758, 12.34, 600.0, {\"g\", \"bi\"},\"chl\"},  \
   \n{1,  2, 0.1800, 12.16, 600.0, {\"g\", \"bi\"},\"chl\"},     \n{1,  2, \
0.2000, 11.21, 600.0, {\"g\", \"bi\"},\"chl\"},    \n{1,  2, 0.2200, 10.16, \
600.0, {\"g\", \"bi\"},\"chl\"},   \n{1,  2, 0.2400, 9.02, 600.0, {\"g\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.2600, 7.86, 600.0, {\"g\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.2800, 6.76, 600.0, {\"g\", \"bi\"},\"chl\"}, \
    \n{1,  2, 0.3000, 5.78, 600.0, {\"g\", \"bi\"},\"chl\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5044, 9.16, 600.0, {\"chl\", \"bi\"},\"g\"},  \
   \n{1,  2, 0.5045, 9.14, 600.0, {\"chl\", \"bi\"},\"g\"},      \n{1,  2, \
0.5050, 9.07, 600.0, {\"chl\", \"bi\"},\"g\"},     \n{1,  2, 0.5055, 9.00, \
600.0, {\"chl\", \"bi\"},\"g\"},     \n{1,  2, 0.5060, 8.92, 600.0, {\"chl\", \
\"bi\"},\"g\"},     \n{1,  2, 0.5065, 8.85, 600.0, {\"chl\", \"bi\"},\"g\"},  \
  \n{1,  2, 0.5070, 8.78, 600.0, {\"chl\", \"bi\"},\"g\"},     \n{1,  2, \
0.5075, 8.71, 600.0, {\"chl\", \"bi\"},\"g\"},   \n{1,  2, 0.5080, 8.64, \
600.0, {\"chl\", \"bi\"},\"g\"},    \n{1,  2, 0.5085, 8.57, 600.0, {\"chl\", \
\"bi\"},\"g\"},  \n{1,  2, 0.5090, 8.49, 600.0, {\"chl\", \"bi\"},\"g\"},   \n\
{1,  2, 0.5095, 8.42, 600.0, {\"chl\", \"bi\"},\"g\"},   \n{1,  2, 0.5100, \
8.35, 600.0, {\"chl\", \"bi\"},\"g\"},    \n{1,  2, 0.5200, 7.08, 600.0, \
{\"chl\", \"bi\"},\"g\"}},    \n   \n{(*",
    FontWeight->"Plain"],
  StyleBox[" g-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1758, 12.34, 600.0, {\"g\", \"chl\"},\"bi\"}, \
   \n{1,  2, 0.1900, 12.17, 600.0, {\"g\", \"chl\"},\"bi\"},  \n{1,  2, \
0.2300, 11.71, 600.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.2700, 11.27, \
600.0, {\"g\", \"chl\"},\"bi\"},  \n{1,  2, 0.3100, 10.85, 600.0, {\"g\", \
\"chl\"},\"bi\"},\n{1,  2, 0.3500, 10.46, 600.0, {\"g\", \"chl\"},\"bi\"},   \
\n{1,  2, 0.3900, 10.09, 600.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.4300, \
9.75, 600.0, {\"g\", \"chl\"},\"bi\"},   \n{1,  2, 0.4700, 9.42, 600.0, \
{\"g\", \"chl\"},\"bi\"},   \n{1,  2, 0.5044, 9.16, 600.0, {\"g\", \
\"chl\"},\"bi\"}}};   \n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["allqlines = {\n{",
    FontWeight->"Plain"],
  StyleBox["(* g *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n{1,  2, 0, 7.68, 600.0, {\"g\"},\"bi\"},     \n{1,  2, \
0.0200, 8.28, 600.0, {\"g\"},\"bi\"},     \n{1,  2, 0.0400, 8.86, 600.0, {\"g\
\"},\"bi\"},     \n{1,  2, 0.0600, 9.42, 600.0, {\"g\"},\"bi\"},      \n{1,  \
2, 0.0800, 9.96, 600.0, {\"g\"},\"bi\"},     \n{1,  2, 0.1000, 10.49, 600.0, \
{\"g\"},\"bi\"},      \n{1,  2, 0.1200, 11.00, 600.0, {\"g\"},\"bi\"},    \n\
{1,  2, 0.1400, 11.50, 600.0, {\"g\"},\"bi\"},    \n{1,  2, 0.1600, 11.98, \
600.0, {\"g\"},\"bi\"},     \n{1,  2, 0.1800, 12.44, 600.0, {\"g\"},\"bi\"},  \
  \n{1,  2, 0.2000, 12.89, 600.0, {\"g\"},\"bi\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["g-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n{1,  2, 0.1400, 8.59, 600.0, {\"g\"},\"chl\"},   \n{1,  2, \
0.1600, 10.93, 600.0, {\"g\"},\"chl\"},     \n{1,  2, 0.1800, 12.69, 600.0, {\
\"g\"},\"chl\"},    \n{1,  2, 0.2000, 14.18, 600.0, {\"g\"},\"chl\"}},    \n\n\
{(* ",
    FontWeight->"Plain"],
  StyleBox["g-q",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)          ",
    FontWeight->"Plain"],
  StyleBox["(* manually entered boundary to make quadri work *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n{1,  2, -1, 5.0, 600.0, {\"g\"},\"q\"},     \n{1,  2, -1, 14.0, \
600.0, {\"g\"},\"q\"}},    \n\n{",
    FontWeight->"Plain"],
  StyleBox["(* chl *)",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n(* ",
    FontWeight->"Plain"],
  StyleBox["chl-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n{1,  2, 0.4800, 9.11, 600.0, {\"chl\"},\"bi\"},    \n{1,  2, \
0.5000, 9.15, 600.0, {\"chl\"},\"bi\"},    \n{1,  2, 0.5200, 9.19, 600.0, \
{\"chl\"},\"bi\"},   \n{1,  2, 0.5400, 9.24, 600.0, {\"chl\"},\"bi\"},     \n\
{1,  2, 0.5600, 9.28, 600.0, {\"chl\"},\"bi\"},    \n{1,  2, 0.5800, 9.33, \
600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.6000, 9.38, 600.0, {\"chl\"},\"bi\"}, \
  \n{1,  2, 0.6200, 9.43, 600.0, {\"chl\"},\"bi\"},  \n{1,  2, 0.6400, 9.48, \
600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.6600, 9.54, 600.0, {\"chl\"},\"bi\"}, \
  \n{1,  2, 0.6800, 9.60, 600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.7000, 9.66, \
600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.7200, 9.72, 600.0, {\"chl\"},\"bi\"}, \
   \n{1,  2, 0.7400, 9.78, 600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.7600, \
9.85, 600.0, {\"chl\"},\"bi\"},    \n{1,  2, 0.7800, 9.92, 600.0, \
{\"chl\"},\"bi\"},    \n{1,  2, 0.8000, 9.99, 600.0, {\"chl\"},\"bi\"},   \n\
{1,  2, 0.8200, 10.07, 600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.8400, 10.15, \
600.0, {\"chl\"},\"bi\"},   \n{1,  2, 0.8600, 10.23, 600.0, \
{\"chl\"},\"bi\"},    \n{1,  2, 0.8800, 10.32, 600.0, {\"chl\"},\"bi\"},  \n\
{1,  2, 0.9000, 10.41, 600.0, {\"chl\"},\"bi\"},  \n{1,  2, 0.9200, 10.50, \
600.0, {\"chl\"},\"bi\"},     \n{1,  2, 0.9400, 10.60, 600.0, \
{\"chl\"},\"bi\"},     \n{1,  2, 0.9600, 10.70, 600.0, {\"chl\"},\"bi\"},   \n\
{1,  2, 0.9800, 10.81, 600.0, {\"chl\"},\"bi\"},     \n{1,  2, 1.0000, 10.92, \
600.0, {\"chl\"},\"bi\"}},  \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" chl-g",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5000, 8.77, 600.0, {\"chl\"},\"g\"},     \n\
{1,  2, 0.5200, 10.34, 600.0, {\"chl\"},\"g\"},    \n{1,  2, 0.5400, 11.61, \
600.0, {\"chl\"},\"g\"},    \n{1,  2, 0.5600, 12.76, 600.0, {\"chl\"},\"g\"}, \
    \n{1,  2, 0.5800, 13.84, 600.0, {\"chl\"},\"g\"},   \n{1,  2, 0.6000, \
14.88, 600.0, {\"chl\"},\"g\"}},   \n\n{(*",
    FontWeight->"Plain"],
  StyleBox[" chl-q",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    ",
    FontWeight->"Plain"],
  StyleBox["(* manually entered boundary to make quadri work *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n{1,  2, 2, 11.0, 600.0, {\"chl\"},\"q\"},    \n{1,  2, 2, 14.0, \
600.0, {\"chl\"},\"q\"}}};    \n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["assembling data", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setupvx;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["plotting", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
bottom = 2; top = 14; left = 0; right = 1;   
delv = 0.05;
makevx[600];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% PlotRegion
0 1 0 1 MPlotRegion
% Scaling calculations
-0 1 -0.166667 0.0833333 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(2)] -0.0125 0 1 0 Msboxa
[(4)] -0.0125 .16667 1 0 Msboxa
[(6)] -0.0125 .33333 1 0 Msboxa
[(8)] -0.0125 .5 1 0 Msboxa
[(10)] -0.0125 .66667 1 0 Msboxa
[(12)] -0.0125 .83333 1 0 Msboxa
[(14)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(2)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .16667 m
.00625 .16667 L
s
P
[(4)] -0.0125 .16667 1 0 Mshowa
p
.002 w
0 .33333 m
.00625 .33333 L
s
P
[(6)] -0.0125 .33333 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(8)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .66667 m
.00625 .66667 L
s
P
[(10)] -0.0125 .66667 1 0 Mshowa
p
.002 w
0 .83333 m
.00625 .83333 L
s
P
[(12)] -0.0125 .83333 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(14)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .03333 m
.00375 .03333 L
s
P
p
.001 w
0 .06667 m
.00375 .06667 L
s
P
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .13333 m
.00375 .13333 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23333 m
.00375 .23333 L
s
P
p
.001 w
0 .26667 m
.00375 .26667 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .36667 m
.00375 .36667 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .43333 m
.00375 .43333 L
s
P
p
.001 w
0 .46667 m
.00375 .46667 L
s
P
p
.001 w
0 .53333 m
.00375 .53333 L
s
P
p
.001 w
0 .56667 m
.00375 .56667 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .63333 m
.00375 .63333 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .73333 m
.00375 .73333 L
s
P
p
.001 w
0 .76667 m
.00375 .76667 L
s
P
p
.001 w
0 .8 m
.00375 .8 L
s
P
p
.001 w
0 .86667 m
.00375 .86667 L
s
P
p
.001 w
0 .9 m
.00375 .9 L
s
P
p
.001 w
0 .93333 m
.00375 .93333 L
s
P
p
.001 w
0 .96667 m
.00375 .96667 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .16667 m
1 .16667 L
s
P
p
.002 w
.99375 .33333 m
1 .33333 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .66667 m
1 .66667 L
s
P
p
.002 w
.99375 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .03333 m
1 .03333 L
s
P
p
.001 w
.99625 .06667 m
1 .06667 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .13333 m
1 .13333 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23333 m
1 .23333 L
s
P
p
.001 w
.99625 .26667 m
1 .26667 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .36667 m
1 .36667 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .43333 m
1 .43333 L
s
P
p
.001 w
.99625 .46667 m
1 .46667 L
s
P
p
.001 w
.99625 .53333 m
1 .53333 L
s
P
p
.001 w
.99625 .56667 m
1 .56667 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .63333 m
1 .63333 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .73333 m
1 .73333 L
s
P
p
.001 w
.99625 .76667 m
1 .76667 L
s
P
p
.001 w
.99625 .8 m
1 .8 L
s
P
p
.001 w
.99625 .86667 m
1 .86667 L
s
P
p
.001 w
.99625 .9 m
1 .9 L
s
P
p
.001 w
.99625 .93333 m
1 .93333 L
s
P
p
.001 w
.99625 .96667 m
1 .96667 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
1 .7 .7 r
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
F
P
p
1 .55 .55 r
p
.48 .5925 m
.50513 .59667 L
.50437 .59667 L
.50497 .60087 L
.50557 .60507 L
.50618 .60927 L
.5068 .61347 L
.50742 .61767 L
.50805 .62188 L
.50869 .62608 L
.50933 .63028 L
.50998 .63448 L
.51064 .63868 L
.5113 .64288 L
.51197 .64708 L
.51264 .65128 L
.51332 .65549 L
.51401 .65969 L
.5147 .66389 L
.5154 .66809 L
.5161 .67229 L
.51681 .67649 L
.51753 .68069 L
.51825 .6849 L
.51897 .6891 L
.5197 .6933 L
.52044 .6975 L
.52118 .7017 L
.52193 .7059 L
.52268 .7101 L
.52343 .71431 L
.5242 .71851 L
.52496 .72271 L
.52573 .72691 L
.52651 .73111 L
.52729 .73531 L
.52807 .73951 L
.52886 .74372 L
.52966 .74792 L
.53046 .75212 L
.53126 .75632 L
.53206 .76052 L
.53287 .76472 L
.53369 .76892 L
.53451 .77313 L
.53533 .77733 L
.53616 .78153 L
.53699 .78573 L
.53782 .78993 L
.53866 .79413 L
.5395 .79833 L
.54034 .80253 L
.54119 .80674 L
.54203 .81094 L
.54288 .81514 L
.54374 .81934 L
.5446 .82354 L
.54546 .82774 L
.54632 .83194 L
.54719 .83615 L
.54806 .84035 L
.54893 .84455 L
.54981 .84875 L
.55068 .85295 L
.55157 .85715 L
.55245 .86135 L
.55334 .86556 L
.55423 .86976 L
.55512 .87396 L
.55602 .87816 L
.55692 .88236 L
.55782 .88656 L
.55873 .89076 L
.55963 .89497 L
.56054 .89917 L
.56145 .90337 L
.56237 .90757 L
.56329 .91177 L
.5642 .91597 L
.56513 .92017 L
.56605 .92438 L
.56698 .92858 L
.56791 .93278 L
.56884 .93698 L
.56977 .94118 L
.57071 .94538 L
.57164 .94958 L
.57258 .95378 L
.57352 .95799 L
.57447 .96219 L
.57541 .96639 L
.57636 .97059 L
.57731 .97479 L
.57826 .97899 L
.57921 .98319 L
.58017 .9874 L
.58112 .9916 L
.58208 .9958 L
.58304 1 L
1 1 L
1 .75 L
.48 .5925 L
F
0 .47333 m
.00165 .47751 L
.0033 .48168 L
.00495 .48586 L
.00661 .49004 L
.00827 .49421 L
.00994 .49839 L
.01161 .50256 L
.01329 .50674 L
.01497 .51091 L
.01666 .51509 L
.01835 .51927 L
.02004 .52344 L
.02174 .52762 L
.02345 .53179 L
.02516 .53597 L
.02688 .54014 L
.0286 .54432 L
.03033 .54849 L
.03206 .55267 L
.03379 .55685 L
.03554 .56102 L
.03728 .5652 L
.03903 .56937 L
.04079 .57355 L
.04256 .57772 L
.04432 .5819 L
.0461 .58608 L
.04788 .59025 L
.04966 .59443 L
.05146 .5986 L
.05325 .60278 L
.05506 .60695 L
.05687 .61113 L
.05868 .6153 L
.0605 .61948 L
.06234 .62366 L
.06417 .62783 L
.06602 .63201 L
.06787 .63618 L
.06972 .64036 L
.07158 .64453 L
.07344 .64871 L
.07531 .65289 L
.07718 .65706 L
.07906 .66124 L
.08093 .66541 L
.0828 .66959 L
.08467 .67376 L
.08655 .67794 L
.08843 .68211 L
.09032 .68629 L
.09221 .69047 L
.09411 .69464 L
.09602 .69882 L
.09793 .70299 L
.09985 .70717 L
.10178 .71134 L
.10373 .71552 L
.10568 .7197 L
.10764 .72387 L
.1096 .72805 L
.11157 .73222 L
.11354 .7364 L
.11552 .74057 L
.1175 .74475 L
.11949 .74892 L
.12147 .7531 L
.12345 .75728 L
.12544 .76145 L
.12743 .76563 L
.12943 .7698 L
.13143 .77398 L
.13344 .77815 L
.13546 .78233 L
.13749 .78651 L
.13952 .79068 L
.14156 .79486 L
.14362 .79903 L
.14569 .80321 L
.14776 .80738 L
.14984 .81156 L
.15193 .81573 L
.15403 .81991 L
.15614 .82409 L
.15826 .82826 L
.1604 .83244 L
.16254 .83661 L
.1647 .84079 L
.16686 .84496 L
.16904 .84914 L
.17122 .85332 L
.17341 .85749 L
.1756 .86167 L
.1757 .86167 L
.17631 .86586 L
.17692 .87005 L
.17754 .87424 L
.17815 .87843 L
.17877 .88263 L
.1794 .88682 L
.18003 .89101 L
.18066 .8952 L
.18129 .89939 L
.18193 .90359 L
.18257 .90778 L
.18321 .91197 L
.18386 .91616 L
.18451 .92035 L
.18516 .92455 L
.18582 .92874 L
.18648 .93293 L
.18714 .93712 L
.1878 .94131 L
.18847 .94551 L
.18914 .9497 L
.18982 .95389 L
.1905 .95808 L
.19118 .96227 L
.19186 .96646 L
.19255 .97066 L
.19324 .97485 L
.19393 .97904 L
.19463 .98323 L
.19533 .98742 L
.19603 .99162 L
.19673 .99581 L
.19744 1 L
0 1 L
0 .25 L
0 .47333 L
F
P
0 g
p
.004 w
.48 .5925 m
.50513 .59667 L
.50437 .59667 L
.50497 .60087 L
.50557 .60507 L
.50618 .60927 L
.5068 .61347 L
.50742 .61767 L
.50805 .62188 L
.50869 .62608 L
.50933 .63028 L
.50998 .63448 L
.51064 .63868 L
.5113 .64288 L
.51197 .64708 L
.51264 .65128 L
.51332 .65549 L
.51401 .65969 L
.5147 .66389 L
.5154 .66809 L
.5161 .67229 L
.51681 .67649 L
.51753 .68069 L
.51825 .6849 L
.51897 .6891 L
.5197 .6933 L
.52044 .6975 L
.52118 .7017 L
.52193 .7059 L
.52268 .7101 L
.52343 .71431 L
.5242 .71851 L
.52496 .72271 L
.52573 .72691 L
.52651 .73111 L
.52729 .73531 L
.52807 .73951 L
.52886 .74372 L
.52966 .74792 L
.53046 .75212 L
.53126 .75632 L
.53206 .76052 L
.53287 .76472 L
.53369 .76892 L
.53451 .77313 L
.53533 .77733 L
.53616 .78153 L
.53699 .78573 L
.53782 .78993 L
.53866 .79413 L
Mistroke
.5395 .79833 L
.54034 .80253 L
.54119 .80674 L
.54203 .81094 L
.54288 .81514 L
.54374 .81934 L
.5446 .82354 L
.54546 .82774 L
.54632 .83194 L
.54719 .83615 L
.54806 .84035 L
.54893 .84455 L
.54981 .84875 L
.55068 .85295 L
.55157 .85715 L
.55245 .86135 L
.55334 .86556 L
.55423 .86976 L
.55512 .87396 L
.55602 .87816 L
.55692 .88236 L
.55782 .88656 L
.55873 .89076 L
.55963 .89497 L
.56054 .89917 L
.56145 .90337 L
.56237 .90757 L
.56329 .91177 L
.5642 .91597 L
.56513 .92017 L
.56605 .92438 L
.56698 .92858 L
.56791 .93278 L
.56884 .93698 L
.56977 .94118 L
.57071 .94538 L
.57164 .94958 L
.57258 .95378 L
.57352 .95799 L
.57447 .96219 L
.57541 .96639 L
.57636 .97059 L
.57731 .97479 L
.57826 .97899 L
.57921 .98319 L
.58017 .9874 L
.58112 .9916 L
.58208 .9958 L
.58304 1 L
1 1 L
Mistroke
1 .75 L
.48 .5925 L
Mfstroke
0 .47333 m
.00165 .47751 L
.0033 .48168 L
.00495 .48586 L
.00661 .49004 L
.00827 .49421 L
.00994 .49839 L
.01161 .50256 L
.01329 .50674 L
.01497 .51091 L
.01666 .51509 L
.01835 .51927 L
.02004 .52344 L
.02174 .52762 L
.02345 .53179 L
.02516 .53597 L
.02688 .54014 L
.0286 .54432 L
.03033 .54849 L
.03206 .55267 L
.03379 .55685 L
.03554 .56102 L
.03728 .5652 L
.03903 .56937 L
.04079 .57355 L
.04256 .57772 L
.04432 .5819 L
.0461 .58608 L
.04788 .59025 L
.04966 .59443 L
.05146 .5986 L
.05325 .60278 L
.05506 .60695 L
.05687 .61113 L
.05868 .6153 L
.0605 .61948 L
.06234 .62366 L
.06417 .62783 L
.06602 .63201 L
.06787 .63618 L
.06972 .64036 L
.07158 .64453 L
.07344 .64871 L
.07531 .65289 L
.07718 .65706 L
.07906 .66124 L
.08093 .66541 L
.0828 .66959 L
.08467 .67376 L
.08655 .67794 L
Mistroke
.08843 .68211 L
.09032 .68629 L
.09221 .69047 L
.09411 .69464 L
.09602 .69882 L
.09793 .70299 L
.09985 .70717 L
.10178 .71134 L
.10373 .71552 L
.10568 .7197 L
.10764 .72387 L
.1096 .72805 L
.11157 .73222 L
.11354 .7364 L
.11552 .74057 L
.1175 .74475 L
.11949 .74892 L
.12147 .7531 L
.12345 .75728 L
.12544 .76145 L
.12743 .76563 L
.12943 .7698 L
.13143 .77398 L
.13344 .77815 L
.13546 .78233 L
.13749 .78651 L
.13952 .79068 L
.14156 .79486 L
.14362 .79903 L
.14569 .80321 L
.14776 .80738 L
.14984 .81156 L
.15193 .81573 L
.15403 .81991 L
.15614 .82409 L
.15826 .82826 L
.1604 .83244 L
.16254 .83661 L
.1647 .84079 L
.16686 .84496 L
.16904 .84914 L
.17122 .85332 L
.17341 .85749 L
.1756 .86167 L
.1757 .86167 L
.17631 .86586 L
.17692 .87005 L
.17754 .87424 L
.17815 .87843 L
.17877 .88263 L
Mistroke
.1794 .88682 L
.18003 .89101 L
.18066 .8952 L
.18129 .89939 L
.18193 .90359 L
.18257 .90778 L
.18321 .91197 L
.18386 .91616 L
.18451 .92035 L
.18516 .92455 L
.18582 .92874 L
.18648 .93293 L
.18714 .93712 L
.1878 .94131 L
.18847 .94551 L
.18914 .9497 L
.18982 .95389 L
.1905 .95808 L
.19118 .96227 L
.19186 .96646 L
.19255 .97066 L
.19324 .97485 L
.19393 .97904 L
.19463 .98323 L
.19533 .98742 L
.19603 .99162 L
.19673 .99581 L
.19744 1 L
0 1 L
0 .25 L
0 .47333 L
Mfstroke
P
P
p
1 g
p
.11291 0 m
.12514 .00431 L
.13747 .00861 L
.14986 .01292 L
.1623 .01722 L
.17477 .02153 L
.18715 .02583 L
.19947 .03014 L
.21184 .03444 L
.22426 .03875 L
.23676 .04306 L
.24942 .04736 L
.26221 .05167 L
.27511 .05597 L
.28813 .06028 L
.30129 .06458 L
.31465 .06889 L
.32811 .07319 L
.34163 .0775 L
.35519 .08181 L
.3687 .08611 L
.38217 .09042 L
.39565 .09472 L
.40913 .09903 L
.42259 .10333 L
.43597 .10764 L
.44939 .11194 L
.46288 .11625 L
.47647 .12056 L
.4902 .12486 L
.50409 .12917 L
.53191 .12917 L
.51789 .12486 L
.50378 .12056 L
.48961 .11625 L
.47542 .11194 L
.46125 .10764 L
.44711 .10333 L
.43305 .09903 L
.41912 .09472 L
.4055 .09042 L
.39199 .08611 L
.37856 .08181 L
.36518 .0775 L
.35174 .07319 L
.33826 .06889 L
.32478 .06458 L
.3113 .06028 L
.29781 .05597 L
.28425 .05167 L
.27072 .04736 L
.25725 .04306 L
.24387 .03875 L
.23079 .03444 L
.21789 .03014 L
.20502 .02583 L
.19213 .02153 L
.17914 .01722 L
.16569 .01292 L
.15218 .00861 L
.13866 .00431 L
.12519 0 L
.11291 0 L
F
0 .02417 m
.00367 .02837 L
.00762 .03257 L
.01176 .03677 L
.01597 .04097 L
.02016 .04517 L
.02413 .04937 L
.02797 .05357 L
.03167 .05777 L
.03526 .06197 L
.03885 .06617 L
.04261 .07037 L
.04649 .07457 L
.0504 .07877 L
.05432 .08297 L
.05818 .08717 L
.06192 .09137 L
.06553 .09557 L
.0691 .09977 L
.07269 .10397 L
.07629 .10817 L
.07989 .11237 L
.08349 .11657 L
.08709 .12077 L
.09069 .12497 L
.09429 .12917 L
.18395 .12917 L
.17731 .12497 L
.17065 .12077 L
.16391 .11657 L
.15696 .11237 L
.14979 .10817 L
.14254 .10397 L
.13531 .09977 L
.12811 .09557 L
.12091 .09137 L
.11371 .08717 L
.10651 .08297 L
.09932 .07877 L
.0922 .07457 L
.085 .07037 L
.07758 .06617 L
.06987 .06197 L
.06205 .05777 L
.05428 .05357 L
.04652 .04937 L
.03877 .04517 L
.03102 .04097 L
.02326 .03677 L
.01551 .03257 L
.00775 .02837 L
0 .02417 L
0 .02417 L
F
.50576 .12917 m
.52424 .1335 L
.54259 .13783 L
.56094 .14217 L
.57929 .1465 L
.59747 .15083 L
.61575 .15517 L
.63425 .1595 L
.65333 .16383 L
.6728 .16817 L
.69243 .1725 L
.712 .17683 L
.7315 .18117 L
.751 .1855 L
.77038 .18983 L
.78974 .19417 L
.80931 .1985 L
.82933 .20283 L
.84989 .20717 L
.87094 .2115 L
.8928 .21583 L
.91517 .22017 L
.93745 .2245 L
.95927 .22883 L
.98025 .23317 L
1 .2375 L
1 .2375 L
.9805 .23317 L
.961 .22883 L
.9415 .2245 L
.922 .22017 L
.9025 .21583 L
.883 .2115 L
.8635 .20717 L
.844 .20283 L
.8245 .1985 L
.80487 .19417 L
.78528 .18983 L
.7659 .1855 L
.7471 .18117 L
.7287 .17683 L
.71048 .1725 L
.69217 .16817 L
.6737 .16383 L
.65535 .1595 L
.63731 .15517 L
.61995 .15083 L
.6027 .1465 L
.58538 .14217 L
.56734 .13783 L
.54894 .1335 L
.53054 .12917 L
.50576 .12917 L
F
.25686 .50333 m
.25599 .5075 L
.25512 .51167 L
.25426 .51583 L
.2534 .52 L
.25253 .52417 L
.25167 .52833 L
.25081 .5325 L
.24995 .53667 L
.24909 .54083 L
.24823 .545 L
.24738 .54917 L
.24652 .55333 L
.24566 .5575 L
.2448 .56167 L
.24395 .56583 L
.24309 .57 L
.24223 .57417 L
.24137 .57833 L
.24052 .5825 L
.23966 .58667 L
.2388 .59083 L
.23794 .595 L
.23708 .59917 L
.23621 .60333 L
.23535 .6075 L
.23448 .61167 L
.23362 .61583 L
.23275 .62 L
.23188 .62417 L
.23101 .62833 L
.23014 .6325 L
.22926 .63667 L
.22838 .64083 L
.2275 .645 L
.22662 .64917 L
.22573 .65333 L
.22485 .6575 L
.22396 .66167 L
.22306 .66583 L
.22217 .67 L
.22127 .67417 L
.22036 .67833 L
.21945 .6825 L
.21854 .68667 L
.21762 .69083 L
.2167 .695 L
.21577 .69917 L
.21485 .70333 L
.21391 .7075 L
.21298 .71167 L
.21203 .71583 L
.21109 .72 L
.21014 .72417 L
.20919 .72833 L
.20823 .7325 L
.20727 .73667 L
.2063 .74083 L
.20533 .745 L
.20435 .74917 L
.20337 .75333 L
.20239 .7575 L
.2014 .76167 L
.2004 .76583 L
.19941 .77 L
.19842 .77417 L
.19743 .77833 L
.19643 .7825 L
.19542 .78667 L
.19441 .79083 L
.19339 .795 L
.19236 .79917 L
.19133 .80333 L
.19028 .8075 L
.18923 .81167 L
.18817 .81583 L
.1871 .82 L
.18602 .82417 L
.18493 .82833 L
.18382 .8325 L
.18271 .83667 L
.18159 .84083 L
.18046 .845 L
.17931 .84917 L
.17815 .85333 L
.17698 .8575 L
.1758 .86167 L
.1758 .86167 L
.17998 .85746 L
.18419 .85325 L
.18843 .84905 L
.1927 .84484 L
.197 .84063 L
.20133 .83643 L
.20568 .83222 L
.21006 .82802 L
.21447 .82381 L
.2189 .8196 L
.22336 .8154 L
.22784 .81119 L
.23233 .80698 L
.23684 .80278 L
.24137 .79857 L
.24593 .79437 L
.25051 .79016 L
.25511 .78595 L
.25974 .78175 L
.26439 .77754 L
.26907 .77333 L
.27375 .76913 L
.27846 .76492 L
.2832 .76071 L
.28797 .75651 L
.29277 .7523 L
.29762 .7481 L
.3025 .74389 L
.30743 .73968 L
.31242 .73548 L
.31747 .73127 L
.32257 .72706 L
.32771 .72286 L
.3329 .71865 L
.33812 .71444 L
.34339 .71024 L
.34869 .70603 L
.354 .70183 L
.35933 .69762 L
.3647 .69341 L
.37013 .68921 L
.37561 .685 L
.38115 .68079 L
.38675 .67659 L
.39245 .67238 L
.39827 .66817 L
.40414 .66397 L
.41007 .65976 L
.41605 .65556 L
.42206 .65135 L
.42811 .64714 L
.4341 .64294 L
.44009 .63873 L
.44613 .63452 L
.45222 .63032 L
.45838 .62611 L
.46463 .6219 L
.47096 .6177 L
.4774 .61349 L
.48395 .60929 L
.49063 .60508 L
.49744 .60087 L
.5044 .59667 L
.5044 .59667 L
.5047 .59242 L
.50509 .58818 L
.50545 .58394 L
.50577 .5797 L
.5061 .57545 L
.50647 .57121 L
.50683 .56697 L
.50719 .56273 L
.50756 .55848 L
.50792 .55424 L
.50829 .55 L
.50863 .54576 L
.50895 .54152 L
.5093 .53727 L
.50967 .53303 L
.51003 .52879 L
.5104 .52455 L
.51076 .5203 L
.51113 .51606 L
.51149 .51182 L
.51186 .50758 L
.51223 .50333 L
.25686 .50333 L
F
1 .41167 m
.95597 .416 L
.91867 .42033 L
.87873 .42467 L
.83472 .429 L
.79271 .43333 L
.75584 .43767 L
.71359 .442 L
.67 .44633 L
.62667 .45067 L
.58333 .455 L
.6 .455 L
.64356 .45067 L
.68133 .44633 L
.72127 .442 L
.76528 .43767 L
.8075 .43333 L
.84446 .429 L
.88083 .42467 L
.92163 .42033 L
.96438 .416 L
1 .41167 L
1 .41167 L
F
.52252 .455 m
.51575 .45939 L
.50877 .46379 L
.50163 .46818 L
.49423 .47258 L
.48669 .47697 L
.47909 .48136 L
.47156 .48576 L
.46403 .49015 L
.45649 .49455 L
.44896 .49894 L
.44143 .50333 L
.51168 .50333 L
.52044 .49894 L
.52872 .49455 L
.53675 .49015 L
.5445 .48576 L
.55204 .48136 L
.55949 .47697 L
.56701 .47258 L
.57455 .46818 L
.58208 .46379 L
.58961 .45939 L
.59714 .455 L
.52252 .455 L
F
.09442 .12917 m
.09784 .13375 L
.10125 .13833 L
.10469 .14292 L
.10813 .1475 L
.11158 .15208 L
.11503 .15667 L
.22248 .15667 L
.2161 .15208 L
.21 .1475 L
.20311 .14292 L
.19665 .13833 L
.19057 .13375 L
.1838 .12917 L
.09442 .12917 L
F
.11479 .15667 m
.11681 .16084 L
.11881 .16502 L
.12081 .1692 L
.12279 .17337 L
.12477 .17755 L
.12674 .18173 L
.12869 .1859 L
.13064 .19008 L
.13259 .19426 L
.13452 .19843 L
.13645 .20261 L
.13836 .20679 L
.14027 .21096 L
.14218 .21514 L
.14407 .21932 L
.14596 .22349 L
.14784 .22767 L
.14971 .23185 L
.15158 .23602 L
.15344 .2402 L
.1553 .24438 L
.15715 .24855 L
.15899 .25273 L
.16083 .25691 L
.16265 .26108 L
.16447 .26526 L
.16628 .26944 L
.16809 .27361 L
.16988 .27779 L
.17167 .28197 L
.17345 .28614 L
.17523 .29032 L
.17699 .2945 L
.17875 .29867 L
.18049 .30285 L
.18222 .30703 L
.18394 .3112 L
.18565 .31538 L
.18736 .31956 L
.18905 .32373 L
.19074 .32791 L
.19243 .33209 L
.1941 .33627 L
.19577 .34044 L
.19744 .34462 L
.19909 .3488 L
.20074 .35297 L
.20239 .35715 L
.20403 .36133 L
.20566 .3655 L
.20729 .36968 L
.20891 .37386 L
.21053 .37803 L
.21216 .38221 L
.21378 .38639 L
.21539 .39056 L
.217 .39474 L
.2186 .39892 L
.22021 .40309 L
.2218 .40727 L
.22339 .41145 L
.22498 .41562 L
.22656 .4198 L
.22813 .42398 L
.22971 .42815 L
.23127 .43233 L
.23283 .43651 L
.23439 .44068 L
.23594 .44486 L
.23749 .44904 L
.23903 .45321 L
.24057 .45739 L
.2421 .46157 L
.24362 .46574 L
.24514 .46992 L
.24666 .4741 L
.24817 .47827 L
.24967 .48245 L
.25117 .48663 L
.25267 .4908 L
.25416 .49498 L
.25565 .49916 L
.25714 .50333 L
.44303 .50333 L
.44062 .49916 L
.43821 .49498 L
.43577 .4908 L
.43333 .48663 L
.43088 .48245 L
.42841 .47827 L
.42594 .4741 L
.42345 .46992 L
.42095 .46574 L
.41844 .46157 L
.41592 .45739 L
.41339 .45321 L
.41085 .44904 L
.40829 .44486 L
.40572 .44068 L
.40314 .43651 L
.40055 .43233 L
.39794 .42815 L
.39532 .42398 L
.39269 .4198 L
.39004 .41562 L
.38737 .41145 L
.3847 .40727 L
.382 .40309 L
.37929 .39892 L
.37656 .39474 L
.37381 .39056 L
.37104 .38639 L
.36826 .38221 L
.36547 .37803 L
.36266 .37386 L
.35984 .36968 L
.35701 .3655 L
.35416 .36133 L
.3513 .35715 L
.34842 .35297 L
.34554 .3488 L
.34264 .34462 L
.33973 .34044 L
.33682 .33627 L
.33389 .33209 L
.33095 .32791 L
.328 .32373 L
.32504 .31956 L
.32206 .31538 L
.31907 .3112 L
.31607 .30703 L
.31305 .30285 L
.31002 .29867 L
.30698 .2945 L
.30392 .29032 L
.30084 .28614 L
.29775 .28197 L
.29464 .27779 L
.29151 .27361 L
.28837 .26944 L
.28522 .26526 L
.28205 .26108 L
.27887 .25691 L
.27567 .25273 L
.27246 .24855 L
.26924 .24438 L
.266 .2402 L
.26275 .23602 L
.25949 .23185 L
.25622 .22767 L
.25294 .22349 L
.24965 .21932 L
.24634 .21514 L
.24302 .21096 L
.23968 .20679 L
.23633 .20261 L
.23297 .19843 L
.22959 .19426 L
.2262 .19008 L
.22279 .1859 L
.21936 .18173 L
.21592 .17755 L
.21247 .17337 L
.209 .1692 L
.20551 .16502 L
.20201 .16084 L
.1985 .15667 L
.11479 .15667 L
F
.47247 .29083 m
.47402 .29504 L
.47555 .29925 L
.47708 .30346 L
.47858 .30767 L
.48007 .31188 L
.48153 .31609 L
.48297 .3203 L
.48439 .32451 L
.48579 .32872 L
.48717 .33293 L
.48854 .33714 L
.4899 .34135 L
.49124 .34556 L
.49257 .34976 L
.49388 .35397 L
.49518 .35818 L
.49647 .36239 L
.49774 .3666 L
.499 .37081 L
.50025 .37502 L
.50149 .37923 L
.50272 .38344 L
.50394 .38765 L
.50515 .39186 L
.50634 .39607 L
.50753 .40028 L
.5087 .40449 L
.50987 .4087 L
.51103 .41291 L
.51219 .41712 L
.51333 .42132 L
.51447 .42553 L
.51559 .42974 L
.5167 .43395 L
.51781 .43816 L
.5189 .44237 L
.51998 .44658 L
.52104 .45079 L
.52208 .455 L
.58295 .455 L
.58172 .45079 L
.58047 .44658 L
.5792 .44237 L
.57789 .43816 L
.57658 .43395 L
.57525 .42974 L
.57392 .42553 L
.57257 .42132 L
.57122 .41712 L
.56986 .41291 L
.56853 .4087 L
.56719 .40449 L
.56584 .40028 L
.56448 .39607 L
.5631 .39186 L
.56172 .38765 L
.56032 .38344 L
.55888 .37923 L
.55743 .37502 L
.55596 .37081 L
.55448 .3666 L
.55298 .36239 L
.55146 .35818 L
.54993 .35397 L
.54839 .34976 L
.54684 .34556 L
.54527 .34135 L
.54369 .33714 L
.54209 .33293 L
.54047 .32872 L
.53883 .32451 L
.53717 .3203 L
.5355 .31609 L
.53381 .31188 L
.53211 .30767 L
.53039 .30346 L
.52869 .29925 L
.52697 .29504 L
.52524 .29083 L
.47247 .29083 L
F
.2 .15667 m
.21054 .16086 L
.2208 .16505 L
.23083 .16924 L
.24065 .17344 L
.2503 .17763 L
.25986 .18182 L
.26929 .18602 L
.2786 .19021 L
.28782 .1944 L
.29695 .19859 L
.30612 .20279 L
.31527 .20698 L
.32433 .21117 L
.3333 .21536 L
.34214 .21956 L
.35085 .22375 L
.3593 .22794 L
.3676 .23214 L
.37577 .23633 L
.38381 .24052 L
.39172 .24471 L
.39952 .24891 L
.40719 .2531 L
.41476 .25729 L
.42223 .26148 L
.42961 .26568 L
.4369 .26987 L
.44413 .27406 L
.4513 .27826 L
.4585 .28245 L
.46563 .28664 L
.47269 .29083 L
.52549 .29083 L
.51806 .28664 L
.51054 .28245 L
.50292 .27826 L
.49518 .27406 L
.48732 .26987 L
.47933 .26568 L
.47122 .26148 L
.46298 .25729 L
.45459 .2531 L
.44604 .24891 L
.4373 .24471 L
.42843 .24052 L
.41942 .23633 L
.41027 .23214 L
.40099 .22794 L
.39155 .22375 L
.38199 .21956 L
.37233 .21536 L
.36256 .21117 L
.35271 .20698 L
.34294 .20279 L
.33313 .19859 L
.32316 .1944 L
.31299 .19021 L
.30257 .18602 L
.29157 .18182 L
.28024 .17763 L
.26875 .17344 L
.25715 .16924 L
.24568 .16505 L
.23442 .16086 L
.22307 .15667 L
.2 .15667 L
F
P
0 g
p
.004 w
.11291 0 m
.12514 .00431 L
.13747 .00861 L
.14986 .01292 L
.1623 .01722 L
.17477 .02153 L
.18715 .02583 L
.19947 .03014 L
.21184 .03444 L
.22426 .03875 L
.23676 .04306 L
.24942 .04736 L
.26221 .05167 L
.27511 .05597 L
.28813 .06028 L
.30129 .06458 L
.31465 .06889 L
.32811 .07319 L
.34163 .0775 L
.35519 .08181 L
.3687 .08611 L
.38217 .09042 L
.39565 .09472 L
.40913 .09903 L
.42259 .10333 L
.43597 .10764 L
.44939 .11194 L
.46288 .11625 L
.47647 .12056 L
.4902 .12486 L
.50409 .12917 L
.53191 .12917 L
.51789 .12486 L
.50378 .12056 L
.48961 .11625 L
.47542 .11194 L
.46125 .10764 L
.44711 .10333 L
.43305 .09903 L
.41912 .09472 L
.4055 .09042 L
.39199 .08611 L
.37856 .08181 L
.36518 .0775 L
.35174 .07319 L
.33826 .06889 L
.32478 .06458 L
.3113 .06028 L
.29781 .05597 L
.28425 .05167 L
Mistroke
.27072 .04736 L
.25725 .04306 L
.24387 .03875 L
.23079 .03444 L
.21789 .03014 L
.20502 .02583 L
.19213 .02153 L
.17914 .01722 L
.16569 .01292 L
.15218 .00861 L
.13866 .00431 L
.12519 0 L
.11291 0 L
Mfstroke
0 .02417 m
.00367 .02837 L
.00762 .03257 L
.01176 .03677 L
.01597 .04097 L
.02016 .04517 L
.02413 .04937 L
.02797 .05357 L
.03167 .05777 L
.03526 .06197 L
.03885 .06617 L
.04261 .07037 L
.04649 .07457 L
.0504 .07877 L
.05432 .08297 L
.05818 .08717 L
.06192 .09137 L
.06553 .09557 L
.0691 .09977 L
.07269 .10397 L
.07629 .10817 L
.07989 .11237 L
.08349 .11657 L
.08709 .12077 L
.09069 .12497 L
.09429 .12917 L
.18395 .12917 L
.17731 .12497 L
.17065 .12077 L
.16391 .11657 L
.15696 .11237 L
.14979 .10817 L
.14254 .10397 L
.13531 .09977 L
.12811 .09557 L
.12091 .09137 L
.11371 .08717 L
.10651 .08297 L
.09932 .07877 L
.0922 .07457 L
.085 .07037 L
.07758 .06617 L
.06987 .06197 L
.06205 .05777 L
.05428 .05357 L
.04652 .04937 L
.03877 .04517 L
.03102 .04097 L
.02326 .03677 L
.01551 .03257 L
Mistroke
.00775 .02837 L
0 .02417 L
0 .02417 L
Mfstroke
.50576 .12917 m
.52424 .1335 L
.54259 .13783 L
.56094 .14217 L
.57929 .1465 L
.59747 .15083 L
.61575 .15517 L
.63425 .1595 L
.65333 .16383 L
.6728 .16817 L
.69243 .1725 L
.712 .17683 L
.7315 .18117 L
.751 .1855 L
.77038 .18983 L
.78974 .19417 L
.80931 .1985 L
.82933 .20283 L
.84989 .20717 L
.87094 .2115 L
.8928 .21583 L
.91517 .22017 L
.93745 .2245 L
.95927 .22883 L
.98025 .23317 L
1 .2375 L
1 .2375 L
.9805 .23317 L
.961 .22883 L
.9415 .2245 L
.922 .22017 L
.9025 .21583 L
.883 .2115 L
.8635 .20717 L
.844 .20283 L
.8245 .1985 L
.80487 .19417 L
.78528 .18983 L
.7659 .1855 L
.7471 .18117 L
.7287 .17683 L
.71048 .1725 L
.69217 .16817 L
.6737 .16383 L
.65535 .1595 L
.63731 .15517 L
.61995 .15083 L
.6027 .1465 L
.58538 .14217 L
.56734 .13783 L
Mistroke
.54894 .1335 L
.53054 .12917 L
.50576 .12917 L
Mfstroke
.25686 .50333 m
.25599 .5075 L
.25512 .51167 L
.25426 .51583 L
.2534 .52 L
.25253 .52417 L
.25167 .52833 L
.25081 .5325 L
.24995 .53667 L
.24909 .54083 L
.24823 .545 L
.24738 .54917 L
.24652 .55333 L
.24566 .5575 L
.2448 .56167 L
.24395 .56583 L
.24309 .57 L
.24223 .57417 L
.24137 .57833 L
.24052 .5825 L
.23966 .58667 L
.2388 .59083 L
.23794 .595 L
.23708 .59917 L
.23621 .60333 L
.23535 .6075 L
.23448 .61167 L
.23362 .61583 L
.23275 .62 L
.23188 .62417 L
.23101 .62833 L
.23014 .6325 L
.22926 .63667 L
.22838 .64083 L
.2275 .645 L
.22662 .64917 L
.22573 .65333 L
.22485 .6575 L
.22396 .66167 L
.22306 .66583 L
.22217 .67 L
.22127 .67417 L
.22036 .67833 L
.21945 .6825 L
.21854 .68667 L
.21762 .69083 L
.2167 .695 L
.21577 .69917 L
.21485 .70333 L
.21391 .7075 L
Mistroke
.21298 .71167 L
.21203 .71583 L
.21109 .72 L
.21014 .72417 L
.20919 .72833 L
.20823 .7325 L
.20727 .73667 L
.2063 .74083 L
.20533 .745 L
.20435 .74917 L
.20337 .75333 L
.20239 .7575 L
.2014 .76167 L
.2004 .76583 L
.19941 .77 L
.19842 .77417 L
.19743 .77833 L
.19643 .7825 L
.19542 .78667 L
.19441 .79083 L
.19339 .795 L
.19236 .79917 L
.19133 .80333 L
.19028 .8075 L
.18923 .81167 L
.18817 .81583 L
.1871 .82 L
.18602 .82417 L
.18493 .82833 L
.18382 .8325 L
.18271 .83667 L
.18159 .84083 L
.18046 .845 L
.17931 .84917 L
.17815 .85333 L
.17698 .8575 L
.1758 .86167 L
.1758 .86167 L
.17998 .85746 L
.18419 .85325 L
.18843 .84905 L
.1927 .84484 L
.197 .84063 L
.20133 .83643 L
.20568 .83222 L
.21006 .82802 L
.21447 .82381 L
.2189 .8196 L
.22336 .8154 L
.22784 .81119 L
Mistroke
.23233 .80698 L
.23684 .80278 L
.24137 .79857 L
.24593 .79437 L
.25051 .79016 L
.25511 .78595 L
.25974 .78175 L
.26439 .77754 L
.26907 .77333 L
.27375 .76913 L
.27846 .76492 L
.2832 .76071 L
.28797 .75651 L
.29277 .7523 L
.29762 .7481 L
.3025 .74389 L
.30743 .73968 L
.31242 .73548 L
.31747 .73127 L
.32257 .72706 L
.32771 .72286 L
.3329 .71865 L
.33812 .71444 L
.34339 .71024 L
.34869 .70603 L
.354 .70183 L
.35933 .69762 L
.3647 .69341 L
.37013 .68921 L
.37561 .685 L
.38115 .68079 L
.38675 .67659 L
.39245 .67238 L
.39827 .66817 L
.40414 .66397 L
.41007 .65976 L
.41605 .65556 L
.42206 .65135 L
.42811 .64714 L
.4341 .64294 L
.44009 .63873 L
.44613 .63452 L
.45222 .63032 L
.45838 .62611 L
.46463 .6219 L
.47096 .6177 L
.4774 .61349 L
.48395 .60929 L
.49063 .60508 L
.49744 .60087 L
Mistroke
.5044 .59667 L
.5044 .59667 L
.5047 .59242 L
.50509 .58818 L
.50545 .58394 L
.50577 .5797 L
.5061 .57545 L
.50647 .57121 L
.50683 .56697 L
.50719 .56273 L
.50756 .55848 L
.50792 .55424 L
.50829 .55 L
.50863 .54576 L
.50895 .54152 L
.5093 .53727 L
.50967 .53303 L
.51003 .52879 L
.5104 .52455 L
.51076 .5203 L
.51113 .51606 L
.51149 .51182 L
.51186 .50758 L
.51223 .50333 L
.25686 .50333 L
Mfstroke
1 .41167 m
.95597 .416 L
.91867 .42033 L
.87873 .42467 L
.83472 .429 L
.79271 .43333 L
.75584 .43767 L
.71359 .442 L
.67 .44633 L
.62667 .45067 L
.58333 .455 L
.6 .455 L
.64356 .45067 L
.68133 .44633 L
.72127 .442 L
.76528 .43767 L
.8075 .43333 L
.84446 .429 L
.88083 .42467 L
.92163 .42033 L
.96438 .416 L
1 .41167 L
1 .41167 L
s
.52252 .455 m
.51575 .45939 L
.50877 .46379 L
.50163 .46818 L
.49423 .47258 L
.48669 .47697 L
.47909 .48136 L
.47156 .48576 L
.46403 .49015 L
.45649 .49455 L
.44896 .49894 L
.44143 .50333 L
.51168 .50333 L
.52044 .49894 L
.52872 .49455 L
.53675 .49015 L
.5445 .48576 L
.55204 .48136 L
.55949 .47697 L
.56701 .47258 L
.57455 .46818 L
.58208 .46379 L
.58961 .45939 L
.59714 .455 L
.52252 .455 L
s
.09442 .12917 m
.09784 .13375 L
.10125 .13833 L
.10469 .14292 L
.10813 .1475 L
.11158 .15208 L
.11503 .15667 L
.22248 .15667 L
.2161 .15208 L
.21 .1475 L
.20311 .14292 L
.19665 .13833 L
.19057 .13375 L
.1838 .12917 L
.09442 .12917 L
s
.11479 .15667 m
.11681 .16084 L
.11881 .16502 L
.12081 .1692 L
.12279 .17337 L
.12477 .17755 L
.12674 .18173 L
.12869 .1859 L
.13064 .19008 L
.13259 .19426 L
.13452 .19843 L
.13645 .20261 L
.13836 .20679 L
.14027 .21096 L
.14218 .21514 L
.14407 .21932 L
.14596 .22349 L
.14784 .22767 L
.14971 .23185 L
.15158 .23602 L
.15344 .2402 L
.1553 .24438 L
.15715 .24855 L
.15899 .25273 L
.16083 .25691 L
.16265 .26108 L
.16447 .26526 L
.16628 .26944 L
.16809 .27361 L
.16988 .27779 L
.17167 .28197 L
.17345 .28614 L
.17523 .29032 L
.17699 .2945 L
.17875 .29867 L
.18049 .30285 L
.18222 .30703 L
.18394 .3112 L
.18565 .31538 L
.18736 .31956 L
.18905 .32373 L
.19074 .32791 L
.19243 .33209 L
.1941 .33627 L
.19577 .34044 L
.19744 .34462 L
.19909 .3488 L
.20074 .35297 L
.20239 .35715 L
.20403 .36133 L
Mistroke
.20566 .3655 L
.20729 .36968 L
.20891 .37386 L
.21053 .37803 L
.21216 .38221 L
.21378 .38639 L
.21539 .39056 L
.217 .39474 L
.2186 .39892 L
.22021 .40309 L
.2218 .40727 L
.22339 .41145 L
.22498 .41562 L
.22656 .4198 L
.22813 .42398 L
.22971 .42815 L
.23127 .43233 L
.23283 .43651 L
.23439 .44068 L
.23594 .44486 L
.23749 .44904 L
.23903 .45321 L
.24057 .45739 L
.2421 .46157 L
.24362 .46574 L
.24514 .46992 L
.24666 .4741 L
.24817 .47827 L
.24967 .48245 L
.25117 .48663 L
.25267 .4908 L
.25416 .49498 L
.25565 .49916 L
.25714 .50333 L
.44303 .50333 L
.44062 .49916 L
.43821 .49498 L
.43577 .4908 L
.43333 .48663 L
.43088 .48245 L
.42841 .47827 L
.42594 .4741 L
.42345 .46992 L
.42095 .46574 L
.41844 .46157 L
.41592 .45739 L
.41339 .45321 L
.41085 .44904 L
.40829 .44486 L
.40572 .44068 L
Mistroke
.40314 .43651 L
.40055 .43233 L
.39794 .42815 L
.39532 .42398 L
.39269 .4198 L
.39004 .41562 L
.38737 .41145 L
.3847 .40727 L
.382 .40309 L
.37929 .39892 L
.37656 .39474 L
.37381 .39056 L
.37104 .38639 L
.36826 .38221 L
.36547 .37803 L
.36266 .37386 L
.35984 .36968 L
.35701 .3655 L
.35416 .36133 L
.3513 .35715 L
.34842 .35297 L
.34554 .3488 L
.34264 .34462 L
.33973 .34044 L
.33682 .33627 L
.33389 .33209 L
.33095 .32791 L
.328 .32373 L
.32504 .31956 L
.32206 .31538 L
.31907 .3112 L
.31607 .30703 L
.31305 .30285 L
.31002 .29867 L
.30698 .2945 L
.30392 .29032 L
.30084 .28614 L
.29775 .28197 L
.29464 .27779 L
.29151 .27361 L
.28837 .26944 L
.28522 .26526 L
.28205 .26108 L
.27887 .25691 L
.27567 .25273 L
.27246 .24855 L
.26924 .24438 L
.266 .2402 L
.26275 .23602 L
.25949 .23185 L
Mistroke
.25622 .22767 L
.25294 .22349 L
.24965 .21932 L
.24634 .21514 L
.24302 .21096 L
.23968 .20679 L
.23633 .20261 L
.23297 .19843 L
.22959 .19426 L
.2262 .19008 L
.22279 .1859 L
.21936 .18173 L
.21592 .17755 L
.21247 .17337 L
.209 .1692 L
.20551 .16502 L
.20201 .16084 L
.1985 .15667 L
.11479 .15667 L
Mfstroke
.47247 .29083 m
.47402 .29504 L
.47555 .29925 L
.47708 .30346 L
.47858 .30767 L
.48007 .31188 L
.48153 .31609 L
.48297 .3203 L
.48439 .32451 L
.48579 .32872 L
.48717 .33293 L
.48854 .33714 L
.4899 .34135 L
.49124 .34556 L
.49257 .34976 L
.49388 .35397 L
.49518 .35818 L
.49647 .36239 L
.49774 .3666 L
.499 .37081 L
.50025 .37502 L
.50149 .37923 L
.50272 .38344 L
.50394 .38765 L
.50515 .39186 L
.50634 .39607 L
.50753 .40028 L
.5087 .40449 L
.50987 .4087 L
.51103 .41291 L
.51219 .41712 L
.51333 .42132 L
.51447 .42553 L
.51559 .42974 L
.5167 .43395 L
.51781 .43816 L
.5189 .44237 L
.51998 .44658 L
.52104 .45079 L
.52208 .455 L
.58295 .455 L
.58172 .45079 L
.58047 .44658 L
.5792 .44237 L
.57789 .43816 L
.57658 .43395 L
.57525 .42974 L
.57392 .42553 L
.57257 .42132 L
.57122 .41712 L
Mistroke
.56986 .41291 L
.56853 .4087 L
.56719 .40449 L
.56584 .40028 L
.56448 .39607 L
.5631 .39186 L
.56172 .38765 L
.56032 .38344 L
.55888 .37923 L
.55743 .37502 L
.55596 .37081 L
.55448 .3666 L
.55298 .36239 L
.55146 .35818 L
.54993 .35397 L
.54839 .34976 L
.54684 .34556 L
.54527 .34135 L
.54369 .33714 L
.54209 .33293 L
.54047 .32872 L
.53883 .32451 L
.53717 .3203 L
.5355 .31609 L
.53381 .31188 L
.53211 .30767 L
.53039 .30346 L
.52869 .29925 L
.52697 .29504 L
.52524 .29083 L
.47247 .29083 L
Mfstroke
.2 .15667 m
.21054 .16086 L
.2208 .16505 L
.23083 .16924 L
.24065 .17344 L
.2503 .17763 L
.25986 .18182 L
.26929 .18602 L
.2786 .19021 L
.28782 .1944 L
.29695 .19859 L
.30612 .20279 L
.31527 .20698 L
.32433 .21117 L
.3333 .21536 L
.34214 .21956 L
.35085 .22375 L
.3593 .22794 L
.3676 .23214 L
.37577 .23633 L
.38381 .24052 L
.39172 .24471 L
.39952 .24891 L
.40719 .2531 L
.41476 .25729 L
.42223 .26148 L
.42961 .26568 L
.4369 .26987 L
.44413 .27406 L
.4513 .27826 L
.4585 .28245 L
.46563 .28664 L
.47269 .29083 L
.52549 .29083 L
.51806 .28664 L
.51054 .28245 L
.50292 .27826 L
.49518 .27406 L
.48732 .26987 L
.47933 .26568 L
.47122 .26148 L
.46298 .25729 L
.45459 .2531 L
.44604 .24891 L
.4373 .24471 L
.42843 .24052 L
.41942 .23633 L
.41027 .23214 L
.40099 .22794 L
.39155 .22375 L
Mistroke
.38199 .21956 L
.37233 .21536 L
.36256 .21117 L
.35271 .20698 L
.34294 .20279 L
.33313 .19859 L
.32316 .1944 L
.31299 .19021 L
.30257 .18602 L
.29157 .18182 L
.28024 .17763 L
.26875 .17344 L
.25715 .16924 L
.24568 .16505 L
.23442 .16086 L
.22307 .15667 L
.2 .15667 L
Mfstroke
P
P
p
.004 w
.53191 .12917 m
.09429 .12917 L
s
.47269 .29083 m
1 .29083 L
s
P
p
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
p
p
/Helvetica findfont 14 scalefont setfont
[(P = 600.)] .01 52.75 -1 0 Mshowa
P
p
/Times-Bold findfont 22 scalefont setfont
[(AFM)] .01 53.3333 -1 0 Mshowa
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{423, 423},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W0001Ya000`40O003h00OogooZ7oo003oOonX
Ool00?moojQoo`00ogooZ7oo001KOol20004Ool01000Oomoogoo1@00@Goo0P0017oo00<007ooOol0
0goo0`00@Goo0P0017oo00<007ooOol00Woo0`00@Woo0P0017oo00<007ooOol00Woo0`00AWoo0`00
1Goo001JOol01000Oomoo`0027oo00@007ooOol0041oo`04001oogoo000:Ool00`00Oomoo`0oOol0
1000Oomoo`001goo00D007ooOomoo`00041oo`04001oogoo0007Ool01@00Oomoogoo0000AWoo00<0
07ooOol017oo001JOol01000Oomoo`002Goo00<007ooOol0@7oo00@007ooOol000Moo`D0041oo`04
001oogoo0007Ool01@00Oomoogoo0000@7oo00@007ooOol000Moo`05001oogooOol00016Ool00`00
Oomoo`04Ool005Yoo`04001oogoo000:Ool00`00Oomoo`0oOol01000Oomoo`001goo00@007ooOol0
045oo`04001oogoo0007Ool40011Ool01000Oomoo`0027oo0`00Agoo00<007ooOol017oo001JOol0
1000Oomoo`001goo00D007ooOomoo`00041oo`04001oogoo0008Ool00`00Ool00011Ool01000Oomo
o`001goo00<007ooOol0@Woo00@007ooOol000Moo`05001oogooOol00016Ool00`00Oomoo`04Ool0
05Yoo`04001oogoo0007Ool01@00Oomoogoo0000@7oo00@007ooOol000Uoo`80045oo`04001oogoo
0008Ool00`00Oomoo`11Ool01000Oomoo`001goo00D007ooOomoo`0004Eoo`8000Ioo`00Fgoo0P00
2Goo0`00@Woo0P002goo00<007ooOol0@7oo0P002Woo0P00@Woo0P002Goo0`00Agoo00<007ooOol0
17oo003oOonXOol00?moojQoo`00ogooZ7oo003oOonXOol000Moo`D00?mooiaoo`0027oo00@007oo
Ool00?mooiaoo`002Goo00<007ooOol01Wooo`00T@001Goo000:Ool00`00Oomoo`05Ool00`00O]In
eP0/O]H30002Ool3003oO]IIO]H00`00Oomoo`03Ool000Moo`05001oogooOol00006Ool00`00O]In
eP0_O]H30002Ool4003oO]IEO]H00`00Oomoo`03Ool000Moo`05001oogooOol00006Ool00`00O]In
eP0bO]H30003Ool4003oO]IAO]H00`00Oomoo`03Ool000Qoo`<000Moo`03001neWkF03EneP<000Ao
o`<00?mneTineP03001oogoo00=oo`004Woo00<007kFO]H0>7kF0P001Goo0P00ogkFC7kF00<007oo
Ool00goo000BOol00`00O]IneP0jO]H30004Ool3003oO]I9O]H00`00Oomoo`03Ool0019oo`03001n
eWkF03eneP8000Eoo`800?mneTMneP03001oogoo00=oo`004Woo00<007kFO]H0?gkF0`0017oo0`00
ogkFA7kF00<007ooOol00goo000BOol00`00O]IneP12O]H40003Ool4003oO]I0O]H00`00Oomoo`03
Ool0019oo`<004IneP<000Aoo`@00?mneSaneP03001oogoo00=oo`004Woo0P0000=oo`000000AgkF
0`001Goo0`00ogkF>GkF00<007ooOol00goo000BOol00`00O]H00002Ool00`00O]IneP17O]H20006
Ool2003oO]HgO]H00`00Oomoo`03Ool0019oo`04001neWkF0002Ool20019O]H30005Ool3003oO]Hd
O]H00`00Oomoo`03Ool0019oo`04001neWkF0004Ool00`00O]IneP19O]H40004Ool4003oO]H`O]H0
0`00Oomoo`03Ool0019oo`04001neWkFO]H20003Ool3001<O]H30005Ool3003oO]H]O]H00`00Oomo
o`03Ool0019oo`03001neWkF00=neP03001oogoo00=oo`8004eneP<000Eoo`<00?mneRYneP03001o
ogoo00=oo`004Woo00<007kFO]H017kF00<007ooOol017oo00<007kFO]H0CGkF0P001Woo0`00ogkF
9gkF00<007ooOol00goo000BOol00`00O]IneP05O]H00`00Oomoo`04Ool2001?O]H30006Ool3003o
O]HTO]H00`00Oomoo`03Ool0019oo`03001neWkF00EneP03001oogoo00Ioo`03001neWkF04mneP80
00Moo`800?mneR9neP03001oogoo00=oo`004Woo00<007kFO]H01WkF0P001goo0`00D7kF0`001Woo
0`00ogkF7gkF00<007ooOol00goo000BOol00`00O]IneP08O]H00`00Oomoo`07Ool2001AO]H40005
Ool4003oO]HKO]H00`00Oomoo`03Ool0019oo`03001neWkF00QneP03001oogoo00Uoo`03001neWkF
059neP@000Eoo`@00?mneQMneP03001oogoo00=oo`004Woo00<007kFO]H02GkF00<007ooOol02Goo
0P00EWkF0`001Woo0`00ogkF57kF00<007ooOol00goo000BOol00`00O]IneP0:O]H00`00Oomoo`0:
Ool00`00O]IneP1FO]H20007Ool2003oO]HBO]H00`00Oomoo`03Ool0019oo`03001neWkF00]neP03
001oogoo00Yoo`<005MneP<000Ioo`<00?mnePmneP03001oogoo00=oo`004Woo00<007kFO]H037kF
00<007ooOol037oo0`00EgkF0P001goo0`00ogkF37kF00<007ooOol00goo000BOol00`00O]IneP0=
O]H00`00Oomoo`0>Ool00`00O]IneP1FO]H30007Ool3003oO]H9O]H00`00Oomoo`03Ool0019oo`03
001neWkF00ineP03001oogoo00ioo`03001neWkF05QneP@000Ioo`@00?mnePEneP03001oogoo00=o
o`004Woo00<007kFO]H03WkF00<007ooOol03goo00<007kFO]H0FgkF10001Woo1000ogkF0GkF00<0
07ooOol00goo000BOol00`00O]IneP0?O]H00`00Oomoo`0?Ool2001OO]H30007Ool3003mO]H00`00
Oomoo`03Ool0019oo`03001neWkF011neP03001oogoo011oo`03001neWkF05mneP<000Moo`800?]n
eP03001oogoo00=oo`004Woo00<007kFO]H04GkF00<007ooOol047oo0`00HGkF0`001Woo0`00n7kF
00<007ooOol00goo000BOol00`00O]IneP0BO]H00`00Oomoo`0BOol2001RO]H40005Ool4003dO]H0
0`00Oomoo`03Ool0019oo`03001neWkF01=neP03001oogoo01=oo`03001neWkF06=neP<000Ioo`@0
0?1neP03001oogoo00=oo`004Woo00<007kFO]H057kF00<007ooOol04goo0P00IWkF0`001goo0`00
kGkF00<007ooOol00goo000BOol00`00O]IneP0DO]H00`00Oomoo`0EOol00`00O]IneP1VO]H30007
Ool2003[O]H00`00Oomoo`03Ool0019oo`03001neWkF01EneP8001Ioo`<006QneP<000Ioo`<00>Qn
eP03001oogoo00=oo`004Woo00<007kFO]H05gkF00<007ooOol05Woo0P00JGkF0P001goo0`00iGkF
00<007ooOol00goo000BOol00`00O]IneP0GO]H00`00Oomoo`0HOol00`00O]IneP1XO]H30007Ool3
003RO]H00`00Oomoo`03Ool0019oo`03001neWkF01QneP03001oogoo01Qoo`8006]neP@000Ioo`@0
0=ineP03001oogoo00=oo`004Woo00<007kFO]H06GkF00<007ooOol06Goo00<007kFO]H0K7kF1000
1Woo1000fWkF00<007ooOol00goo000BOol00`00O]IneP0JO]H00`00Oomoo`0IOol2001`O]H30007
Ool3003GO]H00`00Oomoo`03Ool0019oo`03001neWkF01]neP03001oogoo01Yoo`80075neP8000Qo
o`<00=AneP03001oogoo00=oo`004Woo00<007kFO]H06gkF00<007ooOol077oo00<007kFO]H0L7kF
0`0027oo0`00dGkF00<007ooOol00goo000BOol00`00O]IneP0LO]H00`00Oomoo`0LOol2001cO]H4
0007Ool4003=O]H00`00Oomoo`03Ool0019oo`03001neWkF01eneP03001oogoo01eoo`03001neWkF
07AneP@000Moo`@00<UneP03001oogoo00=oo`004Woo00<007kFO]H07WkF00<007ooOol07Goo0`00
MgkF0`0027oo0`00aWkF00<007ooOol00goo000BOol00`00O]IneP0OO]H00`00Oomoo`0OOol00`00
O]IneP1gO]H30008Ool30033O]H00`00Oomoo`03Ool0019oo`03001neWkF021neP03001oogoo01mo
o`03001neWkF07UneP<000Qoo`<00<1neP03001oogoo00=oo`004Woo00<007kFO]H08GkF00<007oo
Ool07goo0P00O7kF0P002Goo0P00_WkF00<007ooOol00goo000BOol00`00O]IneP0QO]H00`00Oomo
o`0QOol00`00O]IneP1kO]H30008Ool3002kO]H00`00Oomoo`03Ool0019oo`03001neWkF029ne[@0
0;IneP03001oogoo00=oo`004Woo00<007kFO]H097kF00<007ooOol08Woo00<007kFO]H0P7kF1@00
1Goo1@00/GkF00<007ooOol00goo000BOol00`00O]IneP0TO]H00`00Oomoo`0SOol00`00O]IneP24
O]H40006Ool3002^O]H00`00Oomoo`03Ool0019oo`03001neWkF02EneP03001oogoo02=oo`8008Qn
eP@000Eoo`@00:YneP03001oogoo00=oo`004Woo00<007kFO]H09GkF00<007ooOol09Goo00<007kF
O]H0RGkF0`001Woo1000YWkF00<007ooOol00goo000BOol00`00O]IneP0VO]H00`00Oomoo`0UOol2
002<O]H40006Ool4002RO]H00`00Oomoo`03Ool0019oo`03001neWkF02MneP03001oogoo02Ioo`03
001neWkF08eneP<000Moo`<009mneP03001oogoo00=oo`004Woo00<007kFO]H0:7kF00<007ooOol0
9Woo00<007kFO]H0SgkF1P0017oo1@00VWkF00<007ooOol00goo000BOol00`00O]IneP0XO]H00`00
Oomoo`0WOol00`00O]IneP2DO]H50004Ool5002EO]H00`00Oomoo`03Ool0019oo`03001neWkF02Un
eP03001oogoo02Moo`03001neWkF09QneP@000Eoo`<0099neP03001oogoo00=oo`004Woo00<007kF
O]H0:WkF00<007ooOol09goo00<007kFO]H0VgkF100017oo1000SWkF00<007ooOol00goo000BOol0
0`00O]IneP0ZO]H_002MO]H30005Ool4002:O]H00`00Oomoo`03Ool000Uoo`<000Ioo`03001neWkF
02]neP03001oogoo01moo`03001neWkF00<000Ioo`<009eneP@000Eoo`@008IneP03001oogoo00=o
o`002Woo00<007ooOol01Goo00<007kFO]H0:gkF00<007ooOol087oo00<007kFO]H00WkF0P001goo
0`00WWkF10001Goo0`00PgkF00<007ooOol00goo0007Ool50006Ool00`00O]IneP0/O]H00`00Oomo
o`0POol00`00O]IneP03O]H20008Ool2002PO]H60002Ool6001mO]H00`00Oomoo`03Ool000Moo`04
001oogoo0007Ool00`00O]IneP0/O]H00`00Oomoo`0POol00`00O]IneP05O]H20008Ool2002TO]H6
0002Ool5001hO]H00`00Oomoo`03Ool000Qoo`03001oo`0000Moo`03001neWkF02eneP03001oogoo
021oo`03001neWkF00IneP<000Moo`@00:IneP<000Aoo`@007AneP03001oogoo00=oo`002Goo0P00
1goo00<007kFO]H0;WkF00<007ooOol087oo00<007kFO]H027kF0`0027oo0`00YWkF100017oo1000
L7kF00<007ooOol00goo000:Ool00`00Oomoo`05Ool00`00O]IneP0^O]H00`00Oomoo`0QOol00`00
O]IneP0:O]H20009Ool3002WO]H40004Ool3001]O]H00`00Oomoo`03Ool0019oo`03001neWkF02in
eP03001oogoo029oo`03001neWkF00]neP8000Yoo`800:UnePH00003Ool0000000@006MneP03001o
ogoo00=oo`004Woo00<007kFO]H0;WkF00<007ooOol08Woo00<007kFO]H03GkF00<007ooOol02Goo
0P00[GkF1P0000=oo`0000000`00HWkF00<007ooOol00goo000BOol00`00O]IneP0_O]H00`00Oomo
o`0ROol2000>O]H3000:Ool4002_O]H40002Ool4001NO]H00`00Oomoo`03Ool0019oo`03001neWkF
031neP03001oogoo02=oo`03001neWkF00ineP<000]oo`<00;1neP@0009oo`@005YneP03001oogoo
00=oo`004Woo00<007kFO]H0<7kF00<007ooOol08goo00<007kFO]H04GkF0P0037oo0P00/WkF1000
0Woo1000EWkF00<007ooOol00goo000BOol00`00O]IneP0aO]H00`00Oomoo`0SOol00`00O]IneP0B
O]H2000<Ool2002dO]H40002Ool4001BO]H00`00Oomoo`03Ool0019oo`03001neWkF035neP03001o
ogoo02=oo`03001neWkF01AneP8000aoo`800;IneP<000=oo`<004mneP03001oogoo00=oo`004Woo
00<007kFO]H0<WkF00<007ooOol08goo0P005WkF0`002goo0`00]WkF3000BGkF00<007ooOol00goo
000BOol00`00O]IneP0bO]H00`00Oomoo`0UOol00`00O]IneP0FO]H2000<Ool3002iO]H<0013O]H0
0`00Oomoo`03Ool0019oo`03001neWkF039neP03001oogoo02Eoo`03001neWkF01QneP8000eoo`80
0;eneP@0009oo`@003mneP03001oogoo00=oo`004Woo00<007kFO]H0<gkF00<007ooOol09Goo00<0
07kFO]H06GkF0P003Goo0P00_gkF10000Woo1000>gkF00<007ooOol00goo000BOol00`00O]IneP0c
O]H00`00Oomoo`0UOol00`00O]IneP0KO]H2000=Ool20031O]H40002Ool4000gO]H00`00Oomoo`03
Ool0019oo`03001neWkF03AneP03001oogoo02Eoo`8001eneP<000aoo`<00<9neP@0009oo`@003=n
eP03001oogoo00=oo`004Woo00<007kFO]H0=GkF00<007ooOol09Woo00<007kFO]H07GkF0P003Goo
0`00`gkF1@0000=oo`0000000P00;gkF00<007ooOol00goo000BOol00`00O]IneP0eO]H00`00Oomo
o`0VOol00`00O]IneP0OO]H2000>Ool00`00O]IneP35O]H;000YO]H00`00Oomoo`03Ool0019oo`03
001neWkF03EneP03001oogoo02Moo`03001neWkF021neP8000eoo`800<anePX002=neP03001oogoo
00=oo`004Woo00<007kFO]H0=GkF00<007ooOol09goo00<007kFO]H08WkF00<007ooOol037oo0P00
d7kF1`0087kF00<007ooOol00goo000BOol00`00O]IneP0fO]H00`00Oomoo`0WOol2000SO]H3000=
Ool3003BO]H6000LO]H00`00Oomoo`03Ool0019oo`03001neWkF03MneP03001oogoo02Qoo`03001n
eWkF02=neP<000eoo`<00==nePH001QneP03001oogoo00=oo`004Woo00<007kFO]H0=gkF00<007oo
Ool0:7oo00<007kFO]H09WkF00<007ooOol03Goo0P00eGkF1P0057kF00<007ooOol00goo000BOol0
0`00O]IneP0hO]H00`00Oomoo`0XOol00`00O]IneP0VO]H2000?Ool2003GO]H6000@O]H00`00Oomo
o`03Ool0019oo`03001neWkF03QneP03001oogoo02Qoo`03001neWkF02QneP8000moo`800=YnePL0
00YneP03001oogoo00=oo`004Woo00<007kFO]H0>7kF00<007ooOol0:Goo0P00:WkF0P003goo0P00
ggkF1P0017kF00<007ooOol00goo000BOol00`00O]IneP0iO]H00`00Oomoo`0ZOol00`00O]IneP0Y
O]H00`00Oomoo`0>Ool00`00O]IneP3RO]H300000gkF001oo`04Ool0019oo`03001neWkF03UneP03
001oogoo02Yoo`03001neWkF02YneP<000ioo`<00>AneP8000Eoo`004Woo00<007kFO]H0>WkF00<0
07ooOol0:Woo00<007kFO]H0;7kF0P003goo0`00hWkF00<007ooOol00goo000BOol00`00O]IneP0j
O]H00`00Oomoo`0ZOol00`00O]IneP0^O]H00`00Oomoo`0?Ool00`00O]IneP3OO]H00`00Oomoo`03
Ool0019oo`03001neWkF03]neP03001oogoo02Yoo`03001neWkF02ineP80011oo`800=mneP03001o
ogoo00=oo`004Woo00<007kFO]H0>gkF00<007ooOol0:goo00<007kFO]H0;gkF00<007ooOol03goo
0P00gGkF00<007ooOol00goo000BOol00`00O]IneP0kO]H00`00Oomoo`0/Ool00`00O]IneP0_O]H3
000@Ool3003JO]H00`00Oomoo`03Ool0019oo`03001neWkF03aneP03001oogoo02aoo`03001neWkF
035neP80015oo`800=QneP03001oogoo00=oo`004Woo00<007kFO]H0?7kF00<007ooOol0;7oo00<0
07kFO]H0<gkF00<007ooOol047oo0P00eWkF00<007ooOol00goo000BOol00`00O]IneP0mO]H00`00
Oomoo`0/Ool00`00O]IneP0cO]H2000BOol2003DO]H00`00Oomoo`03Ool0019oo`03001neWkF03in
eP03001oogoo02aoo`03001neWkF03AneP03001oogoo015oo`03001neWkF0=5neP03001oogoo00=o
o`004Woo00<007kFO]H0?WkF00<007ooOol0;Goo00<007kFO]H0=7kF0`004Goo0`00d7kF00<007oo
Ool00goo000BOol00`00O]IneP0nO]H00`00Oomoo`0^Ool00`00O]IneP0fO]H2000BOol2003>O]H0
0`00Oomoo`03Ool0019oo`03001neWkF03ineP03001oogoo02ioo`03001neWkF03QneP03001oogoo
015oo`03001neWkF0<]neP03001oogoo00=oo`004Woo00<007kFO]H0?gkF00<007ooOol0;Woo00<0
07kFO]H0>7kF0P004Woo0P00bgkF00<007ooOol00goo000BOol00`00O]IneP10O]H00`00Oomoo`0^
Ool00`00O]IneP0iO]H00`00Oomoo`0AOol20039O]H00`00Oomoo`03Ool0019oo`03001neWkF041n
eP03001oogoo02ioo`03001neWkF03YneP<0019oo`<00<IneP03001oogoo00=oo`004Woo00<007kF
O]H0@7kF00<007ooOol0;goo00<007kFO]H0?7kF0P004goo0P00a7kF00<007ooOol00goo000BOol0
0`00O]IneP10O]H00`00Oomoo`0`Ool00`00O]IneP0mO]H00`00Oomoo`0BOol00`00O]IneP31O]H0
0`00Oomoo`03Ool0019oo`03001neWkF045neP03001oogoo031oo`03001neWkF03eneP8001=oo`80
0<5neP03001oogoo00=oo`004Woo00<007kFO]H0@WkF00<007ooOol0<7oo00<007kFO]H0?WkF00<0
07ooOol04Woo00<007kFO]H0_WkF00<007ooOol00goo000BOol00`00O]IneP12O]H00`00Oomoo`0`
Ool00`00O]IneP0oO]H3000BOol3002mO]H00`00Oomoo`03Ool0019oo`03001neWkF04=neP03001o
ogoo031oo`03001neWkF041ne]@000Eoo`004Woo00<007kFO]H0@gkF00<007ooOol0<7oo00<007kF
O]H0@7kF00<007ooOol04goo00<007kFO]H0^WkF00<007ooOol00goo000BOol00`00O]IneP13O]H0
0`00Oomoo`0aOol20011O]H00`00Oomoo`0BOol00`00O]IneP2jO]H00`00Oomoo`03Ool0019oo`03
001neWkF04AneP03001oogoo039oo`03001neWkF03ineP03001oogoo019oo`03001neWkF0;YneP03
001oogoo00=oo`004Woo00<007kFO]H0A7kF00<007ooOol0<Woo00<007kFO]H0?gkF00<007ooOol0
4Woo00<007kFO]H0^GkF00<007ooOol00goo000BOol00`00O]IneP15O]H00`00Oomoo`0bOol00`00
O]IneP0nO]H00`00Oomoo`0COol00`00O]IneP2hO]H00`00Oomoo`03Ool0019oo`03001neWkF04En
eP03001oogoo039oo`03001neWkF03ineP03001oogoo01=oo`03001neWkF0;QneP03001oogoo00=o
o`004Woo00<007kFO]H0AGkF00<007ooOol0<goo00<007kFO]H0?WkF00<007ooOol04Woo00<007kF
O]H0^7kF00<007ooOol00goo000BOol00`00O]IneP16O]H00`00Oomoo`0cOol00`00O]IneP0mO]H0
0`00Oomoo`0BOol00`00O]IneP2hO]H00`00Oomoo`03Ool0019oo`03001neWkF04IneP03001oogoo
03=oo`03001neWkF03ineP03001oogoo019oo`03001neWkF0;MneP03001oogoo00=oo`004Woo00<0
07kFO]H0AgkF00<007ooOol0<goo00<007kFO]H0?GkF00<007ooOol04goo00<007kFO]H0]WkF00<0
07ooOol00goo000BOol00`00O]IneP17O]H00`00Oomoo`0dOol00`00O]IneP0lO]H00`00Oomoo`0C
Ool00`00O]IneP2fO]H00`00Oomoo`03Ool0019oo`03001neWkF04MneP03001oogoo03Eoo`03001n
eWkF03aneP03001oogoo019oo`03001neWkF0;IneP03001oogoo00=oo`004Woo00<007kFO]H0B7kF
00<007ooOol0=Goo00<007kFO]H0>gkF00<007ooOol04Woo00<007kFO]H0]WkF00<007ooOol00goo
000BOol00`00O]IneP18O]H00`00Oomoo`0eOol00`00O]IneP0kO]H00`00Oomoo`0COol00`00O]In
eP2eO]H00`00Oomoo`03Ool000Qoo`<000Moo`03001neWkF04UneP03001oogoo03Eoo`03001neWkF
03]neP03001oogoo01=oo`03001neWkF0;AneP03001oogoo00=oo`001goo00D007ooOomoo`0000Io
o`03001neWkF04UneP03001oogoo03Eoo`03001neWkF03]neP03001oogoo01=oo`03001neWkF0;An
eP03001oogoo00=oo`001goo00D007ooOomoo`0000Ioo`03001neWkF04UneP03001oogoo03Ioo`03
001neWkF03YneP03001oogoo01=oo`03001neWkF0;AneP03001oogoo00=oo`001goo10001goo00<0
07kFO]H0BGkF00<007ooOol0=Woo00<007kFO]H0>WkF00<007ooOol04goo00<007kFO]H0]7kF00<0
07ooOol00goo0007Ool00`00Oomoo`08Ool00`00O]IneP1:O]H00`00Oomoo`0fOol00`00O]IneP0j
O]H00`00Oomoo`0COol00`00O]IneP2cO]H00`00Oomoo`03Ool000Qoo`03001oogoo00Moo`03001n
eWkF04]neP03001oogoo03Ioo`03001neWkF03UneP03001oogoo01=oo`03001neWkF0;=neP03001o
ogoo00=oo`002Goo0P001goo00<007kFO]H0BgkF00<007ooOol0=goo00<007kFO]H0>7kF00<007oo
Ool057oo00<007kFO]H0/WkF00<007ooOol00goo000BOol00`00O]IneP1;O]H00`00Oomoo`0hOol0
0`00O]IneP0hO]H00`00Oomoo`0COol00`00O]IneP2bO]H00`00Oomoo`03Ool0019oo`03001neWkF
04]neP03001oogoo03Qoo`03001neWkF03QneP03001oogoo01=oo`03001neWkF0;9neP03001oogoo
00=oo`004Woo00<007kFO]H0C7kF00<007ooOol0>7oo00<007kFO]H0>7kF00<007ooOol04goo00<0
07kFO]H0/GkF00<007ooOol00goo000BOol00`00O]IneP1=O]H00`00Oomoo`0hOol00`00O]IneP0g
O]H00`00Oomoo`0COol00`00O]IneP2aO]H00`00Oomoo`03Ool0019oo`03001neWkF04eneP03001o
ogoo03Qoo`03001neWkF03MneP03001oogoo01=oo`03001neWkF0;5neP03001oogoo00=oo`004Woo
00<007kFO]H0CGkF00<007ooOol0>Goo00<007kFO]H0=gkF00<007ooOol04goo00<007kFO]H0/7kF
00<007ooOol00goo000BOol00`00O]IneP1=O]H00`00Oomoo`0iOol00`00O]IneP0gO]H00`00Oomo
o`0COol00`00O]IneP2`O]H00`00Oomoo`03Ool0019oo`03001neWkF04ineP03001oogoo03Uoo`03
001neWkF03IneP03001oogoo01Aoo`03001neWkF0:mneP03001oogoo00=oo`004Woo00<007kFO]H0
CgkF00<007ooOol0>Goo00<007kFO]H0=GkF00<007ooOol057oo00<007kFO]H0[gkF00<007ooOol0
0goo000BOol00`00O]IneP1?O]H00`00Oomoo`0iOol00`00O]IneP0fO]H00`00Oomoo`0COol00`00
O]IneP2_O]H00`00Oomoo`03Ool0019oo`03001neWkF04mneP03001oogoo03Yoo`03001neWkF03En
eP03001oogoo01Aoo`03001neWkF0:ineP03001oogoo00=oo`004Woo00<007kFO]H0CgkF00<007oo
Ool0>goo00<007kFO]H0=7kF00<007ooOol057oo00<007kFO]H0[WkF00<007ooOol00goo000BOol0
0`00O]IneP1@O]H00`00Oomoo`0kOol00`00O]IneP0dO]H00`00Oomoo`0COol00`00O]IneP2^O]H0
0`00Oomoo`03Ool0019oo`03001neWkF055neP03001oogoo03]oo`03001neWkF03=neP03001oogoo
01=oo`03001neWkF0:ineP03001oogoo00=oo`004Woo00<007kFO]H0DGkF00<007ooOol0>goo00<0
07kFO]H0<gkF00<007ooOol057oo00<007kFO]H0[GkF00<007ooOol00goo000BOol00`00O]IneP1A
O]H00`00Oomoo`0lOol00`00O]IneP0cO]H00`00Oomoo`0DOol00`00O]IneP2/O]H00`00Oomoo`03
Ool0019oo`03001neWkF055neP03001oogoo03aoo`03001neWkF03=neP03001oogoo01Aoo`03001n
eWkF0:aneP03001oogoo00=oo`004Woo00<007kFO]H0DWkF00<007ooOol0?7oo00<007kFO]H0<WkF
00<007ooOol057oo00<007kFO]H0[7kF00<007ooOol00goo000BOol00`00O]IneP1CO]H00`00Oomo
o`0lOol00`00O]IneP0aO]H00`00Oomoo`0DOol00`00O]IneP2/O]H00`00Oomoo`03Ool0019oo`03
001neWkF05=neP03001oogoo03aoo`03001neWkF039neP03001oogoo01Aoo`03001neWkF0:]neP03
001oogoo00=oo`004Woo00<007kFO]H0DgkF00<007ooOol0?Goo00<007kFO]H0<GkF00<007ooOol0
57oo00<007kFO]H0ZgkF00<007ooOol00goo000BOol00`00O]IneP1CO]H00`00Oomoo`0mOol00`00
O]IneP0aO]H00`00Oomoo`0DOol00`00O]IneP2[O]H00`00Oomoo`03Ool0019oo`03001neWkF05An
eP03001oogoo03eoo`03001neWkF035neP03001oogoo01Aoo`03001neWkF0:YneP03001oogoo00=o
o`004Woo00<007kFO]H0EGkF00<007ooOol0?Goo00<007kFO]H0<7kF00<007ooOol057oo00<007kF
O]H0ZWkF00<007ooOol00goo000BOol00`00O]IneP1EO]H00`00Oomoo`0mOol00`00O]IneP0`O]H0
0`00Oomoo`0DOol00`00O]IneP2ZO]H00`00Oomoo`03Ool0019oo`03001neWkF05EneP03001oogoo
03ioo`03001neWkF02mneP03001oogoo01Eoo`03001neWkF0:UneP03001oogoo00=oo`004Woo00<0
07kFO]H0EGkF00<007ooOol0?Woo00<007kFO]H0;gkF00<007ooOol05Goo00<007kFO]H0ZGkF00<0
07ooOol00goo000BOol00`00O]IneP1FO]H00`00Oomoo`0nOol2000`O]H00`00Oomoo`0DOol00`00
O]IneP2QO]H90005Ool0019oo`03001neWkF05IneP03001oogoo041oo`03001neWkF02eneP03001o
ogoo01Aoo`03001neWkF09AnePh000MneP03001oogoo00=oo`004Woo00<007kFO]H0EWkF00<007oo
Ool0@7oo00<007kFO]H0;GkF00<007ooOol05Goo00<007kFO]H0S7kF2P004WkF00<007ooOol00goo
000BOol00`00O]IneP1GO]H00`00Oomoo`10Ool00`00O]IneP0/O]H00`00Oomoo`0EOol00`00O]In
eP24O]H9000KO]H00`00Oomoo`03Ool0019oo`03001neWkF05MneP03001oogoo041oo`03001neWkF
02eneP03001oogoo01Eoo`03001neWkF07]nePT002=neP03001oogoo00=oo`004Woo00<007kFO]H0
F7kF00<007ooOol0@7oo00<007kFO]H0;7kF00<007ooOol05Goo00<007kFO]H0LgkF2@00:gkF00<0
07ooOol00goo000BOol00`00O]IneP1HO]H00`00Oomoo`11Ool00`00O]IneP0[O]H00`00Oomoo`0E
Ool00`00O]IneP1ZO]H:000cO]H00`00Oomoo`03Ool0019oo`03001neWkF05QneP03001oogoo045o
o`03001neWkF02aneP03001oogoo01Eoo`03001neWkF05aneQ0003YneP03001oogoo00=oo`004Woo
00<007kFO]H0FGkF00<007ooOol0@Goo00<007kFO]H0:gkF00<007ooOol05Goo00<007kFO]H0D7kF
4@00AGkF00<007ooOol00goo000BOol00`00O]IneP1IO]H00`00Oomoo`11Ool00`00O]IneP0[O]H0
0`00Oomoo`0EOol00`00O]IneP19O]H=001@O]H00`00Oomoo`03Ool0019oo`03001neWkF05YneP03
001oogoo045oo`03001neWkF02]neP03001oogoo01Eoo`03001neWkF041neP`005UneP03001oogoo
00=oo`004Woo00<007kFO]H0FWkF00<007ooOol0@Woo00<007kFO]H0:WkF00<007ooOol05Goo00<0
07kFO]H0=gkF3@00HGkF00<007ooOol00goo000BOol00`00O]IneP1JO]H00`00Oomoo`12Ool00`00
O]IneP0ZO]H00`00Oomoo`0EOol00`00O]IneP0_O]H<001ZO]H00`00Oomoo`03Ool0019oo`03001n
eWkF05]neP03001oogoo049oo`03001neWkF02UneP03001oogoo01Eoo`03001neWkF02IneP`007=n
eP03001oogoo00=oo`004Woo00<007kFO]H0FgkF00<007ooOol0@Woo00<007kFO]H0:GkF00<007oo
Ool05Woo00<007kFO]H067kF4@00NgkF00<007ooOol00goo000BOol00`00O]IneP1KO]H00`00Oomo
o`13Ool00`00O]IneP0YO]H00`00Oomoo`0EOol00`00O]IneP0;O]HC0026O]H00`00Oomoo`03Ool0
019oo`03001neWkF05aneP03001oogoo04=oo`03001neWkF02QneP03001oogoo01Eoo`03001neWkF
009neQ00099neP03001oogoo00=oo`004Woo00<007kFO]H0G7kF00<007ooOol0@goo00<007kFO]H0
:7kF9000VgkF00<007ooOol00goo000BOol00`00O]IneP1MO]H00`00Oomoo`13Ool00`00O]IneP0V
O]H00`00Oomoo`0JOol00`00O]IneP2PO]H00`00Oomoo`03Ool0019oo`03001neWkF05eneP03001o
ogoo04=oo`03001neWkF02AneP8001]oo`800:=neP03001oogoo00=oo`004Woo00<007kFO]H0GGkF
00<007ooOol0A7oo00<007kFO]H08WkF00<007ooOol06Woo00<007kFO]H0XgkF00<007ooOol00goo
000BOol00`00O]IneP1NO]H00`00Oomoo`14Ool00`00O]IneP0OO]H2000KOol2002VO]H00`00Oomo
o`03Ool0019oo`03001neWkF05ineP03001oogoo04Aoo`03001neWkF01aneP<001Yoo`<00:QneP03
001oogoo00=oo`004Woo00<007kFO]H0GgkF00<007ooOol0A7oo00<007kFO]H06WkF00<007ooOol0
6Woo00<007kFO]H0ZGkF00<007ooOol00goo000BOol00`00O]IneP1OO]H00`00Oomoo`14Ool00`00
O]IneP0HO]H2000KOol2002/O]H00`00Oomoo`03Ool0019oo`03001neWkF05mneP03001oogoo04Eo
o`03001neWkF01IneP03001oogoo01Yoo`03001neWkF0:aneP03001oogoo00=oo`004Woo00<007kF
O]H0H7kF00<007ooOol0AGoo00<007kFO]H04gkF0P006goo0P00[gkF00<007ooOol00goo000BOol0
0`00O]IneP1PO]H00`00Oomoo`15Ool00`00O]IneP0BO]H00`00Oomoo`0JOol00`00O]IneP2_O]H0
0`00Oomoo`03Ool0019oo`80065neP03001oogoo04Ioo`03001neWkF00mneP8001]oo`800;9neP03
001oogoo00=oo`004Woo0P00HGkF00<007ooOol0AWoo00<007kFO]H037kF0`006Woo0`00]7kF00<0
07ooOol00goo000BOol2001RO]H00`00Oomoo`16Ool00`00O]IneP0:O]H00`00Oomoo`0JOol00`00
O]IneP2eO]H00`00Oomoo`03Ool0019oo`03001n<@00069neP03001oogoo04Ioo`03001neWkF00Mn
eP8001]oo`800;QneP03001oogoo00=oo`0027oo0`001goo00<007ha0000HWkF00<007ooOol0AWoo
00<007kFO]H01WkF00<007ooOol06Woo00<007kFO]H0^7kF00<007ooOol00goo0007Ool01@00Oomo
ogoo00001Woo00@007haOS40065neP03001oogoo04Moo`03001neWkF00=neP8001]oo`800;]neP03
001oogoo00=oo`001goo00D007ooOomoo`0000Ioo`04001n<Gha001QO]H00`00Oomoo`17Ool00`00
O]IneP02O]H00`00Oomoo`0JOol00`00O]IneP2kO]H00`00Oomoo`03Ool000Qoo`<000Moo`04001n
<Gha001RO]H00`00Oomoo`17Ool01000O]H000006Woo0`00_WkF00<007ooOol00goo0007Ool01@00
Oomoogoo00001Woo00D007haOS5n<@00065neVP00<5neP03001oogoo00=oo`001goo00D007ooOomo
o`0000Ioo`05001n<GhaOS40001QO]H00`00Oomoo`1SOol00`00O]IneP30O]H00`00Oomoo`03Ool0
00Qoo`<000Moo`03001n<Gha009n<@03001neWkF05ineP03001oogoo06=oo`03001neWkF0<1neP03
001oogoo00=oo`004Woo00<007haOS400Wha00<007kFO]H0GWkF00<007ooOol0Hgoo00<007kFO]H0
`7kF00<007ooOol00goo000BOol00`00OS5n<@02OS400`00O]IneP1NO]H00`00Oomoo`1SOol00`00
O]IneP30O]H00`00Oomoo`03Ool0019oo`03001n<Gha00=n<@03001neWkF05aneP03001oogoo06Ao
o`03001neWkF0<1neP03001oogoo00=oo`004Woo00<007haOS400gha00<007kFO]H0G7kF00<007oo
Ool0I7oo00<007kFO]H0`7kF00<007ooOol00goo000BOol00`00OS5n<@04OS400`00O]IneP1KO]H0
0`00Oomoo`1TOol00`00O]IneP30O]H00`00Oomoo`03Ool0019oo`03001n<Gha00En<@03001neWkF
05YneP03001oogoo06Aoo`03001neWkF0<1neP03001oogoo00=oo`004Woo00<007haOS401Gha00<0
07kFO]H0FWkF00<007ooOol0I7oo00<007kFO]H0`7kF00<007ooOol00goo000BOol00`00OS5n<@05
OS400`00O]IneP1IO]H00`00Oomoo`1UOol00`00O]IneP30O]H00`00Oomoo`03Ool0019oo`03001n
<Gha00En<@03001neWkF05UneP03001oogoo06Eoo`03001neWkF0<1neP03001oogoo00=oo`004Woo
00<007haOS401Wha00<007kFO]H0F7kF00<007ooOol0I7oo00<007kFO]H0`GkF00<007ooOol00goo
000BOol00`00OS5n<@07OS400`00O]IneP1GO]H00`00Oomoo`1TOol00`00O]IneP31O]H00`00Oomo
o`03Ool0019oo`03001n<Gha00Mn<@03001neWkF05IneP03001oogoo06Eoo`03001neWkF0<5neP03
001oogoo00=oo`004Woo00<007haOS401gha00<007kFO]H0EWkF00<007ooOol0IGoo00<007kFO]H0
`GkF00<007ooOol00goo000BOol00`00OS5n<@07OS400`00O]IneP1FO]H00`00Oomoo`1UOol00`00
O]IneP31O]H00`00Oomoo`03Ool0019oo`03001n<Gha00Qn<@03001neWkF05EneP03001oogoo06Eo
o`03001neWkF0<5neP03001oogoo00=oo`004Woo00<007haOS402Gha00<007kFO]H0E7kF00<007oo
Ool0IGoo00<007kFO]H0`GkF00<007ooOol00goo000BOol00`00OS5n<@09OS400`00O]IneP1CO]H0
0`00Oomoo`1VOol00`00O]IneP31O]H00`00Oomoo`03Ool0019oo`03001n<Gha00Un<@03001neWkF
05=neP03001oogoo06Ioo`03001neWkF0<5neP03001oogoo00=oo`004Woo00<007haOS402Gha00<0
07kFO]H0DgkF00<007ooOol0IWoo00<007kFO]H0`GkF00<007ooOol00goo000BOol00`00OS5n<@0:
OS400`00O]IneP1BO]H00`00Oomoo`1VOol00`00O]IneP31O]H00`00Oomoo`03Ool0019oo`03001n
<Gha00]n<@03001neWkF055neP03001oogoo06Ioo`03001neWkF0<5neP03001oogoo00=oo`004Woo
00<007haOS402gha00<007kFO]H0D7kF00<007ooOol0IWoo00<007kFO]H0`WkF00<007ooOol00goo
000BOol00`00OS5n<@0;OS400`00O]IneP1@O]H00`00Oomoo`1VOol00`00O]IneP32O]H00`00Oomo
o`03Ool0019oo`03001n<Gha00]n<@03001neWkF051neP03001oogoo06Ioo`03001neWkF0<9neP03
001oogoo00=oo`004Woo00<007haOS4037ha00<007kFO]H0CgkF00<007ooOol0IWoo00<007kFO]H0
`WkF00<007ooOol00goo000BOol00`00OS5n<@0=OS400`00O]IneP1>O]H00`00Oomoo`1VOol00`00
O]IneP32O]H00`00Oomoo`03Ool0019oo`03001n<Gha00en<@03001neWkF04eneP03001oogoo06Mo
o`03001neWkF0<9neP03001oogoo00=oo`004Woo00<007haOS403Wha00<007kFO]H0C7kF00<007oo
Ool0Igoo00<007kFO]H0`WkF00<007ooOol00goo000BOol00`00OS5n<@0>OS400`00O]IneP1<O]H0
0`00Oomoo`1WOol00`00O]IneP32O]H00`00Oomoo`03Ool0019oo`03001n<Gha00in<@03001neWkF
04aneP03001oogoo06Moo`03001neWkF0<9neP03001oogoo00=oo`004Woo00<007haOS403gha00<0
07kFO]H0BgkF00<007ooOol0Igoo00<007kFO]H0`WkF00<007ooOol00goo000BOol00`00OS5n<@0?
OS400`00O]IneP1:O]H00`00Oomoo`1XOol00`00O]IneP32O]H00`00Oomoo`03Ool0019oo`03001n
<Gha011n<@03001neWkF04UneP03001oogoo06Qoo`03001neWkF0<9neP03001oogoo00=oo`004Woo
00<007haOS4047ha00<007kFO]H0BGkF00<007ooOol0Igoo00<007kFO]H0`gkF00<007ooOol00goo
000BOol00`00OS5n<@0@OS400`00O]IneP19O]H00`00Oomoo`1WOol00`00O]IneP33O]H00`00Oomo
o`03Ool0019oo`03001n<Gha015n<@03001neWkF04QneP03001oogoo06Ioo`<00<AneP03001oogoo
00=oo`004Woo00<007haOS404Gha00<007kFO]H0AgkF00<007ooOol0IGoo0P0000=neP0000000P00
`WkF00<007ooOol00goo000BOol00`00OS5n<@0BOS400`00O]IneP16O]H00`00Oomoo`1TOol01@00
O]IneWkF00000gha0`00_gkF00<007ooOol00goo000BOol00`00OS5n<@0BOS400`00O]IneP16O]H0
0`00Oomoo`1ROol20005O]H00`00OS5n<@03OS43002lO]H00`00Oomoo`03Ool0019oo`03001n<Gha
01=n<@03001neWkF04EneP03001oogoo065oo`03001neWkF00EneP03001n<Gha00In<@<00;UneP03
001oogoo00=oo`004Woo00<007haOS404gha00<007kFO]H0AGkF00<007ooOol0Ggoo0P0027kF00<0
07haOS402Gha1000]GkF00<007ooOol00goo000BOol00`00OS5n<@0COS400`00O]IneP14O]H00`00
Oomoo`1NOol2000:O]H00`00OS5n<@0=OS43002bO]H00`00Oomoo`03Ool0019oo`03001n<Gha01An
<@03001neWkF04=neP03001oogoo05eoo`03001neWkF00YneP03001n<Gha011n<@<00:mneP03001o
ogoo00=oo`004Woo00<007haOS4057ha00<007kFO]H0@gkF00<007ooOol0Fgoo0P003GkF00<007ha
OS404gha1000ZgkF00<007ooOol00goo000BOol00`00OS5n<@0EOS400`00O]IneP12O]H00`00Oomo
o`1JOol00`00O]IneP0=O]H00`00OS5n<@0GOS43002XO]H00`00Oomoo`03Ool0019oo`03001n<Gha
01En<@03001neWkF049neP03001oogoo05Qoo`80015neP03001n<Gha01Un<@<00:EneP03001oogoo
00=oo`004Woo00<007haOS405Gha00<007kFO]H0@GkF00<007ooOol0Egoo0P004gkF00<007haOS40
77ha0`00XWkF00<007ooOol00goo000BOol00`00OS5n<@0FOS400`00O]IneP10O]H00`00Oomoo`1F
Ool00`00O]IneP0CO]H00`00OS5n<@0OOS44002NO]H00`00Oomoo`03Ool0019oo`03001n<Gha01In
<@03001neWkF041neP03001oogoo05Eoo`03001neWkF01AneP03001n<Gha02=n<@<009]neP03001o
ogoo00=oo`004Woo00<007haOS405gha00<007kFO]H0?gkF00<007ooOol0E7oo00<007kFO]H05GkF
00<007haOS409Wha0`00V7kF00<007ooOol00goo000BOol00`00OS5n<@0HOS400`00O]IneP0nO]H0
0`00Oomoo`1BOol2000HO]H00`00OS5n<@0YOS44002DO]H00`00Oomoo`03Ool0019oo`03001n<Gha
01Qn<@03001neWkF03eneP03001oogoo055oo`8001]neP03001n<Gha02an<@<0095neP03001oogoo
00=oo`004Woo00<007haOS4067ha00<007kFO]H0?GkF00<007ooOol0D7oo00<007kFO]H06gkF00<0
07haOS40;gha0`00SWkF00<007ooOol00goo000BOol00`00OS5n<@0HOS400`00O]IneP0mO]H00`00
Oomoo`1?Ool00`00O]IneP0LO]H00`00OS5n<@0bOS43002;O]H00`00Oomoo`03Ool0019oo`03001n
<Gha01Un<@03001neWkF03aneP03001oogoo04ioo`03001neWkF01eneP03001n<Gha03En<@@008Mn
eP03001oogoo00=oo`004Woo00<007haOS406Wha00<007kFO]H0>gkF00<007ooOol0C7oo0P0087kF
00<007haOS40>Gha0`00Q7kF00<007ooOol00goo000BOol00`00OS5n<@0JOS400`00O]IneP0jO]H0
0`00Oomoo`1<Ool00`00O]IneP0PO]H00`00OS5n<@0lOS430021O]H00`00Oomoo`03Ool0019oo`03
001n<Gha01]n<@03001neWkF03UneP03001oogoo04Yoo`8002AneP03001n<Gha03in<@@007eneP03
001oogoo00=oo`004Woo00<007haOS406gha00<007kFO]H0>GkF00<007ooOol0BGoo00<007kFO]H0
97kF00<007haOS40@Wha0`00NWkF00<007ooOol00goo000BOol00`00OS5n<@0KOS400`00O]IneP0h
O]H00`00Oomoo`19Ool00`00O]IneP0UO]H00`00OS5n<@15OS43001gO]H00`00Oomoo`03Ool0009o
o`<000Aoo`8000Moo`03001n<Gha01an<@03001neWkF03MneP03001oogoo04Moo`8002QneP03001n
<Gha04Qn<@<007AneP03001oogoo00=oo`000goo00<007ooOol00Woo00@007ooOol000Ioo`03001n
<Gha01an<@03001neWkF03MneP03001oogoo04Ioo`03001neWkF02QneP03001n<Gha04]n<@@0071n
eP03001oogoo00=oo`000goo00<007ooOol00Woo00@007ooOol000Ioo`03001n<Gha01en<@03001n
eWkF03IneP03001oogoo04Aoo`8002]neP03001n<Gha04mn<@<006eneP03001oogoo00=oo`000goo
00<007ooOol00Woo00@007ooOol000Ioo`03001n<Gha01en<@03001neWkF03IneP03001oogoo049o
o`8002ineP03001n<Gha055n<@<006YneP03001oogoo00=oo`000goo00<007ooOol00Woo00@007oo
Ool000Ioo`03001n<Gha01in<@03001neWkF03AneP03001oogoo049oo`03001neWkF02ineP03001n
<Gha05An<@@006IneP03001oogoo00=oo`000Woo0P0017oo00@007ooOol000Ioo`03001n<Gha01in
<@03001neWkF03AneP03001oogoo045oo`03001neWkF02mneP03001n<Gha05Qn<@<006=neP03001o
ogoo00=oo`000goo00<007ooOol00goo0P001goo00<007haOS407Wha00<007kFO]H0=7kF00<007oo
Ool0@7oo00<007kFO]H0<7kF00<007haOS40Fgha0`00H7kF00<007ooOol00goo000BOol00`00OS5n
<@0OOS400`00O]IneP0cO]H00`00Oomoo`0nOol2000cO]H00`00OS5n<@1NOS43001MO]H00`00Oomo
o`03Ool0019oo`03001n<Gha01mn<@03001neWkF03=neP03001oogoo03eoo`03001neWkF03AneP03
001n<Gha061n<@@005UneP03001oogoo00=oo`004Woo00<007haOS4087ha00<007kFO]H0<GkF00<0
07ooOol0?Goo00<007kFO]H0=GkF00<007haOS40I7ha0`00EWkF00<007ooOol00goo000BOol00`00
OS5n<@0POS400`00O]IneP0aO]H00`00Oomoo`0lOol00`00O]IneP0fO]H00`00OS5n<@1WOS43001C
O]H00`00Oomoo`03Ool0019oo`03001n<Gha025n<@03001neWkF031neP03001oogoo03]oo`03001n
eWkF03MneP03001n<Gha06Yn<@@004mneP03001oogoo00=oo`004Woo00<007haOS408Gha00<007kF
O]H0<7kF00<007ooOol0>Goo0P00>WkF00<007haOS40KWha0`00C7kF00<007ooOol00goo000BOol0
0`00OS5n<@0QOS400`00O]IneP0`O]H00`00Oomoo`0gOol2000lO]H00`00OS5n<@1aOS430019O]H0
0`00Oomoo`03Ool0019oo`03001n<Gha029n<@03001neWkF02ineP03001oogoo03Moo`03001neWkF
03aneP03001n<Gha07An<@<004IneP03001oogoo00=oo`004Woo00<007haOS408Wha00<007kFO]H0
;WkF00<007ooOol0=Woo00<007kFO]H0?WkF00<007haOS40MWha1000@WkF00<007ooOol00goo000B
Ool00`00OS5n<@0SOS400`00O]IneP0]O]H00`00Oomoo`0eOol00`00O]IneP0oO]H00`00OS5n<@1j
OS43000oO]H00`00Oomoo`03Ool0019oo`03001n<Gha02An<@03001neWkF02]neP03001oogoo03Ao
o`80049neP03001n<Gha07en<@<003aneP03001oogoo00=oo`004Woo00<007haOS4097ha00<007kF
O]H0:gkF00<007ooOol0<goo00<007kFO]H0@WkF00<007haOS40P7ha1000>7kF00<007ooOol00goo
000BOol00`00OS5n<@0TOS400`00O]IneP0[O]H00`00Oomoo`0bOol00`00O]IneP13O]H00`00OS5n
<@24OS43000eO]H00`00Oomoo`03Ool0019oo`03001n<Gha02An<@03001neWkF02]neP03001oogoo
035oo`03001neWkF04EneP03001n<Gha08In<@<0039neP03001oogoo00=oo`004Woo00<007haOS40
9Gha00<007kFO]H0:WkF00<007ooOol0<7oo00<007kFO]H0AWkF00<007haOS40RGha0`00;gkF00<0
07ooOol00goo000BOol00`00OS5n<@0VOS400`00O]IneP0XO]H00`00Oomoo`0_Ool20019O]H00`00
OS5n<@2<OS44000[O]H00`00Oomoo`03Ool0019oo`03001n<Gha02In<@03001neWkF02QneP03001o
ogoo02ioo`03001neWkF04UneP03001n<Gha091n<@<002QneP03001oogoo00=oo`004Woo00<007ha
OS409gha00<007kFO]H09gkF00<007ooOol0;Goo00<007kFO]H0BWkF00<007haOS40Tgha0`009GkF
00<007ooOol00goo000BOol00`00OS5n<@0WOS400`00O]IneP0WO]H00`00Oomoo`0/Ool00`00O]In
eP1;O]H00`00OS5n<@2FOS44000QO]H00`00Oomoo`03Ool0019oo`03001n<Gha02Qn<@03001neWkF
02IneP03001oogoo02]oo`03001neWkF04aneP03001n<Gha09Yn<@<001ineP03001oogoo00=oo`00
4Woo00<007haOS40:7ha00<007kFO]H09GkF00<007ooOol0:Woo0P00D7kF00<007haOS40W7ha0`00
6gkF00<007ooOol00goo000BOol00`00OS5n<@0XOS400`00O]IneP0UO]H00`00Oomoo`0YOol00`00
O]IneP1@O]H00`00OS5n<@2OOS43000HO]H00`00Oomoo`03Ool0019oo`03001n<Gha02Un<@03001n
eWkF02AneP03001oogoo02Moo`8005=neP03001n<Gha0:9n<@@001AneP03001oogoo00=oo`004Woo
00<007haOS40:Gha00<007kFO]H097kF00<007ooOol09Woo00<007kFO]H0DgkF00<007haOS40YWha
0`004GkF00<007ooOol00goo000BOol00`00OS5n<@0ZOS400`00O]IneP0RO]H00`00Oomoo`0VOol0
0`00O]IneP1DO]H00`00OS5n<@2YOS43000>O]H00`00Oomoo`03Ool0019oo`03001n<Gha02]n<@03
001neWkF025neP03001oogoo02Eoo`03001neWkF05IneP03001n<Gha0:]n<@@000YneP03001oogoo
00=oo`004Woo00<007haOS40:gha00<007kFO]H08GkF00<007ooOol09Goo00<007kFO]H0EWkF00<0
07haOS40[gha0`001gkF00<007ooOol00goo000BOol00`00OS5n<@0/OS400`00O]IneP0PO]H00`00
Oomoo`0SOol2001IO]H00`00OS5n<@2bOS430004O]H00`00Oomoo`03Ool0019oo`03001n<Gha02an
<@03001neWkF021neP03001oogoo029oo`03001neWkF05UneP03001n<Gha0;En<@<00003O]H007oo
00Aoo`004Woo00<007haOS40;7ha00<007kFO]H07gkF00<007ooOol08Woo00<007kFO]H0FWkF00<0
07haOS40^7ha0P001Goo000BOol00`00OS5n<@0]OS400`00O]IneP0NO]H00`00Oomoo`0QOol00`00
O]IneP1LO]H00`00OS5n<@2hOS400`00Oomoo`03Ool0019oo`03001n<Gha02en<@03001neWkF01in
eP03001oogoo021oo`03001neWkF05eneP03001n<Gha0;Qn<@03001oogoo00=oo`004Woo00<007ha
OS40;Wha00<007kFO]H077kF00<007ooOol07goo0P00H7kF00<007haOS40^7ha00<007ooOol00goo
000BOol00`00OS5n<@0^OS400`00O]IneP0LO]H00`00Oomoo`0NOol00`00O]IneP1PO]H00`00OS5n
<@2hOS400`00Oomoo`03Ool0019oo`03001n<Gha02mn<@03001neWkF01]neP03001oogoo01eoo`03
001neWkF065neP03001n<Gha0;Qn<@03001oogoo00=oo`004Woo00<007haOS40;gha00<007kFO]H0
6gkF00<007ooOol077oo00<007kFO]H0HgkF00<007haOS40]gha00<007ooOol00goo000BOol00`00
OS5n<@0_OS400`00O]IneP0KO]H00`00Oomoo`0KOol00`00O]IneP1TO]H00`00OS5n<@2gOS400`00
Oomoo`03Ool0019oo`03001n<Gha031n<@03001neWkF01UneP03001oogoo01Yoo`8006MneP03001n
<Gha0;Mn<@03001oogoo00=oo`004Woo00<007haOS40<7ha00<007kFO]H06GkF00<007ooOol06Goo
00<007kFO]H0IgkF00<007haOS40]gha00<007ooOol00goo000BOol00`00OS5n<@0aOS400`00O]In
eP0HO]H00`00Oomoo`0HOol00`00O]IneP1XO]H00`00OS5n<@2gOS400`00Oomoo`03Ool0019oo`03
001n<Gha039n<@03001neWkF01IneP03001oogoo01Qoo`03001neWkF06YneP03001n<Gha0;In<@03
001oogoo00=oo`004Woo00<007haOS40<Wha00<007kFO]H05WkF00<007ooOol05goo00<007kFO]H0
JgkF00<007haOS40]Wha00<007ooOol00goo000BOol00`00OS5n<@0cOS400`00O]IneP0EO]H00`00
Oomoo`0FOol00`00O]IneP1/O]H00`00OS5n<@2fOS400`00Oomoo`03Ool0019oo`03001n<Gha03=n
<@03001neWkF01EneP03001oogoo01Eoo`03001neWkF06eneP03001n<Gha0;In<@03001oogoo00=o
o`004Woo00<007haOS40<gha00<007kFO]H05GkF00<007ooOol057oo00<007kFO]H0KWkF00<007ha
OS40]Wha00<007ooOol00goo000BOol00`00OS5n<@0dOS400`00O]IneP0CO]H00`00Oomoo`0DOol0
0`00O]IneP1`O]H00`00OS5n<@2eOS400`00Oomoo`03Ool0019oo`03001n<Gha03An<@03001neWkF
01=neP03001oogoo01=oo`03001neWkF075neP03001n<Gha0;En<@03001oogoo00=oo`004Woo00<0
07haOS40=Gha00<007kFO]H04WkF00<007ooOol04Goo0P00M7kF00<007haOS40]Gha00<007ooOol0
0goo000BOol00`00OS5n<@0eOS400`00O]IneP0BO]H00`00Oomoo`0@Ool00`00O]IneP1dO]H00`00
OS5n<@2eOS400`00Oomoo`03Ool0019oo`03001n<Gha03In<@03001neWkF011neP03001oogoo011o
o`03001neWkF07EneP03001n<Gha0;En<@03001oogoo00=oo`004Woo00<007haOS40=gha00<007kF
O]H03gkF00<007ooOol03goo00<007kFO]H0MgkF00<007haOS40]7ha00<007ooOol00goo000BOol0
0`00OS5n<@0gOS400`00O]IneP0?O]H00`00Oomoo`0>Ool00`00O]IneP1hO]H00`00OS5n<@2dOS40
0`00Oomoo`03Ool0019oo`03001n<Gha03Qn<@03001neWkF00ineP03001oogoo00eoo`03001neWkF
07UneP03001n<Gha0;An<@03001oogoo00=oo`004Woo00<007haOS40>7ha00<007kFO]H03WkF00<0
07ooOol037oo00<007kFO]H0NWkF00<007haOS40]7ha00<007ooOol00goo000BOol00`00OS5n<@0h
OS400`00O]IneP0=O]H00`00Oomoo`0<Ool00`00O]IneP1kO]H00`00OS5n<@2dOS400`00Oomoo`03
Ool0019oo`03001n<Gha03Un<@03001neWkF00aneP03001oogoo00]oo`03001neWkF07eneP03001n
<Gha0;=n<@03001oogoo00=oo`004Woo00<007haOS40>Gha00<007kFO]H037kF00<007ooOol02Woo
00<007kFO]H0OWkF00<007haOS40/gha00<007ooOol00goo000BOol00`00OS5n<@0jOS400`00O]In
eP0:O]H00`00Oomoo`0:Ool00`00O]IneP1oO]H00`00OS5n<@2cOS400`00Oomoo`03Ool0019oo`03
001n<Gha03Yn<@03001neWkF00YneP03001oogoo00Uoo`03001neWkF081neP03001n<Gha0;=n<@03
001oogoo00=oo`004Woo00<007haOS40>gha00<007kFO]H02GkF00<007ooOol027oo00<007kFO]H0
PGkF00<007haOS40/gha00<007ooOol00goo0002Ool30002Ool50006Ool00`00OS5n<@0lOS400`00
O]IneP07O]H00`00Oomoo`08Ool00`00O]IneP23O]H00`00OS5n<@2bOS400`00Oomoo`03Ool000=o
o`03001oogoo009oo`04001oogoo0006Ool00`00OS5n<@0lOS400`00O]IneP07O]H00`00Oomoo`07
Ool00`00O]IneP24O]H00`00OS5n<@2bOS400`00Oomoo`03Ool000=oo`03001oogoo00=oo`03001o
ogoo00Ioo`03001n<Gha03en<@03001neWkF00IneP03001oogoo00Ioo`03001neWkF08EneP03001n
<Gha0;9n<@03001oogoo00=oo`000goo00<007ooOol017oo00<007ooOol01Goo00<007haOS40?Gha
00<007kFO]H01WkF00<007ooOol01Goo00<007kFO]H0QWkF00<007haOS40/Wha00<007ooOol00goo
0003Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007haOS40?Wha00<007kFO]H01GkF00<0
07ooOol00goo0P00RGkF00<007haOS40/Wha00<007ooOol00goo0002Ool20003Ool01@00Oomoogoo
00001Woo00<007haOS40?Wha00<007kFO]H017kF00<007ooOol00goo00<007kFO]H0RWkF00<007ha
OS40/Gha00<007ooOol00goo0003Ool00`00Oomoo`02Ool30007Ool00`00OS5n<@0nOS400`00O]In
eP04O]H00`00Oomoo`03Ool00`00O]IneP2:O]H00`00OS5n<@2aOS400`00Oomoo`03Ool0019oo`03
001n<Gha03mn<@03001neWkF00=neP03001oogoo009oo`03001neWkF08]neP03001n<Gha0;5n<@03
001oogoo00=oo`004Woo00<007haOS40?gha00<007kFO]H00gkF00D007ooOomoo`0008ineP03001n
<Gha0;5n<@03001oogoo00=oo`004Woo00<007haOS40@7ha00D007kFO]IneP00009oo`8008mneP03
001n<Gha0;5n<@03001oogoo00=oo`004Woo00<007haOS40@Gha00H007kFO]H007oo002BO]H00`00
OS5n<@2`OS400`00Oomoo`03Ool0019oo`03001n<Gha045n<@03001neWkF008009=neP03001n<Gha
0;1n<@03001oogoo00=oo`004Woo00<007haOS40@Wha0`00U7kF00<007haOS40/7ha00<007ooOol0
0goo000BOol00`00OS5n<@12OS43002DO]H00`00OS5n<@2`OS400`00Oomoo`03Ool0019oo`03001n
<Gha04=n<@03001neWkF09=neP03001n<Gha0;1n<@03001oogoo00=oo`004Woo00<007haOS40@gha
00<007kFO]H0U7kF00<007haOS40[gha00<007ooOol00goo000BOol00`00OS5n<@13OS400`00O]In
eP2DO]H00`00OS5n<@2_OS400`00Oomoo`03Ool0019oo`03001n<Gha04=n<@03001neWkF09AneP03
001n<Gha0:mn<@03001oogoo00=oo`004Woo00<007haOS40@gha00<007kFO]H0U7kF00<007haOS40
[gha00<007ooOol00goo000BOol00`00OS5n<@14OS400`00O]IneP2DO]H00`00OS5n<@2^OS400`00
Oomoo`03Ool0019oo`03001n<Gha04An<@03001neWkF09AneP03001n<Gha0:in<@03001oogoo00=o
o`004Woo00<007haOS40A7ha00<007kFO]H0U7kF00<007haOS40[Wha00<007ooOol00goo000BOol0
0`00OS5n<@14OS400`00O]IneP2DO]H00`00OS5n<@2^OS400`00Oomoo`03Ool0019oo`03001n<Gha
04An<@03001neWkF09AneP03001n<Gha0:in<@03001oogoo00=oo`004Woo00<007haOS40A7ha00<0
07kFO]H0UGkF00<007haOS40[Gha00<007ooOol00goo000BOol00`00OS5n<@15OS400`00O]IneP2D
O]H00`00OS5n<@2]OS400`00Oomoo`03Ool0019oo`03001n<Gha04En<@03001neWkF09AneP03001n
<Gha0:en<@03001oogoo00=oo`004Woo00<007haOS40AGha00<007kFO]H0U7kF00<007haOS40[Gha
00<007ooOol00goo000BOol00`00OS5n<@15OS400`00O]IneP2DO]H00`00OS5n<@2]OS400`00Oomo
o`03Ool0019oo`03001n<Gha04En<@03001neWkF09EneP03001n<Gha0:an<@03001oogoo00=oo`00
4Woo00<007haOS40AGha00<007kFO]H0UGkF00<007haOS40[7ha00<007ooOol00goo000BOol00`00
OS5n<@15OS400`00O]IneP2EO]H00`00OS5n<@2/OS400`00Oomoo`03Ool0019oo`03001n<Gha04In
<@03001neWkF09AneP03001n<Gha0:an<@03001oogoo00=oo`004Woo00<007haOS40AWha00<007kF
O]H0U7kF00<007haOS40[7ha00<007ooOol00goo000BOol00`00OS5n<@16OS400`00O]IneP2EO]H0
0`00OS5n<@2[OS400`00Oomoo`03Ool0019oo`03001n<Gha04In<@03001neWkF09EneP03001n<Gha
0:]n<@03001oogoo00=oo`004Woo00<007haOS40AWha00<007kFO]H0UGkF00<007haOS40Zgha00<0
07ooOol00goo000BOol00`00OS5n<@16OS400`00O]IneP2FO]H00`00OS5n<@2ZOS400`00Oomoo`03
Ool0019oo`03001n<Gha04In<@03001neWkF09IneP03001n<Gha0:Yn<@03001oogoo00=oo`004Woo
00<007haOS40Agha00<007kFO]H0UGkF00<007haOS40ZWha00<007ooOol00goo000BOol00`00OS5n
<@17OS400`00O]IneP2EO]H00`00OS5n<@2ZOS400`00Oomoo`03Ool0019oo`03001n<Gha04Mn<@03
001neWkF09EneP03001n<Gha0:Yn<@03001oogoo00=oo`004Woo00<007haOS40Agha00<007kFO]H0
UWkF00<007haOS40ZGha00<007ooOol00goo000BOol00`00OS5n<@17OS400`00O]IneP2FO]H00`00
OS5n<@2YOS400`00Oomoo`03Ool0019oo`03001n<Gha04Mn<@03001neWkF09IneP03001n<Gha0:Un
<@03001oogoo00=oo`004Woo00<007haOS40Agha00<007kFO]H0UWkF00<007haOS40ZGha00<007oo
Ool00goo000BOol00`00OS5n<@18OS400`00O]IneP2EO]H00`00OS5n<@2YOS400`00Oomoo`03Ool0
019oo`03001n<Gha04Qn<@03001neWkF09IneP03001n<Gha0:Qn<@03001oogoo00=oo`004Woo00<0
07haOS40B7ha00<007kFO]H0UWkF00<007haOS40Z7ha00<007ooOol00goo000BOol00`00OS5n<@18
OS400`00O]IneP2FO]H00`00OS5n<@2XOS400`00Oomoo`03Ool0019oo`03001n<Gha04Qn<@03001n
eWkF09IneP03001n<Gha0:Qn<@03001oogoo00=oo`004Woo00<007haOS40B7ha00<007kFO]H0UgkF
00<007haOS40Ygha00<007ooOol00goo000BOol00`00OS5n<@19OS400`00O]IneP2FO]H00`00OS5n
<@2WOS400`00Oomoo`03Ool0019oo`03001n<Gha04Un<@03001neWkF09IneP03001n<Gha0:Mn<@03
001oogoo00=oo`004Woo00<007haOS40BGha00<007kFO]H0UWkF00<007haOS40Ygha00<007ooOol0
0goo000BOol00`00OS5n<@19OS400`00O]IneP2FO]H00`00OS5n<@2WOS400`00Oomoo`03Ool0019o
o`03001n<Gha04Un<@03001neWkF09MneP03001n<Gha0:In<@03001oogoo00=oo`004Woo00<007ha
OS40BWha00<007kFO]H0UWkF00<007haOS40YWha00<007ooOol00goo000BOol00`00OS5n<@1:OS40
0`00O]IneP2FO]H00`00OS5n<@2VOS400`00Oomoo`03Ool0019oo`03001n<Gha04Yn<@03001neWkF
09IneP03001n<Gha0:In<@03001oogoo00=oo`004Woo00<007haOS40BWha00<007kFO]H0UWkF00<0
07haOS40YWha00<007ooOol00goo000BOol00`00OS5n<@1:OS400`00O]IneP2GO]H00`00OS5n<@2U
OS400`00Oomoo`03Ool0019oo`03001n<Gha04Yn<@03001neWkF09MneP03001n<Gha0:En<@03001o
ogoo00=oo`004Woo00<007haOS40BWha00<007kFO]H0UgkF00<007haOS40YGha00<007ooOol00goo
000BOol00`00OS5n<@1;OS400`00O]IneP2GO]H00`00OS5n<@2TOS400`00Oomoo`03Ool0019oo`03
001n<Gha04]n<@03001neWkF09MneP03001n<Gha0:An<@03001oogoo00=oo`000Woo0`0017oo0`00
1Woo00<007haOS40Bgha00<007kFO]H0UgkF00<007haOS40Y7ha00<007ooOol00goo0003Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00OS5n<@1;OS400`00O]IneP2GO]H00`00OS5n<@2TOS400`00
Oomoo`03Ool000=oo`04001oogooOol50006Ool00`00OS5n<@1;OS400`00O]IneP2GO]H00`00OS5n
<@2TOS400`00Oomoo`03Ool000=oo`05001oogooOol00002Ool00`00Oomoo`05Oooo002A0005Ool0
00=oo`03001oogoo009oo`03001oo`000?mooieoo`000Woo0P001Goo0P00ogooWGoo0003Ool00`00
Oomoo`04Ool00`00Oomoo`3oOonKOol00?moojQoo`00ogooZ7oo0000\
\>"],
  ImageRangeCache->{{{0, 422}, {422, 0}} -> {-0.0450054, 1.50494, 0.00250003, \
0.0300003}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{650, 761},
WindowMargins->{{97, Automatic}, {19, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Gd000400@00000000000000040801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 143, 5, 67, "Section"],

Cell[CellGroupData[{
Cell[1895, 61, 73, 1, 63, "Subsection"],
Cell[1971, 64, 423, 11, 68, "Input"],
Cell[2397, 77, 95, 1, 46, "Text"],
Cell[2495, 80, 693, 19, 77, "Input"],
Cell[3191, 101, 67, 1, 46, "Text"],
Cell[3261, 104, 987, 28, 168, "Input"],
Cell[4251, 134, 66, 1, 46, "Text"],
Cell[4320, 137, 843, 17, 142, "Input"],
Cell[5166, 156, 58, 1, 46, "Text"],
Cell[5227, 159, 673, 14, 142, "Input"],
Cell[5903, 175, 97, 1, 46, "Text"],
Cell[6003, 178, 375, 11, 64, "Input"],
Cell[6381, 191, 97, 1, 46, "Text"],
Cell[6481, 194, 284, 9, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6802, 208, 73, 1, 47, "Subsection"],
Cell[6878, 211, 85, 1, 46, "Text"],
Cell[6966, 214, 131, 4, 38, "Input"],
Cell[7100, 220, 92, 4, 38, "Input"],
Cell[7195, 226, 69, 1, 25, "Input"],
Cell[7267, 229, 91, 1, 46, "Text"],
Cell[7361, 232, 485, 12, 129, "Input"],
Cell[7849, 246, 132, 4, 62, "Text"],
Cell[7984, 252, 425, 11, 103, "Input"],
Cell[8412, 265, 160, 4, 62, "Text"],
Cell[8575, 271, 3567, 75, 766, "Input"],
Cell[12145, 348, 93, 1, 46, "Text"],
Cell[12241, 351, 375, 11, 64, "Input"],
Cell[12619, 364, 97, 1, 46, "Text"],
Cell[12719, 367, 284, 9, 38, "Input"],
Cell[13006, 378, 122, 4, 46, "Text"],
Cell[13131, 384, 2992, 61, 688, "Input"],
Cell[16126, 447, 82, 1, 46, "Text"],
Cell[16211, 450, 7189, 151, 1507, "Input"],
Cell[23403, 603, 122, 4, 46, "Text"],
Cell[23528, 609, 1635, 35, 350, "Input"],
Cell[25166, 646, 8165, 172, 1598, "Input"],
Cell[33334, 820, 77, 1, 46, "Text"],
Cell[33414, 823, 503, 13, 77, "Input"],
Cell[33920, 838, 73, 1, 46, "Text"],
Cell[33996, 841, 487, 13, 77, "Input"],
Cell[34486, 856, 99, 1, 46, "Text"],
Cell[34588, 859, 3498, 71, 636, "Input"],
Cell[38089, 932, 86, 1, 46, "Text"],
Cell[38178, 935, 884, 28, 67, "Input"],
Cell[39065, 965, 61, 1, 46, "Text"],
Cell[39129, 968, 2448, 50, 480, "Input"],
Cell[41580, 1020, 62, 1, 46, "Text"],
Cell[41645, 1023, 8247, 136, 1884, "Input"],
Cell[49895, 1161, 62, 1, 46, "Text"],
Cell[49960, 1164, 731, 15, 155, "Input"]
}, Closed]],
Cell[50706, 1182, 102, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[50833, 1187, 67, 1, 63, "Subsection"],
Cell[50903, 1190, 118, 4, 38, "Input"],
Cell[51024, 1196, 68, 1, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51129, 1202, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[51221, 1207, 65, 1, 61, "Subsubsection"],
Cell[51289, 1210, 494, 13, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51820, 1228, 70, 1, 47, "Subsubsection"],
Cell[51893, 1231, 391, 9, 90, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52321, 1245, 64, 1, 47, "Subsubsection"],
Cell[52388, 1248, 201, 5, 78, "Text"],
Cell[52592, 1255, 18441, 348, 3600, "Input"],
Cell[71036, 1605, 4297, 89, 883, "Input"],
Cell[75336, 1696, 134, 4, 70, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[75507, 1705, 74, 1, 47, "Subsubsection"],
Cell[75584, 1708, 59, 1, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[75692, 1715, 64, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[75781, 1720, 130, 5, 51, "Input"],
Cell[75914, 1727, 75233, 3254, 431, 35583, 2760, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

