(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    197627,       4376]*)
(*NotebookOutlinePosition[    198707,       4410]*)
(*  CellTagsIndexPosition[    198663,       4406]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["AFM T-x (range of P)",
  FontColor->RGBColor[1, 0, 0]]], "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Off[General::spell]; Off[General::spell1]; Off[Set::shape];\n\
Off[Interpolation::inhr]; Off[InterpolatingFunction::dmwarn",
    FontWeight->"Plain"],
  StyleBox["]",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0.499992]],
  StyleBox["\nSetOptions[Position, Heads -> False];\n<<Graphics`Animation`",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["making combinations (used in one phase field)", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};  \n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                            \
                       gray[n-1,m-1]]}],m];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number formatting", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[format]; \n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ, n_Integer, _?TrueQ, w_Integer]:=\n     \
Block[{m=N[10^n], y},\n           y = ToString[Round[m x]/m]; ly = \
StringLength[y];\n           If[ly < w, StringJoin[Apply[StringJoin,Table[\" \
\",{w-ly}]],y],y]]\n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,_?TrueQ]:=Block[{m=N[10^n]},Round[m x]/m];\n\
",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,___]:=N[x,n];\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_,___]:=x;\n\nSetAttributes[format,{Listable}];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["interval halving", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[ih];\n",
    FontWeight->"Plain"],
  StyleBox["ih",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[f__Function, params:{_?NumberQ...}, lim1_Function, \
lim2_Function] := \n   Block[{v1,v2,s1,s2,v,sv},\n          \
v1=N[Apply[lim1,params]]; s1=N[Apply[f,Join[{v1},params]]];            \n     \
     v2=N[Apply[lim2,params]]; s2=N[Apply[f,Join[{v2},params]]];  \n          \
If[ Sign[s1]==Sign[s2],Print[\"same sign - meaningless answer?\"]];           \
   \n          FixedPoint[( v = (v1+v2)/2; sv = N[Apply[f,Join[{v},params]]];\
\n                       If[Sign[s1]==Sign[sv], v1=v; s1=sv, v2=v; s2=sv];\n  \
                     (v1+v2)/2  )&,0.5,15]];\nih[___] = \"something is wrong \
with the input\";",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["linecuts", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[linecuts];\n\n",
    FontWeight->"Plain"],
  StyleBox["linecuts",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{slope_,intercept_},{{xlow_,xhigh_},{ylow_,yhigh_}}]:=\n  \
(y1=intercept+slope xlow; y2=intercept+slope xhigh;\n      {If[slope>0,\n     \
   If[y1<ylow, {(ylow-intercept)/slope,ylow},  {xlow,y1}],\n        \
If[y1>yhigh,{(yhigh-intercept)/slope,yhigh},{xlow,y1}]],\n       If[slope>0,\n\
        If[y2>yhigh,{(yhigh-intercept)/slope,yhigh},{xhigh,y2}],\n        \
If[y2<ylow, {(ylow-intercept)/slope,ylow},  {xhigh,y2}] ]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["general T-x/P-x functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default values, normally overridden", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 400; top = 800;
delv = 5; addx = addy = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
varyTatP = True;
debugit = False;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["labelling[p_]:={};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["differentiating an interpolation function", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[dif];\n",
    FontWeight->"Plain"],
  StyleBox["dif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifr_,v_] := \n    ({r1,r2} = ifr;\n     Which[v > \
r2-difdelv,\n             (if[r2]-if[r2-difdelv])/difdelv,\n           v < \
r1,\n             (if[r1+difdelv]-if[r1])/difdelv,\n           True,\n        \
     (if[v+difdelv]-if[v])/difdelv]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
substitute into interpolation function in value (T or P) range v1 \
<-> v2\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[subsif];\n",
    FontWeight->"Plain"],
  StyleBox["subsif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,v1_,v2_] :=\n    (dv = Abs[v2-v1];\n     If[dv <= 2 delv,\n  \
      {{if[v1],v1},{if[v2],v2}},\n        kd = Floor[dv/delv]; \n        \
Map[{if[#],#}&, v1 + dv/kd Range[0,kd]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
make a boundary of the a divariant using the interpolation fn, if;  \
(note that vs < ve  OR  vs > ve)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makeboundary];\n",
    FontWeight->"Plain"],
  StyleBox["makeboundary",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifrange_,vs_,ve_] :=\n    (\n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb is maximum substitution range, with vb > va ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     If[ve > vs, {va,vb} = {vs,ve}, {va,vb} = {ve,vs}];\
\n   \n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb adjusted to be consistent with interpolation function ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     {vr1,vr2} = ifrange;\n     If[va<vr1, va=vr1];  \
If[vb>vr2, vb=vr2];\n     \n",
    FontWeight->"Plain"],
  StyleBox["     If[debugit, Print[\"    \",if]; Print[\"  \",ifrange,\"  \", \
{vs,ve},\"  \",{va,vb}]];\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n     (* ",
    FontWeight->"Plain"],
  StyleBox["xa <-> xb corresponds to va <-> vb ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)     \n     \n     z = Which[(va > top  || vb < bottom) || \
(va>=vb),\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["boundary doesn't appear within diagram ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 {{}},\n                 \n     \
          {xa,xb} = {if[va],if[vb]};  xb > xa,\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["positive slope in v-x ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 Which[xa >= left && xb <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xa > right && xb  >right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[{{left,va}},subsif[if,vsol,vb]],\n                       True,   (* \
ie xb > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[subsif[if,va,vsol],{{right,vb}}] ],\n               True,\n              \
      \n               (* ",
    FontWeight->"Plain"],
  StyleBox["negative slope in v-x",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *) \n             \n                 Which[xb >= left && xa <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xb > right && xb > right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[subsif[if,va,vsol], {{left,vb}}],\n                       True,   (* \
ie xa > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[{{right,va}}, subsif[if,vsol,vb]] ]  ];   \n                             \
  \n     (* ",
    FontWeight->"Plain"],
  StyleBox["reverse info if ve < vs ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n  \n     If[ve > vs, z, Reverse[z]]  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["no of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[diwhich];\n",
    FontWeight->"Plain"],
  StyleBox["diwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points which see s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = nposi[Map[incommon[s,#]&,plines],3];\n    \
muni = nposi[Map[incommon[s,#]&,puni]-Map[Length,puni],-1];\n    mpoints = \
nposi[Map[incommon[s,#]&,ppoints],3];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["which univariants, if any, are in range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       ipuni = \
Flatten[Position[uni[[muni]],\n                          \
_?((#[[vuposi]]>bottom && #[[vuposi]]<top)&),{1}]];\n       muni = \
muni[[ipuni]] ];\n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["duni = degenerate univariants; cduni are the others",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       duni = \
muni[[nposi[Map[Length,puni[[muni]]],2]]];  \n       cduni = \
Complement[muni,duni],\n       duni = {}; cduni = {}];\n           \n    (* ",
    
    FontWeight->"Plain"],
  StyleBox["removing degenerate univariant(s) not relevant to this divariant \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[Length[cduni]>0 && Length[duni] > 0,  \n       \
idel = Map[({v,{react,prod}} = uni[[#,{vuposi,5}]];  \n       ph = \
Flatten[{react,prod}];\n       If[incommon[prod,s] == Length[prod],\n         \
     Position[uni[[duni]],\n                  _?((#[[vuposi]] < v && \
incommon[ph,#[[5,2]]] == 1)&),{1}],\n              Position[uni[[duni]],\n    \
              _?((#[[vuposi]] > v && incommon[ph,#[[5,1]]] == \
1)&),{1}]])&,cduni];\n       muni = \
Complement[muni,duni[[Union[Flatten[idel]]]]]];\n       \n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
{\",plines[[#,{1,2}]],\", \",plines[[#,3]],\"}\"]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no univariants\"],\n             \
Print[\"  univariants\"];\n             Map[Print[\"    \", #,\": \
\",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["does a T-x / P-x divariant field", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doadi];\n",
    FontWeight->"Plain"],
  StyleBox["doadi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points relevant to s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = diwhich[s,False];\n        \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["using any univariants to get the value (ie T or P) range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n\n    Switch[Length[muni],\n       2, {va,vb} = \
uni[[muni,vuposi]]; \n          If[vb>va, {v1,v2} = {va,vb}, {v2,v1} = \
{va,vb}],\n       1, {vuni,{react,prod}} = uni[[muni[[1]],{vuposi,5}]];\n     \
     If[incommon[react,s]==Length[react],\n             v1 = bottom; v2 = \
vuni,\n             v1 = vuni; v2 = top],\n       _, v1 = bottom; v2 = top];\n\
            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iff[[mlines]]; ifrange = iffrange[[mlines]];\n\
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = plines[[mlines,{1,2}]];\n    pp = Map[(ppk = \
#; \n              pos = Position[pm, _?((#==ppk)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,1]]];\n    cpp = \
Complement[Range[Length[mlines]],Flatten[pp]];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["lc = no of lines; lpp = no of points; pcpp = no not connected to \
points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; luni = Length[muni];\n  \n   ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp,\"  \",luni]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n    \n    p = Which[lc == 1,\n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a divariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2], \n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && luni == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries, one point, and one univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            vuni = uni[[muni]][[1,vuposi]];\n                {p1,p2} = \
pp[[1]];                \n                If[vuni>vp, vw = v2, vw = v1];      \
          \n                Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp],\n\
                     makeboundary[if[[p2]],ifrange[[p2]],vp,vw]],\n           \
   \n              lc == 2, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point - ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["logic not complete",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[{d1,d2},\"  \",{vp,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    (* ",
    FontWeight->"Plain"],
  StyleBox["from here down, three boundaries (ie max for 3 phase divariants) \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n              lpp == 1,\n              \n              (* ",
    
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                      \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[ifrange[[{pp1,pp2}]],\"  \",{d1,d2},\"  \
\",{vp,vc,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lpp == 2 \
&& luni == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points: boundaries connected through points, and to a \
univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                vuni = \
uni[[muni]][[1,vuposi]];\n                {pp1,pp2}=pp;\n                p2 = \
Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
If[vuni>vp1, vw = v2, vw = v1];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,vw]],\n              \n              \
(* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** \
geometry for \",s,\" not implemented yet **\"]; {{}} ];\n    Join[p,{p[[1]]}] \
 );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadriwhich];\n",
    FontWeight->"Plain"],
  StyleBox["quadriwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, points, and degenerate univariants which see \
s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = \
Flatten[Position[Map[#[[1]]&,pqlines],_?((#==s)&)]];\n    mpoints = \
Flatten[Position[Map[#[[1]]&,ppoints],_?((#==s)&)]];        \n    muni = \
Flatten[Position[puni,_?((Length[#]==2 && incommon[#,s]==1)&),{1}]];\n       \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
\",{pqlines[[#,1]]},\", \",pqlines[[#,2]]]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no degenerate univariants\"],\n   \
          Print[\"  degenerate univariants\"];\n             Map[Print[\"    \
\", #,\": \",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doaquadri];\n",
    FontWeight->"Plain"],
  StyleBox["doaquadri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_]:=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["qline, points and degenerate univariants for this quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = quadriwhich[s,False];",
    FontWeight->"Plain"],
  StyleBox["\n    ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n    v1 = bottom; v2 = top;           \n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iffq[[mlines]];  ifrange = \
iffqrange[[mlines]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = pqlines[[mlines,2]];\n    pp = Map[(ppk = #; \n\
              pos = Position[pm, _?((incommon[#,ppk]==1)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,{2,3}]]];\n    \
cpp = Complement[Range[Length[mlines]],Flatten[pp]];\n  \n    ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; lu = Length[muni];\n\n    p = Which[lc == 1,\n    \n             \
 (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a quadrivariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0 && lu == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["- assumes lines have same slope",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && lpp == 0 && lu == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points, but one degenerate univariant *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n    \n                vuni = uni[[muni,vuposi]][[1]];\n         \
       If[{s} == puni[[muni]][[1]], vw = v1, vw = v2];\n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw,vuni],\n                     \
makeboundary[if[[2]],ifrange[[2]],vuni,vw]],\n              \n              \
lc == 2 && lpp == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n                vp = points[[mpoints]][[1,vposi]];\n        \
        d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n                ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[{d1,d2},\" \",{vp,vw1,vw2}]]",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[";       \n                      \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    lc == 3 && lpp == 1 && lu == 0,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lc == 3 \
&& lpp == 1 && lu == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, one degenerate univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vuni = uni[[muni,vuposi]][[1]];\n       \
         vp = points[[mpoints]][[1,vposi]];\n                {pp1,pp2} = \
pp[[1]]; cpp1 = cpp[[1]];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],v1,vp],  (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to ky",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vuni],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vuni,v1]],\n  \n              lc == 3 \
&& lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2}=pp;\n              \
  p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],v1,vp1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v1]],\n  \n              lc == 4 && \
lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries, plus one separate boundary ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2} = pp;\n            \
    p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                p4 = \
Complement[Range[4],{p1,p2,p3}][[1]];\n                \
Join[makeboundary[if[[p4]],ifrange[[p4]],v2,v1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p1]],ifrange[[p1]],v1,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v2]],\n  \n              (* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** not \
implemented yet **\"]; {{}} ];\n    If[p[[1]]=={}, \n       \
Join[Drop[p,1],{p[[2]]}], \n       Join[p,{p[[1]]}]]",
    FontWeight->"Plain"],
  StyleBox["   ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[");",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the quadrivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadrvariant];\n",
    FontWeight->"Plain"],
  StyleBox["quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = \
Map[doaquadri,Intersection[Map[#[[1]]&,pqlines]]];\n      ipoly = \
Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > 0)&)]];\n      \
{Hue[1,0.45,1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]\
});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[divariant];\n",
    FontWeight->"Plain"],
  StyleBox["divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = Map[doadi,Intersection[Map[Sort,plines]]];\n    \
  ipoly = Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > \
0)&)]];\n      \
{GrayLevel[1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]}\
);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["makes horizontal lines for degenerate univariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makehor];\n",
    FontWeight->"Plain"],
  StyleBox["makehor",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pluni is position of degenerate reactions in uni ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pluni = nposi[Map[Length[Flatten[#[[5]]]]&,uni],2];\
\n    If[Length[pluni]==0, Line[{{0,top+1},{1,top+1}}], (* ",
    FontWeight->"Plain"],
  StyleBox["dummy line",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n       Map[(            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ph is phases involved in A=B; vuni is T/P  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            ph = Flatten[uni[[#,5]]]; vuni = \
uni[[#,vuposi]];\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["dl2 is positions in lines which involve A or B disappearing  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            dl = plines; (* \
Map[#[[1]][[{6,7}]]&,lines]; *)\n            dl2 = \
Flatten[Position[dl,_?((#[[-1]]==ph[[1]] || #[[-1]]==ph[[2]])&),{1}]];\n      \
      \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ii locates which of the dl2 involve A and B disappearing at A=B ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            gg = gray[Length[dl2],2];\n         \
   dl1 = Map[Drop[#,-1]&,dl[[dl2]]];\n            ii = \
Flatten[Position[Map[incommon[dl1[[#[[1]]]],dl1[[#[[2]]]]]&,gg],\n            \
                       _?((#==2)&)]];\n                                   \n  \
          If[debugit, ",
    FontWeight->"Plain"],
  StyleBox["Print[ph,\"  \",dl2,\"  \",Map[gg[[#]]&,ii]]]; ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["draws horizontal line, length depends on length of ii ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            Switch[Length[ii],\n                \
   0, Line[{{left,vuni},{right,vuni}}],\n                   1, ig = \
dl2[[gg[[ii[[1]],1]]]];\n                      {r1,r2} = \
Apply[List,iff[[ig]]][[1]];\n                      If[vuni<=r1 || vuni>=r2,\n \
                        Line[{{left,vuni},{right,vuni}}],\n                   \
      Line[{{iff[[ig]][vuni],vuni},{right,vuni}}]],\n                   2, \
ig1 = dl2[[gg[[ii[[1]],1]]]];               \n                      {r11,r12} \
= Apply[List,iff[[ig1]]][[1]];\n                      ig2 = \
dl2[[gg[[ii[[2]],1]]]];\n                      {r21,r22} = \
Apply[List,iff[[ig2]]][[1]];\n                      Which[(vuni<=r11 || \
vuni>=r12) && (vuni<=r21 || vuni>=r22),\n                              \
Line[{{left,vuni},{right,vuni}}],\n                            vuni<=r11 || \
vuni>=r12,\n                              \
Line[{{iff[[ig2]][vuni],vuni},{right,vuni}}],\n                            \
vuni<=r21 || vuni>=r22,\n                              \
Line[{{iff[[ig1]][vuni],vuni},{right,vuni}}],\n                            \
True,\n                              Line[{{iff[[ig1]][vuni],vuni},\n         \
                           {iff[[ig2]][vuni],vuni}}]] ] )&,pluni] ] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["generate the outlines of the diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background]; Clear[outline]; Clear[box];\n",
    FontWeight->"Plain"],
  StyleBox["box",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {{left, bottom},{left, top},{right, top},{right, \
bottom},{left, bottom}};\n",
    FontWeight->"Plain"],
  StyleBox["background",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[1,0.3,1], Polygon[box]};\n",
    FontWeight->"Plain"],
  StyleBox["outline",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0], Line",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[box]};",
    FontWeight->"Plain"],
  StyleBox["                                    ",
    FontSize->11,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setting up ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setupvx];\n",
    FontWeight->"Plain"],
  StyleBox["setupvx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (If[TrueQ[varyTatP], \n       vposi = 5; oposi = 4; \
vuposi = 4; ouposi = 3; delv =   5; difdelv =   0.01, \n       vposi = 4; \
oposi = 5; vuposi = 3; ouposi = 4; delv = 0.2; difdelv = 0.0001];\n        \n \
   (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for lines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    rolines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,alllines];\n    alliff = Array[(ak = \
alllines[[#]]; ro = rolines[[#]];\n                    Map[(rok = #;\n        \
                 ii = Flatten[Position[Map[#[[oposi]]&,ak],\n                 \
                              _?((#==rok)&),{1}]];\n                         \
Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                        \
)&,ro])&,Length[alllines]];\n    alliffrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliff];\n                        \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for qlines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    roqlines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,allqlines];\n    alliffq = Array[(ak = \
allqlines[[#]]; ro = roqlines[[#]];\n                     Map[(rok = #;\n     \
                     ii = Flatten[Position[Map[#[[oposi]]&,ak],\n             \
                                   _?((#==rok)&),{1}]];\n                     \
     Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                         \
)&,ro])&,Length[allqlines]]; \n    alliffqrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliffq];\n                            \n    \
(* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffuni = \
Map[Interpolation[Map[#[[{ouposi,vuposi}]]&,#]]&,alluni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffpoints = \
Map[Interpolation[Map[#[[{oposi,vposi}]]&,#]]&,allpoints];\n    iffpointsx = \
Map[Interpolation[Map[#[[{oposi,3}]]&,#]]&,allpoints];  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemblevx];\n",
    FontWeight->"Plain"],
  StyleBox["assemblevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := \n   (    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming uni (ie univariants) at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    iuni = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffuni],\n                           \
 _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    uni = Map[(if = iffuni[[#]];\n   \
            If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = ok; pp = if[tt]];\n  \
             {0,2,pp,tt,alluni[[#]][[1,5]]})&,iuni];       \n    puni =  \
Map[Flatten[#[[5]]]&,uni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants excluded by out of range univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    dels1 = Map[(sp = #[[5]];\n                 \
If[#[[vuposi]]>top,\n                    If[Length[sp[[1]]]==1, {sp[[2]]},\n  \
                     {Flatten[{sp[[1,1]],sp[[2]]}],Flatten[{sp[[1,2]],sp[[2]]}\
]}],\n                    {{\"junk\"}}])&,uni];\n    dels2 = Map[(sp = \
#[[5]];\n                 If[#[[vuposi]]<bottom,\n                    \
If[Length[sp[[2]]]==1, {sp[[1]]},\n                       \
{Flatten[{sp[[1]],sp[[2,1]]}],Flatten[{sp[[1]],sp[[2,1]]}]}],\n               \
     {{\"junk\"}}])&,uni];\n    dels = Flatten[Union[dels1,dels2],1];\n       \
                         \n    cjuni =  Map[(dsk = #; ll = Length[dsk];\n     \
             Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,puni],\n   \
                                _?((#==0)&)]])&, dels];\n    juni = \
Complement[Range[Length[puni]],Intersection[Flatten[cjuni]]];\n               \
                  \n    uni = uni[[juni]];\n    puni =  puni[[juni]];         \
                   \n                                    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants that are excluded by degenerate univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    (* ",
    FontWeight->"Plain"],
  StyleBox["ie does Schreinemakers in this special case",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    dlu = \
Flatten[Position[Map[Length,puni],_?((#==2)&)]];\n    cdlu = \
Complement[Range[Length[puni]],dlu];\n    idel1 = Map[(v = uni[[#,vuposi]]; p \
= puni[[#]];\n                Position[uni[[cdlu]],\n                     \
_?((ll1 = incommon[{p[[1]]},Flatten[#[[5]]]];\n                         \
#[[vuposi]] > v && ll1 == 1)&),{1}])&,dlu];\n    idel2 = Map[(v = \
uni[[#,vuposi]]; p = puni[[#]];\n                Position[uni[[cdlu]],\n      \
               _?((ll2 = incommon[{p[[2]]},Flatten[#[[5]]]];\n                \
         #[[vuposi]] < v && ll2 == 1)&),{1}])&,dlu];\n    idel1 = \
Union[Flatten[idel1]]; idel2 = Union[Flatten[idel2]];\n    \n    udel1 = \
Map[{#[[{1,3,4}]],#[[{2,3,4}]]}&,puni[[idel1]]];\n    udel2 = \
Map[{#[[{1,2,3}]],#[[{1,2,4}]]}&,puni[[idel2]]];\n    udel = \
Partition[Flatten[{udel1,udel2}],3];\n    \n    iuni = \
Complement[Range[Length[puni]],Union[Flatten[{idel1,idel2}]]];\n    uni = \
uni[[iuni]];\n    puni =  puni[[iuni]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming points at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    ip = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffpoints],\n                        \
    _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    points = Map[(if = \
iffpoints[[#]];\n               If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = \
ok; pp = if[tt]];\n               \
{1,2,iffpointsx[[#]][ok],pp,tt,allpoints[[#]][[1,6]],\n                \
allpoints[[#]][[1,7]],allpoints[[#]][[1,8]]})&,ip];       \n    \n    ppoints \
= Map[Flatten[#[[{6,7,8}]]]&,points];\n    \n    cipoints =  Map[(dsk = #; ll \
= Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,ppoints],\n             \
                         _?((#==0)&)]])&, dels];\n    ipoints = \
Complement[Range[Length[ppoints]],Intersection[Flatten[cipoints]]];\n    \
points = points[[ipoints]];\n    ppoints = ppoints[[ipoints]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming lines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    plines = Map[Flatten[#[[1,{6,7}]]]&,alllines];\n    \
ilines1 = Flatten[Position[Map[#[[{1,-1}]]&,rolines],\n                       \
       _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    cilines2 = \
Flatten[Map[(udelk = #;\n                            Flatten[Position[plines,\
\n                                             _?((Length[Intersection[#,\
udelk]]==3)&),\n                                             {1}]])&,udel]];\n\
    ilines2 = Complement[Range[Length[rolines]],cilines2];\n    cilines3 =  \
Map[(dsk = #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,plines],\n              \
                        _?((#==0)&)]])&, dels];\n    ilines3 = \
Complement[Range[Length[plines]],Intersection[Flatten[cilines3]]];\n    \
ilines = Intersection[ilines1,ilines2,ilines3];                          \n   \
                           \n    iff = Map[(ii = #; rok = rolines[[ii]];\n    \
           kkm = Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n           \
    If[Length[kkm] == 1,\n                  alliff[[ii,kkm[[1]]]],\n          \
        kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  \
k1 = kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {f1,f2} = alliff[[ii,{k1,k2}]]; \n                  \
{fr1,fr2} = alliffrange[[ii,{k1,k2}]];\n                  diff1 = \
(fr1[[2]]-fr1[[1]]-2del)/ni;\n                  v1 = Map[{#,f1[#]}&, \
Range[fr1[[1]]+del,fr1[[2]]-del,diff1]];\n                  diff2 = \
(fr2[[2]]-fr2[[1]]-2del)/ni;\n                  v2 = Map[{#,f2[#]}&, \
Range[fr2[[1]]+del,fr2[[2]]-del,diff2]];\n                  \
Interpolation[v1(1-prop) + v2 prop]]\n              )&, ilines];            \n\
              \n    iffrange = Map[Apply[List,#][[1]]&, iff];    \n           \
        \n    plines = plines[[ilines]];\n                 \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming qlines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pqlines = Map[Flatten[#[[1,{6,7}]]]&,allqlines];\n  \
  iqlines1 = Flatten[Position[Map[#[[{1,-1}]]&,roqlines],\n                   \
           _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    ciqlines2 =  Map[(dsk \
= #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,pqlines],\n             \
                         _?((#==0)&)]])&, dels];\n    iqlines2 = \
Complement[Range[Length[pqlines]],Intersection[Flatten[ciqlines2]]];\n    \
iqlines = Intersection[iqlines1,iqlines2];\n              \n    iffq = \
Map[(ii = #; rok = roqlines[[ii]];\n               kkm = \
Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n               \
If[Length[kkm] == 1,\n                  alliffq[[ii,kkm[[1]]]],\n             \
     kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  k1 \
= kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {fq1,fq2} = alliffq[[ii,{k1,k2}]]; \n                  \
{fqr1,fqr2} = alliffqrange[[ii,{k1,k2}]];\n                  diffq1 = \
(fqr1[[2]]-fqr1[[1]]-2del)/ni;\n                  vq1 = Map[{#,fq1[#]}&, \
Range[fqr1[[1]]+del,fqr1[[2]]-del,diffq1]];\n                  diffq2 = \
(fqr2[[2]]-fqr2[[1]]-2del)/ni;\n                  vq2 = Map[{#,fq2[#]}&, \
Range[fqr2[[1]]+del,fqr2[[2]]-del,diffq2]];\n                  \
Interpolation[vq1(1-prop) + vq2 prop]]\n               )&, iqlines];          \
  \n              \n    iffqrange = Map[Apply[List,#][[1]]&, iffq];          \
\n           \n    pqlines = pqlines[[iqlines]]   );\n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makevx];\n",
    FontWeight->"Plain"],
  StyleBox["makevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := (assemblevx[ok];\n                \
Show[Graphics[{background,\n                               quadrivariant,\n   \
                            divariant,\n                               \
makehor,\n                               outline,\n                           \
    labelling[ok]}],\n                     AspectRatio -> 1, Frame -> True,\n \
                    PlotRange -> {{left, right}, {bottom, top}},\n            \
         PlotRegion-> {{addx,1-addx},{addy,1-addy}}])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell["bulk composition line below garnet - chlorite in AFM", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["definitions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["labelling", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["fontsize = 14;  pl = 2;\n\nClear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] :=\n     ({Text[FontForm[ StringJoin[\"P = \
\",ToString[N[Round[10^pl ok]/10^pl]]],\n                     \
{\"Helvetica\",fontsize}], {0.81,632}, {-1,0}],\n       \
Text[FontForm[\"AFM\",{\"Times-Bold\",22}], {0.852,642}]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["diagram's (max) coordinates", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["left = 0; right = 1; bottom = 500; top = 650;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["adding", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["addx = 0.05; addy = 0.05;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["T increment in graphics", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["delv = 2;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["it is a T-x diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["points", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
allpoints = {
{{0,  2,     0, 4.85, 522.5, {\"chl\"},\"g\", \"bi\"},   
{0,  2, 0.0265, 5.00, 525.6, {\"chl\"},\"g\", \"bi\"}, 
{0,  2, 0.0500, 5.14, 528.5, {\"chl\"},\"g\", \"bi\"},     
{0,  2, 0.1000, 5.46, 534.8, {\"chl\"},\"g\", \"bi\"},    
{0,  2, 0.1500, 5.80, 541.4, {\"chl\"},\"g\", \"bi\"},     
{0,  2, 0.1785, 6.00, 545.3, {\"chl\"},\"g\", \"bi\"}, 
{0,  2, 0.2000, 6.16, 548.3, {\"chl\"},\"g\", \"bi\"},  
{0,  2, 0.2500, 6.56, 555.6, {\"chl\"},\"g\", \"bi\"},    
{0,  2, 0.3000, 6.98, 563.4, {\"chl\"},\"g\", \"bi\"},
{0,  2, 0.3015, 7.00, 563.6, {\"chl\"},\"g\", \"bi\"},     
{0,  2, 0.3500, 7.45, 571.5, {\"chl\"},\"g\", \"bi\"},     
{0,  2, 0.4000, 7.95, 580.2, {\"chl\"},\"g\", \"bi\"},
{0,  2, 0.4040, 8.00, 580.9, {\"chl\"},\"g\", \"bi\"},      
{0,  2, 0.4500, 8.50, 589.4, {\"chl\"},\"g\", \"bi\"},
{0,  2, 0.4915, 9.00, 597.4, {\"chl\"},\"g\", \"bi\"},   
{0,  2, 0.5000, 9.11, 599.1, {\"chl\"},\"g\", \"bi\"},   
{0,  2, 0.5500, 9.76, 609.5, {\"chl\"},\"g\", \"bi\"}, 
{0,  2, 0.5665, 10.00, 613.1, {\"chl\"},\"g\", \"bi\"},  
{0,  2, 0.6000, 10.49, 620.6, {\"chl\"},\"g\", \"bi\"},
{0,  2, 0.6325, 11.00, 628.2, {\"chl\"},\"g\", \"bi\"},    
{0,  2, 0.6500, 11.28, 632.4, {\"chl\"},\"g\", \"bi\"}, 
{0,  2, 0.6910, 12.00, 642.8, {\"chl\"},\"g\", \"bi\"},      
{0,  2, 0.7000, 12.16, 645.1, {\"chl\"},\"g\", \"bi\"}},

{{0,  2,     0, 7.51, 529.7, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0142, 8.00, 537.7, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0200, 8.19, 540.7, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0400, 8.83, 550.6, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0456, 9.00, 553.2, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0600, 9.42, 559.6, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0800, 9.99, 567.8, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.0804, 10.00, 568.0, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.1000, 10.52, 575.4, {\"g\"},\"chl\", \"bi\"},
{0,  2, 0.1186, 11.00, 582.0, {\"g\"},\"chl\", \"bi\"},  
{0,  2, 0.1200, 11.03, 582.5, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.1400, 11.52, 589.1, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.1600, 11.99, 595.3, {\"g\"},\"chl\", \"bi\"},
{0,  2, 0.1604, 12.00, 595.5, {\"g\"},\"chl\", \"bi\"},  
{0,  2, 0.1800, 12.44, 601.2, {\"g\"},\"chl\", \"bi\"}, 
{0,  2, 0.2000, 12.87, 606.8, {\"g\"},\"chl\", \"bi\"}} };\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["univariants", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  " ",
  StyleBox["manually reactions.",
    FontSize->12,
    FontColor->RGBColor[0, 1, 0]]
}], "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
alluni ={
{{1,  1, 5.00, 557.1,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}},
{1,  1, 6.00, 572.4,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}},
{1,  1, 7.00, 586.5,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}},
{1,  1, 8.00, 599.6,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}},
{1,  1, 9.00, 611.7,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}},
{1,  1, 9.98, 622.9,  {{\"g\", \"chl\"},{\"st\", \"bi\"}}}},
     
{{1,  1, 5.00, 573.3,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 5.25, 576.3,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 5.50, 579.2,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 5.75, 582.0,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 6.00, 584.8,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 6.25, 587.5,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 6.50, 590.2,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 6.75, 592.8,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 7.00, 595.4,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 7.25, 597.9,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 7.50, 600.4,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 7.75, 602.8,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 8.00, 605.2,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 8.25, 607.6,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 8.50, 609.9,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 8.75, 612.1,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 9.00, 614.4,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 9.25, 616.6,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 9.50, 618.8,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 9.75, 620.9,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 9.98, 622.9,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}}},
 
{{1,  1, 5.00, 624.2,  {{\"st\", \"bi\"}, {\"g\", \"sill\"}}},
{1,  1, 6.00, 645.1,  {{\"st\", \"bi\"}, {\"g\", \"sill\"}}},
{1,  1, 7.00, 665.5,  {{\"st\", \"bi\"}, {\"g\", \"sill\"}}},
{1,  1, 8.00, 685.8,  {{\"st\", \"bi\"}, {\"g\", \"sill\"}}}},

{{1,  1, 5.00, 676.2,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}},
{1,  1, 6.00, 670.0,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}},
{1,  1, 7.00, 661.1,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}},
{1,  1, 8.00, 650.1,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}},
{1,  1, 9.00, 637.2,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}},
{1,  1, 9.98, 622.9,  {{\"st\", \"bi\"}, {\"g\", \"ky\"}}}},

{{1,  1, 9.98, 622.9,   {{\"g\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 11.00, 631.3,  {{\"g\", \"chl\"}, {\"bi\", \"ky\"}}},
{1,  1, 12.00, 638.9,  {{\"g\", \"chl\"}, {\"bi\", \"ky\"}}}},

{{1,  1, 5.00, 578,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 6.00, 623,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 7.00, 669,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 8.00, 715,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 9.00, 762,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 10.00, 808,  {{\"ky\"}, {\"sill\"}}},
{1,  1, 12.00, 901,  {{\"ky\"}, {\"sill\"}}}}    };             \
\>", "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
if two di -> tri boundaries (ie lines) meet at a quadri -> di 
(ie a point), then put these in up-temperature (or left->right) order as \
below\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["alllines = {\n{{1,  2, 0,      4.00, 519.1,",
    FontWeight->"Plain"],
  StyleBox[" {\"g\", \"bi\"},\"chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\"}, \n{1,  2, 0.0500, 4.00, 532.0, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.1000, 4.00, 544.1, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, \
4.00, 555.7, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 4.00, 567.0, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.2500, 4.00, 578.3, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3000, 4.00, 589.5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3500, \
4.00, 600.6, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, 4.00, 611.7, {\"g\", \
\"bi\"},\"chl\"}, \n\n{1,  2, 0,      5.00, 523.0, {\"g\", \"bi\"},\"chl\"}, \
\n{1,  2, 0.0500, 5.00, 537.0, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1000, \
5.00, 549.6, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, 5.00, 561.6, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.2000, 5.00, 573.1, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.2500, 5.00, 584.6, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3000, \
5.00, 595.9, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3500, 5.00, 607.1, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.4000, 5.00, 618.3, {\"g\", \"bi\"},\"chl\"}, \n\
\n",
    FontWeight->"Plain"],
  StyleBox["{1,  2, 0,      6.00, 526.0, {\"g\", \"bi\"},\"chl\"}, \n",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["{1,  2, 0.0500, 6.00, 541.4, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, \
0.1000, 6.00, 554.4, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, 6.00, 566.6, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 6.00, 578.3, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.2500, 6.00, 589.7, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3000, 6.00, 601.1, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3500, \
6.00, 612.4, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, 6.00, 623.6, {\"g\", \
\"bi\"},\"chl\"},  \n\n{1,  2, 0.0500, 7.00, 545.5, {\"g\", \"bi\"},\"chl\"}, \
\n{1,  2, 0.1000, 7.00, 558.9, {\"g\", \"bi\"},\"chl\"}, ",
    FontWeight->"Plain"],
  StyleBox["\n{1,  2, 0.1500, 7.00, 571.1, {\"g\", \"bi\"},\"chl\"}, \n{",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["1,  2, 0.2000, 7.00, 582.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, \
0.2500, 7.00, 594.2, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3000, 7.00, 605.5, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3500, 7.00, 616.7, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.4000, 7.00, 627.9, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.4500, 7.00, 639.0, {\"g\", \"bi\"},\"chl\"}, \n\n{0,  2, 0,      \
7.51, 529.7, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.0500, 7.51, 547.6, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.1000, 7.51, 561.1, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.1500, 7.51, 573.3, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, \
7.51, 584.9, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2500, 7.51, 596.3, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.3000, 7.51, 607.5, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3500, 7.51, 618.7, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000,",
    FontWeight->"Plain"],
  StyleBox[" 7.51, 629.7, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, 7.",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["51, 640.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 7.51, \
651.9, {\"g\", \"bi\"},\"chl\"}, \n\n{0,  2, 0.0142, 8.00, 537.7, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.0500, 8.00, 549.8, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.1000, 8.00, 563.3, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, \
8.00, 575.5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 8.00, 587.0, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.2500, 8.00, 598.3, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3000, 8.00, 609.4, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.3500, \
8.00, 620.5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, 8.00, 631.5, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.4500, 8.00, 642.4, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.5000, 8.00, 653.4, {\"g\", \"bi\"},\"chl\"}, \n\n{0,  2, 0.0456, \
9.00, 553.2, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.0500, 9.00, 554.5, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.1000, 9.00, 567.9, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.1500, 9.00, 579.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, \
9.00, 591.1, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2500, 9.00, 602.1, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.3000, 9.00, 612.9, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3500, 9.00, 623.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, \
9.00, 634.",
    FontWeight->"Plain"],
  StyleBox["5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, 9.00, 645.3",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 9.00, 656.1, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5500, 9.00, 666.8, {\"g\", \
\"bi\"},\"chl\"}, \n\n{0,  2, 0.0804, 10.00, 568.0, {\"g\", \"bi\"},\"chl\"}, \
\n{1,  2, 0.1000, 10.00, 572.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, \
10.00, 584.2, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 10.00, 595.1, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2500, 10.00, 605.7, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.3000, 10.00, 616.3, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3500, 10.00, 626.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, \
10.00, 637.2, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, 10.00, 647.7, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 10.00, 658.2, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.5500, 10.00, 668.7, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.6000, 10.00, 679.3, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.6500, \
10.00, 689.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.7000, 10.00, 700.3, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.7500, 10.00, 710.9, {\"g\", \
\"bi\"},\"chl\"}, \n\n{0,  2, 0.0993, 10.50, 575.2, {\"g\", \"bi\"},\"chl\"}, \
\n{1,  2, 0.1000, 10.50, 575.3, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, \
10.50, 586.5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 10.50, 597.1, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.2500, 10.50, 607.5, {\"g\", \
\"bi\"},\"chl",
    FontWeight->"Plain"],
  StyleBox["\"}, \n{1,  2, 0.3000, 10.50, 617.9, {\"g\", \"bi\"},\"c",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["hl\"}, \n{1,  2, 0.3500, 10.50, 628.2, {\"g\", \"bi\"},\"chl\"}, \
\n{1,  2, 0.4000, 10.50, 638.5, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, \
10.50, 648.8, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 10.50, 659.2, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5500, 10.50, 669.5, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.6000, 10.50, 679.9, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.6500, 10.50, 690.3, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.7000, \
10.50, 700.7, {\"g\", \"bi\"},\"chl\"}, \n\n{0,  2, 0.1604, 12.00, 595.5, \
{\"g",
    FontWeight->"Plain"],
  StyleBox["\", \"bi\"},\"chl\"},  \n{1,  2, 0.2000, 12.00, 603.2, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.2500, 12.00, 612.9, {\"g\", \"",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["bi\"},\"chl\"}, \n{1,  2, 0.3000, 12.00, 622.5, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.3500, 12.00, 632.2, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.4000, 12.00, 641.9, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, \
12.00, 651.7, {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 12.00, 661.5, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.5500, 12.00, 671.4, {\"g\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.6000, 12.00, 681.3, {\"g\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.6500, 12.00, 691.3,",
    FontWeight->"Plain"],
  StyleBox[" {\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.7000, 12.00, 701.3, \
{\"g\", \"bi\"},\"chl\"}, \n{1,  2, 0.7500, 12.00, 711.3, {\"",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["g\", \"bi\"},\"chl\"}}, \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0,     5.00, \
523.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.0030, 5.00, 523.3, {\"g\", \"chl\
\"},\"bi\"}, \n{1,  2, 0.0060, 5.00, 523.6, {\"g\", \"chl\"},\"bi\"}, \n{1,  \
2, 0.0090, 5.00, 523.9, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.0120, 5.00, \
524.2, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.0150, 5.00, 524.5, {\"g\", \"chl\
\"},\"bi\"}, \n{1,  2, 0.0180, 5.00, 524.8, {\"g\", ",
    FontWeight->"Plain"],
  StyleBox["\"chl\"},\"bi\"}, \n{1,  2, 0.0210, 5.00, 525.1, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.0240, 5.00, 525.4, {\"g\", \"chl\"}",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\"bi\"}, \n{0,  2, 0.0265, 5.00, 525.6, {\"g\", \
\"chl\"},\"bi\"}, \n\n{1,  2,     0,  6.00, 526.0, {\"g\", \"chl\"},\"bi\"},  \
   \n{1,  2, 0.0200, 6.00, 529.0, {\"g\", \"chl\"},\"bi\"},    \n{1,  2, \
0.0400, 6.00, 531.6, {\"g\", \"chl\"},\"bi\"},   \n{1,  2, 0.0600, 6.00, \
534.0, {\"g\", \"chl\"},\"bi\"},   \n{1,  2, 0.0800, 6.00, 536.1, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.1000, 6.00, 538.2, {\"g\", \"chl\"},\"bi\"},   \
\n{1,  2, 0.1200, 6.00, 540.1, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.1400, \
6.00, 542.0, {\"g\", \"",
    FontWeight->"Plain"],
  StyleBox["chl\"},\"bi\"}, \n{1,  2, 0.1600, 6.00, 543.7, {\"g\", \
\"chl\"},\"bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\"},  \n{0,  2, 0.1785, 6.00, 545.3, {\"g\", \"chl\"},\"bi\"}, \n\
\n{1,  2, 0,      7.00, 528.5, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.0500, \
7.00, 538.4, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.1000, 7.00, 545.0, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 7.00, 550.4, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.2000, 7.00, 555.2, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.2500, \
7.00, 559.5, {\"g\", \"chl\"},\"bi\"}, \n{0,  2, 0.3015, 7.00, 563.6, {\"g\", \
\"chl\"},\"bi\"},\n\n{0,  2, 0.0142, 8.00, 537.7, {\"g\", \"chl\"},\"bi\"},   \
   \n{1,  2, 0.0500, 8.00, 545.4, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.1000, \
8.00, 552.7, {\"g\", ",
    FontWeight->"Plain"],
  StyleBox["\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 8.00, 558.6, {\"g\", \"",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["chl\"},\"bi\"}, \n{1,  2, 0.2000, 8.00, 563.8, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.2500, 8.00, 568.4, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.3000, 8.00, 572.7, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.3500, \
8.00, 576.8, {\"g\", \"chl\"},\"bi\"}, \n{0,  2, 0.4040, 8.00, 580.9, {\"g\", \
\"chl\"},\"bi\"},\n\n{0,  2, 0.0456, 9.00, 553.2, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.0500, 9.00, 554.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.1000, \
9.00, 561.4, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.1500, 9.00, 567.4, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 9.00, 572.7, {\"g\", \"ch",
    FontWeight->"Plain"],
  StyleBox["l\"},\"bi\"}, \n{1,  2, 0.2500, 9.00, 577.5, {\"g\", \"ch",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["l\"},\"bi\"}, \n{1,  2, 0.3000, 9.00, 582.1, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 9.00, 586.3, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.4000, 9.00, 590.4, {\"g\", \"chl\"},\"bi\"}, \n{0,  2, 0.4915, \
9.00, 597.4, {\"g\", \"chl\"},\"bi\"},   \n\n{0,  2, 0.0804, 10.00, 568.0, \
{\"g\", \"chl\"},\"bi\"},   \n{1,  2, 0.1000, 10.00, 570.6, {\"g\", \"chl\"},\
\"bi\"}, \n{1,  2, 0.1500, 10.00, 576.5, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, \
0.2000, 10.00, 581.8, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.2500, 10.00, \
586.7, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.3000, 10.00, 591.3, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 10.00, 595.7, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.4000, 10.00, 600.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.4500, \
10.00, 604.1, {\"g\", \"chl\"},\"bi\"}, \n{0,  2, 0.5665, 10.00, 613.1, \
{\"g\", \"chl\"},\"bi\"}, \n\n{0,  2, 0.1186, 11.00, 582.0, {\"g\", \"chl\"},\
\"bi\"},  \n{1,  2, 0.1500, 11.00, 585.6, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, \
0.2000, 11.00, 590.8, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.2500, 11.00, \
595.7, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.3000, 11.00, 600.4, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 11.00, 604.9, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.4000, 11.00, 609.3, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.4500, \
11.00, 613.5, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.5000, 11.00, 617.6, \
{\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.5500, 11.00, 621.7, {\"g\", \
\"chl\"},\"bi\"}, \n{0,  2, 0.6325, 11.00, 628.2, {\"g\", \"chl\"},\"bi\"},   \
 \n\n{0,  2, 0.1604, 12.00, 595.5, {\"g\", \"chl\"},\"bi\"},  \n{1,  2, \
0.2050, 12.00, 600.0, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.26",
    FontWeight->"Plain"],
  StyleBox["00, 12.00, 605.4, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["3150, 12.00, 610.5, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.3700, \
12.00, 615.5, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.4250, 12.00, 620.3, \
{\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.4800, 12.00, 625.1, {\"g\", \
\"chl\"},\"bi\"}, \n{1,  2, 0.5350, 12.00, 629.7, {\"g\", \"chl\"},\"bi\"}, \n\
{1,  2, 0.5900, 12.00, 634.4, {\"g\", \"chl\"},\"bi\"}, \n{1,  2, 0.6450, \
12.00, 639.0, {\"g\", \"chl\"},\"bi\"}, \n{0,  2, 0.6910, 12.00, 642.8, \
{\"g\", \"chl\"},\"bi\"}},      \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0,     4.00, \
519.1, {\"chl\", \"bi\"},\"g\"},",
    FontWeight->"Plain"],
  StyleBox[" \n{1,  2, 0.0500, 4.00, 524.1, {\"chl\", \"bi\"},\"g\"}, ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n{1,  2, 0.1000, 4.00, 529.4, {\"chl\", \"bi\"},\"g\"}, \n{1,  \
2, 0.1500, 4.00, 535.0, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.2000, 4.00, \
540.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.2500, 4.00, 547.3, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.3000, 4.00, 554.1, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.3500, 4.00, 561.4, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.4000, \
4.00, 569.2, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, ",
    FontWeight->"Plain"],
  StyleBox["0.4500, 4.00, 577.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5000, \
4.00, 586.9, {\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.0265, 5.00, 525.6, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.0500, 5.00, 528.0, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.1000, 5.00, 533.3, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.1500, 5.00, 538.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.2000, \
5.00, 544.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.2500, 5.00, 551.2, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.3000, 5.00, 558.1, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.3500, 5.00, 565.4, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.4000, 5.00, 573.2, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.4500, \
5.00, 581.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5000, 5.00, 591.0, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5500, 5.00, 601.1, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.6000, 5.00, 612.1, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.6500, 5.00, 624.3, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7000, \
5.00, 637.8, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7500, 5.00, 652.7, \
{\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.1785, 6.00, 545.3, {\"chl\", \"bi\"},\
\"g\"}, \n{1,  2, 0.2000, 6.00, 547.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, \
0.2500, 6.00, 554.3, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.3000, 6.00, 561.0, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.3500, 6.00, 568.3, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.4000, 6.00, 576.2, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.4500, 6.00, 584.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5000, \
6.00, 593.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5500, 6.00, 603.9, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6000, 6.00, 614.9, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.6500, 6.00, 627.0, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7000, 6.00, 640.5, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7500, \
6.00, 655.4, {\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.3015, 7.00, 563.6, \
{\"chl\", \"bi\"},\"g\"},     \n{1,  2, 0.3500, 7.00, 570.6, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.4000, 7.00, 578.4, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.4500, 7.00, 586.8, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5000, \
7.00, 596.0, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.5500, 7.00, 605.9, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6000, 7.00, 616.9, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.6500, 7.00, 628.9, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7000, 7.00, 642.2, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7500, \
7.00, 657.1, {\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.4040, 8.00, 580.9, \
{\"chl\", \"bi\"},\"g\"},\n{1,  2, 0.4500, 8.00, 588.6, {\"chl\", \"bi\"},\"g\
\"}, \n{1,  2, 0.5000, 8.00, 597.6, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, \
0.5500, 8.00, 607.4, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6000, 8.00, 618.2, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6500, 8.00, 630.1, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.7000, 8.00, 643.3, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7500, 8.00, 658.0, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.8000, \
8.00, 674.5, {\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.4915, 9.00, 597.4, \
{\"chl\", \"bi\"},\"g\"},   \n{1,  2, 0.5000, 9.00, 599.0, {\"chl\", \"bi\"},\
\"g\"}, \n{1,  2, 0.5500, 9.00, 608.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, \
0.6000, 9.00, 619.3, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6500, 9.00, 631.0, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7000, 9.00, 644.0, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.7500, 9.00, 658.5, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.8000, 9.00, 674.8, {\"chl\", \"bi\"},\"g\"}, \n\n{0,  2, 0.5665, \
10.00, 613.1, {\"chl\", \"bi\"},\"g\"},\n{1,  2, 0.5800, 10.00, 615.9, {\"chl\
\", \"bi\"},\"g\"}, \n{1,  2, 0.6000, 10.00, 620.2, {\"chl\", \"bi\"},\"g\"}, \
\n{1,  2, 0.6200, 10.00, 624.6, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6400, \
10.00, 629.3, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6600, 10.00, 634.1, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6800, 10.00, 639.2, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.7000, 10.00, 644.4, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7200, 10.00, 650.0, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7400, \
10.00, 655.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7600, 10.00, 661.8, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7800, 10.00, 668.1, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.8000, 10.00, 674.8, {\"chl\", \"bi\"},\"g\"}, \n\n\
{0,  2, 0.6325, 11.00, 628.2, {\"chl\", \"bi\"},\"g\"},    \n{1,  2, 0.6400, \
11.00, 629.9, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6600, 11.00, 634.7, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.6800, 11.00, 639.6, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.7000, 11.00, 644.8, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7200, 11.00, 650.2, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7400, \
11.00, 655.8, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7600, 11.00, 661.7, \
{\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7800, 11.00, 668.0, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.8000, 11.00, 674.5, {\"chl\", \"bi\"},\"g\"}, \n\n\
{0,  2, 0.6910, 12.00, 642.8, {\"chl\", \"bi\"},\"g\"},      \n{1,  2, \
0.7000, 12.00, 645.0, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7200, 12.00, \
650.3, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.7400, 12.00, 655.8, {\"chl\", \
\"bi\"},\"g\"}, \n{1,  2, 0.7600, 12.00, 661.6, {\"chl\", \"bi\"},\"g\"}, \n\
{1,  2, 0.7800, 12.00, 667.7, {\"chl\", \"bi\"},\"g\"}, \n{1,  2, 0.8000, \
12.00, 674.1, {\"chl\", \"bi\"},\"g\"}},        \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.2000, 5.00, \
552.8, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.2500, 5.00, 555.1, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.3000, 5.00, 557.4, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.3500, 5.00, 560.0, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4000, \
5.00, 562.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, 5.00, 565.4, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, 5.00, 568.4, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.5500, 5.00, 571.5, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.6000, 5.00, 574.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6500, \
5.00, 578.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, 5.00, 582.6, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, 5.00, 587.1, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.8000, 5.00, 592.0, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.8500, 5.00, 597.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.9000, \
5.00, 604.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.9500, 5.00, 611.7, {\"chl\
\", \"bi\"},\"st\"}, \n\n{1,  2, 0.2500, 5.50, 560.8, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.3000, 5.50, 563.1, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.3500, 5.50, 565.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4000, \
5.50, 568.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, 5.50, 571.0, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, 5.50, 574.0, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.5500, 5.50, 577.1, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.6000, 5.50, 580.5, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6500, \
5.50, 584.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, 5.50, 588.2, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, 5.50, 592.6, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.8000, 5.50, 597.5, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.8500, 5.50, 603.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.9000, \
5.50, 609.6, {\"chl\", \"bi\"},\"st\"}, \n\n{1,  2, 0.3000, 6.00, 568.6, \
{\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.3500, 6.00, 571.1, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.4000, 6.00, 573.7, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.4500, 6.00, 576.4, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, \
6.00, 579.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, 6.00, 582.5, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, 6.00, 585.8, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6500, 6.00, 589.5, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.7000, 6.00, 593.5, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, \
6.00, 597.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 6.00, 602.8, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.8500, 6.00, 608.4, {\"chl\", \
\"bi\"},\"st\"}, \n\n{1,  2, 0.3000, 6.50, 573.9, {\"chl\", \"bi\"},\"st\"}, \
\n{1,  2, 0.3500, 6.50, 576.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4000, \
6.50, 578.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, 6.50, 581.6, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, 6.50, 584.5, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.5500, 6.50, 587.6, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.6000, 6.50, 590.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6500, \
6.50, 594.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, 6.50, 598.5, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, 6.50, 602.9, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.8000, 6.50, 607.8, {\"chl\", \"bi\"},\"st\"}, \n\
\n{1,  2, 0.2000, 7.00, 574.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.2500, \
7.00, 576.7, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.3000, 7.00, 579.0, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.3500, 7.00, 581.4, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.4000, 7.00, 583.9, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.4500, 7.00, 586.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, \
7.00, 589.5, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, 7.00, 592.5, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, 7.00, 595.9, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6500, 7.00, 599.4, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.7000, 7.00, 603.4, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, \
7.00, 607.7, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 7.00, 612.6, {\"chl\
\", \"bi\"},\"st\"}, \n\n{1,  2, 0.2000, 7.50, 579.6, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.2500, 7.50, 581.7, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.3000, 7.50, 584.0, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.3500, \
7.50, 586.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4000, 7.50, 588.8, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, 7.50, 591.5, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.5000, 7.50, 594.3, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.5500, 7.50, 597.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, \
7.50, 600.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6500, 7.50, 604.1, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, 7.50, 608.0, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.7500, 7.50, 612.3, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.8000, 7.50, 617.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8500, \
7.50, 622.7, {\"chl\", \"bi\"},\"st\"}, \n\n{1,  2, 0.2500, 8.00, 586.7, \
{\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.3000, 8.00, 588.8, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.3500, 8.00, 591.1, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.4000, 8.00, 593.6, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, \
8.00, 596.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, 8.00, 599.0, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, 8.00, 601.9, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6000, 8.00, 605.2, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.6500, 8.00, 608.7, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, \
8.00, 612.5, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, 8.00, 616.8, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 8.00, 621.6, {\"chl\", \
\"bi\"},\"st\"}, \n\n{1,  2, 0.3500, 8.50, 595.8, {\"chl\", \"bi\"},\"st\"}, \
\n{1,  2, 0.4000, 8.50, 598.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.4500, \
8.50, 600.8, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, 8.50, 603.5, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, 8.50, 606.4, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6000, 8.50, 609.6, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.6500, 8.50, 613.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7000, \
8.50, 616.8, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, 8.50, 621.1, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 8.50, 625.8, {\"chl\", \
\"bi\"},\"st\"}, \n\n{1,  2, 0.4000, 9.00, 602.8, {\"chl\", \"bi\"},\"st\"}, \
\n{1,  2, 0.4500, 9.00, 605.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5000, \
9.00, 607.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, 9.00, 610.8, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, 9.00, 613.9, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6500, 9.00, 617.3, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.7000, 9.00, 621.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, \
9.00, 625.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 9.00, 629.9, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.8500, 9.00, 635.2, {\"chl\", \
\"bi\"},\"st\"}, \n\n{1,  2, 0.4500, 9.50, 609.7, {\"chl\", \"bi\"},\"st\"}, \
\n{1,  2, 0.5000, 9.50, 612.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.5500, \
9.50, 615.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, 9.50, 618.1, {\"chl\
\", \"bi\"},\"st\"}, \n{1,  2, 0.6500, 9.50, 621.5, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.7000, 9.50, 625.1, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.7500, 9.50, 629.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, \
9.50, 633.9, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8500, 9.50, 639.1, {\"chl\
\", \"bi\"},\"st\"}, \n\n{1,  2, 0.5000, 9.98, 616.5, {\"chl\", \
\"bi\"},\"st\"}, (* 10 kbar made to 9.98 kbar *)\n{1,  2, 0.5500, 9.98, \
619.3, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.6000, 9.98, 622.3, {\"chl\", \
\"bi\"},\"st\"}, \n{1,  2, 0.6500, 9.98, 625.5, {\"chl\", \"bi\"},\"st\"}, \n\
{1,  2, 0.7000, 9.98, 629.1, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.7500, \
9.98, 633.2, {\"chl\", \"bi\"},\"st\"}, \n{1,  2, 0.8000, 9.98, 637.7, {\"chl\
\", \"bi\"},\"st\"}}, \n\n(* ____________________________________________ *)\n\
\n{{1,  2, 0.1000, 5.00, 549.5, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.1500, \
5.00, 552.1, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.2000, 5.00, 554.8, \
{\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.2500, 5.00, 557.6, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.3000, 5.00, 560.5, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.3500, 5.00, 563.5, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.4000, \
5.00, 566.6, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.4500, 5.00, 569.9, \
{\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.5000, 5.00, 573.4, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.5500, 5.00, 577.0, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.6000, 5.00, 580.8, {\"st\", \"bi\"},\"chl\"}, \n\n{1,  2, 0.3000, \
6.00, 571.5, {\"st\", \"bi\"},\"chl\"},   \n{1,  2, 0.3500, 6.00, 574.5, \
{\"st\", \"bi\"},\"chl\"},      \n{1,  2, 0.4000, 6.00, 577.5, {\"st\", \
\"bi\"},\"chl\"},  \n{1,  2, 0.4500, 6.00, 580.8, {\"st\", \"bi\"},\"chl\"},  \
 \n{1,  2, 0.5000, 6.00, 584.2, {\"st\", \"bi\"},\"chl\"},  \n{1,  2, 0.5500, \
6.00, 587.8, {\"st\", \"bi\"},\"chl\"},    \n\n{1,  2, 0.3000, 8.00, 591.4, {\
\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.3600, 8.00, 594.7, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.4200, 8.00, 598.3, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.4800, 8.00, 602.1, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.5400, \
8.00, 606.1, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.6000, 8.00, 610.5, \
{\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.6600, 8.00, 615.3, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.7200, 8.00, 620.5, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.7800, 8.00, 626.1, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.8400, \
8.00, 632.1, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.9000, 8.00, 638.6, \
{\"st\", \"bi\"},\"chl\"}, \n\n{1,  2, 0.3000, 9.98, 609.5, {\"st\", \"bi\"},\
\"chl\"}, (* 10 kbar made to 9.98 kbar *)\n{1,  2, 0.3600, 9.98, 612.4, {\"st\
\", \"bi\"},\"chl\"}, \n{1,  2, 0.4200, 9.98, 615.7, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.4800, 9.98, 619.1, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.5400, 9.98, 622.9, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.6000, \
9.98, 627.0, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.6600, 9.98, 631.5, \
{\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.7200, 9.98, 636.4, {\"st\", \
\"bi\"},\"chl\"}, \n{1,  2, 0.7800, 9.98, 641.8, {\"st\", \"bi\"},\"chl\"}, \n\
{1,  2, 0.8400, 9.98, 647.6, {\"st\", \"bi\"},\"chl\"}, \n{1,  2, 0.9000, \
9.98, 653.8, {\"st\", \"bi\"},\"chl\"}}, \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.0500, 5.00, \
421.0, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.0750, 5.00, 464.3, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.1000, 5.00, 506.1, {\"g\", \"bi\"},\"st\"}, \n\
{1,  2, 0.1250, 5.00, 547.0, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.1500, 5.00, \
587.5, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.1750, 5.00, 627.9, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.2000, 5.00, 668.6, {\"g\", \"bi\"},\"st\"}, \n\n\
{1,  2, 0.1700, 6.00, 565.0, {\"g\", \"bi\"},\"st\"},   \n{1,  2, 0.1800, \
6.00, 580.3, {\"g\", \"bi\"},\"st\"},     \n{1,  2, 0.1900, 6.00, 595.5, {\"g\
\", \"bi\"},\"st\"},     \n{1,  2, 0.2000, 6.00, 610.9, {\"g\", \
\"bi\"},\"st\"},    \n{1,  2, 0.2100, 6.00, 626.1, {\"g\", \"bi\"},\"st\"},   \
  \n{1,  2, 0.2200, 6.00, 641.2, {\"g\", \"bi\"},\"st\"},    \n{1,  2, \
0.2300, 6.00, 656.4, {\"g\", \"bi\"},\"st\"},     \n\n{1,  2, 0.1200, 8.00, \
411.8, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.1400, 8.00, 440.9, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.1600, 8.00, 469.3, {\"g\", \"bi\"},\"st\"}, \n\
{1,  2, 0.1800, 8.00, 497.2, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.2000, 8.00, \
524.6, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.2200, 8.00, 551.7, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.2400, 8.00, 578.6, {\"g\", \"bi\"},\"st\"}, \n\
{1,  2, 0.2600, 8.00, 605.4, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.2800, 8.00, \
632.1, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.3000, 8.00, 658.8, {\"g\", \
\"bi\"},\"st\"}, \n\n{1,  2, 0.1600, 9.98, 419.8, {\"g\", \"bi\"},\"st\"}, (* \
10 kbar made to 9.98 kbar *)\n{1,  2, 0.1900, 9.98, 455.8, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.2200, 9.98, 491.4, {\"g\", \"bi\"},\"st\"}, \n\
{1,  2, 0.2500, 9.98, 526.7, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.2800, 9.98, \
561.8, {\"g\", \"bi\"},\"st\"}, \n{1,  2, 0.3100, 9.98, 596.8, {\"g\", \
\"bi\"},\"st\"}, \n{1,  2, 0.3400, 9.98, 631.8, {\"g\", \"bi\"},\"st\"}, \n\
{1,  2, 0.3700, 9.98, 666.8, {\"g\", \"bi\"},\"st\"}},\n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.2000, 5.00, \
506.6, {\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.2300, 5.00, 542.6, {\"st\", \
\"bi\"},\"g\"}, \n{1,  2, 0.2600, 5.00, 581.3, {\"st\", \"bi\"},\"g\"}, \n{1, \
 2, 0.2900, 5.00, 623.0, {\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.3200, 5.00, \
668.6, {\"st\", \"bi\"},\"g\"},  \n\n{1,  2, 0.3100, 6.00, 564.6, {\"st\", \
\"bi\"},\"g\"},     \n{1,  2, 0.3200, 6.00, 578.6, {\"st\", \"bi\"},\"g\"},   \
\n{1,  2, 0.3300, 6.00, 592.9, {\"st\", \"bi\"},\"g\"},  \n{1,  2, 0.3400, \
6.00, 607.5, {\"st\", \"bi\"},\"g\"},    \n{1,  2, 0.3500, 6.00, 622.5, {\"st\
\", \"bi\"},\"g\"},      \n{1,  2, 0.3600, 6.00, 637.8, {\"st\", \
\"bi\"},\"g\"},     \n{1,  2, 0.3700, 6.00, 653.4, {\"st\", \"bi\"},\"g\"},   \
  \n\n{1,  2, 0.3400, 8.00, 451.8, {\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.3800, \
8.00, 507.6, {\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.4200, 8.00, 567.2, {\"st\", \
\"bi\"},\"g\"}, \n{1,  2, 0.4600, 8.00, 630.5, {\"st\", \"bi\"},\"g\"}, \n{1, \
 2, 0.5000, 8.00, 697.8, {\"st\", \"bi\"},\"g\"}, \n\n{1,  2, 0.4200, 9.98, \
427.0, {\"st\", \"bi\"},\"g\"}, (* 10 kbar made to 9.98 kbar *)\n{1,  2, \
0.4600, 9.98, 488.3, {\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.5000, 9.98, 552.1, \
{\"st\", \"bi\"},\"g\"}, \n{1,  2, 0.5400, 9.98, 618.1, {\"st\", \
\"bi\"},\"g\"}, \n{1,  2, 0.5800, 9.98, 686.3, {\"st\", \"bi\"},\"g\"}}, \n\n\
(* ____________________________________________ *)\n\n{{1,  2, 0.4000, 5.00, \
570.9, {\"chl\", \"bi\"},\"sill\"}, \n{1,  2, 0.4600, 5.00, 571.9, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.5200, 5.00, 572.8, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.5800, 5.00, 573.8, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.6400, 5.00, 574.7, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.7000, 5.00, 575.7, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.7600, 5.00, 576.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.8200, 5.00, 577.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.8800, 5.00, 578.5, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.9400, 5.00, 579.5, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 1.0000, 5.00, 580.4, {\"chl\", \
\"bi\"},\"sill\"},\n\n{1,  2, 0.3000, 6.00, 584.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.3700, 6.00, 585.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.4400, 6.00, 586.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.5100, 6.00, 587.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.5800, 6.00, 588.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.6500, 6.00, 589.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.7200, 6.00, 590.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.7900, 6.00, 591.6, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.8600, 6.00, 592.5, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.9300, 6.00, 593.5, {\"chl\", \
\"bi\"},\"sill\"}, \n{1,  2, 1.0000, 6.00, 594.5, {\"chl\", \
\"bi\"},\"sill\"}},  \n\n{{1,  2, 0.2500, 5.00, 568.8, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.3250, 5.00, 570.1, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.4000, 5.00, 571.3, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.4750, 5.00, 572.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.5500, 5.00, 573.7, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.6250, 5.00, 574.8, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.7000, 5.00, 576.0, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.7750, 5.00, 577.1, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.8500, 5.00, 578.2, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.9250, 5.00, 579.3, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 1.0000, 5.00, 580.4, {\"bi\", \
\"sill\"},\"chl\"},\n\n{1,  2, 0.2500, 6.00, 584.0, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.3250, 6.00, 585.2, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.4000, 6.00, 586.3, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.4750, 6.00, 587.4, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.5500, 6.00, 588.4, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.6250, 6.00, 589.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.7000, 6.00, 590.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.7750, 6.00, 591.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.8500, 6.00, 592.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 0.9250, 6.00, 593.5, {\"bi\", \
\"sill\"},\"chl\"}, \n{1,  2, 1.0000, 6.00, 594.5, {\"bi\", \
\"sill\"},\"chl\"}},  \n\n(* ____________________________________________ *)\n\
\n{{1,  2, 0.4000, 5.00, 570.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, \
5.00, 571.1, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, 5.00, 571.9, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, 5.00, 572.8, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.6000, 5.00, 573.7, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.6500, 5.00, 574.6, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, \
5.00, 575.5, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7500, 5.00, 576.3, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.8000, 5.00, 577.2, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.8500, 5.00, 578.1, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.9000, 5.00, 579.0, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9500, \
5.00, 579.8, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, 5.00, 580.7, {\"chl\
\", \"bi\"},\"ky\"},\n\n{1,  2, 0.4000, 6.00, 581.9, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.4500, 6.00, 582.7, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.5000, 6.00, 583.5, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, \
6.00, 584.3, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 6.00, 585.1, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 6.00, 585.8, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.7000, 6.00, 586.6, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.7500, 6.00, 587.4, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8000, \
6.00, 588.1, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8500, 6.00, 588.9, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.9000, 6.00, 589.7, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.9500, 6.00, 590.4, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 1.0000, 6.00, 591.2, {\"chl\", \"bi\"},\"ky\"}, \n\n{1,  2, 0.4000, \
7.00, 592.8, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 7.00, 593.5, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, 7.00, 594.2, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.5500, 7.00, 594.8, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.6000, 7.00, 595.5, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, \
7.00, 596.1, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, 7.00, 596.8, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.7500, 7.00, 597.4, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.8000, 7.00, 598.1, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.8500, 7.00, 598.7, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9000, \
7.00, 599.3, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9500, 7.00, 599.9, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, 7.00, 600.6, {\"chl\", \
\"bi\"},\"ky\"}, \n\n{1,  2, 0.4000, 8.00, 603.1, {\"chl\", \"bi\"},\"ky\"}, \
\n{1,  2, 0.4500, 8.00, 603.6, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, \
8.00, 604.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, 8.00, 604.7, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 8.00, 605.2, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.6500, 8.00, 605.7, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.7000, 8.00, 606.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7500, \
8.00, 606.7, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8000, 8.00, 607.2, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.8500, 8.00, 607.7, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.9000, 8.00, 608.2, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.9500, 8.00, 608.6, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, \
8.00, 609.1, {\"chl\", \"bi\"},\"ky\"}, \n\n{1,  2, 0.4000, 9.00, 612.8, \
{\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 9.00, 613.2, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.5000, 9.00, 613.6, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.5500, 9.00, 614.0, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, \
9.00, 614.3, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 9.00, 614.7, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, 9.00, 615.0, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.7500, 9.00, 615.4, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.8000, 9.00, 615.7, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8500, \
9.00, 616.0, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9000, 9.00, 616.3, {\"chl\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.9500, 9.00, 616.6, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 1.0000, 9.00, 616.9, {\"chl\", \"bi\"},\"ky\"}, \n\
\n{1,  2, 0.4000, 10.00, 622.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, \
10.00, 622.4, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, 10.00, 622.6, \
{\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, 10.00, 622.8, {\"chl\", \"bi\"},\
\"ky\"}, \n{1,  2, 0.6000, 10.00, 623.0, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, \
0.6500, 10.00, 623.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, 10.00, \
623.3, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.7500, 10.00, 623.5, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.8000, 10.00, 623.6, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.8500, 10.00, 623.8, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9000, \
10.00, 623.9, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9500, 10.00, 624.0, \
{\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, 10.00, 624.1, {\"chl\", \"bi\"},\
\"ky\"}, \n\n{1,  2, 0.5000, 10.50, 627.0, {\"chl\", \"bi\"},\"ky\"}, \n{1,  \
2, 0.5500, 10.50, 627.1, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 10.50, \
627.2, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 10.50, 627.3, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.7000, 10.50, 627.35, {\"chl\", \"bi\"},\"ky\"}, \
\n{1,  2, 0.7500, 10.50, 627.4, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8000, \
10.50, 627.45, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.8500, 10.50, 627.5, \
{\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9000, 10.50, 627.51, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.9500, 10.50, 627.52, {\"chl\", \"bi\"},\"ky\"}, \
\n{1,  2, 1.0000, 10.50, 627.53, {\"chl\", \"bi\"},\"ky\"}, \n\n{1,  2, \
0.6000, 11.00, 631.3, {\"chl\", \"bi\"},\"ky\"}, (* cotectic vsisible at 10.8 \
*)\n{1,  2, 0.7500, 11.00, 631.31, {\"chl\", \"bi\"},\"ky\"}, (* followed \
immediately by singularity in uni *)\n{1,  2, 0.8500, 11.00, 631.32, \
{\"chl\", \"bi\"},\"ky\"}, (* here NOT used - this is fiddled! *)\n{1,  2, \
0.9000, 11.00, 631.33, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9500, 11.00, \
631.34, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, 11.00, 631.35, {\"chl\", \
\"bi\"},\"ky\"},  \n\n{1,  2, 0.7600, 12.00, 638.5, {\"chl\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.8200, 12.00, 638.1, {\"chl\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.8800, 12.00, 637.8, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 0.9400, \
12.00, 637.4, {\"chl\", \"bi\"},\"ky\"}, \n{1,  2, 1.0000, 12.00, 637.0, \
{\"chl\", \"bi\"},\"ky\"}}, \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.4000, 5.00, \
570.6, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.4500, 5.00, 571.5, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.5000, 5.00, 572.3, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.5500, 5.00, 573.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6000, \
5.00, 574.1, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, 5.00, 574.9, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7000, 5.00, 575.8, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.7500, 5.00, 576.6, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.8000, 5.00, 577.4, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8500, \
5.00, 578.3, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, 5.00, 579.1, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, 5.00, 579.9, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 1.0000, 5.00, 580.7, {\"bi\", \"ky\"},\"chl\"}, \n\
\n{1,  2, 0.4000, 6.00, 582.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.4500, \
6.00, 583.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5000, 6.00, 583.8, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5500, 6.00, 584.6, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.6000, 6.00, 585.3, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.6500, 6.00, 586.1, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7000, \
6.00, 586.8, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7500, 6.00, 587.6, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8000, 6.00, 588.3, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.8500, 6.00, 589.0, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.9000, 6.00, 589.7, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, \
6.00, 590.5, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 1.0000, 6.00, 591.2, \
{\"bi\", \"ky\"},\"chl\"},\n\n{1,  2, 0.4000, 7.00, 593.1, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.4500, 7.00, 593.7, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.5000, 7.00, 594.4, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5500, \
7.00, 595.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6000, 7.00, 595.7, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, 7.00, 596.3, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.7000, 7.00, 597.0, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.7500, 7.00, 597.6, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8000, \
7.00, 598.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8500, 7.00, 598.8, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, 7.00, 599.4, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.9500, 7.00, 600.0, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 1.0000, 7.00, 600.6, {\"bi\", \"ky\"},\"chl\"}, \n\n{1,  2, 0.4000, \
8.00, 603.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.4500, 8.00, 603.8, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5000, 8.00, 604.3, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.5500, 8.00, 604.8, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.6000, 8.00, 605.3, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, \
8.00, 605.8, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7000, 8.00, 606.3, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7500, 8.00, 606.8, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.8000, 8.00, 607.3, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.8500, 8.00, 607.7, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, \
8.00, 608.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, 8.00, 608.6, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 1.0000, 8.00, 609.1, {\"bi\", \
\"ky\"},\"chl\"}, \n\n{1,  2, 0.4000, 9.00, 612.9, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.4500, 9.00, 613.3, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5000, \
9.00, 613.7, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.5500, 9.00, 614.0, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6000, 9.00, 614.4, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.6500, 9.00, 614.8, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.7000, 9.00, 615.1, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7500, \
9.00, 615.4, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8000, 9.00, 615.7, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8500, 9.00, 616.0, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.9000, 9.00, 616.3, {\"bi\", \"ky\"},\"chl\"}, \n\
{1,  2, 0.9500, 9.00, 616.6, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 1.0000, \
9.00, 616.9, {\"bi\", \"ky\"},\"chl\"}, \n\n{1,  2, 0.4000, 10.00, 622.2, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.4500, 10.00, 622.4, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.5000, 10.00, 622.6, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.5500, 10.00, 622.8, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6000, \
10.00, 623.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, 10.00, 623.2, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7000, 10.00, 623.4, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.7500, 10.00, 623.5, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.8000, 10.00, 623.6, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8500, \
10.00, 623.8, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, 10.00, 623.9, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, 10.00, 624.0, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 1.0000, 10.00, 624.1, {\"bi\", \"ky\"},\"chl\"}, \
\n\n{1,  2, 0.5000, 10.50, 627.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, \
0.5500, 10.50, 627.1, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6000, 10.50, \
627.2, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, 10.50, 627.3, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.7000, 10.50, 627.35, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.7500, 10.50, 627.4, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8000, \
10.50, 627.45, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.8500, 10.50, 627.5, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, 10.50, 627.51, {\"bi\", \"ky\"},\
\"chl\"}, \n{1,  2, 0.9500, 10.50, 627.52, {\"bi\", \"ky\"},\"chl\"}, \n{1,  \
2, 1.0000, 10.50, 627.53, {\"bi\", \"ky\"},\"chl\"}, \n\n{1,  2, 0.5000, \
11.00, 631.3, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, 11.00, 631.31, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7500, 11.00, 631.32, {\"bi\", \"ky\"},\
\"chl\"}, \n{1,  2, 0.8000, 11.00, 631.33, {\"bi\", \"ky\"},\"chl\"}, \n{1,  \
2, 0.9000, 11.00, 631.34, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, 11.00, \
631.345, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 1.0000, 11.00, 631.35, {\"bi\", \
\"ky\"},\"chl\"},  \n\n{1,  2, 0.5000, 12.00, 639.7, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.5500, 12.00, 639.5, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.6000, 12.00, 639.3, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.6500, \
12.00, 639.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7000, 12.00, 638.8, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.7500, 12.00, 638.6, {\"bi\", \
\"ky\"},\"chl\"}, \n{1,  2, 0.8000, 12.00, 638.3, {\"bi\", \"ky\"},\"chl\"}, \
\n{1,  2, 0.8500, 12.00, 638.0, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9000, \
12.00, 637.7, {\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 0.9500, 12.00, 637.4, \
{\"bi\", \"ky\"},\"chl\"}, \n{1,  2, 1.0000, 12.00, 637.0, {\"bi\", \
\"ky\"},\"chl\"}},   \n\n(* ____________________________________________ *)\n\
\n{{1,  2, 0.1000, 5.00, 788.6, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.1500, \
5.00, 765.1, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.2000, 5.00, 740.9, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.2500, 5.00, 715.7, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.3000, 5.00, 689.5, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.3500, 5.00, 662.3, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4000, \
5.00, 634.0, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 5.00, 604.2, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, 5.00, 572.6, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.5500, 5.00, 538.8, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.6000, 5.00, 502.1, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, \
5.00, 461.5, {\"st\", \"bi\"},\"ky\"}, \n\n{1,  2, 0.1500, 6.00, 800.8, {\"st\
\", \"bi\"},\"ky\"}, \n{1,  2, 0.2000, 6.00, 774.3, {\"st\", \"bi\"},\"ky\"}, \
\n{1,  2, 0.2500, 6.00, 746.7, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.3000, \
6.00, 718.1, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.3500, 6.00, 688.4, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4000, 6.00, 657.6, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.4500, 6.00, 625.3, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.5000, 6.00, 591.1, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, \
6.00, 554.6, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 6.00, 515.1, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 6.00, 471.5, {\"st\", \
\"bi\"},\"ky\"}, \n\n{1,  2, 0.2000, 7.00, 808.3, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.2500, 7.00, 778.2, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.3000, \
7.00, 747.0, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.3500, 7.00, 714.6, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4000, 7.00, 681.2, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.4500, 7.00, 646.2, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.5000, 7.00, 609.2, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.5500, \
7.00, 569.9, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 7.00, 527.4, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 7.00, 480.6, {\"st\", \
\"bi\"},\"ky\"}, \n\n{1,  2, 0.2500, 8.00, 810.7, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.3000, 8.00, 776.7, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.3500, \
8.00, 741.5, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4000, 8.00, 705.2, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 8.00, 667.3, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.5000, 8.00, 627.4, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.5500, 8.00, 585.0, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, \
8.00, 539.2, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 8.00, 488.9, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, 8.00, 431.9, {\"st\", \
\"bi\"},\"ky\"}, \n\n{1,  2, 0.3000, 9.00, 807.7, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.3500, 9.00, 769.4, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4000, \
9.00, 729.8, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 9.00, 688.9, \
{\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.5000, 9.00, 645.7, {\"st\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.5500, 9.00, 600.0, {\"st\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.6000, 9.00, 550.7, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, \
9.00, 496.6, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.7000, 9.00, 435.2, \
{\"st\", \"bi\"},\"ky\"}, \n\n{1,  2, 0.3500, 9.98, 798.7, {\"st\", \
\"bi\"},\"ky\"}, (* 10 kbar made to 9.98 kbar *)\n{1,  2, 0.4000, 9.98, \
755.7, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.4500, 9.98, 711.2, {\"st\", \"bi\
\"},\"ky\"}, \n{1,  2, 0.5000, 9.98, 664.5, {\"st\", \"bi\"},\"ky\"}, \n{1,  \
2, 0.5500, 9.98, 615.1, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6000, 9.98, \
561.9, {\"st\", \"bi\"},\"ky\"}, \n{1,  2, 0.6500, 9.98, 503.6, {\"st\", \"bi\
\"},\"ky\"}, \n{1,  2, 0.7000, 9.98, 437.5, {\"st\", \"bi\"},\"ky\"}},\n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.1000, 5.00, \
793.0, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.1500, 5.00, 771.9, {\"bi\", \"ky\
\"},\"st\"}, \n{1,  2, 0.2000, 5.00, 750.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  \
2, 0.2500, 5.00, 727.8, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3000, 5.00, \
704.7, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3500, 5.00, 680.9, {\"bi\", \"ky\
\"},\"st\"}, \n{1,  2, 0.4000, 5.00, 656.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  \
2, 0.4500, 5.00, 630.7, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.5000, 5.00, \
603.9, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.5500, 5.00, 576.0, {\"bi\", \"ky\
\"},\"st\"}, \n{1,  2, 0.6000, 5.00, 546.1, {\"bi\", \"ky\"},\"st\"}, \n{1,  \
2, 0.6500, 5.00, 514.3, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.7000, 5.00, \
480.0, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.7500, 5.00, 442.3, {\"bi\", \"ky\
\"},\"st\"},   \n\n{1,  2, 0.1500, 6.00, 808.3, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.2000, 6.00, 784.6, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.2500, \
6.00, 760.1, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3000, 6.00, 735.0, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3500, 6.00, 708.9, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.4000, 6.00, 682.1, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.4500, 6.00, 654.4, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.5000, \
6.00, 625.5, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.5500, 6.00, 595.1, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6000, 6.00, 563.2, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.6500, 6.00, 529.1, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.7000, 6.00, 492.5, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.7500, \
6.00, 452.3, {\"bi\", \"ky\"},\"st\"}, \n\n{1,  2, 0.2000, 7.00, 819.6, {\"bi\
\", \"ky\"},\"st\"}, \n{1,  2, 0.2500, 7.00, 792.9, {\"bi\", \"ky\"},\"st\"}, \
\n{1,  2, 0.3000, 7.00, 765.5, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3500, \
7.00, 737.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4000, 7.00, 708.1, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4500, 7.00, 678.0, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.5000, 7.00, 646.9, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.5500, 7.00, 614.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6000, \
7.00, 580.0, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6500, 7.00, 543.5, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.7000, 7.00, 504.3, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.7500, 7.00, 461.6, {\"bi\", \"ky\"},\"st\"}, \n\n\
{1,  2, 0.3000, 8.00, 797.0, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3500, \
8.00, 766.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4000, 8.00, 734.6, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4500, 8.00, 702.1, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.5000, 8.00, 668.5, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.5500, 8.00, 633.4, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6000, \
8.00, 596.6, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6500, 8.00, 557.6, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.7000, 8.00, 515.7, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.7500, 8.00, 470.3, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.8000, 8.00, 419.7, {\"bi\", \"ky\"},\"st\"}, \n\n{1,  2, 0.3000, \
9.00, 829.8, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.3500, 9.00, 796.4, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4000, 9.00, 762.0, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.4500, 9.00, 726.8, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.5000, 9.00, 690.6, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.5500, \
9.00, 652.8, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6000, 9.00, 613.3, \
{\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6500, 9.00, 571.5, {\"bi\", \
\"ky\"},\"st\"}, \n{1,  2, 0.7000, 9.00, 526.9, {\"bi\", \"ky\"},\"st\"}, \n\
{1,  2, 0.7500, 9.00, 478.5, {\"bi\", \"ky\"},\"st\"}, \n\n{1,  2, 0.3000, \
9.98, 864.7, {\"bi\", \"ky\"},\"st\"},  (* 10 kbar made to 9.98 kbar *)\n{1,  \
2, 0.3500, 9.98, 828.2, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4000, 9.98, \
790.9, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.4500, 9.98, 752.7, {\"bi\", \"ky\
\"},\"st\"}, \n{1,  2, 0.5000, 9.98, 713.5, {\"bi\", \"ky\"},\"st\"}, \n{1,  \
2, 0.5500, 9.98, 672.8, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6000, 9.98, \
630.3, {\"bi\", \"ky\"},\"st\"}, \n{1,  2, 0.6500, 9.98, 585.5, {\"bi\", \"ky\
\"},\"st\"}, \n{1,  2, 0.7000, 9.98, 537.8, {\"bi\", \"ky\"},\"st\"}, \n{1,  \
2, 0.7500, 9.98, 486.2, {\"bi\", \"ky\"},\"st\"}}, \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.2000, 5.00, \
642.3, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.2300, 5.00, 636.4, {\"st\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.2600, 5.00, 630.5, {\"st\", \"bi\"},\"sill\"}, \
\n{1,  2, 0.2900, 5.00, 624.4, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.3200, \
5.00, 618.2, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.3500, 5.00, 611.7, {\"st\
\", \"bi\"},\"sill\"}, \n{1,  2, 0.3800, 5.00, 605.0, {\"st\", \"bi\"},\"sill\
\"}, \n{1,  2, 0.4100, 5.00, 598.1, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, \
0.4400, 5.00, 590.9, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.4700, 5.00, \
583.5, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.5000, 5.00, 575.8, {\"st\", \
\"bi\"},\"sill\"}, \n\n{1,  2, 0.3600, 6.00, 646.2, {\"st\", \
\"bi\"},\"sill\"},   \n{1,  2, 0.3700, 6.00, 643.8, {\"st\", \
\"bi\"},\"sill\"},    \n{1,  2, 0.3800, 6.00, 641.4, {\"st\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.3900, 6.00, 639.1, {\"st\", \"bi\"},\"sill\
\"},   \n{1,  2, 0.4000, 6.00, 636.6, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, \
0.4100, 6.00, 634.2, {\"st\", \"bi\"},\"sill\"},  \n{1,  2, 0.4200, 6.00, \
631.7, {\"st\", \"bi\"},\"sill\"},  \n{1,  2, 0.4300, 6.00, 629.3, {\"st\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.4400, 6.00, 626.7, {\"st\", \"bi\"},\"sill\"}, \
    \n{1,  2, 0.4500, 6.00, 624.1, {\"st\", \"bi\"},\"sill\"},    \n{1,  2, \
0.4600, 6.00, 621.5, {\"st\", \"bi\"},\"sill\"},    \n\n{1,  2, 0.4600, 8.00, \
695.3, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.5000, 8.00, 683.8, {\"st\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.5400, 8.00, 671.6, {\"st\", \"bi\"},\"sill\"}, \
\n{1,  2, 0.5800, 8.00, 658.9, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.6200, \
8.00, 645.3, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.6600, 8.00, 631.1, {\"st\
\", \"bi\"},\"sill\"}, \n{1,  2, 0.7000, 8.00, 615.9, {\"st\", \"bi\"},\"sill\
\"},\n\n{1,  2, 0.7000, 9.98, 689.0, {\"st\", \"bi\"},\"sill\"}, (* 10 kbar \
made to 9.98 kbar *)\n{1,  2, 0.7200, 9.98, 680.6, {\"st\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.7400, 9.98, 672.0, {\"st\", \"bi\"},\"sill\"}, \
\n{1,  2, 0.7600, 9.98, 663.1, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.7800, \
9.98, 653.9, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.8000, 9.98, 644.3, {\"st\
\", \"bi\"},\"sill\"}, \n{1,  2, 0.8200, 9.98, 634.4, {\"st\", \"bi\"},\"sill\
\"}, \n{1,  2, 0.8400, 9.98, 624.1, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, \
0.8600, 9.98, 613.4, {\"st\", \"bi\"},\"sill\"}, \n{1,  2, 0.8800, 9.98, \
602.3, {\"st\", \"bi\"},\"sill\"}},  \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.2000, 5.00, \
646.4, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.2400, 5.00, 639.6, {\"bi\", \
\"sill\"},\"st\"}, \n{1,  2, 0.2800, 5.00, 632.5, {\"bi\", \"sill\"},\"st\"}, \
\n{1,  2, 0.3200, 5.00, 625.2, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.3600, \
5.00, 617.8, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.4000, 5.00, 609.8, {\"bi\
\", \"sill\"},\"st\"}, \n{1,  2, 0.4400, 5.00, 601.6, {\"bi\", \"sill\"},\"st\
\"}, \n{1,  2, 0.4800, 5.00, 593.2, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, \
0.5200, 5.00, 584.1, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.5600, 5.00, \
574.7, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.6000, 5.00, 564.7, {\"bi\", \
\"sill\"},\"st\"}, \n\n{1,  2, 0.4000, 6.00, 646.6, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.4100, 6.00, 644.4, {\"bi\", \
\"sill\"},\"st\"},     \n{1,  2, 0.4200, 6.00, 642.3, {\"bi\", \"sill\"},\"st\
\"},    \n{1,  2, 0.4300, 6.00, 640.1, {\"bi\", \"sill\"},\"st\"},  \n{1,  2, \
0.4400, 6.00, 637.9, {\"bi\", \"sill\"},\"st\"},  \n{1,  2, 0.4500, 6.00, \
635.7, {\"bi\", \"sill\"},\"st\"},     \n{1,  2, 0.4600, 6.00, 633.5, \
{\"bi\", \"sill\"},\"st\"},     \n{1,  2, 0.4700, 6.00, 631.2, {\"bi\", \
\"sill\"},\"st\"},    \n{1,  2, 0.4800, 6.00, 628.9, {\"bi\", \
\"sill\"},\"st\"},    \n{1,  2, 0.4900, 6.00, 626.6, {\"bi\", \
\"sill\"},\"st\"},  \n{1,  2, 0.5000, 6.00, 624.2, {\"bi\", \
\"sill\"},\"st\"}, \n{1,  2, 0.5100, 6.00, 621.9, {\"bi\", \"sill\"},\"st\"}, \
 \n\n{1,  2, 0.5200, 8.00, 692.7, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, \
0.5600, 8.00, 681.9, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.6000, 8.00, \
670.4, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.6400, 8.00, 658.4, {\"bi\", \
\"sill\"},\"st\"}, \n{1,  2, 0.6800, 8.00, 645.5, {\"bi\", \"sill\"},\"st\"}, \
\n{1,  2, 0.7200, 8.00, 631.7, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.7600, \
8.00, 616.7, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.8000, 8.00, 600.2, {\"bi\
\", \"sill\"},\"st\"}, \n\n{1,  2, 0.7400, 9.98, 696.4, {\"bi\", \
\"sill\"},\"st\"}, (* 10 kbar made to 9.98 kbar *)\n{1,  2, 0.7600, 9.98, \
688.2, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.7800, 9.98, 679.8, {\"bi\", \
\"sill\"},\"st\"}, \n{1,  2, 0.8000, 9.98, 670.8, {\"bi\", \"sill\"},\"st\"}, \
\n{1,  2, 0.8200, 9.98, 661.5, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.8400, \
9.98, 651.6, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, 0.8600, 9.98, 641.1, {\"bi\
\", \"sill\"},\"st\"}, \n{1,  2, 0.8800, 9.98, 629.8, {\"bi\", \"sill\"},\"st\
\"}, \n{1,  2, 0.9000, 9.98, 617.6, {\"bi\", \"sill\"},\"st\"}, \n{1,  2, \
0.9200, 9.98, 604.3, {\"bi\", \"sill\"},\"st\"}}, \n\n(* \
____________________________________________ *)\n\n{{1,  2, 0.1560, 5.00, \
680.2, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.1640, 5.00, 652.8, {\"g\", \"bi\
\"},\"sill\"}, \n{1,  2, 0.1720, 5.00, 627.0, {\"g\", \"bi\"},\"sill\"}, \n\
{1,  2, 0.1800, 5.00, 600.7, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.1880, \
5.00, 574.8, {\"g\", \"bi\"},\"sill\"}, \n\n{1,  2, 0.2210, 6.00, 651.2, {\"g\
\", \"bi\"},\"sill\"},   \n{1,  2, 0.2215, 6.00, 649.2, {\"g\", \
\"bi\"},\"sill\"},    \n{1,  2, 0.2220, 6.00, 647.3, {\"g\", \
\"bi\"},\"sill\"},      \n{1,  2, 0.2225, 6.00, 645.3, {\"g\", \"bi\"},\"sill\
\"},   \n{1,  2, 0.2230, 6.00, 643.3, {\"g\", \"bi\"},\"sill\"},   \n\n{1,  \
2, 0.3200, 8.00, 687.1, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.3240, 8.00, \
662.8, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.3280, 8.00, 638.7, {\"g\", \"bi\
\"},\"sill\"}, \n{1,  2, 0.3320, 8.00, 614.9, {\"g\", \"bi\"},\"sill\"}, \n\
{1,  2, 0.3360, 8.00, 591.6, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.3400, \
8.00, 568.7, {\"g\", \"bi\"},\"sill\"}, \n\n{1,  2, 0.4240, 10.00, 682.3, \
{\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.4260, 10.00, 656.9, {\"g\", \
\"bi\"},\"sill\"}, \n{1,  2, 0.4280, 10.00, 634.4, {\"g\", \"bi\"},\"sill\"}, \
\n{1,  2, 0.4300, 10.00, 611.6, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.4320, \
10.00, 589.2, {\"g\", \"bi\"},\"sill\"}, \n{1,  2, 0.4340, 10.00, 567.3, {\"g\
\", \"bi\"},\"sill\"}}, \n\n(* ____________________________________________ \
*)\n\n{{1,  2, 0.2800, 5.00, 692.1, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, \
0.3000, 5.00, 661.9, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.3200, 5.00, \
632.2, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.3400, 5.00, 603.0, {\"bi\", \
\"sill\"},\"g\"}, \n{1,  2, 0.3600, 5.00, 573.9, {\"bi\", \"sill\"},\"g\"}, \n\
{1,  2, 0.3800, 5.00, 547.2, {\"bi\", \"sill\"},\"g\"}, \n\n{1,  2, 0.4030, \
6.00, 651.4, {\"bi\", \"sill\"},\"g\"},  \n{1,  2, 0.4040, 6.00, 649.7, {\"bi\
\", \"sill\"},\"g\"},      \n{1,  2, 0.4050, 6.00, 648.0, {\"bi\", \"sill\"},\
\"g\"},    \n{1,  2, 0.4060, 6.00, 646.4, {\"bi\", \"sill\"},\"g\"},    \n{1, \
 2, 0.4070, 6.00, 644.7, {\"bi\", \"sill\"},\"g\"},   \n\n{1,  2, 0.5400, \
8.00, 698.2, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.5600, 8.00, 653.7, \
{\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.5800, 8.00, 614.0, {\"bi\", \"sill\"},\
\"g\"}, \n{1,  2, 0.6000, 8.00, 573.4, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, \
0.6200, 8.00, 538.0, {\"bi\", \"sill\"},\"g\"},  \n\n{1,  2, 0.6720, 10.00, \
689.3, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.6780, 10.00, 672.9, {\"bi\", \
\"sill\"},\"g\"}, \n{1,  2, 0.6840, 10.00, 656.4, {\"bi\", \"sill\"},\"g\"}, \
\n{1,  2, 0.6900, 10.00, 640.2, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.6960, \
10.00, 624.4, {\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.7020, 10.00, 608.7, \
{\"bi\", \"sill\"},\"g\"}, \n{1,  2, 0.7080, 10.00, 593.6, {\"bi\", \
\"sill\"},\"g\"}, \n{1,  2, 0.7140, 10.00, 578.7, {\"bi\", \"sill\"},\"g\"}}, \
\n\n(* ____________________________________________ *)\n\n{{1,  2, 0.1800, \
5.00, 540.4, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.1840, 5.00, 561.8, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.1880, 5.00, 583.2, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.1920, 5.00, 604.8, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.1960, 5.00, \
626.7, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2000, 5.00, 649.1, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.2040, 5.00, 672.4, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.2080, 5.00, 698.3, {\"g\", \"bi\"},\"ky\"},\n\n{1,  2, 0.2120, \
6.00, 555.5, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2180, 6.00, 580.5, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.2240, 6.00, 605.9, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.2300, 6.00, 631.6, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2360, 6.00, \
657.6, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2420, 6.00, 684.0, {\"g\", \
\"bi\"},\"ky\"},\n\n{1,  2, 0.2600, 8.00, 552.1, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.2660, 8.00, 569.1, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2720, 8.00, \
587.7, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2780, 8.00, 603.8, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.2840, 8.00, 621.8, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.2900, 8.00, 639.6, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.2960, 8.00, \
657.4, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3020, 8.00, 675.2, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.3080, 8.00, 693.1, {\"g\", \"bi\"},\"ky\"},   \n\
\n{1,  2, 0.3200, 10.00, 595.9, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3260, \
10.00, 609.1, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3320, 10.00, 622.4, \
{\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3380, 10.00, 635.7, {\"g\", \"bi\"},\"ky\
\"}, \n{1,  2, 0.3440, 10.00, 649.0, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, \
0.3500, 10.00, 662.3, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3560, 10.00, \
675.7, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3620, 10.00, 689.2, {\"g\", \
\"bi\"},\"ky\"},\n\n{1,  2, 0.3600, 12.00, 596.0, {\"g\", \"bi\"},\"ky\"}, \n\
{1,  2, 0.3660, 12.00, 606.4, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3720, \
12.00, 616.9, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3780, 12.00, 627.4, \
{\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.3840, 12.00, 638.7, {\"g\", \"bi\"},\"ky\
\"}, \n{1,  2, 0.3900, 12.00, 648.6, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, \
0.3960, 12.00, 659.2, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.4020, 12.00, \
669.9, {\"g\", \"bi\"},\"ky\"}, \n{1,  2, 0.4080, 12.00, 680.6, {\"g\", \
\"bi\"},\"ky\"}, \n{1,  2, 0.4140, 12.00, 691.3, {\"g\", \"bi\"},\"ky\"}},\n\n\
(* ____________________________________________ *)\n\n{{1,  2, 0.4180, 6.00, \
575.0, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.4184, 6.00, 585.2, {\"bi\", \
\"ky\"},\"g\"}, \n{1,  2, 0.4188, 6.00, 595.2, {\"bi\", \"ky\"},\"g\"}, \n{1, \
 2, 0.4192, 6.00, 604.5, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.4196, 6.00, \
613.9, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.4200, 6.00, 623.0, {\"bi\", \
\"ky\"},\"g\"}, \n{1,  2, 0.4204, 6.00, 632.0, {\"bi\", \"ky\"},\"g\"}, \n{1, \
 2, 0.4208, 6.00, 640.8, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.4212, 6.00, \
649.5, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.4216, 6.00, 658.3, {\"bi\", \
\"ky\"},\"g\"}, \n{1,  2, 0.4220, 6.00, 667.3, {\"bi\", \"ky\"},\"g\"}, \n\n\
{1,  2, 0.5180, 8.00, 529.7, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.5200, 8.00, \
564.0, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.5220, 8.00, 593.1, {\"bi\", \
\"ky\"},\"g\"}, \n{1,  2, 0.5240, 8.00, 619.0, {\"bi\", \"ky\"},\"g\"}, \n{1, \
 2, 0.5260, 8.00, 644.5, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.5280, 8.00, \
669.1, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.5300, 8.00, 691.2, {\"bi\", \
\"ky\"},\"g\"}, \n\n{1,  2, 0.6000, 10.00, 527.7, {\"bi\", \"ky\"},\"g\"}, \n\
{1,  2, 0.6020, 10.00, 552.5, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6040, \
10.00, 574.9, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6060, 10.00, 595.5, \
{\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6080, 10.00, 614.9, {\"bi\", \"ky\"},\"g\
\"}, \n{1,  2, 0.6100, 10.00, 633.2, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, \
0.6120, 10.00, 650.7, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6140, 10.00, \
667.6, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6160, 10.00, 684.0, {\"bi\", \"ky\
\"},\"g\"}, \n{1,  2, 0.6180, 10.00, 699.8, {\"bi\", \"ky\"},\"g\"}, \n\n{1,  \
2, 0.6720, 12.00, 572.9, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6740, 12.00, \
589.3, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6760, 12.00, 605.6, {\"bi\", \"ky\
\"},\"g\"}, \n{1,  2, 0.6780, 12.00, 620.2, {\"bi\", \"ky\"},\"g\"}, \n{1,  \
2, 0.6800, 12.00, 635.6, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6820, 12.00, \
649.1, {\"bi\", \"ky\"},\"g\"}, \n{1,  2, 0.6840, 12.00, 662.9, {\"bi\", \"ky\
\"},\"g\"}, \n{1,  2, 0.6860, 12.00, 676.3, {\"bi\", \"ky\"},\"g\"}, \n{1,  \
2, 0.6880, 12.00, 689.2, {\"bi\", \"ky\"},\"g\"}} };      ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  " ",
  StyleBox["manually inserted numbers in same form as provided...",
    FontSize->12,
    FontColor->RGBColor[0, 1, 0]]
}], "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["allqlines = {\n{{1,  2,   ",
    FontWeight->"Plain"],
  StyleBox["-2,  5.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      5.00, 522.5, {\"chl\"},\"g\
\"}, \n{1,  2, 0.0500, 5.00, 528.5, {\"chl\"},\"g\"}, \n{1,  2, 0.1000, 5.00, \
534.8, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 5.00, 541.5, {\"chl\"},\"g\"}, \n\
{1,  2, 0.2000, 5.00, 548.5, {\"chl\"},\"g\"}, \n{1,  2, 0.2500, 5.00, 556.1, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3000, 5.00, 564.0, {\"chl\"},\"g\"}, \n{1,  2, \
0.3500, 5.00, 572.6, {\"chl\"},\"g\"}, \n{1,  2, 0.4000, 5.00, 581.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.4500, 5.00, 591.5, {\"chl\"},\"g\"}, \n{1,  2, \
0.5000, 5.00, 601.9, {\"chl\"},\"g\"}, \n{1,  2, 0.5500, 5.00, 613.2, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6000, 5.00, 625.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.6500, 5.00, 638.5, {\"chl\"},\"g\"}, \n{1,  2, 0.7000, 5.00, 652.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.7500, 5.00, 668.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.8000, 5.00, 685.3, {\"chl\"},\"g\"}, \n\n{1,  2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  6.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      6.00, 521.8, {\"chl\"},\"g\
\"}, \n{1,  2, 0.0500, 6.00, 527.9, {\"chl\"},\"g\"}, \n{1,  2, 0.1000, 6.00, \
534.4, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 6.00, 541.2, {\"chl\"},\"g\"}, \n\
{0,  2, 0.1785, 6.00, 545.3, {\"chl\"},\"g\"},   (*****)\n{1,  2, 0.2000, \
6.00, 548.5, {\"chl\"},\"g\"}, \n{1,  2, 0.2500, 6.00, 556.2, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3000, 6.00, 564.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.3500, 6.00, 573.1, {\"chl\"},\"g\"}, \n{1,  2, 0.4000, 6.00, 582.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.4500, 6.00, 592.4, {\"chl\"},\"g\"}, \n{1,  2, \
0.5000, 6.00, 603.2, {\"chl\"},\"g\"}, \n{1,  2, 0.5500, 6.00, 614.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6000, 6.00, 627.2, {\"chl\"},\"g\"}, \n{1,  2, \
0.6500, 6.00, 640.7, {\"chl\"},\"g\"}, \n{1,  2, 0.7000, 6.00, 655.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.7500, 6.00, 671.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.8000, 6.00, 688.6, {\"chl\"},\"g\"}, \n\n{1,  2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  7.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      7.00, 520.0, {\"chl\"},\"g\
\"}, \n{1,  2, 0.0500, 7.00, 526.2, {\"chl\"},\"g\"}, \n{1,  2, 0.1000, 7.00, \
532.8, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 7.00, 539.7, {\"chl\"},\"g\"}, \n\
{1,  2, 0.2000, 7.00, 547.1, {\"chl\"},\"g\"}, \n{1,  2, 0.2500, 7.00, 555.0, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3000, 7.00, 563.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.3500, 7.00, 572.3, {\"chl\"},\"g\"}, \n{1,  2, 0.4000, 7.00, 581.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.4500, 7.00, 592.1, {\"chl\"},\"g\"}, \n{1,  2, \
0.5000, 7.00, 603.0, {\"chl\"},\"g\"}, \n{1,  2, 0.5500, 7.00, 614.9, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6000, 7.00, 627.6, {\"chl\"},\"g\"}, \n{1,  2, \
0.6500, 7.00, 641.4, {\"chl\"},\"g\"}, \n{1,  2, 0.7000, 7.00, 656.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.7500, 7.00, 672.6, {\"chl\"},\"g\"}, \n{1,  2, \
0.8000, 7.00, 690.3, {\"chl\"},\"g\"}, \n\n{1,  2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  8.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      8.00, 517.2, {\"chl\"},\"g\
\"}, \n{1,  2, 0.0500, 8.00, 523.5, {\"chl\"},\"g\"}, \n{1,  2, 0.1000, 8.00, \
530.2, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 8.00, 537.3, {\"chl\"},\"g\"}, \n\
{1,  2, 0.2000, 8.00, 544.8, {\"chl\"},\"g\"}, \n{1,  2, 0.2500, 8.00, 552.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3000, 8.00, 561.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.3500, 8.00, 570.4, {\"chl\"},\"g\"}, \n{1,  2, 0.4000, 8.00, 580.1, \
{\"chl\"},\"g\"}, \n{1,  2, 0.4500, 8.00, 590.5, {\"chl\"},\"g\"}, \n{1,  2, \
0.5000, 8.00, 601.7, {\"chl\"},\"g\"}, \n{1,  2, 0.5500, 8.00, 613.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6000, 8.00, 626.7, {\"chl\"},\"g\"}, \n{1,  2, \
0.6500, 8.00, 640.8, {\"chl\"},\"g\"}, \n{1,  2, 0.7000, 8.00, 656.1, \
{\"chl\"},\"g\"}, \n{1,  2, 0.7500, 8.00, 672.6, {\"chl\"},\"g\"}, \n{1,  2, \
0.8000, 8.00, 690.6, {\"chl\"},\"g\"}, \n\n{1,  2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  9.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      9.00, 513.6, {\"chl\"},\"g\
\"}, \n{1,  2, 0.0500, 9.00, 520.0, {\"chl\"},\"g\"}, \n{1,  2, 0.1000, 9.00, \
526.8, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 9.00, 534.0, {\"chl\"},\"g\"}, \n\
{1,  2, 0.2000, 9.00, 541.6, {\"chl\"},\"g\"}, \n{1,  2, 0.2500, 9.00, 549.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3000, 9.00, 558.4, {\"chl\"},\"g\"}, \n{1,  2, \
0.3500, 9.00, 567.6, {\"chl\"},\"g\"}, \n{1,  2, 0.4000, 9.00, 577.5, \
{\"chl\"},\"g\"}, \n{1,  2, 0.4500, 9.00, 588.0, {\"chl\"},\"g\"}, \n{1,  2, \
0.5000, 9.00, 599.4, {\"chl\"},\"g\"}, \n{1,  2, 0.5500, 9.00, 611.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6000, 9.00, 624.9, {\"chl\"},\"g\"}, \n{1,  2, \
0.6500, 9.00, 639.2, {\"chl\"},\"g\"}, \n{1,  2, 0.7000, 9.00, 654.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.7500, 9.00, 671.5, {\"chl\"},\"g\"}, \n{1,  2, \
0.8000, 9.00, 689.8, {\"chl\"},\"g\"}, \n\n{1,  2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  10.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      10.00, 509.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.0500, 10.00, 515.9, {\"chl\"},\"g\"}, \n{1,  2, \
0.1000, 10.00, 522.8, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 10.00, 530.0, \
{\"chl\"},\"g\"}, \n{1,  2, 0.2000, 10.00, 537.7, {\"chl\"},\"g\"}, \n{1,  2, \
0.2500, 10.00, 546.0, {\"chl\"},\"g\"}, \n{1,  2, 0.3000, 10.00, 554.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3500, 10.00, 564.1, {\"chl\"},\"g\"}, \n{1,  2, \
0.4000, 10.00, 574.0, {\"chl\"},\"g\"}, \n{1,  2, 0.4500, 10.00, 584.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.5000, 10.00, 596.3, {\"chl\"},\"g\"}, \n{1,  2, \
0.5500, 10.00, 608.8, {\"chl\"},\"g\"}, \n{1,  2, 0.6000, 10.00, 622.2, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6500, 10.00, 636.7, {\"chl\"},\"g\"}, \n{1,  2, \
0.7000, 10.00, 652.4, {\"chl\"},\"g\"}, \n{1,  2, 0.7500, 10.00, 669.5, \
{\"chl\"},\"g\"}, \n{1,  2, 0.8000, 10.00, 688.1, {\"chl\"},\"g\"}, \n\n{1,  \
2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  11.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2, 0,      11.00, 504.6, \
{\"chl\"},\"g\"}, \n{1,  2, 0.0500, 11.00, 511.2, {\"chl\"},\"g\"}, \n{1,  2, \
0.1000, 11.00, 518.1, {\"chl\"},\"g\"}, \n{1,  2, 0.1500, 11.00, 525.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.2000, 11.00, 533.2, {\"chl\"},\"g\"}, \n{1,  2, \
0.2500, 11.00, 541.6, {\"chl\"},\"g\"}, \n{1,  2, 0.3000, 11.00, 550.4, \
{\"chl\"},\"g\"}, \n{1,  2, 0.3500, 11.00, 559.9, {\"chl\"},\"g\"}, \n{1,  2, \
0.4000, 11.00, 570.0, {\"chl\"},\"g\"}, \n{1,  2, 0.4500, 11.00, 580.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.5000, 11.00, 592.5, {\"chl\"},\"g\"}, \n{1,  2, \
0.5500, 11.00, 605.1, {\"chl\"},\"g\"}, \n{1,  2, 0.6000, 11.00, 618.7, \
{\"chl\"},\"g\"}, \n{1,  2, 0.6500, 11.00, 633.5, {\"chl\"},\"g\"}, \n{1,  2, \
0.7000, 11.00, 649.4, {\"chl\"},\"g\"}, \n{1,  2, 0.7500, 11.00, 666.8, \
{\"chl\"},\"g\"}, \n{1,  2, 0.8000, 11.00, 685.6, {\"chl\"},\"g\"}, \n\n{1,  \
2,    ",
    FontWeight->"Plain"],
  StyleBox["-2,  12.00, 400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[",   {\"chl\"},\"g\"},\n{1,  2,      0, 12.00, 499.3, \
{\"chl\"},\"g\"}, \n{1,  2, 0.1000, 12.00, 512.9, {\"chl\"},\"g\"}, \n{1,  2, \
0.2000, 12.00, 528.2, {\"chl\"},\"g\"}, \n{1,  2, 0.3000, 12.00, 545.5, \
{\"chl\"},\"g\"},   \n{1,  2, 0.4000, 12.00, 565.3, {\"chl\"},\"g\"},  \n{1,  \
2, 0.5000, 12.00, 588.1, {\"chl\"},\"g\"},    \n{1,  2, 0.6000, 12.00, 614.7, \
{\"chl\"},\"g\"},  \n{1,  2, 0.7000, 12.00, 645.8, {\"chl\"},\"g\"}, \n{1,  \
2, 0.8000, 12.00, 682.3, {\"chl\"},\"g\"}},   \n\n(* \
_______________________________________ *) \n\n\n{{1,  2, 0,     5.00, 525.8, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.0500, 5.00, 525.4, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1000, 5.00, 525.0, {\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 5.00, 524.6, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 5.00, 524.0, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.2500, 5.00, 523.5, {\"chl\"},\"bi\"}, \n{1,  2, 0.3000, 5.00, 522.8, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 5.00, 522.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4000, 5.00, 521.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.4500, 5.00, 520.4, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 5.00, 519.4, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.5500, 5.00, 518.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.6000, 5.00, 517.1, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 5.00, 515.7, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7000, 5.00, 514.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.7500, 5.00, 512.7, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 5.00, 511.0, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.8500, 5.00, 508.9, {\"chl\"},\"bi\"}, \n{1,  2, 0.9000, 5.00, 507.0, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 5.00, 504.7, {\"chl\"},\"bi\"}, \n{1,  \
2, 1.0000, 5.00, 502.1, {\"chl\"},\"bi\"}, \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 5.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0.0500, 6.00, 546.9, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.1000, 6.00, 546.3, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1500, 6.00, 545.7, {\"chl\"},\"bi\"}, \n{0,  2, 0.1785, 6.00, 545.3, \
{\"chl\"},\"bi\"},    (*****)\n{1,  2, 0.2000, 6.00, 545.0, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.2500, 6.00, 544.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.3000, 6.00, 543.4, {\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 6.00, 542.4, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.4000, 6.00, 541.4, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4500, 6.00, 540.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 6.00, 539.1, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.5500, 6.00, 537.8, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.6000, 6.00, 536.4, {\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 6.00, 534.8, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.7000, 6.00, 533.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7500, 6.00, 531.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 6.00, 529.3, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.8500, 6.00, 527.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.9000, 6.00, 524.7, {\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 6.00, 522.1, \
{\"chl\"},\"bi\"}, \n{1,  2, 1.0000, 6.00, 519.2, {\"chl\"},\"bi\"}, \n{1,  \
2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 6.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0,      7.00, 568.8, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.0500, 7.00, 568.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1000, 7.00, 567.4, {\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 7.00, 566.6, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 7.00, 565.7, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.2500, 7.00, 564.7, {\"chl\"},\"bi\"}, \n{1,  2, 0.3000, 7.00, 563.7, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 7.00, 562.6, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4000, 7.00, 561.4, {\"chl\"},\"bi\"}, \n{1,  2, 0.4500, 7.00, 560.0, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 7.00, 558.6, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.5500, 7.00, 557.1, {\"chl\"},\"bi\"}, \n{1,  2, 0.6000, 7.00, 555.4, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 7.00, 553.6, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7000, 7.00, 551.6, {\"chl\"},\"bi\"}, \n{1,  2, 0.7500, 7.00, 549.6, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 7.00, 547.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.8500, 7.00, 544.8, {\"chl\"},\"bi\"}, \n{1,  2, 0.9000, 7.00, 542.1, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 7.00, 539.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 1.0000, 7.00, 536.0, {\"chl\"},\"bi\"}, \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 7.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0,      8.00, 590.1, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.0500, 8.00, 589.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1000, 8.00, 588.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 8.00, 587.4, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 8.00, 586.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.2500, 8.00, 585.1, {\"chl\"},\"bi\"}, \n{1,  2, 0.3000, 8.00, 583.9, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 8.00, 582.5, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4000, 8.00, 581.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.4500, 8.00, 579.6, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 8.00, 577.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.5500, 8.00, 576.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.6000, 8.00, 574.2, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 8.00, 572.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7000, 8.00, 570.0, {\"chl\"},\"bi\"}, \n{1,  2, 0.7500, 8.00, 567.6, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 8.00, 565.0, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.8500, 8.00, 562.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.9000, 8.00, 559.3, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 8.00, 556.0, {\"chl\"},\"bi\"}, \n{1,  \
2, 1.0000, 8.00, 552.5, {\"chl\"},\"bi\"}, \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 8.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0,      9.00, 611.3, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.0500, 9.00, 610.3, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1000, 9.00, 609.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 9.00, 608.0, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 9.00, 606.7, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.2500, 9.00, 605.4, {\"chl\"},\"bi\"}, \n{1,  2, 0.3000, 9.00, 603.9, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 9.00, 602.5, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4000, 9.00, 600.7, {\"chl\"},\"bi\"}, \n{1,  2, 0.4500, 9.00, 599.0, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 9.00, 597.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.5500, 9.00, 595.1, {\"chl\"},\"bi\"}, \n{1,  2, 0.6000, 9.00, 592.9, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 9.00, 590.6, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7000, 9.00, 588.1, {\"chl\"},\"bi\"}, \n{1,  2, 0.7500, 9.00, 585.5, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 9.00, 582.6, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.8500, 9.00, 579.6, {\"chl\"},\"bi\"}, \n{1,  2, 0.9000, 9.00, 576.2, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 9.00, 572.7, {\"chl\"},\"bi\"}, \n{1,  \
2, 1.0000, 9.00, 568.9, {\"chl\"},\"bi\"}, \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 9.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0,      10.00, 632.5, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.0500, 10.00, 631.3, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1000, 10.00, 630.0, {\"chl\"},\"bi\"}, \n{1,  2, 0.1500, 10.00, 628.6, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 10.00, 627.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.2500, 10.00, 625.6, {\"chl\"},\"bi\"}, \n{1,  2, 0.3000, 10.00, 624.0, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 10.00, 622.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4000, 10.00, 620.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.4500, 10.00, 618.4, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 10.00, 616.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.5500, 10.00, 614.0, {\"chl\"},\"bi\"}, \n{1,  2, 0.6000, 10.00, 611.6, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 10.00, 608.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7000, 10.00, 606.2, {\"chl\"},\"bi\"}, \n{1,  2, 0.7500, 10.00, 603.2, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 10.00, 600.1, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.8500, 10.00, 596.8, {\"chl\"},\"bi\"}, \n{1,  2, 0.9000, 10.00, 593.1, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 10.00, 589.3, {\"chl\"},\"bi\"}, \n{1,  \
2, 1.0000, 10.00, 585.1, {\"chl\"},\"bi\"}, \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 10.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0.0500, 11.00, 652.4, \
{\"chl\"},\"bi\"}, \n{1,  2, 0.1000, 11.00, 650.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.1500, 11.00, 649.3, {\"chl\"},\"bi\"}, \n{1,  2, 0.2000, 11.00, 647.6, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.2500, 11.00, 645.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.3000, 11.00, 644.0, {\"chl\"},\"bi\"}, \n{1,  2, 0.3500, 11.00, 642.0, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.4000, 11.00, 639.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.4500, 11.00, 637.7, {\"chl\"},\"bi\"}, \n{1,  2, 0.5000, 11.00, 635.3, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.5500, 11.00, 632.8, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.6000, 11.00, 630.1, {\"chl\"},\"bi\"}, \n{1,  2, 0.6500, 11.00, 627.3, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.7000, 11.00, 624.2, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.7500, 11.00, 620.9, {\"chl\"},\"bi\"}, \n{1,  2, 0.8000, 11.00, 617.5, {\
\"chl\"},\"bi\"}, \n{1,  2, 0.8500, 11.00, 613.9, {\"chl\"},\"bi\"}, \n{1,  \
2, 0.9000, 11.00, 609.9, {\"chl\"},\"bi\"}, \n{1,  2, 0.9500, 11.00, 605.8, {\
\"chl\"},\"bi\"}, \n{1,  2, 1.0000, 11.00, 601.3, {\"chl\"},\"bi\"}, \n{1,  \
2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 11.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"},\n\n{1,  2, 0,      12.00, 675.2, \
{\"chl\"},\"bi\"},     \n{1,  2, 0.1000, 12.00, 671.9, {\"chl\"},\"bi\"},   \n\
{1,  2, 0.2000, 12.00, 668.2, {\"chl\"},\"bi\"},   \n{1,  2, 0.3000, 12.00, \
664.1, {\"chl\"},\"bi\"},\n{1,  2, 0.4000, 12.00, 659.5, {\"chl\"},\"bi\"},   \
\n{1,  2, 0.5000, 12.00, 654.4, {\"chl\"},\"bi\"},  \n{1,  2, 0.6000, 12.00, \
648.7, {\"chl\"},\"bi\"},    \n{1,  2, 0.7000, 12.00, 642.2, \
{\"chl\"},\"bi\"},   \n{1,  2, 0.8000, 12.00, 635.0, {\"chl\"},\"bi\"},   \n\
{1,  2, 0.9000, 12.00, 626.7, {\"chl\"},\"bi\"},     \n{1,  2, 1.0000, 12.00, \
617.4, {\"chl\"},\"bi\"},\n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["3, 12.00, 400.0",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[", {\"chl\"},\"bi\"}},  ",
    FontWeight->"Plain"],
  StyleBox["(* manual addition *)\n\n{",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["{1,  2, 0,      7.51, 529.7, {\"g\"},\"chl\"}, \n{1,  2, 0.0100, \
7.51, 536.5, {\"g\"},\"chl\"}, \n{1,  2, 0.0200, 7.51, 542.9, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0300, 7.51, 549.0, {\"g\"},\"chl\"}, \n{1,  2, \
0.0400, 7.51, 554.8, {\"g\"},\"chl\"}, \n{1,  2, 0.0500, 7.51, 560.4, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0600, 7.51, 565.8, {\"g\"},\"chl\"}, \n{1,  2, \
0.0700, 7.51, 570.9, {\"g\"},\"chl\"}, \n{1,  2, 0.0800, 7.51, 575.8, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0900, 7.51, 580.7, {\"g\"},\"chl\"}, \n{1,  2, \
0.1000, 7.51, 585.3, {\"g\"},\"chl\"},\n\n{1,  2, 0,      8.00, 528.0, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0150, 8.00, 538.2, {\"g\"},\"chl\"}, \n{1,  2, \
0.0300, 8.00, 547.6, {\"g\"},\"chl\"}, \n{1,  2, 0.0450, 8.00, 556.3, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0600, 8.00, 564.5, {\"g\"},\"chl\"}, \n{1,  2, \
0.0750, 8.00, 572.2, {\"g\"},\"chl\"}, \n{1,  2, 0.0900, 8.00, 579.5, \
{\"g\"},\"chl\"}, \n{1,  2, 0.1050, 8.00, 586.4, {\"g\"},\"chl\"}, \n{1,  2, \
0.1200, 8.00, 593.1, {\"g\"},\"chl\"}, \n{1,  2, 0.1350, 8.00, 599.4, \
{\"g\"},\"chl\"}, \n{1,  2, 0.1500, 8.00, 605.5, {\"g\"},\"chl\"}, \n\n{1,  \
2,      0, 9.00, 524.1, {\"g\"},\"chl\"}, \n{1,  2, 0.0050, 9.00, 527.6, {\"g\
\"},\"chl\"}, \n{1,  2, 0.0100, 9.00, 531.1, {\"g\"},\"chl\"}, \n{1,  2, \
0.0150, 9.00, 534.4, {\"g\"},\"chl\"}, \n{1,  2, 0.0200, 9.00, 537.7, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0250, 9.00, 540.9, {\"g\"},\"chl\"}, \n{1,  2, \
0.0300, 9.00, 544.0, {\"g\"},\"chl\"}, \n{1,  2, 0.0350, 9.00, 547.0, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0400, 9.00, 550.0, {\"g\"},\"chl\"}, \n{1,  2, \
0.0450, 9.00, 552.9, {\"g\"},\"chl\"}, \n{1,  2, 0.0500, 9.00, 555.7, \
{\"g\"},\"chl\"}, \n\n{1,  2,      0, 10.00, 519.4, {\"g\"},\"chl\"}, \n{1,  \
2, 0.0200, 10.00, 533.3, {\"g\"},\"chl\"}, \n{1,  2, 0.0400, 10.00, 545.8, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0600, 10.00, 557.2, {\"g\"},\"chl\"}, \n{1,  2, \
0.0800, 10.00, 567.8, {\"g\"},\"chl\"}, \n{1,  2, 0.1000, 10.00, 577.6, \
{\"g\"},\"chl\"}, \n{1,  2, 0.1200, 10.00, 586.8, {\"g\"},\"chl\"}, \n\n{1,  \
2, 0,      11.00, 514.1, {\"g\"},\"chl\"}, \n{1,  2, 0.0120, 11.00, 522.9, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0240, 11.00, 531.0, {\"g\"},\"chl\"}, \n{1,  2, \
0.0360, 11.00, 538.7, {\"g\"},\"chl\"}, \n{1,  2, 0.0480, 11.00, 545.9, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0600, 11.00, 552.7, {\"g\"},\"chl\"}, \n{1,  2, \
0.0720, 11.00, 559.2, {\"g\"},\"chl\"}, \n{1,  2, 0.0840, 11.00, 565.4, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0960, 11.00, 571.4, {\"g\"},\"chl\"}, \n{1,  2, \
0.1080, 11.00, 577.1, {\"g\"},\"chl\"}, \n{1,  2, 0.1200, 11.00, 582.6, \
{\"g\"},\"chl\"}, \n\n{1,  2, 0, 12.00, 508.4, {\"g\"},\"chl\"}, \n{1,  2, \
0.0200, 12.00, 522.9, {\"g\"},\"chl\"}, \n{1,  2, 0.0400, 12.00, 535.9, \
{\"g\"},\"chl\"}, \n{1,  2, 0.0600, 12.00, 547.7, {\"g\"},\"chl\"}, \n{1,  2, \
0.0800, 12.00, 558.5, {\"g\"},\"chl\"}, \n{1,  2, 0.1000, 12.00, 568.6, \
{\"g\"},\"chl\"}, \n{1,  2, 0.1200, 12.00, 578.0, {\"g\"},\"chl\"}, \n{1,  2, \
0.1400, 12.00, 586.9, {\"g\"},\"chl\"}, \n{1,  2, 0.1600, 12.00, 595.3, \
{\"g\"},\"chl\"}, \n{1,  2, 0.1800, 12.00, 603.3, {\"g\"},\"chl\"}, \n{1,  2, \
0.2000, 12.00, 610.9, {\"g\"},\"chl\"}},\n\n{{1,  2, 0, 7.51, 400, \
{\"g\"},\"bi\"},\n {1,  2, 0, 7.51, 800, {\"g\"},\"bi\"},\n \n {1,  2, \
0.0142, 8, 400, {\"g\"},\"bi\"},\n {1,  2, 0.0142, 8, 800, {\"g\"},\"bi\"},\n \
\n {1,  2, 0.0456, 9, 400, {\"g\"},\"bi\"},\n {1,  2, 0.0456, 9, 800, \
{\"g\"},\"bi\"},\n \n {1,  2, 0.0804, 10, 400, {\"g\"},\"bi\"},\n {1,  2, \
0.0804, 10, 800, {\"g\"},\"bi\"},\n \n {1,  2, 0.1186, 11, 400, \
{\"g\"},\"bi\"},\n {1,  2, 0.1186, 11, 800, {\"g\"},\"bi\"},\n \n {1,  2, \
0.1604, 12, 400, {\"g\"},\"bi\"},\n {1,  2, 0.1604, 12, 800, \
{\"g\"},\"bi\"}},\n \n{{1,  2, -1, 7.51, 400, {\"g\"},\"Q\"},\n {1,  2, -1, \
7.51, 800, {\"g\"},\"Q\"},\n \n {1,  2, -1, 8, 400, {\"g\"},\"Q\"},\n {1,  2, \
-1, 8, 800, {\"g\"},\"Q\"},\n \n {1,  2, -1, 9, 400, {\"g\"},\"Q\"},\n {1,  \
2, -1, 9, 800, {\"g\"},\"Q\"},\n \n {1,  2, -1, 10, 400, {\"g\"},\"Q\"},\n \
{1,  2, -1, 10, 800, {\"g\"},\"Q\"},\n \n {1,  2, -1, 11, 400, \
{\"g\"},\"Q\"},\n {1,  2, -1, 11, 800, {\"g\"},\"Q\"},\n \n {1,  2, -1, 12, \
400, {\"g\"},\"Q\"},\n {1,  2, -1, 12, 800, {\"g\"},\"Q\"}} }; ",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["assembling data", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setupvx;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["plotting", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
top = 650; bottom = 510; left = 0; right = 1;   
delv = 4;  debugit = False;
makevx[8.5];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% PlotRegion
.05 .95 .05 .95 MPlotRegion
% Scaling calculations
-0 1 -3.64286 0.00714286 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(520)] -0.0125 .07143 1 0 Msboxa
[(540)] -0.0125 .21429 1 0 Msboxa
[(560)] -0.0125 .35714 1 0 Msboxa
[(580)] -0.0125 .5 1 0 Msboxa
[(600)] -0.0125 .64286 1 0 Msboxa
[(620)] -0.0125 .78571 1 0 Msboxa
[(640)] -0.0125 .92857 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .07143 m
.00625 .07143 L
s
P
[(520)] -0.0125 .07143 1 0 Mshowa
p
.002 w
0 .21429 m
.00625 .21429 L
s
P
[(540)] -0.0125 .21429 1 0 Mshowa
p
.002 w
0 .35714 m
.00625 .35714 L
s
P
[(560)] -0.0125 .35714 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(580)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .64286 m
.00625 .64286 L
s
P
[(600)] -0.0125 .64286 1 0 Mshowa
p
.002 w
0 .78571 m
.00625 .78571 L
s
P
[(620)] -0.0125 .78571 1 0 Mshowa
p
.002 w
0 .92857 m
.00625 .92857 L
s
P
[(640)] -0.0125 .92857 1 0 Mshowa
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .12857 m
.00375 .12857 L
s
P
p
.001 w
0 .15714 m
.00375 .15714 L
s
P
p
.001 w
0 .18571 m
.00375 .18571 L
s
P
p
.001 w
0 .24286 m
.00375 .24286 L
s
P
p
.001 w
0 .27143 m
.00375 .27143 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .32857 m
.00375 .32857 L
s
P
p
.001 w
0 .38571 m
.00375 .38571 L
s
P
p
.001 w
0 .41429 m
.00375 .41429 L
s
P
p
.001 w
0 .44286 m
.00375 .44286 L
s
P
p
.001 w
0 .47143 m
.00375 .47143 L
s
P
p
.001 w
0 .52857 m
.00375 .52857 L
s
P
p
.001 w
0 .55714 m
.00375 .55714 L
s
P
p
.001 w
0 .58571 m
.00375 .58571 L
s
P
p
.001 w
0 .61429 m
.00375 .61429 L
s
P
p
.001 w
0 .67143 m
.00375 .67143 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .72857 m
.00375 .72857 L
s
P
p
.001 w
0 .75714 m
.00375 .75714 L
s
P
p
.001 w
0 .81429 m
.00375 .81429 L
s
P
p
.001 w
0 .84286 m
.00375 .84286 L
s
P
p
.001 w
0 .87143 m
.00375 .87143 L
s
P
p
.001 w
0 .9 m
.00375 .9 L
s
P
p
.001 w
0 .04286 m
.00375 .04286 L
s
P
p
.001 w
0 .01429 m
.00375 .01429 L
s
P
p
.001 w
0 .95714 m
.00375 .95714 L
s
P
p
.001 w
0 .98571 m
.00375 .98571 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .07143 m
1 .07143 L
s
P
p
.002 w
.99375 .21429 m
1 .21429 L
s
P
p
.002 w
.99375 .35714 m
1 .35714 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .64286 m
1 .64286 L
s
P
p
.002 w
.99375 .78571 m
1 .78571 L
s
P
p
.002 w
.99375 .92857 m
1 .92857 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .12857 m
1 .12857 L
s
P
p
.001 w
.99625 .15714 m
1 .15714 L
s
P
p
.001 w
.99625 .18571 m
1 .18571 L
s
P
p
.001 w
.99625 .24286 m
1 .24286 L
s
P
p
.001 w
.99625 .27143 m
1 .27143 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .32857 m
1 .32857 L
s
P
p
.001 w
.99625 .38571 m
1 .38571 L
s
P
p
.001 w
.99625 .41429 m
1 .41429 L
s
P
p
.001 w
.99625 .44286 m
1 .44286 L
s
P
p
.001 w
.99625 .47143 m
1 .47143 L
s
P
p
.001 w
.99625 .52857 m
1 .52857 L
s
P
p
.001 w
.99625 .55714 m
1 .55714 L
s
P
p
.001 w
.99625 .58571 m
1 .58571 L
s
P
p
.001 w
.99625 .61429 m
1 .61429 L
s
P
p
.001 w
.99625 .67143 m
1 .67143 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .72857 m
1 .72857 L
s
P
p
.001 w
.99625 .75714 m
1 .75714 L
s
P
p
.001 w
.99625 .81429 m
1 .81429 L
s
P
p
.001 w
.99625 .84286 m
1 .84286 L
s
P
p
.001 w
.99625 .87143 m
1 .87143 L
s
P
p
.001 w
.99625 .9 m
1 .9 L
s
P
p
.001 w
.99625 .04286 m
1 .04286 L
s
P
p
.001 w
.99625 .01429 m
1 .01429 L
s
P
p
.001 w
.99625 .95714 m
1 .95714 L
s
P
p
.001 w
.99625 .98571 m
1 .98571 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
1 .7 .7 r
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
F
P
p
1 .55 .55 r
p
0 0 m
0 .03875 L
.03303 .06811 L
.06478 .09746 L
.09527 .12682 L
.12457 .15617 L
.15277 .18553 L
.17996 .21488 L
.2062 .24424 L
.23188 .27359 L
.25683 .30295 L
.281 .3323 L
.30443 .36166 L
.32714 .39101 L
.34916 .42037 L
.37054 .44972 L
.39138 .47908 L
.41166 .50843 L
.43137 .53779 L
.45053 .56714 L
.4293 .56714 L
.54952 .53789 L
.65379 .50863 L
.74395 .47937 L
.82183 .45012 L
.88925 .42086 L
.94803 .3916 L
1 .36235 L
1 0 L
0 0 L
F
0 .11464 m
.00704 .14942 L
.01435 .1842 L
.02207 .21898 L
.03017 .25376 L
.0299 .25376 L
.0299 .28246 L
.0299 .31116 L
.0299 .33986 L
.0299 .36856 L
.0299 .39727 L
.0299 .42597 L
.0299 .45467 L
.0299 .48337 L
.0299 .51207 L
.0299 .54077 L
.0299 .56948 L
.0299 .59818 L
.0299 .62688 L
.0299 .65558 L
.0299 .68428 L
.0299 .71298 L
.0299 .74169 L
.0299 .77039 L
.0299 .79909 L
.0299 .82779 L
.0299 .85649 L
.0299 .88519 L
.0299 .9139 L
.0299 .9426 L
.0299 .9713 L
.0299 1 L
0 1 L
0 0 L
0 .11464 L
F
P
0 g
p
.004 w
0 0 m
0 0 rlineto
0 .03875 m
.03303 .06811 L
s
.03303 .06811 m
.06478 .09746 L
.09527 .12682 L
.12457 .15617 L
.15277 .18553 L
.17996 .21488 L
.2062 .24424 L
.23188 .27359 L
.25683 .30295 L
.281 .3323 L
.30443 .36166 L
.32714 .39101 L
.34916 .42037 L
.37054 .44972 L
.39138 .47908 L
.41166 .50843 L
.43137 .53779 L
.45053 .56714 L
.4293 .56714 L
.54952 .53789 L
.65379 .50863 L
.74395 .47937 L
.82183 .45012 L
.88925 .42086 L
.94803 .3916 L
1 .36235 L
1 0 L
0 0 L
s
0 .11464 m
.00704 .14942 L
.01435 .1842 L
.02207 .21898 L
.03017 .25376 L
.0299 .25376 L
.0299 .28246 L
.0299 .31116 L
.0299 .33986 L
.0299 .36856 L
.0299 .39727 L
.0299 .42597 L
.0299 .45467 L
.0299 .48337 L
.0299 .51207 L
.0299 .54077 L
.0299 .56948 L
.0299 .59818 L
.0299 .62688 L
.0299 .65558 L
.0299 .68428 L
.0299 .71298 L
.0299 .74169 L
.0299 .77039 L
.0299 .79909 L
.0299 .82779 L
.0299 .85649 L
.0299 .88519 L
.0299 .9139 L
.0299 .9426 L
.0299 .9713 L
.0299 1 L
0 1 L
0 0 L
0 .11464 L
s
P
P
p
1 g
p
.53798 .68396 m
.51693 .65476 L
.4951 .62555 L
.47252 .59635 L
.4492 .56714 L
.44775 .56536 L
.39001 .5342 L
.33623 .50304 L
.28464 .47188 L
.23625 .44072 L
.1919 .40956 L
.15071 .3784 L
.11357 .34724 L
.08072 .31608 L
.05264 .28492 L
.03024 .25376 L
.03012 .25376 L
.04238 .28244 L
.05568 .31112 L
.0699 .3398 L
.08492 .36848 L
.10062 .39716 L
.11684 .42584 L
.13347 .45452 L
.15049 .4832 L
.16782 .51188 L
.18541 .54056 L
.20321 .56924 L
.22118 .59792 L
.23927 .6266 L
.25746 .65528 L
.27565 .68396 L
.53798 .68396 L
F
.61536 .71357 m
1 .73571 L
1 .73571 L
.60493 .71357 L
.61536 .71357 L
F
.53924 .68396 m
.60445 .71357 L
.53356 .71357 L
.47001 .68396 L
.53924 .68396 L
F
.3043 .95625 m
.30649 1 L
.54785 1 L
.5473 .95625 L
.3043 .95625 L
F
.27493 .68396 m
.27821 .71422 L
.2815 .74447 L
.28479 .77473 L
.28808 .80498 L
.29137 .83524 L
.29466 .86549 L
.29795 .89574 L
.30124 .926 L
.30452 .95625 L
.49019 .95625 L
.48764 .926 L
.48508 .89574 L
.48252 .86549 L
.47995 .83524 L
.47736 .80498 L
.47477 .77473 L
.47217 .74447 L
.46956 .71422 L
.46694 .68396 L
.27493 .68396 L
F
.53025 .71357 m
.52543 .74391 L
.52059 .77424 L
.51571 .80458 L
.51081 .83491 L
.50587 .86525 L
.5009 .89558 L
.49591 .92592 L
.49088 .95625 L
.54946 .95625 L
.55515 .92592 L
.56081 .89558 L
.56644 .86525 L
.57204 .83491 L
.57761 .80458 L
.58315 .77424 L
.58866 .74391 L
.59413 .71357 L
.53025 .71357 L
F
P
0 g
p
.004 w
.53798 .68396 m
.51693 .65476 L
.4951 .62555 L
.47252 .59635 L
.4492 .56714 L
.44775 .56536 L
.39001 .5342 L
.33623 .50304 L
.28464 .47188 L
.23625 .44072 L
.1919 .40956 L
.15071 .3784 L
.11357 .34724 L
.08072 .31608 L
.05264 .28492 L
.03024 .25376 L
.03012 .25376 L
.04238 .28244 L
.05568 .31112 L
.0699 .3398 L
.08492 .36848 L
.10062 .39716 L
.11684 .42584 L
.13347 .45452 L
.15049 .4832 L
.16782 .51188 L
.18541 .54056 L
.20321 .56924 L
.22118 .59792 L
.23927 .6266 L
.25746 .65528 L
.27565 .68396 L
.53798 .68396 L
s
.61536 .71357 m
1 .73571 L
1 .73571 L
.60493 .71357 L
.61536 .71357 L
s
.53924 .68396 m
.60445 .71357 L
.53356 .71357 L
.47001 .68396 L
.53924 .68396 L
s
.3043 .95625 m
.30649 1 L
.54785 1 L
.5473 .95625 L
.3043 .95625 L
s
.27493 .68396 m
.27821 .71422 L
.2815 .74447 L
.28479 .77473 L
.28808 .80498 L
.29137 .83524 L
.29466 .86549 L
.29795 .89574 L
.30124 .926 L
.30452 .95625 L
.49019 .95625 L
.48764 .926 L
.48508 .89574 L
.48252 .86549 L
.47995 .83524 L
.47736 .80498 L
.47477 .77473 L
.47217 .74447 L
.46956 .71422 L
.46694 .68396 L
.27493 .68396 L
s
.53025 .71357 m
.52543 .74391 L
.52059 .77424 L
.51571 .80458 L
.51081 .83491 L
.50587 .86525 L
.5009 .89558 L
.49591 .92592 L
.49088 .95625 L
.54946 .95625 L
.55515 .92592 L
.56081 .89558 L
.56644 .86525 L
.57204 .83491 L
.57761 .80458 L
.58315 .77424 L
.58866 .74391 L
.59413 .71357 L
.53025 .71357 L
s
P
P
.004 w
s
s
p
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
p
p
/Helvetica findfont 14 scalefont setfont
[(P = 8.5)] .81 .87143 -1 0 Mshowa
P
p
/Times-Bold findfont 22 scalefont setfont
[(AFM)] .852 .94286 0 0 Mshowa
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T1000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo001UOol20004Ool01000Oomoogoo1@00=7oo0P00
17oo00<007ooOol00goo0`00=7oo0P0017oo00<007ooOol00Woo0`00=Goo0P0017oo00<007ooOol0
0Woo0`00>Woo0`005goo001TOol01000Oomoo`0027oo00@007ooOol003=oo`04001oogoo000:Ool0
0`00Oomoo`0bOol01000Oomoo`001goo00D007ooOomoo`0003=oo`04001oogoo0007Ool01@00Oomo
ogoo0000>Woo00<007ooOol05Woo001TOol01000Oomoo`002Goo00<007ooOol0<goo00@007ooOol0
00Moo`D003=oo`04001oogoo0007Ool01@00Oomoogoo0000<goo00@007ooOol000Moo`05001oogoo
Ool0000jOol00`00Oomoo`0FOol006Aoo`04001oogoo000:Ool00`00Oomoo`0bOol01000Oomoo`00
1goo00@007ooOol003Aoo`04001oogoo0007Ool4000dOol01000Oomoo`0027oo0`00>goo00<007oo
Ool05Woo001TOol01000Oomoo`001goo00D007ooOomoo`0003=oo`04001oogoo0008Ool00`00Ool0
000dOol01000Oomoo`001goo00<007ooOol0=Goo00@007ooOol000Moo`05001oogooOol0000jOol0
0`00Oomoo`0FOol006Aoo`04001oogoo0007Ool01@00Oomoogoo0000<goo00@007ooOol000Uoo`80
03Aoo`04001oogoo0008Ool00`00Oomoo`0dOol01000Oomoo`001goo00D007ooOomoo`0003Uoo`80
01Qoo`00IGoo0P002Goo0`00=Goo0P002goo00<007ooOol0<goo0P002Woo0P00=Goo0P002Goo0`00
>goo00<007ooOol05Woo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogoo
TGoo000YOooo001A000GOol002Yoo`03001n<Gha0?mn<Dan<@03001oogoo01Eoo`00:Woo00<007ha
OS40oghaC7ha00<007ooOol05Goo000ZOol00`00OS5n<@3oOS5<OS400`00Oomoo`0EOol002Yoo`03
001n<Gha0?mn<Dan<@03001oogoo01Eoo`00:Woo00<007haOS40oghaC7ha00<007ooOol05Goo000Z
Ool00`00OS5n<@3oOS5<OS400`00Oomoo`0EOol002Yoo`03001n<Gha0?mn<Dan<@03001oogoo01Eo
o`00:Woo00<007haOS40oghaC7ha00<007ooOol05Goo000ZOol00`00OS5n<@3oOS5<OS400`00Oomo
o`0EOol002Yoo`03001n<Gha0?mn<Dan<@03001oogoo01Eoo`00:Woo00<007haOS40oghaC7ha00<0
07ooOol05Goo000ZOol00`00OS5n<@3oOS5<OS400`00Oomoo`0EOol002Yoo`800?mn<Den<@03001o
ogoo01Eoo`00:Woo00<007kF0000oghaC7ha00<007ooOol05Goo000ZOol01000O]IneP00oghaBgha
00<007ooOol05Goo000ZOol01@00O]IneWkF0000oghaBWha00<007ooOol05Goo000ZOol00`00O]In
eP02O]H00`00OS5n<@3oOS57OS400`00Oomoo`0EOol002Yoo`03001neWkF00=neP03001n<Gha0?mn
<DIn<@03001oogoo01Eoo`00:Woo00<007kFO]H017kF00<007haOS40oghaAGha00<007ooOol05Goo
000ZOol00`00O]IneP05O]H00`00OS5n<@3oOS54OS400`00Oomoo`0EOol001Aoo`<0009oo`D000=o
o`8000Moo`03001neWkF00IneP03001n<Gha0?mn<D=n<@03001oogoo01Eoo`004goo00D007ooOomo
o`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007kFO]H01gkF00<007haOS40ogha@Wha
00<007ooOol05Goo000GOol01@00Oomoogoo000017oo00@007ooOol000Ioo`03001neWkF00QneP03
001n<Gha0?mn<D5n<@03001oogoo01Eoo`005goo00<007ooOol00Woo00D007ooOomoo`00009oo`03
001oogoo00Aoo`03001neWkF00UneP03001n<Gha0?mn<D1n<@03001oogoo01Eoo`004goo10000Woo
00D007ooOomoo`00009oo`04001oogoo0006Ool00`00O]IneP0:O]H00`00OS5n<@3oOS4oOS400`00
Oomoo`0EOol001=oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`001Woo00<007kF
O]H02gkF00<007haOS40ogha?Wha00<007ooOol05Goo000COol50002Ool30004Ool20007Ool00`00
O]IneP0<O]H00`00OS5n<@3oOS4mOS400`00Oomoo`0EOol002Yoo`03001neWkF00eneP03001n<Gha
0?mn<Can<@03001oogoo01Eoo`00:Woo00<007kFO]H03WkF00<007haOS40ogha>gha00<007ooOol0
5Goo000ZOol00`00O]IneP0?O]H00`00OS5n<@3oOS4jOS400`00Oomoo`0EOol002Yoo`03001neWkF
011neP03001n<Gha0?mn<CUn<@03001oogoo01Eoo`00:Woo00<007kFO]H04GkF00<007haOS40ogha
>7ha00<007ooOol05Goo000ZOol00`00O]IneP0BO]H2003oOS4hOS400`00Oomoo`0EOol002Yoo`03
001neWkF01AneP03001n<Gha0?mn<CEn<@03001oogoo01Eoo`00:Woo00<007kFO]H05GkF00<007ha
OS40ogha=7ha00<007ooOol05Goo000ZOol00`00O]IneP0FO]H00`00OS5n<@3oOS4cOS400`00Oomo
o`0EOol002Yoo`03001neWkF01MneP03001n<Gha0?mn<C9n<@03001oogoo01Eoo`00:Woo00<007kF
O]H067kF00<007haOS40ogha<Gha00<007ooOol05Goo000ZOol00`00O]IneP0IO]H00`00OS5n<@3o
OS4`OS400`00Oomoo`0EOol002Yoo`03001neWkF01YneP03001n<Gha0?mn<Bmn<@03001oogoo01Eo
o`00:Woo00<007kFO]H06gkF00<007haOS40ogha;Wha00<007ooOol05Goo000ZOol2000MO]H00`00
OS5n<@3oOS4]OS400`00Oomoo`0EOol002Yoo`8001ineP03001n<Gha0?mn<Ban<@03001oogoo01Eo
o`00:Woo0P007gkF00<007haOS40ogha:gha00<007ooOol05Goo000ZOol2000PO]H00`00OS5n<@3o
OS4ZOS400`00Oomoo`0EOol002Yoo`80025neP03001n<Gha0?mn<BUn<@03001oogoo01Eoo`00:Woo
0P008WkF00<007haOS40ogha:7ha00<007ooOol05Goo000ZOol00`00OS40000RO]H00`00OS5n<@3o
OS4WOS400`00Oomoo`0EOol002Yoo`03001n<@0002=neP03001n<Gha0?mn<BIn<@03001oogoo01Eo
o`00:Woo00<007ha000097kF00<007haOS40ogha9Gha00<007ooOol05Goo000ZOol00`00OS40000U
O]H00`00OS5n<@3oOS4TOS400`00Oomoo`0EOol002Yoo`03001n<@0002IneP03001n<Gha0?mn<B=n
<@03001oogoo01Eoo`00:Woo00<007ha00009gkF00<007haOS40ogha8Wha00<007ooOol05Goo000Z
Ool01000OS5n<@009gkF00<007haOS40ogha8Gha00<007ooOol05Goo000ZOol01000OS5n<@00:7kF
00<007haOS40ogha87ha00<007ooOol05Goo000ZOol01000OS5n<@00:GkF00<007haOS40ogha7gha
00<007ooOol05Goo000ZOol01000OS5n<@00:WkF00<007haOS40ogha7Wha00<007ooOol05Goo000Z
Ool01000OS5n<@00:gkF00<007haOS40ogha7Gha00<007ooOol05Goo000ZOol01000OS5n<@00;7kF
00<007haOS40ogha77ha00<007ooOol05Goo000ZOol01@00OS5n<Gha0000;7kF00<007haOS40ogha
6gha00<007ooOol05Goo000ZOol01@00OS5n<Gha0000;GkF00<007haOS40ogha6Wha00<007ooOol0
5Goo000ZOol01@00OS5n<Gha0000;WkF00<007haOS40ogha6Gha00<007ooOol05Goo000ZOol01@00
OS5n<Gha0000;WkF00<007haOS40ogha6Gha00<007ooOol05Goo000ZOol01@00OS5n<Gha0000;gkF
00<007haOS40ogha67ha00<007ooOol05Goo000ZOol00`00OS5n<@02OS400`00O]IneP0]O]H00`00
OS5n<@3oOS4GOS400`00Oomoo`0EOol002Yoo`03001n<Gha009n<@03001neWkF02ineP03001n<Gha
0?mn<AIn<@03001oogoo01Eoo`00:Woo00<007haOS400Wha00<007kFO]H0;gkF00<007haOS40ogha
5Gha00<007ooOol05Goo000ZOol00`00OS5n<@03OS400`00O]IneP0_O]H00`00OS5n<@3oOS4DOS40
0`00Oomoo`0EOol001Aoo`<000Aoo`<000=oo`8000Moo`03001n<Gha00=n<@03001neWkF031neP03
001n<Gha0?mn<A=n<@03001oogoo01Eoo`004goo00D007ooOomoo`0000Aoo`05001oogooOol00002
Ool00`00Oomoo`04Ool00`00OS5n<@03OS400`00O]IneP0aO]H00`00OS5n<@3oOS4BOS400`00Oomo
o`0EOol001Moo`03001oo`0000@0009oo`04001oogoo0006Ool00`00OS5n<@03OS400`00O]IneP0b
O]H00`00OS5n<@3oOS4AOS400`00Oomoo`0EOol001Moo`03001oo`00009oo`05001oogooOol00002
Ool00`00Oomoo`04Ool00`00OS5n<@04OS400`00O]IneP0bO]H00`00OS5n<@3oOS4@OS400`00Oomo
o`0EOol001=oo`@000=oo`03001oo`0000=oo`04001oogoo0006Ool00`00OS5n<@04OS400`00O]In
eP0bO]H00`00OS5n<@3oOS4@OS400`00Oomoo`0EOol001=oo`03001oogoo00Eoo`8000=oo`04001o
ogoo0006Ool00`00OS5n<@04OS400`00O]IneP0cO]H00`00OS5n<@3oOS4?OS400`00Oomoo`0EOol0
01=oo`D000Aoo`03001oogoo009oo`8000Moo`03001n<Gha00An<@03001neWkF03AneP03001n<Gha
0?mn<@in<@03001oogoo01Eoo`00:Woo00<007haOS401Gha00<007kFO]H0=7kF00<007haOS40ogha
3Gha00<007ooOol05Goo000ZOol00`00OS5n<@05OS400`00O]IneP0eO]H00`00OS5n<@3oOS4<OS40
0`00Oomoo`0EOol002Yoo`03001n<Gha00En<@03001neWkF03EneP03001n<Gha0?mn<@an<@03001o
ogoo01Eoo`00:Woo00<007haOS401Gha00<007kFO]H0=WkF00<007haOS40ogha2gha00<007ooOol0
5Goo000ZOol00`00OS5n<@06OS400`00O]IneP0fO]H00`00OS5n<@3oOS4:OS400`00Oomoo`0EOol0
02Yoo`03001n<Gha00In<@03001neWkF03MneP03001n<Gha0?mn<@Un<@03001oogoo01Eoo`00:Woo
00<007haOS401Wha00<007kFO]H0>7kF00<007haOS40ogha27ha00<007ooOol05Goo000ZOol00`00
OS5n<@06OS400`00O]IneP0iO]H00`00OS5n<@3oOS47OS400`00Oomoo`0EOol002Yoo`03001n<Gha
00Mn<@03001neWkF03UneP03001n<Gha0?mn<@In<@03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H0>WkF00<007haOS40ogha1Gha00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00
O]IneP0kO]H00`00OS5n<@3oOS44OS400`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@8003eneP03
001n<Gha0?mn<@=n<@03001oogoo01Eoo`00:Woo00<007haOS401gha0`00?GkF00<007haOS40ogha
0Wha00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]H0000nO]H00`00OS5n<@3oOS41OS40
0`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@04001neP00000nO]H00`00OS5n<@3oOS400`00Oomo
o`0EOol002Yoo`03001n<Gha00Mn<@05001neP00Ool0000nO]H00`00OS5n<@3nOS400`00Oomoo`0E
Ool002Yoo`03001n<Gha00Mn<@06001neWkF001oo`00?GkF00<007haOS40oWha00<007ooOol05Goo
000ZOol00`00OS5n<@07OS401P00O]IneP00Ool003ineP03001n<Gha0?en<@03001oogoo01Eoo`00
:Woo00<007haOS401gha00L007kFO]IneP00Ool0000nO]H00`00OS5n<@3lOS400`00Oomoo`0EOol0
02Yoo`03001n<Gha00Mn<@05001neWkFO]H00002Ool00`00O]IneP0lO]H00`00OS5n<@3kOS400`00
Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF009neP03001oo`0003mneP03001n<Gha0?Yn
<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H00WkF00@007ooOol003ineP03001n
<Gha0?Yn<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H00WkF00D007ooOomoo`00
03ineP03001n<Gha0?Un<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H00gkF00D0
07ooOomoo`0003ineP03001n<Gha0?Qn<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kF
O]H00gkF00<007ooOol00Woo00<007kFO]H0?7kF00<007haOS40mgha00<007ooOol05Goo000ZOol0
0`00OS5n<@07OS400`00O]IneP04O]H00`00Oomoo`02Ool00`00O]IneP0lO]H00`00OS5n<@3fOS40
0`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF00AneP03001oogoo00=oo`03001neWkF
03]neP03001n<Gha0?In<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H017kF00<0
07ooOol017oo00<007kFO]H0>gkF00<007haOS40mGha00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP05O]H00`00Oomoo`04Ool00`00O]IneP0kO]H00`00OS5n<@3dOS400`00Oomoo`0E
Ool002Yoo`03001n<Gha00Mn<@03001neWkF00EneP03001oogoo00Eoo`03001neWkF03]neP03001n
<Gha0?=n<@03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H01WkF00<007ooOol01Goo
0P00?7kF00<007haOS40lWha00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP06O]H0
0`00Oomoo`07Ool00`00O]IneP0iO]H00`00OS5n<@3bOS400`00Oomoo`0EOol002Yoo`03001n<Gha
00Mn<@03001neWkF00MneP03001oogoo00Moo`03001neWkF03UneP03001n<Gha0?5n<@03001oogoo
01Eoo`00:Woo00<007haOS401gha00<007kFO]H01gkF00<007ooOol027oo00<007kFO]H0>GkF00<0
07haOS40l7ha00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP08O]H00`00Oomoo`08
Ool00`00O]IneP0iO]H00`00OS5n<@3_OS400`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001n
eWkF00QneP03001oogoo00Uoo`03001neWkF03UneP03001n<Gha0>in<@03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H02GkF00<007ooOol02Goo00<007kFO]H0>7kF00<007haOS40kWha
00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP09O]H00`00Oomoo`0:Ool00`00O]In
eP0hO]H00`00OS5n<@3]OS400`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF00YneP03
001oogoo00Yoo`03001neWkF03QneP03001n<Gha0>an<@03001oogoo01Eoo`00:Woo00<007haOS40
1gha00<007kFO]H02WkF00<007ooOol02goo00<007kFO]H0>7kF00<007haOS40jgha00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP0;O]H00`00Oomoo`0;Ool2000iO]H00`00OS5n<@3Z
OS400`00Oomoo`0EOol001Aoo`<000=oo`<000Aoo`8000Moo`03001n<Gha00Mn<@03001neWkF00]n
eP03001oogoo00eoo`03001neWkF03IneP03001n<Gha0>Yn<@03001oogoo01Eoo`004goo00L007oo
Oomoo`00Ool00003Ool01000Oomoo`000Woo00<007ooOol017oo00<007haOS401gha00<007kFO]H0
37kF00<007ooOol03Goo00<007kFO]H0=WkF00<007haOS40jGha00<007ooOol05Goo000GOol00`00
Ool00003Ool01000Oomoo`000Woo00<007ooOol017oo00<007haOS401gha00<007kFO]H03GkF00<0
07ooOol03Goo00<007kFO]H0=WkF00<007haOS40j7ha00<007ooOol05Goo000GOol00`00Ool00003
0003Ool01000Oomoo`001Woo00<007haOS401gha00<007kFO]H03GkF00<007ooOol03Woo00<007kF
O]H0=WkF00<007haOS40igha00<007ooOol05Goo000COol40002Ool00`00Oomoo`04Ool01000Oomo
o`001Woo00<007haOS401gha00<007kFO]H03WkF00<007ooOol03Woo0P00=gkF00<007haOS40iGha
0P005goo000COol00`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`001Woo00<007haOS401gha
00<007kFO]H03WkF00<007ooOol047oo00<007kFO]H0=7kF00<007haOS40hgha0P0000=neP00Ool0
5Woo000COol50003Ool20004Ool20007Ool00`00OS5n<@07OS400`00O]IneP0?O]H00`00Oomoo`0@
Ool00`00O]IneP0dO]H00`00OS5n<@3POS420003O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn
<@03001neWkF00mneP03001oogoo015oo`03001neWkF03AneP03001n<Gha0=in<@03001neWkF00=n
eP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H047kF00<007ooOol04Goo00<007kF
O]H0=7kF00<007haOS40fgha0P001WkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]In
eP0@O]H00`00Oomoo`0BOol2000eO]H00`00OS5n<@3HOS420008O]H00`00Oomoo`0EOol002Yoo`03
001n<Gha00Mn<@03001neWkF015neP03001oogoo01=oo`03001neWkF039neP03001n<Gha0=In<@80
00YneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H04GkF00<007ooOol057oo00<0
07kFO]H0<WkF00<007haOS40dgha0P0037kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00
O]IneP0BO]H00`00Oomoo`0DOol00`00O]IneP0bO]H00`00OS5n<@3AOS400`00O]IneP0<O]H00`00
Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF019neP03001oogoo01Eoo`8003=neP03001n
<Gha0<in<@8000mneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H04gkF00<007oo
Ool05Woo00<007kFO]H0<GkF00<007haOS40bgha0P004GkF00<007ooOol05Goo000ZOol00`00OS5n
<@07OS400`00O]IneP0CO]H00`00Oomoo`0GOol00`00O]IneP0`O]H00`00OS5n<@39OS42000CO]H0
0`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01AneP03001oogoo01Moo`80035neP03
001n<Gha0<In<@8001EneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H057kF00<0
07ooOol06Goo00<007kFO]H0;gkF00<007haOS40`gha0P005gkF00<007ooOol05Goo000ZOol00`00
OS5n<@07OS400`00O]IneP0EO]H00`00Oomoo`0IOol00`00O]IneP0_O]H00`00OS5n<@30OS42000I
O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01IneP03001oogoo01Uoo`03001n
eWkF02mneP03001n<Gha0;in<@03001neWkF01UneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H05WkF00<007ooOol06Woo0P00;gkF00<007haOS40_7ha0P0077kF00<007ooOol05Goo
000ZOol00`00OS5n<@07OS400`00O]IneP0GO]H00`00Oomoo`0KOol00`00O]IneP0]O]H00`00OS5n
<@2iOS42000NO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01QneP03001oogoo
01]oo`8002ineP03001n<Gha0;In<@80021neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H067kF00<007ooOol07Goo00<007kFO]H0;7kF00<007haOS40/gha0P008WkF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP0IO]H00`00Oomoo`0MOol00`00O]IneP0[O]H00`00
OS5n<@2aOS42000TO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01YneP03001o
ogoo01eoo`8002aneP03001n<Gha0:en<@<002IneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H06WkF00<007ooOol07goo00<007kFO]H0:WkF00<007haOS40ZWha0P00:GkF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0KO]H00`00Oomoo`0OOol2000ZO]H00`00OS5n
<@2WOS43000[O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01]neP03001oogoo
025oo`03001neWkF02QneP03001n<Gha0:=n<@<002ineP03001oogoo01Eoo`00:Woo00<007haOS40
1gha00<007kFO]H077kF00<007ooOol08Goo00<007kFO]H0:7kF00<007haOS40X7ha0P00<GkF00<0
07ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0LO]H00`00Oomoo`0ROol2000YO]H00`00
OS5n<@2LOS43000cO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01eneP03001o
ogoo02=oo`03001neWkF02IneP03001n<Gha09Yn<@8003IneP03001oogoo01Eoo`00:Woo00<007ha
OS401gha00<007kFO]H07GkF00<007ooOol097oo0P009gkF00<007haOS40UWha0`00>7kF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0NO]H00`00Oomoo`0UOol00`00O]IneP0UO]H0
0`00OS5n<@2COS42000kO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF01ineP03
001oogoo02Ioo`8002EneP03001n<Gha091n<@<003eneP03001oogoo01Eoo`00:Woo00<007haOS40
1gha00<007kFO]H07gkF00<007ooOol09goo0P0097kF00<007haOS40S7ha0`00@7kF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP0OO]H00`00Oomoo`0YOol00`00O]IneP0RO]H00`00
OS5n<@29OS420013O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF021neP03001o
ogoo02Uoo`80029neP03001n<Gha08In<@<004EneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H08GkF00<007ooOol0:Woo00<007kFO]H087kF00<007haOS40Pgha0P00B7kF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0QO]H00`00Oomoo`0[Ool2000QO]H00`00OS5n
<@1oOS43001:O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF029neP03001oogoo
02aoo`03001neWkF01mneP03001n<Gha07]n<@<004eneP03001oogoo01Eoo`00:Woo00<007haOS40
1gha00<007kFO]H08gkF00<007ooOol0;7oo0P007gkF00<007haOS40NGha0P00D7kF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP0SO]H00`00Oomoo`0^Ool2000NO]H00`00OS5n<@1e
OS43001BO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF02AneP03001oogoo02mo
o`03001neWkF01aneP03001n<Gha079n<@8005EneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H09GkF00<007ooOol0;goo0P0077kF00<007haOS40Kgha0`00EgkF00<007ooOol05Goo
000ZOol00`00OS5n<@07OS400`00O]IneP0UO]H00`00Oomoo`0aOol2000KO]H00`00OS5n<@1[OS43
001JO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF02IneP03001oogoo039oo`03
001neWkF01UneP03001n<Gha06Mn<@<005eneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H09gkF00<007ooOol0<Woo0P006GkF00<007haOS40I7ha0`00H7kF00<007ooOol05Goo000D
Ool30003Ool30004Ool20007Ool00`00OS5n<@07OS400`00O]IneP0WO]H00`00Oomoo`0dOol2000H
O]H00`00OS5n<@1POS43001SO]H00`00Oomoo`0EOol001=oo`07001oogooOol007oo00000goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001n<Gha00Mn<@03001neWkF02QneP03001oogoo03Eoo`03
001neWkF01IneP03001n<Gha05an<@<006IneP03001oogoo01Eoo`005goo00<007oo00000goo00@0
07ooOol0009oo`03001oogoo00Aoo`03001n<Gha00Mn<@03001neWkF02QneP03001oogoo03Ioo`80
01MneP03001n<Gha05Qn<@<006UneP03001oogoo01Eoo`005goo00<007ooOol00`000goo00@007oo
Ool000Ioo`03001n<Gha00Mn<@03001neWkF02UneP03001oogoo03Moo`8001EneP03001n<Gha05En
<@<006aneP03001oogoo01Eoo`004goo10000Woo00D007ooOomoo`00009oo`04001oogoo0006Ool0
0`00OS5n<@07OS400`00O]IneP0ZO]H00`00Oomoo`0hOol2000DO]H00`00OS5n<@1AOS43001_O]H0
0`00Oomoo`0EOol001=oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`001Woo00<0
07haOS401gha00<007kFO]H0:WkF00<007ooOol0>Woo0P004gkF00<007haOS40C7ha1000LWkF00<0
07ooOol05Goo000COol50002Ool30004Ool20007Ool00`00OS5n<@07OS400`00O]IneP0[O]H00`00
Oomoo`0kOol00`00O]IneP0@O]H00`00OS5n<@19OS43001fO]H00`00Oomoo`0EOol002Yoo`03001n
<Gha00Mn<@03001neWkF02]neP03001oogoo03aoo`80015neP03001n<Gha04An<@@007UneP03001o
ogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0;7kF00<007ooOol0?Goo0P0047kF00<007ha
OS40@7ha0`00OGkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0]O]H00`00Oomo
o`0nOol2000>O]H00`00OS5n<@0lOS440020O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03
001neWkF02eneP03001oogoo041oo`8000eneP03001n<Gha03Qn<@<008AneP03001oogoo01Eoo`00
:Woo00<007haOS401gha00<007kFO]H0;WkF00<007ooOol0@Goo00<007kFO]H02gkF00<007haOS40
<gha1000QgkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0^O]H00`00Oomoo`12
Ool2000<O]H00`00OS5n<@0_OS43002;O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001n
eWkF02mneP03001oogoo04=oo`8000YneP03001n<Gha02]n<@@008ineP03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H0<7kF00<007ooOol0A7oo0P002GkF00<007haOS409gha0`00TWkF
00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0`O]H00`00Oomoo`16Ool00`00O]In
eP07O]H00`00OS5n<@0ROS44002EO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF
035neP03001oogoo04Ioo`8000MneP03001n<Gha01en<@D009UneP03001oogoo01Eoo`00:Woo00<0
07haOS401gha00<007kFO]H0<GkF00<007ooOol0B7oo0P001WkF00<007haOS4067ha1000WWkF00<0
07ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0bO]H00`00Oomoo`19Ool20005O]H00`00
OS5n<@0BOS45002RO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF039neP03001o
ogoo04]oo`03001neWkF009neP03001n<Gha00in<@@00:MneP03001oogoo01Eoo`00:Woo00<007ha
OS401gha00<007kFO]H0<gkF00<007ooOol0Bgoo0P000gkF00<007haOS402Gha1000ZgkF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0dO]H00`00Oomoo`1<Ool20002O]H00`00OS5n
<@03OS45002_O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF03AneP03001oogoo
04ioo`04001neP00OS44002dO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF03En
eP03001oogoo04ioo`<00;QneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0=GkF
00<007ooOol0D7oo0P00]gkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0fO]H0
0`00Oomoo`1@Ool00`00O]IneP2eO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF
03IneP03001oogoo055oo`03001neWkF0;AneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H0=gkF00<007ooOol0DGoo00<007kFO]H0/gkF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP0hO]H00`00Oomoo`1@Ool00`00O]IneP2cO]H00`00Oomoo`0EOol002Yoo`03001n
<Gha00Mn<@03001neWkF03QneP03001oogoo055oo`03001neWkF0;9neP03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H0>GkF00<007ooOol0DGoo00<007kFO]H0/GkF00<007ooOol05Goo
000ZOol00`00OS5n<@07OS400`00O]IneP0iO]H00`00Oomoo`1BOol00`00O]IneP2`O]H00`00Oomo
o`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF03YneP03001oogoo055oo`03001neWkF0;1neP03
001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0>gkF00<007ooOol0DGoo00<007kFO]H0
[gkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0kO]H00`00Oomoo`1BOol00`00
O]IneP2^O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF03aneP03001oogoo055o
o`03001neWkF0:ineP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0?7kF00<007oo
Ool0DWoo00<007kFO]H0[GkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP0mO]H0
0`00Oomoo`1BOol00`00O]IneP2/O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF
03ineP03001oogoo059oo`03001neWkF0:]neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H0?gkF00<007ooOol0DWoo00<007kFO]H0ZWkF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP10O]H00`00Oomoo`1AOol00`00O]IneP2ZO]H00`00Oomoo`0EOol002Yoo`03001n
<Gha00Mn<@03001neWkF041neP03001oogoo059oo`03001neWkF0:UneP03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H0@GkF00<007ooOol0DWoo00<007kFO]H0Z7kF00<007ooOol05Goo
000ZOol00`00OS5n<@07OS400`00O]IneP12O]H00`00Oomoo`1BOol00`00O]IneP2WO]H00`00Oomo
o`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04=neP03001oogoo059oo`03001neWkF0:IneP03
001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0@gkF00<007ooOol0DWoo00<007kFO]H0
YWkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP14O]H00`00Oomoo`1BOol00`00
O]IneP2UO]H00`00Oomoo`0EOol001Aoo`<000Aoo`8000Aoo`8000Moo`03001n<Gha00Mn<@03001n
eWkF04EneP03001oogoo059oo`03001neWkF0:AneP03001oogoo01Eoo`004goo00D007ooOomoo`00
009oo`04001oogoo0002Ool01000Oomoo`001Woo00<007haOS401gha00<007kFO]H0AGkF00<007oo
Ool0DWoo00<007kFO]H0Y7kF00<007ooOol05Goo000COol01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0006Ool00`00OS5n<@07OS400`00O]IneP16O]H00`00Oomoo`1BOol00`00O]In
eP2SO]H00`00Oomoo`0EOol001=oo`@000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007ha
OS401gha00<007kFO]H0AWkF00<007ooOol0Dgoo00<007kFO]H0XWkF00<007ooOol05Goo000COol0
0`00Oomoo`04Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001n<Gha00Mn<@03001neWkF04Mn
eP03001oogoo05=oo`03001neWkF0:5neP03001oogoo01Eoo`0057oo00<007ooOol00goo00@007oo
Ool0009oo`04001oogoo0006Ool00`00OS5n<@07OS400`00O]IneP18O]H00`00Oomoo`1BOol00`00
O]IneP2QO]H00`00Oomoo`0EOol001Eoo`8000Aoo`8000Aoo`8000Moo`03001n<Gha00Mn<@03001n
eWkF04QneP03001oogoo05=oo`03001neWkF0:1neP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H0BGkF00<007ooOol0Dgoo00<007kFO]H0WgkF00<007ooOol05Goo000ZOol00`00OS5n
<@07OS400`00O]IneP19O]H00`00Oomoo`1COol00`00O]IneP2OO]H00`00Oomoo`0EOol002Yoo`03
001n<Gha00Mn<@03001neWkF04YneP03001oogoo05=oo`03001neWkF09ineP03001oogoo01Eoo`00
:Woo00<007haOS401gha00<007kFO]H0BgkF00<007ooOol0Dgoo00<007kFO]H0WGkF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP1;O]H00`00Oomoo`1DOol00`00O]IneP2LO]H00`00
Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04aneP03001oogoo05Aoo`03001neWkF09]n
eP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0CGkF00<007ooOol0Dgoo00<007kF
O]H0VgkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1=O]H00`00Oomoo`1DOol0
0`00O]IneP2JO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04ineP03001oogoo
05Aoo`03001neWkF09UneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0CWkFF`00
V7kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1>O]H00`00Oomoo`0nOol00`00
O]IneP02000EOol2002FO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04ineP03
001oogoo03ioo`03001neWkF009neP8001Eoo`8009AneP03001oogoo01Eoo`00:Woo00<007haOS40
1gha00<007kFO]H0CWkF00<007ooOol0?Woo00<007kFO]H017kF0P005Goo0P00TWkF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP1?O]H00`00Oomoo`0mOol00`00O]IneP06O]H2000E
Ool2002@O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04mneP03001oogoo03eo
o`03001neWkF00QneP<001Aoo`<008eneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kF
O]H0CgkF00<007ooOol0?Goo00<007kFO]H02gkF0P005Goo0P00RgkF00<007ooOol05Goo000ZOol0
0`00OS5n<@07OS400`00O]IneP1?O]H00`00Oomoo`0mOol00`00O]IneP0=O]H2000EOol20029O]H0
0`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF04mneP03001oogoo03eoo`03001neWkF
00mneP8001Eoo`8008MneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0D7kF00<0
07ooOol0?7oo00<007kFO]H04GkF0P005Goo0P00QGkF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP1@O]H00`00Oomoo`0lOol00`00O]IneP0BO]HU001hO]H00`00Oomoo`0EOol002Yo
o`03001n<Gha00Mn<@03001neWkF051neP03001oogoo03aoo`03001neWkF019neP03001oogoo019o
o`03001neWkF00YneQ<006QneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0D7kF
00<007ooOol0?7oo00<007kFO]H04WkF00<007ooOol04Woo00<007kFO]H06gkF4P00F7kF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1@O]H00`00Oomoo`0lOol00`00O]IneP0AO]H0
0`00Oomoo`0BOol00`00O]IneP0/O]HB0018O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03
001neWkF051neP03001oogoo03aoo`03001neWkF015neP03001oogoo019oo`03001neWkF03eneQ80
03MneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0D7kF00<007ooOol0?7oo00<0
07kFO]H04GkF00<007ooOol04Woo00<007kFO]H0CGkF4P009gkF00<007ooOol05Goo000ZOol00`00
OS5n<@07OS400`00O]IneP1@O]H00`00Oomoo`0lOol00`00O]IneP0AO]H00`00Oomoo`0BOol00`00
O]IneP1NO]HA000GO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF055neP03001o
ogoo03aoo`03001neWkF011neP03001oogoo019oo`03001neWkF06ineQ4000MneP03001oogoo01Eo
o`00:Woo00<007haOS401gha00<007kFO]H0DGkF00<007ooOol0?7oo00<007kFO]H03gkF00<007oo
Ool04Woo00<007kFO]H0P7kF20005goo000ZOol00`00OS5n<@07OS400`00O]IneP1AO]H00`00Oomo
o`0lOol00`00O]IneP0?O]H00`00Oomoo`0BOol00`00O]IneP27O]H00`00Oomoo`0EOol002Yoo`03
001n<Gha00Mn<@03001neWkF055neP03001oogoo03aoo`03001neWkF00mneP03001oogoo019oo`03
001neWkF08MneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0DGkF00<007ooOol0
?7oo00<007kFO]H03gkF00<007ooOol04Woo00<007kFO]H0QgkF00<007ooOol05Goo000ZOol00`00
OS5n<@07OS400`00O]IneP1AO]H00`00Oomoo`0lOol00`00O]IneP0?O]H00`00Oomoo`0BOol00`00
O]IneP27O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF055neP03001oogoo03ao
o`03001neWkF00mneP03001oogoo019oo`03001neWkF08MneP03001oogoo01Eoo`00:Woo00<007ha
OS401gha00<007kFO]H0DGkF00<007ooOol0?7oo00<007kFO]H03WkF00<007ooOol04Woo00<007kF
O]H0R7kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1AO]H00`00Oomoo`0lOol0
0`00O]IneP0>O]H00`00Oomoo`0BOol00`00O]IneP28O]H00`00Oomoo`0EOol002Yoo`03001n<Gha
00Mn<@03001neWkF055neP03001oogoo03aoo`03001neWkF00ineP03001oogoo019oo`03001neWkF
08QneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0DWkF00<007ooOol0?7oo00<0
07kFO]H03GkF00<007ooOol04Woo00<007kFO]H0R7kF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP1BO]H00`00Oomoo`0lOol00`00O]IneP0=O]H00`00Oomoo`0BOol00`00O]IneP28
O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF059neP03001oogoo03aoo`03001n
eWkF00aneP03001oogoo019oo`03001neWkF08UneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H0DWkF00<007ooOol0?7oo00<007kFO]H037kF00<007ooOol04Woo00<007kFO]H0RGkF
00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1BO]H00`00Oomoo`0lOol00`00O]In
eP0<O]H00`00Oomoo`0BOol00`00O]IneP29O]H00`00Oomoo`0EOol001Aoo`<0009oo`D000=oo`80
00Moo`03001n<Gha00Mn<@03001neWkF059neP03001oogoo03aoo`03001neWkF00aneP03001oogoo
019oo`03001neWkF08UneP03001oogoo01Eoo`004goo00D007ooOomoo`00009oo`04001oogoo0002
Ool01000Oomoo`001Woo00<007haOS401gha00<007kFO]H0DWkF00<007ooOol0?7oo00<007kFO]H0
37kF00<007ooOol04Woo00<007kFO]H0RGkF00<007ooOol05Goo000COol01@00Oomoogoo00000goo
00<007ooOol00Woo00@007ooOol000Ioo`03001n<Gha00Mn<@03001neWkF059neP03001oogoo03ao
o`03001neWkF00aneP03001oogoo015oo`03001neWkF08YneP03001oogoo01Eoo`004goo10001Goo
00D007ooOomoo`00009oo`03001oogoo00Aoo`03001n<Gha00Mn<@03001neWkF059neP03001oogoo
03aoo`03001neWkF00aneP03001oogoo015oo`03001neWkF08YneP03001oogoo01Eoo`004goo00<0
07ooOol00goo00D007ooOomoo`00009oo`04001oogoo0006Ool00`00OS5n<@07OS400`00O]IneP1B
O]H00`00Oomoo`0lOol00`00O]IneP0<O]H00`00Oomoo`0AOol00`00O]IneP2:O]H00`00Oomoo`0E
Ool001Aoo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`001Woo00<007haOS401gha
00<007kFO]H0DgkF00<007ooOol0?7oo00<007kFO]H02WkF00<007ooOol04Woo00<007kFO]H0RWkF
00<007ooOol05Goo000EOol20003Ool30004Ool20007Ool00`00OS5n<@07OS400`00O]IneP1CO]H0
0`00Oomoo`0lOol00`00O]IneP0:O]H00`00Oomoo`0BOol00`00O]IneP2:O]H00`00Oomoo`0EOol0
02Yoo`03001n<Gha00Mn<@03001neWkF05=neP03001oogoo03aoo`03001neWkF00YneP03001oogoo
015oo`03001neWkF08]neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0DgkF00<0
07ooOol0?7oo00<007kFO]H02WkF00<007ooOol04Goo00<007kFO]H0RgkF00<007ooOol05Goo000Z
Ool00`00OS5n<@07OS400`00O]IneP1CO]H00`00Oomoo`0lOol00`00O]IneP0:O]H00`00Oomoo`0A
Ool00`00O]IneP2;O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05=neP03001o
ogoo03aoo`03001neWkF00YneP03001oogoo015oo`03001neWkF08]neP03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H0DgkF00<007ooOol0?7oo00<007kFO]H02WkF00<007ooOol04Goo
00<007kFO]H0RgkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1CO]H00`00Oomo
o`0lOol00`00O]IneP09O]H00`00Oomoo`0BOol00`00O]IneP2;O]H00`00Oomoo`0EOol002Yoo`03
001n<Gha00Mn<@03001neWkF05=neP03001oogoo03aoo`03001neWkF00UneP03001oogoo019oo`03
001neWkF08]neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0DgkF00<007ooOol0
?7oo00<007kFO]H02GkF00<007ooOol04Woo00<007kFO]H0RgkF00<007ooOol05Goo000ZOol00`00
OS5n<@07OS400`00O]IneP1DO]H00`00Oomoo`0lOol00`00O]IneP08O]H00`00Oomoo`0AOol00`00
O]IneP2<O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05AneP03001oogoo03ao
o`03001neWkF00QneP03001oogoo015oo`03001neWkF08aneP03001oogoo01Eoo`00:Woo00<007ha
OS401gha00<007kFO]H0E7kF00<007ooOol0?7oo00<007kFO]H01gkF00<007ooOol04Woo00<007kF
O]H0S7kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1DO]H00`00Oomoo`0lOol0
0`00O]IneP07O]H00`00Oomoo`0BOol00`00O]IneP2<O]H00`00Oomoo`0EOol002Yoo`03001n<Gha
00Mn<@03001neWkF05AneP03001oogoo03aoo`03001neWkF00MneP03001oogoo019oo`03001neWkF
08aneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0E7kF00<007ooOol0?7oo00<0
07kFO]H01gkF00<007ooOol04Woo00<007kFO]H0S7kF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP1DO]H00`00Oomoo`0lOol00`00O]IneP07O]H00`00Oomoo`0BOol00`00O]IneP2<
O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05AneP03001oogoo03aoo`03001n
eWkF00MneP03001oogoo015oo`03001neWkF08eneP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H0E7kF00<007ooOol0?7oo00<007kFO]H01gkF00<007ooOol04Goo00<007kFO]H0SGkF
00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1DO]H00`00Oomoo`0lOol00`00O]In
eP07O]H00`00Oomoo`0AOol00`00O]IneP2=O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03
001neWkF05EneP03001oogoo03aoo`03001neWkF00EneP03001oogoo019oo`03001neWkF08eneP03
001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0EGkF00<007ooOol0?7oo00<007kFO]H0
1GkF00<007ooOol04Woo00<007kFO]H0SGkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00
O]IneP1EO]H00`00Oomoo`0lOol00`00O]IneP05O]H00`00Oomoo`0AOol00`00O]IneP2>O]H00`00
Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05EneP03001oogoo03aoo`03001neWkF00En
eP03001oogoo015oo`03001neWkF04mneP03001neWkF01IneP05BJd000000019[@03O]H01000O]In
eTV]0`0000=9[GkFO]H057kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1EO]H0
0`00Oomoo`0lOol00`00O]IneP05O]H00`00Oomoo`0AOol00`00O]IneP1?O]H00`00O]IneP0EO]H0
1dV]0019[GkFBJd004V]00AneP07BJd004V]O]I9[@00BJd05GkF00<007ooOol05Goo000ZOol00`00
OS5n<@07OS400`00O]IneP1EO]H00`00Oomoo`0lOol00`00O]IneP05O]H00`00Oomoo`0AOol00`00
O]IneP1?O]H00`00O]IneP09O]H70005O]H00`00BJeneP02O]H00dV]001neP03O]H00`00BJeneP02
O]H00dV]001neP0DO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05EneP03001o
ogoo03aoo`03001neWkF00EneP03001oogoo015oo`03001neWkF04mneP03001neWkF01EneP03001n
eWkF00=neP03001neWkF00QneP03001neWkF01=neP03001oogoo01Eoo`00:Woo00<007haOS401gha
00<007kFO]H0EGkF00<007ooOol0?7oo00<007kFO]H017kF00<007ooOol04Goo00<007kFO]H0D7kF
1@0000<@@V8aO]H047kF00LHQ3U:O]IneW:D<@PHQ009O]H00dV]001neP0DO]H00`00Oomoo`0EOol0
02Yoo`03001n<Gha00Mn<@03001neWkF05EneP03001oogoo03aoo`03001neWkF00AneP03001oogoo
015oo`03001neWkF051neP07001neWkFO]IbU3488:D01GkF1`001GkF00=AcP0000000`0000=J47kF
O]H00WkF00L@@R2UJW=neTV]0019[@0EO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001n
eWkF05EneP03001oogoo03aoo`03001neWkF00AneP03001oogoo015oo`03001neWkF051neP03001n
eWkF00=neP03001neWkF00mneP074491JfYcO]IbU3U:68@017kF00<Xia1200000P0000=9[GkFO]H0
57kF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1FO]H00`00Oomoo`0lOol00`00
O]IneP03O]H00`00Oomoo`0AOol00`00O]IneP1@O]H00`00O]IneP03O]H00`00O]IneP0?O]H00`00
BJeneP02O]H00dV]001neP03O]H00d5[:>MneP0IO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn
<@03001neWkF05IneP03001oogoo03aoo`03001neWkF00=neP03001oogoo015oo`03001neWkF051n
eP07001neWkFO]IbU3488:D04GkF00M9[@00BJeneTV]0019[@04O]H00eX@449neP0IO]H00`00Oomo
o`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05IneP03001oogoo03aoo`03001neWkF009neP03
001oogoo015oo`03001neWkF055nePD00003449R<GkF015neP05BJd000000019[@06O]H5000FO]H0
0`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05IneP03001oogoo03aoo`03001neWkF
009neP03001oogoo015oo`03001neWkF091neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H0EWkF00<007ooOol0?7oo00<007kFO]H00WkF00<007ooOol04Goo00<007kFO]H0T7kF00<0
07ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1FO]H00`00Oomoo`0lOol00`00O]IneP02
O]H00`00Oomoo`0AOol00`00O]IneP2@O]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001n
eWkF05IneP03001oogoo03aoo`03001neWkF009neP03001oogoo015oo`03001neWkF091neP03001o
ogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0EWkF00<007ooOol0?7oo00D007kFO]IneP00
01=oo`03001neWkF095neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0EWkF00<0
07ooOol0?7oo00D007kFO]IneP0001=oo`03001neWkF095neP03001oogoo01Eoo`00:Woo00<007ha
OS401gha00<007kFO]H0EWkF00<007ooOol0?7oo00D007kFO]IneP0001=oo`03001neWkF095neP03
001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0EgkF00<007ooOol0>goo00D007kFO]In
eP0001=oo`03001neWkF095neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0EgkF
00<007ooOol0>goo00D007kFO]IneP0001=oo`03001neWkF095neP03001oogoo01Eoo`00:Woo00<0
07haOS401gha00<007kFO]H0EgkF00<007ooOol0>goo00@007kFO]H001=oo`03001neWkF099neP03
001oogoo01Eoo`0057oo0`0017oo0`000goo0P001goo00<007haOS401gha00<007kFO]H0EgkF00<0
07ooOol0>goo00@007kFO]H001=oo`03001neWkF099neP03001oogoo01Eoo`004goo00D007ooOomo
o`0000Aoo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00OS5n<@07OS400`00O]IneP1GO]H0
0`00Oomoo`0kOol01000O]IneP004goo00<007kFO]H0TWkF00<007ooOol05Goo000COol01P00Oomo
ogoo001oo`D0009oo`04001oogoo0006Ool00`00OS5n<@07OS400`00O]IneP1GO]H00`00Oomoo`0k
Ool01000O]IneP004goo00<007kFO]H0AgkF100017kF1`0000=neP0000001@001WkF1@000gkF00=9
[@00LY@00gkF1`006GkF00<007ooOol05Goo000COol40002Ool01000Oomoo`000goo00@007ooOol0
00Ioo`03001n<Gha00Mn<@03001neWkF05MneP03001oogoo03]oo`04001neWkF000COol00`00O]In
eP17O]H00fYc224Xi`06O]H01VYc00000000449bU09neP05@F/00000001AcP08O]H00eX@001J4004
O]H00a12000iBP04O]H01EX@00000000FQ006WkF00<007ooOol05Goo000COol00`00Oomoo`04Ool0
0`00Ool00003Ool01000Oomoo`001Woo00<007haOS401gha00<007kFO]H0EgkF00<007ooOol0>goo
00@007kFO]H0019oo`03001neWkF04UneP03BJdHQ7kF00EneP05JW<00000001R<@04O]H3000:O]H0
0`00O]IneP02O]H0168a000000PQ1GkF0`006gkF00<007ooOol05Goo000DOol00`00Oomoo`04Ool2
0003Ool01000Oomoo`001Woo00<007haOS401gha00<007kFO]H0EgkF00<007ooOol0>goo00@007kF
O]H0019oo`03001neWkF04YneP03225ZLgkF00AneP04:>L00000:>L5O]H3000:O]H00`00O]IneP02
O]H01BSW00000000BJd017kF0`006gkF00<007ooOol05Goo000EOol20005Ool00`00Oomoo`02Ool2
0007Ool00`00OS5n<@07OS400`00O]IneP1GO]H00`00Oomoo`0kOol01000O]IneP004Woo00<007kF
O]H0BWkF00<a200000001`0000=R<GkFO]H00gkF0`0017kF00<XigkFO]H00gkF00D007kFO]IneW:D
00<00003@F/HQ7kF00=neP<001]neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0
F7kF00<007ooOol0>goo0P004goo00<007kFO]H0BWkF00=R<A12O]H00gkF00A1J`00000HQ0IneP<0
00=neP03JW<007kF00AneP05001neWkFO]I9[@0200001112O]H88F8a0gkF0`006gkF00<007ooOol0
5Goo000ZOol00`00OS5n<@07OS400`00O]IneP1HO]H00`00Oomoo`0kOol2000COol00`00O]IneP1;
O]H00`PQJW=neP02O]H010PQ000004V]1WkF0`0000EneW:DDLh@@P0000EneP05001neWkFO]H@@P02
000014V]O]I9[BSW0gkF0`006gkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1H
O]H00`00Oomoo`0kOol2000BOol00`00O]IneP1<O]H01C48@F]neWkFFQ000`001gkF20001GkF00@0
07kFO]IR<@<00005LYAneW:D001bU002O]H3000KO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn
<@03001neWkF05QneP03001oogoo03]oo`80019oo`03001neWkF04aneP05HS4@@WkFO]HPY@020000
0cU:O]IneP05O]H300001GkFLYAAcQ1200001GkF00@007kFO]HXi`800006:>MneWkFO]Ha23U:0WkF
0`006gkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1HO]IC001?O]H00`PQJW=Z
L`0300000fYcO]IneP05O]H30003O]H00f8a001neP04O]H00`00O]IbU00300001VYcO]IneWkFJW<8
8@9neP<001]neP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0F7kF00<007ooOol0
CWoo00<007kFO]H0CWkF00<a200000000P0000<XigkFO]H01WkF0`0017kF00<PYGkFO]H00gkF00<0
07kFBJd00P0000<HQ7kFO]H00gkF00<PYDV]O]H00`006gkF00<007ooOol05Goo000ZOol00`00OS5n
<@07OS400`00O]IneP1HO]H00`00Oomoo`1>Ool00`00O]IneP1>O]H00f8a0000000200000eX@O]In
eP06O]H30007O]H01R2UO]IneP00O]H@@P800003BJeneWkF00=neP03FQ0HQ7kF00<001]neP03001o
ogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0F7kF00<007ooOol0CWoo00<007kFO]H0CgkF
00@88@0000088@UneP<000IneP06HS4007kFO]H0068a0`001gkF00<88F8a00000P006gkF00<007oo
Ool05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1HO]H00`00Oomoo`1>Ool00`00O]IneP1?O]H0
1348000004V]27kF00E1J`000000068a00=neP08FQ0iBP00001neUX@000Xi`800003<@QneWkF00En
eP03BJdXi`0000800003FQ1neWkF01QneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kF
O]H0F7kF00<007ooOol0CWoo00<007kFO]H0CgkF00AR<@00001bU0MneQ<00003JW=neWkF00EneP03
LY@0000000@001UneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<007kFO]H0F7kF00<007oo
Ool0CWoo00<007kFO]H0UGkF00<007ooOol05Goo000ZOol00`00OS5n<@07OS400`00O]IneP1HO]H0
0`00Oomoo`1>Ool00`00O]IneP2EO]H00`00Oomoo`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF
05UneP03001oogoo04ioo`03001neWkF09AneP03001oogoo01Eoo`00:Woo00<007haOS401gha00<0
07kFO]H0FGkF00<007ooOol0CWoo00<007kFO]H0U7kF00<007ooOol05Goo000ZOol00`00OS5n<@07
OS400`00O]IneP1IO]H00`00Oomoo`1>Ool00`00O]IneP2DO]H00`00Oomoo`0EOol002Yoo`03001n
<Gha00Mn<@03001neWkF05UneP03001oogoo04ioo`03001neWkF09AneP03001oogoo01Eoo`00:Woo
00<007haOS401gha00<007kFO]H0FGkF00<007ooOol0CWoo00<007kFO]H0U7kF00<007ooOol05Goo
000ZOol00`00OS5n<@07OS400`00O]IneP1IO]H00`00Oomoo`1>Ool00`00O]IneP2DO]H00`00Oomo
o`0EOol002Yoo`03001n<Gha00Mn<@03001neWkF05UneP03001oogoo04ioo`03001neWkF09AneP03
001oogoo01Eoo`00:Wooo`00D0005goo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mo
oi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo
003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mo
oi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo0000\
\>"],
  ImageRangeCache->{{{19.9375, 379}, {379.062, 20}} -> {-0.126129, 492.973, \
0.00299504, 0.419305}}]
}, Open  ]],

Cell["making a series of diagrams for animation", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["Map[makevx, Range[5.0,5.14,0.01]]; ", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{635, 772},
WindowMargins->{{245, Automatic}, {Automatic, 14}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Gd000400@0000000000000004P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 125, 2, 67, "Section"],

Cell[CellGroupData[{
Cell[1877, 58, 73, 1, 63, "Subsection"],
Cell[1953, 61, 423, 11, 68, "Input"],
Cell[2379, 74, 95, 1, 46, "Text"],
Cell[2477, 77, 693, 19, 77, "Input"],
Cell[3173, 98, 67, 1, 46, "Text"],
Cell[3243, 101, 987, 28, 168, "Input"],
Cell[4233, 131, 66, 1, 46, "Text"],
Cell[4302, 134, 843, 17, 142, "Input"],
Cell[5148, 153, 58, 1, 46, "Text"],
Cell[5209, 156, 673, 14, 142, "Input"],
Cell[5885, 172, 97, 1, 46, "Text"],
Cell[5985, 175, 375, 11, 64, "Input"],
Cell[6363, 188, 97, 1, 46, "Text"],
Cell[6463, 191, 284, 9, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6784, 205, 81, 1, 47, "Subsection"],
Cell[6868, 208, 85, 1, 46, "Text"],
Cell[6956, 211, 131, 4, 38, "Input"],
Cell[7090, 217, 92, 4, 38, "Input"],
Cell[7185, 223, 69, 1, 25, "Input"],
Cell[7257, 226, 91, 1, 46, "Text"],
Cell[7351, 229, 485, 12, 129, "Input"],
Cell[7839, 243, 132, 4, 62, "Text"],
Cell[7974, 249, 425, 11, 103, "Input"],
Cell[8402, 262, 160, 4, 62, "Text"],
Cell[8565, 268, 3567, 75, 766, "Input"],
Cell[12135, 345, 93, 1, 46, "Text"],
Cell[12231, 348, 375, 11, 64, "Input"],
Cell[12609, 361, 97, 1, 46, "Text"],
Cell[12709, 364, 284, 9, 38, "Input"],
Cell[12996, 375, 122, 4, 46, "Text"],
Cell[13121, 381, 2992, 61, 688, "Input"],
Cell[16116, 444, 82, 1, 46, "Text"],
Cell[16201, 447, 7189, 151, 1507, "Input"],
Cell[23393, 600, 122, 4, 46, "Text"],
Cell[23518, 606, 1635, 35, 350, "Input"],
Cell[25156, 643, 8165, 172, 1598, "Input"],
Cell[33324, 817, 77, 1, 46, "Text"],
Cell[33404, 820, 503, 13, 77, "Input"],
Cell[33910, 835, 73, 1, 46, "Text"],
Cell[33986, 838, 487, 13, 77, "Input"],
Cell[34476, 853, 99, 1, 46, "Text"],
Cell[34578, 856, 3498, 71, 636, "Input"],
Cell[38079, 929, 86, 1, 46, "Text"],
Cell[38168, 932, 884, 28, 67, "Input"],
Cell[39055, 962, 61, 1, 46, "Text"],
Cell[39119, 965, 2448, 50, 480, "Input"],
Cell[41570, 1017, 62, 1, 46, "Text"],
Cell[41635, 1020, 8247, 136, 1884, "Input"],
Cell[49885, 1158, 62, 1, 46, "Text"],
Cell[49950, 1161, 731, 15, 155, "Input"]
}, Closed]],
Cell[50696, 1179, 102, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[50823, 1184, 67, 1, 63, "Subsection"],
Cell[50893, 1187, 59, 1, 46, "Text"],
Cell[50955, 1190, 505, 12, 103, "Input"],
Cell[51463, 1204, 77, 1, 46, "Text"],
Cell[51543, 1207, 96, 1, 25, "Input"],
Cell[51642, 1210, 56, 1, 46, "Text"],
Cell[51701, 1213, 76, 1, 25, "Input"],
Cell[51780, 1216, 73, 1, 46, "Text"],
Cell[51856, 1219, 60, 1, 25, "Input"],
Cell[51919, 1222, 69, 1, 46, "Text"],
Cell[51991, 1225, 67, 1, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52095, 1231, 60, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[52180, 1236, 65, 1, 61, "Subsubsection"],
Cell[52248, 1239, 2313, 43, 545, "Input"],
Cell[54564, 1284, 134, 4, 44, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[54735, 1293, 70, 1, 47, "Subsubsection"],
Cell[54808, 1296, 159, 6, 44, "SmallText"],
Cell[54970, 1304, 2884, 56, 701, "Input"],
Cell[57857, 1362, 134, 4, 70, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[58028, 1371, 64, 1, 47, "Subsubsection"],
Cell[58095, 1374, 201, 5, 78, "Text"],
Cell[58299, 1381, 68438, 954, 16080, "Input"],
Cell[126740, 2337, 134, 4, 70, "SmallText"],
Cell[126877, 2343, 193, 6, 70, "SmallText"],
Cell[127073, 2351, 21888, 338, 70, "Input"],
Cell[148964, 2691, 134, 4, 70, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[149135, 2700, 74, 1, 47, "Subsubsection"],
Cell[149212, 2703, 59, 1, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[149320, 2710, 64, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[149409, 2715, 148, 5, 51, "Input"],
Cell[149560, 2722, 47844, 1643, 408, 10667, 1180, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[197419, 4368, 91, 1, 46, "Text"],
Cell[197513, 4371, 86, 1, 25, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

