(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    162836,       4519]*)
(*NotebookOutlinePosition[    163914,       4553]*)
(*  CellTagsIndexPosition[    163870,       4549]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["AFM T-y at 6 kbars",
    FontColor->RGBColor[1, 0, 0]],
  ""
}], "Section",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Off[General::spell]; Off[General::spell1]; Off[Set::shape];\n\
Off[Interpolation::inhr]; Off[InterpolatingFunction::dmwarn",
    FontWeight->"Plain"],
  StyleBox["]",
    FontSize->12,
    FontWeight->"Plain",
    FontColor->GrayLevel[0.499992]],
  StyleBox["\nSetOptions[Position, Heads -> False];\n<<Graphics`Animation`",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["making combinations (used in one phase field)", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};  \n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                            \
                       gray[n-1,m-1]]}],m];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number formatting", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[format]; \n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ, n_Integer, _?TrueQ, w_Integer]:=\n     \
Block[{m=N[10^n], y},\n           y = ToString[Round[m x]/m]; ly = \
StringLength[y];\n           If[ly < w, StringJoin[Apply[StringJoin,Table[\" \
\",{w-ly}]],y],y]]\n\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,_?TrueQ]:=Block[{m=N[10^n]},Round[m x]/m];\n\
",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ,n_Integer,___]:=N[x,n];\n",
    FontWeight->"Plain"],
  StyleBox["format",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_,___]:=x;\n\nSetAttributes[format,{Listable}];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["interval halving", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[ih];\n",
    FontWeight->"Plain"],
  StyleBox["ih",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[f__Function, params:{_?NumberQ...}, lim1_Function, \
lim2_Function] := \n   Block[{v1,v2,s1,s2,v,sv},\n          \
v1=N[Apply[lim1,params]]; s1=N[Apply[f,Join[{v1},params]]];            \n     \
     v2=N[Apply[lim2,params]]; s2=N[Apply[f,Join[{v2},params]]];  \n          \
If[ Sign[s1]==Sign[s2],Print[\"same sign - meaningless answer?\"]];           \
   \n          FixedPoint[( v = (v1+v2)/2; sv = N[Apply[f,Join[{v},params]]];\
\n                       If[Sign[s1]==Sign[sv], v1=v; s1=sv, v2=v; s2=sv];\n  \
                     (v1+v2)/2  )&,0.5,15]];\nih[___] = \"something is wrong \
with the input\";",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["linecuts", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[linecuts];\n\n",
    FontWeight->"Plain"],
  StyleBox["linecuts",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{slope_,intercept_},{{xlow_,xhigh_},{ylow_,yhigh_}}]:=\n  \
(y1=intercept+slope xlow; y2=intercept+slope xhigh;\n      {If[slope>0,\n     \
   If[y1<ylow, {(ylow-intercept)/slope,ylow},  {xlow,y1}],\n        \
If[y1>yhigh,{(yhigh-intercept)/slope,yhigh},{xlow,y1}]],\n       If[slope>0,\n\
        If[y2>yhigh,{(yhigh-intercept)/slope,yhigh},{xhigh,y2}],\n        \
If[y2<ylow, {(ylow-intercept)/slope,ylow},  {xhigh,y2}] ]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["number of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["T-x/P-x functions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["default values, normally overridden", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 400; top = 800;
delv = 5; addx = addy = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
varyTatP = True;
debugit = False;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["labelling[p_]:={};", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["differentiating an interpolation function", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[dif];\n",
    FontWeight->"Plain"],
  StyleBox["dif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifr_,v_] := \n    ({r1,r2} = ifr;\n     Which[v > \
r2-difdelv,\n             (if[r2]-if[r2-difdelv])/difdelv,\n           v < \
r1,\n             (if[r1+difdelv]-if[r1])/difdelv,\n           True,\n        \
     (if[v+difdelv]-if[v])/difdelv]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
substitute into interpolation function in value (T or P) range v1 \
<-> v2\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[subsif];\n",
    FontWeight->"Plain"],
  StyleBox["subsif",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,v1_,v2_] :=\n    (dv = Abs[v2-v1];\n     If[dv <= 2 delv,\n  \
      {{if[v1],v1},{if[v2],v2}},\n        kd = Floor[dv/delv]; \n        \
Map[{if[#],#}&, v1 + dv/kd Range[0,kd]]]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
make a boundary of the a divariant using the interpolation fn, if;  \
(note that vs < ve  OR  vs > ve)\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makeboundary];\n",
    FontWeight->"Plain"],
  StyleBox["makeboundary",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifrange_,vs_,ve_] :=\n    (\n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb is maximum substitution range, with vb > va ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     If[ve > vs, {va,vb} = {vs,ve}, {va,vb} = {ve,vs}];\
\n   \n     (* ",
    FontWeight->"Plain"],
  StyleBox["va <-> vb adjusted to be consistent with interpolation function ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     {vr1,vr2} = ifrange;\n     If[va<vr1, va=vr1];  \
If[vb>vr2, vb=vr2];\n     \n",
    FontWeight->"Plain"],
  StyleBox["     If[debugit, Print[\"    \",if]; Print[\"  \",ifrange,\"  \", \
{vs,ve},\"  \",{va,vb}]];\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n     (* ",
    FontWeight->"Plain"],
  StyleBox["xa <-> xb corresponds to va <-> vb ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)     \n     \n     z = Which[(va > top  || vb < bottom) || \
(va>=vb),\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["boundary doesn't appear within diagram ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 {{}},\n                 \n     \
          {xa,xb} = {if[va],if[vb]};  xb > xa,\n     \n               (* ",
    FontWeight->"Plain"],
  StyleBox["positive slope in v-x ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 Which[xa >= left && xb <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xa > right && xb  >right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[{{left,va}},subsif[if,vsol,vb]],\n                       True,   (* \
ie xb > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[subsif[if,va,vsol],{{right,vb}}] ],\n               True,\n              \
      \n               (* ",
    FontWeight->"Plain"],
  StyleBox["negative slope in v-x",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *) \n             \n                 Which[xb >= left && xa <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xb > right && xb > right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[subsif[if,va,vsol], {{left,vb}}],\n                       True,   (* \
ie xa > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[{{right,va}}, subsif[if,vsol,vb]] ]  ];   \n                             \
  \n     (* ",
    FontWeight->"Plain"],
  StyleBox["reverse info if ve < vs ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n  \n     If[ve > vs, z, Reverse[z]]  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["no of strings in common between two strings", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[diwhich];\n",
    FontWeight->"Plain"],
  StyleBox["diwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points which see s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = nposi[Map[incommon[s,#]&,plines],3];\n    \
muni = nposi[Map[incommon[s,#]&,puni]-Map[Length,puni],-1];\n    mpoints = \
nposi[Map[incommon[s,#]&,ppoints],3];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["which univariants, if any, are in range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       ipuni = \
Flatten[Position[uni[[muni]],\n                          \
_?((#[[vuposi]]>bottom && #[[vuposi]]<top)&),{1}]];\n       muni = \
muni[[ipuni]] ];\n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["duni = degenerate univariants; cduni are the others",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       duni = \
muni[[nposi[Map[Length,puni[[muni]]],2]]];  \n       cduni = \
Complement[muni,duni],\n       duni = {}; cduni = {}];\n           \n    (* ",
    
    FontWeight->"Plain"],
  StyleBox["removing degenerate univariant(s) not relevant to this divariant \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[Length[cduni]>0 && Length[duni] > 0,  \n       \
idel = Map[({v,{react,prod}} = uni[[#,{vuposi,5}]];  \n       ph = \
Flatten[{react,prod}];\n       If[incommon[prod,s] == Length[prod],\n         \
     Position[uni[[duni]],\n                  _?((#[[vuposi]] < v && \
incommon[ph,#[[5,2]]] == 1)&),{1}],\n              Position[uni[[duni]],\n    \
              _?((#[[vuposi]] > v && incommon[ph,#[[5,1]]] == \
1)&),{1}]])&,cduni];\n       muni = \
Complement[muni,duni[[Union[Flatten[idel]]]]]];\n       \n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
{\",plines[[#,{1,2}]],\", \",plines[[#,3]],\"}\"]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no univariants\"],\n             \
Print[\"  univariants\"];\n             Map[Print[\"    \", #,\": \
\",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["does a T-x / P-x divariant field", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doadi];\n",
    FontWeight->"Plain"],
  StyleBox["doadi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points relevant to s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = diwhich[s,False];\n        \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["using any univariants to get the value (ie T or P) range",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n\n    Switch[Length[muni],\n       2, {va,vb} = \
uni[[muni,vuposi]]; \n          If[vb>va, {v1,v2} = {va,vb}, {v2,v1} = \
{va,vb}],\n       1, {vuni,{react,prod}} = uni[[muni[[1]],{vuposi,5}]];\n     \
     If[incommon[react,s]==Length[react],\n             v1 = bottom; v2 = \
vuni,\n             v1 = vuni; v2 = top],\n       _, v1 = bottom; v2 = top];\n\
            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iff[[mlines]]; ifrange = iffrange[[mlines]];\n\
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = plines[[mlines,{1,2}]];\n    pp = Map[(ppk = \
#; \n              pos = Position[pm, _?((#==ppk)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,1]]];\n    cpp = \
Complement[Range[Length[mlines]],Flatten[pp]];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["lc = no of lines; lpp = no of points; pcpp = no not connected to \
points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; luni = Length[muni];\n  \n   ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp,\"  \",luni]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n    \n    p = Which[lc == 1,\n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a divariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2], \n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && luni == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries, one point, and one univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            vuni = uni[[muni]][[1,vuposi]];\n                {p1,p2} = \
pp[[1]];                \n                If[vuni>vp, vw = v2, vw = v1];      \
          \n                Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp],\n\
                     makeboundary[if[[p2]],ifrange[[p2]],vp,vw]],\n           \
   \n              lc == 2, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point - ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["logic not complete",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[{d1,d2},\"  \",{vp,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    (* ",
    FontWeight->"Plain"],
  StyleBox["from here down, three boundaries (ie max for 3 phase divariants) \
",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n              lpp == 1,\n              \n              (* ",
    
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                      \n               ",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[ifrange[[{pp1,pp2}]],\"  \",{d1,d2},\"  \
\",{vp,vc,vw1,vw2}]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lpp == 2 \
&& luni == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points: boundaries connected through points, and to a \
univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                vuni = \
uni[[muni]][[1,vuposi]];\n                {pp1,pp2}=pp;\n                p2 = \
Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
If[vuni>vp1, vw = v2, vw = v1];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,vw]],\n              \n              \
(* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** \
geometry for \",s,\" not implemented yet **\"]; {{}} ];\n    Join[p,{p[[1]]}] \
 );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadriwhich];\n",
    FontWeight->"Plain"],
  StyleBox["quadriwhich",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_, doprint_] :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["positions in lines, points, and degenerate univariants which see \
s",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = \
Flatten[Position[Map[#[[1]]&,pqlines],_?((#==s)&)]];\n    mpoints = \
Flatten[Position[Map[#[[1]]&,ppoints],_?((#==s)&)]];        \n    muni = \
Flatten[Position[puni,_?((Length[#]==2 && incommon[#,s]==1)&),{1}]];\n       \
\n    (* ",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
\",{pqlines[[#,1]]},\", \",pqlines[[#,2]]]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no degenerate univariants\"],\n   \
          Print[\"  degenerate univariants\"];\n             Map[Print[\"    \
\", #,\": \",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doaquadri];\n",
    FontWeight->"Plain"],
  StyleBox["doaquadri",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_]:=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["qline, points and degenerate univariants for this quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = quadriwhich[s,False];",
    FontWeight->"Plain"],
  StyleBox["\n    ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n    v1 = bottom; v2 = top;           \n            \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iffq[[mlines]];  ifrange = \
iffqrange[[mlines]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = pqlines[[mlines,2]];\n    pp = Map[(ppk = #; \n\
              pos = Position[pm, _?((incommon[#,ppk]==1)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,{2,3}]]];\n    \
cpp = Complement[Range[Length[mlines]],Flatten[pp]];\n  \n    ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp]];",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; lu = Length[muni];\n\n    p = Which[lc == 1,\n    \n             \
 (* ",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a quadrivariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0 && lu == 0, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["- assumes lines have same slope",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && lpp == 0 && lu == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points, but one degenerate univariant *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n    \n                vuni = uni[[muni,vuposi]][[1]];\n         \
       If[{s} == puni[[muni]][[1]], vw = v1, vw = v2];\n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw,vuni],\n                     \
makeboundary[if[[2]],ifrange[[2]],vuni,vw]],\n              \n              \
lc == 2 && lpp == 1, \n    \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n                vp = points[[mpoints]][[1,vposi]];\n        \
        d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n                ",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[{d1,d2},\" \",{vp,vw1,vw2}]]",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[";       \n                      \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    lc == 3 && lpp == 1 && lu == 0,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lc == 3 \
&& lpp == 1 && lu == 1,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, one degenerate univariant ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vuni = uni[[muni,vuposi]][[1]];\n       \
         vp = points[[mpoints]][[1,vposi]];\n                {pp1,pp2} = \
pp[[1]]; cpp1 = cpp[[1]];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],v1,vp],  (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to ky",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vuni],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vuni,v1]],\n  \n              lc == 3 \
&& lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2}=pp;\n              \
  p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],v1,vp1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v1]],\n  \n              lc == 4 && \
lpp == 2,\n              \n              (* ",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries, plus one separate boundary ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2} = pp;\n            \
    p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                p4 = \
Complement[Range[4],{p1,p2,p3}][[1]];\n                \
Join[makeboundary[if[[p4]],ifrange[[p4]],v2,v1], (* ",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p1]],ifrange[[p1]],v1,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v2]],\n  \n              (* ",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** not \
implemented yet **\"]; {{}} ];\n    If[p[[1]]=={}, \n       \
Join[Drop[p,1],{p[[2]]}], \n       Join[p,{p[[1]]}]]",
    FontWeight->"Plain"],
  StyleBox["   ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[");",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the quadrivariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadrvariant];\n",
    FontWeight->"Plain"],
  StyleBox["quadrivariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = \
Map[doaquadri,Intersection[Map[#[[1]]&,pqlines]]];\n      ipoly = \
Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > 0)&)]];\n      \
{Hue[1,0.45,1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]\
});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["draw all the divariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[divariant];\n",
    FontWeight->"Plain"],
  StyleBox["divariant",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = Map[doadi,Intersection[Map[Sort,plines]]];\n    \
  ipoly = Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > \
0)&)]];\n      \
{GrayLevel[1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]}\
);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["makes horizontal lines for degenerate univariants", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makehor];\n",
    FontWeight->"Plain"],
  StyleBox["makehor",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (\n    (* ",
    FontWeight->"Plain"],
  StyleBox["pluni is position of degenerate reactions in uni ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pluni = nposi[Map[Length[Flatten[#[[5]]]]&,uni],2];\
\n    If[Length[pluni]==0, Line[{{0,top+1},{1,top+1}}], (* ",
    FontWeight->"Plain"],
  StyleBox["dummy line",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n       Map[(            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ph is phases involved in A=B; vuni is T/P  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            ph = Flatten[uni[[#,5]]]; vuni = \
uni[[#,vuposi]];\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["dl2 is positions in lines which involve A or B disappearing  ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            dl = plines; (* \
Map[#[[1]][[{6,7}]]&,lines]; *)\n            dl2 = \
Flatten[Position[dl,_?((#[[-1]]==ph[[1]] || #[[-1]]==ph[[2]])&),{1}]];\n      \
      \n            (* ",
    FontWeight->"Plain"],
  StyleBox["ii locates which of the dl2 involve A and B disappearing at A=B ",
    
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            gg = gray[Length[dl2],2];\n         \
   dl1 = Map[Drop[#,-1]&,dl[[dl2]]];\n            ii = \
Flatten[Position[Map[incommon[dl1[[#[[1]]]],dl1[[#[[2]]]]]&,gg],\n            \
                       _?((#==2)&)]];\n                                   \n  \
          If[debugit, ",
    FontWeight->"Plain"],
  StyleBox["Print[ph,\"  \",dl2,\"  \",Map[gg[[#]]&,ii]]]; ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n            \n            (* ",
    FontWeight->"Plain"],
  StyleBox["draws horizontal line, length depends on length of ii ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            Switch[Length[ii],\n                \
   0, Line[{{left,vuni},{right,vuni}}],\n                   1, ig = \
dl2[[gg[[ii[[1]],1]]]];\n                      {r1,r2} = \
Apply[List,iff[[ig]]][[1]];\n                      If[vuni<=r1 || vuni>=r2,\n \
                        Line[{{left,vuni},{right,vuni}}],\n                   \
      Line[{{iff[[ig]][vuni],vuni},{right,vuni}}]],\n                   2, \
ig1 = dl2[[gg[[ii[[1]],1]]]];               \n                      {r11,r12} \
= Apply[List,iff[[ig1]]][[1]];\n                      ig2 = \
dl2[[gg[[ii[[2]],1]]]];\n                      {r21,r22} = \
Apply[List,iff[[ig2]]][[1]];\n                      Which[(vuni<=r11 || \
vuni>=r12) && (vuni<=r21 || vuni>=r22),\n                              \
Line[{{left,vuni},{right,vuni}}],\n                            vuni<=r11 || \
vuni>=r12,\n                              \
Line[{{iff[[ig2]][vuni],vuni},{right,vuni}}],\n                            \
vuni<=r21 || vuni>=r22,\n                              \
Line[{{iff[[ig1]][vuni],vuni},{right,vuni}}],\n                            \
True,\n                              Line[{{iff[[ig1]][vuni],vuni},\n         \
                           {iff[[ig2]][vuni],vuni}}]] ] )&,pluni] ] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["generate the outlines of the diagram", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background]; Clear[outline]; Clear[box];\n",
    FontWeight->"Plain"],
  StyleBox["box",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {{left, bottom},{left, top},{right, top},{right, \
bottom},{left, bottom}};\n",
    FontWeight->"Plain"],
  StyleBox["background",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[1,0.3,1], Polygon[box]};\n",
    FontWeight->"Plain"],
  StyleBox["outline",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0], Line",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[box]};",
    FontWeight->"Plain"],
  StyleBox["                                    ",
    FontSize->11,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setting up ", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setupvx];\n",
    FontWeight->"Plain"],
  StyleBox["setupvx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (If[TrueQ[varyTatP], \n       vposi = 5; oposi = 4; \
vuposi = 4; ouposi = 3; delv =   5; difdelv =   0.01, \n       vposi = 4; \
oposi = 5; vuposi = 3; ouposi = 4; delv = 0.2; difdelv = 0.0001];\n        \n \
   (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for lines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    rolines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,alllines];\n    alliff = Array[(ak = \
alllines[[#]]; ro = rolines[[#]];\n                    Map[(rok = #;\n        \
                 ii = Flatten[Position[Map[#[[oposi]]&,ak],\n                 \
                              _?((#==rok)&),{1}]];\n                         \
Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                        \
)&,ro])&,Length[alllines]];\n    alliffrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliff];\n                        \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for qlines",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    roqlines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,allqlines];\n    alliffq = Array[(ak = \
allqlines[[#]]; ro = roqlines[[#]];\n                     Map[(rok = #;\n     \
                     ii = Flatten[Position[Map[#[[oposi]]&,ak],\n             \
                                   _?((#==rok)&),{1}]];\n                     \
     Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                         \
)&,ro])&,Length[allqlines]]; \n    alliffqrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliffq];\n                            \n    \
(* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffuni = \
Map[Interpolation[Map[#[[{ouposi,vuposi}]]&,#]]&,alluni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for points",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffpoints = \
Map[Interpolation[Map[#[[{oposi,vposi}]]&,#]]&,allpoints];\n    iffpointsx = \
Map[Interpolation[Map[#[[{oposi,3}]]&,#]]&,allpoints];  );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemblevx];\n",
    FontWeight->"Plain"],
  StyleBox["assemblevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := \n   (    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming uni (ie univariants) at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    iuni = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffuni],\n                           \
 _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    uni = Map[(if = iffuni[[#]];\n   \
            If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = ok; pp = if[tt]];\n  \
             {0,2,pp,tt,alluni[[#]][[1,5]]})&,iuni];       \n    puni =  \
Map[Flatten[#[[5]]]&,uni];\n    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants excluded by out of range univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    dels1 = Map[(sp = #[[5]];\n                 \
If[#[[vuposi]]>top,\n                    If[Length[sp[[1]]]==1, {sp[[2]]},\n  \
                     {Flatten[{sp[[1,1]],sp[[2]]}],Flatten[{sp[[1,2]],sp[[2]]}\
]}],\n                    {{\"junk\"}}])&,uni];\n    dels2 = Map[(sp = \
#[[5]];\n                 If[#[[vuposi]]<bottom,\n                    \
If[Length[sp[[2]]]==1, {sp[[1]]},\n                       \
{Flatten[{sp[[1]],sp[[2,1]]}],Flatten[{sp[[1]],sp[[2,1]]}]}],\n               \
     {{\"junk\"}}])&,uni];\n    dels = Flatten[Union[dels1,dels2],1];\n       \
                         \n    cjuni =  Map[(dsk = #; ll = Length[dsk];\n     \
             Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,puni],\n   \
                                _?((#==0)&)]])&, dels];\n    juni = \
Complement[Range[Length[puni]],Intersection[Flatten[cjuni]]];\n               \
                  \n    uni = uni[[juni]];\n    puni =  puni[[juni]];         \
                   \n                                    \n    (* ",
    FontWeight->"Plain"],
  StyleBox["removes univariants that are excluded by degenerate univariants",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    (* ",
    FontWeight->"Plain"],
  StyleBox["ie does Schreinemakers in this special case",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    dlu = \
Flatten[Position[Map[Length,puni],_?((#==2)&)]];\n    cdlu = \
Complement[Range[Length[puni]],dlu];\n    idel1 = Map[(v = uni[[#,vuposi]]; p \
= puni[[#]];\n                Position[uni[[cdlu]],\n                     \
_?((ll1 = incommon[{p[[1]]},Flatten[#[[5]]]];\n                         \
#[[vuposi]] > v && ll1 == 1)&),{1}])&,dlu];\n    idel2 = Map[(v = \
uni[[#,vuposi]]; p = puni[[#]];\n                Position[uni[[cdlu]],\n      \
               _?((ll2 = incommon[{p[[2]]},Flatten[#[[5]]]];\n                \
         #[[vuposi]] < v && ll2 == 1)&),{1}])&,dlu];\n    idel1 = \
Union[Flatten[idel1]]; idel2 = Union[Flatten[idel2]];\n    \n    udel1 = \
Map[{#[[{1,3,4}]],#[[{2,3,4}]]}&,puni[[idel1]]];\n    udel2 = \
Map[{#[[{1,2,3}]],#[[{1,2,4}]]}&,puni[[idel2]]];\n    udel = \
Partition[Flatten[{udel1,udel2}],3];\n    \n    iuni = \
Complement[Range[Length[puni]],Union[Flatten[{idel1,idel2}]]];\n    uni = \
uni[[iuni]];\n    puni =  puni[[iuni]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming points at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    ip = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffpoints],\n                        \
    _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    points = Map[(if = \
iffpoints[[#]];\n               If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = \
ok; pp = if[tt]];\n               \
{1,2,iffpointsx[[#]][ok],pp,tt,allpoints[[#]][[1,6]],\n                \
allpoints[[#]][[1,7]],allpoints[[#]][[1,8]]})&,ip];       \n    \n    ppoints \
= Map[Flatten[#[[{6,7,8}]]]&,points];\n    \n    cipoints =  Map[(dsk = #; ll \
= Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,ppoints],\n             \
                         _?((#==0)&)]])&, dels];\n    ipoints = \
Complement[Range[Length[ppoints]],Intersection[Flatten[cipoints]]];\n    \
points = points[[ipoints]];\n    ppoints = ppoints[[ipoints]];\n\n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming lines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    plines = Map[Flatten[#[[1,{6,7}]]]&,alllines];\n    \
ilines1 = Flatten[Position[Map[#[[{1,-1}]]&,rolines],\n                       \
       _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    cilines2 = \
Flatten[Map[(udelk = #;\n                            Flatten[Position[plines,\
\n                                             _?((Length[Intersection[#,\
udelk]]==3)&),\n                                             {1}]])&,udel]];\n\
    ilines2 = Complement[Range[Length[rolines]],cilines2];\n    cilines3 =  \
Map[(dsk = #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,plines],\n              \
                        _?((#==0)&)]])&, dels];\n    ilines3 = \
Complement[Range[Length[plines]],Intersection[Flatten[cilines3]]];\n    \
ilines = Intersection[ilines1,ilines2,ilines3];                          \n   \
                           \n    iff = Map[(ii = #; rok = rolines[[ii]];\n    \
           kkm = Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n           \
    If[Length[kkm] == 1,\n                  alliff[[ii,kkm[[1]]]],\n          \
        kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  \
k1 = kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {f1,f2} = alliff[[ii,{k1,k2}]]; \n                  \
{fr1,fr2} = alliffrange[[ii,{k1,k2}]];\n                  diff1 = \
(fr1[[2]]-fr1[[1]]-2del)/ni;\n                  v1 = Map[{#,f1[#]}&, \
Range[fr1[[1]]+del,fr1[[2]]-del,diff1]];\n                  diff2 = \
(fr2[[2]]-fr2[[1]]-2del)/ni;\n                  v2 = Map[{#,f2[#]}&, \
Range[fr2[[1]]+del,fr2[[2]]-del,diff2]];\n                  \
Interpolation[v1(1-prop) + v2 prop]]\n              )&, ilines];            \n\
              \n    iffrange = Map[Apply[List,#][[1]]&, iff];    \n           \
        \n    plines = plines[[ilines]];\n                 \n    (* ",
    FontWeight->"Plain"],
  StyleBox["forming qlines at ok ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pqlines = Map[Flatten[#[[1,{6,7}]]]&,allqlines];\n  \
  iqlines1 = Flatten[Position[Map[#[[{1,-1}]]&,roqlines],\n                   \
           _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    ciqlines2 =  Map[(dsk \
= #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,pqlines],\n             \
                         _?((#==0)&)]])&, dels];\n    iqlines2 = \
Complement[Range[Length[pqlines]],Intersection[Flatten[ciqlines2]]];\n    \
iqlines = Intersection[iqlines1,iqlines2];\n              \n    iffq = \
Map[(ii = #; rok = roqlines[[ii]];\n               kkm = \
Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n               \
If[Length[kkm] == 1,\n                  alliffq[[ii,kkm[[1]]]],\n             \
     kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  k1 \
= kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {fq1,fq2} = alliffq[[ii,{k1,k2}]]; \n                  \
{fqr1,fqr2} = alliffqrange[[ii,{k1,k2}]];\n                  diffq1 = \
(fqr1[[2]]-fqr1[[1]]-2del)/ni;\n                  vq1 = Map[{#,fq1[#]}&, \
Range[fqr1[[1]]+del,fqr1[[2]]-del,diffq1]];\n                  diffq2 = \
(fqr2[[2]]-fqr2[[1]]-2del)/ni;\n                  vq2 = Map[{#,fq2[#]}&, \
Range[fqr2[[1]]+del,fqr2[[2]]-del,diffq2]];\n                  \
Interpolation[vq1(1-prop) + vq2 prop]]\n               )&, iqlines];          \
  \n              \n    iffqrange = Map[Apply[List,#][[1]]&, iffq];          \
\n           \n    pqlines = pqlines[[iqlines]]   );\n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makevx];\n",
    FontWeight->"Plain"],
  StyleBox["makevx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := (assemblevx[ok];\n                \
Show[Graphics[{background,\n                               quadrivariant,\n   \
                            divariant,\n                               \
makehor,\n                               outline,\n                           \
    labelling[ok]}],\n                     AspectRatio -> 1, Frame -> True,\n \
                    PlotRange -> {{left, right}, {bottom, top}},\n            \
         PlotRegion-> {{addx,1-addx},{addy,1-addy}}])",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell["bulk composition line through aluminosilicate at x = 0.4", "Text",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["definitions", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 500; top = 650;
delv = 2; addx = 0; addy = 0;\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["fontsize = 14;  pl = 2;\n\nClear[labelling];\n",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] :=\n     ({Text[FontForm[ StringJoin[\"P = \
\",ToString[N[Round[10^pl ok]/10^pl]]],\n                     \
{\"Helvetica\",fontsize}], {0.01,635}, {-1,0}],\n       \
Text[FontForm[\"AFM\",{\"Times-Bold\",22}], {0.01,642}, {-1,0}]});",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["coordinates", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["points", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
allpoints = {

(* bi *)
{{1,  2, 0.1460, 6.00, 574.5, {\"bi\"},\"st\", \"chl\"}}, 
{{1,  2, 0.1590, 6.00, 628.2, {\"bi\"},\"st\", \"g\"}}, 

(* chl *)
{{1,  2, 0.4370, 6.00, 544.8, {\"chl\"},\"st\", \"ctd\"}},
{{1,  2, 0.4230, 6.00, 573.5, {\"chl\"},\"st\", \"bi\"}},  

(* ky *)
{{1,  2, 0.9630, 6.00, 585.5, {\"ky\"},\"chl\", \"bi\"}}};\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["univariants", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
alluni ={
 {{1,  1, 6.00, 537.9,  {{\"ctd\", \"ky\"},{\"st\", \"chl\"}}}},    
 {{1,  1, 6.00, 584.8,  {{\"st\", \"chl\"}, {\"bi\", \"ky\"}}}}, 
 {{1,  1, 6.00, 645.1,  {{\"st\", \"bi\"}, {\"g\", \"sill\"}}}},
 {{1,  1, 6.00, 623.4,  {{\"ky\"}, {\"sill\"}}}}};             \
\>", "Input",\

  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["alllines = {\n(* ",
    FontWeight->"Plain"],
  StyleBox["ky-ctd-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ctd-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5200, 6.00, 543.8, {\"ctd\", \
\"chl\"},\"ky\"},     \n{1,  2, 0.5400, 6.00, 536.0, {\"ctd\", \
\"chl\"},\"ky\"},      \n{1,  2, 0.5600, 6.00, 526.8, {\"ctd\", \"chl\"},\"ky\
\"},     \n{1,  2, 0.5800, 6.00, 516.1, {\"ctd\", \"chl\"},\"ky\"},     \n{1, \
 2, 0.6000, 6.00, 503.6, {\"ctd\", \"chl\"},\"ky\"},     \n{1,  2, 0.6060, \
6.00, 499.5, {\"ctd\", \"chl\"},\"ky\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9200, 6.00, 538.1, {\"chl\", \
\"ky\"},\"ctd\"},     \n{1,  2, 0.9225, 6.00, 537.2, {\"chl\", \
\"ky\"},\"ctd\"},     \n{1,  2, 0.9250, 6.00, 536.1, {\"chl\", \
\"ky\"},\"ctd\"},   \n{1,  2, 0.9275, 6.00, 535.0, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9300, 6.00, 533.8, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9325, 6.00, 532.6, {\"chl\", \
\"ky\"},\"ctd\"},   \n{1,  2, 0.9350, 6.00, 531.3, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9375, 6.00, 529.8, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9400, 6.00, 528.3, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9425, 6.00, 526.7, {\"chl\", \
\"ky\"},\"ctd\"},   \n{1,  2, 0.9450, 6.00, 525.0, {\"chl\", \
\"ky\"},\"ctd\"},   \n{1,  2, 0.9475, 6.00, 523.2, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9500, 6.00, 521.2, {\"chl\", \
\"ky\"},\"ctd\"},   \n{1,  2, 0.9525, 6.00, 519.1, {\"chl\", \
\"ky\"},\"ctd\"},  \n{1,  2, 0.9550, 6.00, 516.7, {\"chl\", \"ky\"},\"ctd\"}, \
   \n{1,  2, 0.9575, 6.00, 514.2, {\"chl\", \"ky\"},\"ctd\"},    \n{1,  2, \
0.9600, 6.00, 511.5, {\"chl\", \"ky\"},\"ctd\"},    \n{1,  2, 0.9625, 6.00, \
508.5, {\"chl\", \"ky\"},\"ctd\"},    \n{1,  2, 0.9650, 6.00, 505.3, \
{\"chl\", \"ky\"},\"ctd\"},   \n{1,  2, 0.9675, 6.00, 501.7, {\"chl\", \
\"ky\"},\"ctd\"},    \n{1,  2, 0.9700, 6.00, 497.8, {\"chl\", \
\"ky\"},\"ctd\"}},   \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-ctd-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ctd-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4370, 6.00, 544.8, {\"ctd\", \
\"chl\"},\"st\"},    \n{1,  2, 0.4400, 6.00, 544.6, {\"ctd\", \
\"chl\"},\"st\"},    \n{1,  2, 0.4600, 6.00, 543.5, {\"ctd\", \
\"chl\"},\"st\"},    \n{1,  2, 0.4800, 6.00, 542.3, {\"ctd\", \
\"chl\"},\"st\"},    \n{1,  2, 0.5000, 6.00, 540.9, {\"ctd\", \
\"chl\"},\"st\"},     \n{1,  2, 0.5200, 6.00, 539.3, {\"ctd\", \
\"chl\"},\"st\"},    \n{1,  2, 0.5400, 6.00, 537.5, {\"ctd\", \
\"chl\"},\"st\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4370, 6.00, 544.8, {\"st\", \
\"chl\"},\"ctd\"},    \n{1,  2, 0.4400, 6.00, 544.7, {\"st\", \
\"chl\"},\"ctd\"},     \n{1,  2, 0.4600, 6.00, 544.0, {\"st\", \"chl\"},\"ctd\
\"},     \n{1,  2, 0.4800, 6.00, 543.2, {\"st\", \"chl\"},\"ctd\"},    \n{1,  \
2, 0.5000, 6.00, 542.3, {\"st\", \"chl\"},\"ctd\"},    \n{1,  2, 0.5200, \
6.00, 541.3, {\"st\", \"chl\"},\"ctd\"},   \n{1,  2, 0.5400, 6.00, 540.2, \
{\"st\", \"chl\"},\"ctd\"},   \n{1,  2, 0.5600, 6.00, 538.9, {\"st\", \
\"chl\"},\"ctd\"},    \n{1,  2, 0.5800, 6.00, 537.4, {\"st\", \
\"chl\"},\"ctd\"}},    \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["ky-st-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5600, 6.00, 533.0, {\"st\", \"chl\"},\"ky\"}, \
     \n{1,  2, 0.5800, 6.00, 540.8, {\"st\", \"chl\"},\"ky\"},    \n{1,  2, \
0.6000, 6.00, 550.3, {\"st\", \"chl\"},\"ky\"},   \n{1,  2, 0.6200, 6.00, \
562.1, {\"st\", \"chl\"},\"ky\"},   \n{1,  2, 0.6400, 6.00, 576.7, {\"st\", \
\"chl\"},\"ky\"},   \n{1,  2, 0.6600, 6.00, 594.8, {\"st\", \
\"chl\"},\"ky\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9200, 6.00, 537.6, {\"chl\", \"ky\"},\"st\"}, \
   \n{1,  2, 0.9225, 6.00, 539.1, {\"chl\", \"ky\"},\"st\"},     \n{1,  2, \
0.9250, 6.00, 540.8, {\"chl\", \"ky\"},\"st\"},     \n{1,  2, 0.9275, 6.00, \
542.6, {\"chl\", \"ky\"},\"st\"},    \n{1,  2, 0.9300, 6.00, 544.6, {\"chl\", \
\"ky\"},\"st\"},    \n{1,  2, 0.9325, 6.00, 546.8, {\"chl\", \"ky\"},\"st\"}, \
    \n{1,  2, 0.9350, 6.00, 549.3, {\"chl\", \"ky\"},\"st\"},    \n{1,  2, \
0.9375, 6.00, 552.1, {\"chl\", \"ky\"},\"st\"},    \n{1,  2, 0.9400, 6.00, \
555.3, {\"chl\", \"ky\"},\"st\"},   \n{1,  2, 0.9425, 6.00, 559.0, {\"chl\", \
\"ky\"},\"st\"},    \n{1,  2, 0.9450, 6.00, 563.1, {\"chl\", \"ky\"},\"st\"}, \
   \n{1,  2, 0.9475, 6.00, 568.0, {\"chl\", \"ky\"},\"st\"},    \n{1,  2, \
0.9500, 6.00, 573.5, {\"chl\", \"ky\"},\"st\"},   \n{1,  2, 0.9525, 6.00, \
580.2, {\"chl\", \"ky\"},\"st\"},   \n{1,  2, 0.9550, 6.00, 588.0, {\"chl\", \
\"ky\"},\"st\"}},  \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4230, 6.00, 573.5, {\"st\", \"chl\"},\"bi\"}, \
   \n{1,  2, 0.4400, 6.00, 573.9, {\"st\", \"chl\"},\"bi\"},   \n{1,  2, \
0.4600, 6.00, 574.4, {\"st\", \"chl\"},\"bi\"},  \n{1,  2, 0.4800, 6.00, \
574.9, {\"st\", \"chl\"},\"bi\"},   \n{1,  2, 0.5000, 6.00, 575.6, {\"st\", \
\"chl\"},\"bi\"},  \n{1,  2, 0.5200, 6.00, 576.3, {\"st\", \"chl\"},\"bi\"},  \
 \n{1,  2, 0.5400, 6.00, 577.1, {\"st\", \"chl\"},\"bi\"},    \n{1,  2, \
0.5600, 6.00, 578.0, {\"st\", \"chl\"},\"bi\"},    \n{1,  2, 0.5800, 6.00, \
579.1, {\"st\", \"chl\"},\"bi\"},  \n{1,  2, 0.6000, 6.00, 580.4, {\"st\", \
\"chl\"},\"bi\"},    \n{1,  2, 0.6200, 6.00, 582.0, {\"st\", \
\"chl\"},\"bi\"},   \n{1,  2, 0.6400, 6.00, 583.8, {\"st\", \"chl\"},\"bi\"}, \
 \n{1,  2, 0.6600, 6.00, 586.0, {\"st\", \"chl\"},\"bi\"},  \n{1,  2, 0.6800, \
6.00, 588.7, {\"st\", \"chl\"},\"bi\"},    \n{1,  2, 0.7000, 6.00, 591.8, \
{\"st\", \"chl\"},\"bi\"}},  \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1460, 6.00, 574.5, {\"st\", \"bi\"},\"chl\"}, \
   \n{1,  2, 0.1600, 6.00, 574.6, {\"st\", \"bi\"},\"chl\"},   \n{1,  2, \
0.1800, 6.00, 574.8, {\"st\", \"bi\"},\"chl\"},  \n{1,  2, 0.2000, 6.00, \
574.9, {\"st\", \"bi\"},\"chl\"},   \n{1,  2, 0.2200, 6.00, 575.1, {\"st\", \
\"bi\"},\"chl\"},  \n{1,  2, 0.2400, 6.00, 575.3, {\"st\", \"bi\"},\"chl\"},  \
 \n{1,  2, 0.2600, 6.00, 575.6, {\"st\", \"bi\"},\"chl\"},   \n{1,  2, \
0.2800, 6.00, 575.8, {\"st\", \"bi\"},\"chl\"},   \n{1,  2, 0.3000, 6.00, \
576.1, {\"st\", \"bi\"},\"chl\"},    \n{1,  2, 0.3200, 6.00, 576.3, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.3400, 6.00, 576.6, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.3600, 6.00, 577.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.3800, 6.00, 577.3, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.4000, 6.00, 577.7, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.4200, 6.00, 578.2, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.4400, 6.00, 578.6, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.4600, 6.00, 579.2, {\"st\", \
\"bi\"},\"chl\"},      \n{1,  2, 0.4800, 6.00, 579.7, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5000, 6.00, 580.4, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5200, 6.00, 581.1, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.5400, 6.00, 582.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5600, 6.00, 582.9, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.5800, 6.00, 584.0, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.6000, 6.00, 585.3, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.6200, 6.00, 586.7, {\"st\", \
\"bi\"},\"chl\"},    \n{1,  2, 0.6400, 6.00, 588.4, {\"st\", \
\"bi\"},\"chl\"},     \n{1,  2, 0.6600, 6.00, 590.3, {\"st\", \
\"bi\"},\"chl\"}},  \n \n{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1460, 6.00, 574.5, {\"chl\", \"bi\"},\"st\"}, \
   \n{1,  2, 0.1600, 6.00, 574.4, {\"chl\", \"bi\"},\"st\"},    \n{1,  2, \
0.2000, 6.00, 574.3, {\"chl\", \"bi\"},\"st\"},   \n{1,  2, 0.2400, 6.00, \
574.2, {\"chl\", \"bi\"},\"st\"},    \n{1,  2, 0.2800, 6.00, 574.1, {\"chl\", \
\"bi\"},\"st\"},    \n{1,  2, 0.3000, 6.00, 574.0, {\"chl\", \"bi\"},\"st\"}, \
   \n{1,  2, 0.3400, 6.00, 573.9, {\"chl\", \"bi\"},\"st\"},    \n{1,  2, \
0.3600, 6.00, 573.8, {\"chl\", \"bi\"},\"st\"},  \n{1,  2, 0.3800, 6.00, \
573.7, {\"chl\", \"bi\"},\"st\"},   \n{1,  2, 0.4000, 6.00, 573.6, {\"chl\", \
\"bi\"},\"st\"},   \n{1,  2, 0.4225, 6.00, 573.5, {\"chl\", \"bi\"},\"st\"}}, \
 \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["ky-st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5000, 6.00, 630.5, {\"st\", \"bi\"},\"ky\"},  \
   \n{1,  2, 0.5200, 6.00, 623.2, {\"st\", \"bi\"},\"ky\"},     \n{1,  2, \
0.5400, 6.00, 614.8, {\"st\", \"bi\"},\"ky\"},   \n{1,  2, 0.5600, 6.00, \
605.1, {\"st\", \"bi\"},\"ky\"},   \n{1,  2, 0.5800, 6.00, 593.6, {\"st\", \
\"bi\"},\"ky\"},   \n{1,  2, 0.6000, 6.00, 579.8, {\"st\", \"bi\"},\"ky\"}},  \
 \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9200, 6.00, 632.0, {\"bi\", \"ky\"},\"st\"},  \
  \n{1,  2, 0.9300, 6.00, 622.7, {\"bi\", \"ky\"},\"st\"},   \n{1,  2, \
0.9400, 6.00, 609.9, {\"bi\", \"ky\"},\"st\"},   \n{1,  2, 0.9500, 6.00, \
591.5, {\"bi\", \"ky\"},\"st\"},   \n{1,  2, 0.9600, 6.00, 563.7, {\"bi\", \
\"ky\"},\"st\"}},    \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["ky-bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9510, 6.00, 584.7, {\"bi\", \"ky\"},\"chl\"}, \
     \n{1,  2, 0.9540, 6.00, 584.9, {\"bi\", \"ky\"},\"chl\"},     \n{1,  2, \
0.9560, 6.00, 585.0, {\"bi\", \"ky\"},\"chl\"},     \n{1,  2, 0.9570, 6.00, \
585.1, {\"bi\", \"ky\"},\"chl\"},    \n{1,  2, 0.9590, 6.00, 585.2, {\"bi\", \
\"ky\"},\"chl\"},   \n{1,  2, 0.9600, 6.00, 585.3, {\"bi\", \"ky\"},\"chl\"}, \
  \n{1,  2, 0.9620, 6.00, 585.4, {\"bi\", \"ky\"},\"chl\"},    \n{1,  2, \
0.9630, 6.00, 585.5, {\"bi\", \"ky\"},\"chl\"}},   \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9520, 6.00, 584.7, {\"chl\", \"ky\"},\"bi\"}, \
   \n{1,  2, 0.9550, 6.00, 584.9, {\"chl\", \"ky\"},\"bi\"},    \n{1,  2, \
0.9560, 6.00, 585.0, {\"chl\", \"ky\"},\"bi\"},    \n{1,  2, 0.9580, 6.00, \
585.1, {\"chl\", \"ky\"},\"bi\"},     \n{1,  2, 0.9590, 6.00, 585.2, \
{\"chl\", \"ky\"},\"bi\"},   \n{1,  2, 0.9600, 6.00, 585.3, {\"chl\", \
\"ky\"},\"bi\"},   \n{1,  2, 0.9620, 6.00, 585.4, {\"chl\", \"ky\"},\"bi\"},  \
  \n{1,  2, 0.9630, 6.00, 585.5, {\"chl\", \"ky\"},\"bi\"}},    \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["sill-st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.2200, 6.00, 645.4, {\"st\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.2400, 6.00, 644.6, {\"st\", \"bi\"},\"sill\
\"},    \n{1,  2, 0.2600, 6.00, 643.8, {\"st\", \"bi\"},\"sill\"},    \n{1,  \
2, 0.2800, 6.00, 643.0, {\"st\", \"bi\"},\"sill\"},     \n{1,  2, 0.3000, \
6.00, 642.0, {\"st\", \"bi\"},\"sill\"},    \n{1,  2, 0.3200, 6.00, 641.0, \
{\"st\", \"bi\"},\"sill\"},    \n{1,  2, 0.3400, 6.00, 639.9, {\"st\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.3600, 6.00, 638.7, {\"st\", \"bi\"},\"sill\
\"},    \n{1,  2, 0.3800, 6.00, 637.4, {\"st\", \"bi\"},\"sill\"},    \n{1,  \
2, 0.4000, 6.00, 636.0, {\"st\", \"bi\"},\"sill\"},    \n{1,  2, 0.4200, \
6.00, 634.4, {\"st\", \"bi\"},\"sill\"},    \n{1,  2, 0.4400, 6.00, 632.7, \
{\"st\", \"bi\"},\"sill\"},   \n{1,  2, 0.4600, 6.00, 630.7, {\"st\", \
\"bi\"},\"sill\"},     \n{1,  2, 0.4800, 6.00, 628.6, {\"st\", \"bi\"},\"sill\
\"},    \n{1,  2, 0.5000, 6.00, 626.1, {\"st\", \"bi\"},\"sill\"},   \n{1,  \
2, 0.5200, 6.00, 623.4, {\"st\", \"bi\"},\"sill\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["sill-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5800, 6.00, 645.3, {\"bi\", \
\"sill\"},\"st\"},     \n{1,  2, 0.6000, 6.00, 645.1, {\"bi\", \"sill\"},\"st\
\"},    \n{1,  2, 0.6200, 6.00, 644.9, {\"bi\", \"sill\"},\"st\"},    \n{1,  \
2, 0.6400, 6.00, 644.6, {\"bi\", \"sill\"},\"st\"},   \n{1,  2, 0.6600, 6.00, \
644.3, {\"bi\", \"sill\"},\"st\"},  \n{1,  2, 0.6800, 6.00, 644.0, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.7000, 6.00, 643.7, {\"bi\", \
\"sill\"},\"st\"},     \n{1,  2, 0.7200, 6.00, 643.2, {\"bi\", \"sill\"},\"st\
\"},    \n{1,  2, 0.7400, 6.00, 642.8, {\"bi\", \"sill\"},\"st\"},    \n{1,  \
2, 0.7600, 6.00, 642.2, {\"bi\", \"sill\"},\"st\"},   \n{1,  2, 0.7800, 6.00, \
641.5, {\"bi\", \"sill\"},\"st\"},    \n{1,  2, 0.8000, 6.00, 640.7, {\"bi\", \
\"sill\"},\"st\"},      \n{1,  2, 0.8200, 6.00, 639.7, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.8400, 6.00, 638.5, {\"bi\", \
\"sill\"},\"st\"},  \n{1,  2, 0.8600, 6.00, 636.9, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.8800, 6.00, 634.6, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.9000, 6.00, 631.5, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.9200, 6.00, 626.7, {\"bi\", \
\"sill\"},\"st\"},   \n{1,  2, 0.9400, 6.00, 618.5, {\"bi\", \
\"sill\"},\"st\"}},   \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["st-g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1590, 6.00, 628.2, {\"g\", \"bi\"},\"st\"},   \
 \n{1,  2, 0.1600, 6.00, 629.3, {\"g\", \"bi\"},\"st\"},    \n{1,  2, 0.1700, \
6.00, 636.9, {\"g\", \"bi\"},\"st\"},   \n{1,  2, 0.1800, 6.00, 644.9, \
{\"g\", \"bi\"},\"st\"},    \n{1,  2, 0.1900, 6.00, 653.2, {\"g\", \
\"bi\"},\"st\"}},    \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1590, 6.00, 628.2, {\"st\", \"bi\"},\"g\"},   \
  \n{1,  2, 0.1600, 6.00, 628.7, {\"st\", \"bi\"},\"g\"},     \n{1,  2, \
0.1700, 6.00, 630.9, {\"st\", \"bi\"},\"g\"},     \n{1,  2, 0.1800, 6.00, \
633.1, {\"st\", \"bi\"},\"g\"},   \n{1,  2, 0.1900, 6.00, 635.4, {\"st\", \
\"bi\"},\"g\"},    \n{1,  2, 0.2000, 6.00, 637.8, {\"st\", \"bi\"},\"g\"},   \
\n{1,  2, 0.2100, 6.00, 640.2, {\"st\", \"bi\"},\"g\"},   \n{1,  2, 0.2200, \
6.00, 642.7, {\"st\", \"bi\"},\"g\"},    \n{1,  2, 0.2300, 6.00, 645.4, {\"st\
\", \"bi\"},\"g\"}},   \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["sill-g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1740, 6.00, 651.3, {\"g\", \"bi\"},\"sill\"}, \
   \n{1,  2, 0.1760, 6.00, 649.0, {\"g\", \"bi\"},\"sill\"},    \n{1,  2, \
0.1780, 6.00, 646.6, {\"g\", \"bi\"},\"sill\"},     \n{1,  2, 0.1800, 6.00, \
644.3, {\"g\", \"bi\"},\"sill\"}},     \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["sill-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.5200, 6.00, 650.5, {\"bi\", \"sill\"},\"g\"}, \
    \n{1,  2, 0.5300, 6.00, 649.9, {\"bi\", \"sill\"},\"g\"},    \n{1,  2, \
0.5400, 6.00, 649.3, {\"bi\", \"sill\"},\"g\"},   \n{1,  2, 0.5500, 6.00, \
648.7, {\"bi\", \"sill\"},\"g\"},    \n{1,  2, 0.5600, 6.00, 648.1, {\"bi\", \
\"sill\"},\"g\"},    \n{1,  2, 0.5700, 6.00, 647.4, {\"bi\", \
\"sill\"},\"g\"},  \n{1,  2, 0.5800, 6.00, 646.7, {\"bi\", \"sill\"},\"g\"},  \
\n{1,  2, 0.5900, 6.00, 645.9, {\"bi\", \"sill\"},\"g\"},  \n{1,  2, 0.6000, \
6.00, 645.1, {\"bi\", \"sill\"},\"g\"},     \n{1,  2, 0.6100, 6.00, 644.1, \
{\"bi\", \"sill\"},\"g\"}} };         ",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["allqlines = {\n(* ",
    FontWeight->"Plain"],
  StyleBox["chl",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.3400, 6.00, 499.3, {\"chl\"},\"bi\"},   \n{1, \
 2, 0.3500, 6.00, 506.7, {\"chl\"},\"bi\"},     \n{1,  2, 0.3600, 6.00, \
514.5, {\"chl\"},\"bi\"},      \n{1,  2, 0.3700, 6.00, 522.5, \
{\"chl\"},\"bi\"},      \n{1,  2, 0.3800, 6.00, 531.1, {\"chl\"},\"bi\"},     \
\n{1,  2, 0.3900, 6.00, 540.1, {\"chl\"},\"bi\"},      \n{1,  2, 0.4000, \
6.00, 549.6, {\"chl\"},\"bi\"},     \n{1,  2, 0.4100, 6.00, 559.6, {\"chl\"},\
\"bi\"},    \n{1,  2, 0.4200, 6.00, 570.4, {\"chl\"},\"bi\"},    \n{1,  2, \
0.4300, 6.00, 581.8, {\"chl\"},\"bi\"},    \n{1,  2, 0.4400, 6.00, 594.1, \
{\"chl\"},\"bi\"}},   \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4000, 6.00, 620.7, {\"chl\"},\"st\"},     \n\
{1,  2, 0.4100, 6.00, 600.0, {\"chl\"},\"st\"},    \n{1,  2, 0.4200, 6.00, \
579.4, {\"chl\"},\"st\"},    \n{1,  2, 0.4300, 6.00, 558.6, \
{\"chl\"},\"st\"},     \n{1,  2, 0.4400, 6.00, 537.5, {\"chl\"},\"st\"},   \n\
{1,  2, 0.4500, 6.00, 516.0, {\"chl\"},\"st\"}},   \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ctd-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.4350, 6.00, 563.1, {\"chl\"},\"ctd\"},     \n\
{1,  2, 0.4360, 6.00, 551.1, {\"chl\"},\"ctd\"},    \n{1,  2, 0.4370, 6.00, \
539.3, {\"chl\"},\"ctd\"},    \n{1,  2, 0.4380, 6.00, 527.5, \
{\"chl\"},\"ctd\"},    \n{1,  2, 0.4390, 6.00, 515.8, {\"chl\"},\"ctd\"},   \n\
{1,  2, 0.4400, 6.00, 504.2, {\"chl\"},\"ctd\"},    \n{1,  2, 0.4410, 6.00, \
492.6, {\"chl\"},\"ctd\"}},   \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["bi",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-chl ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["edge *)\n{1,  2, 0.0700, 6.00, 496.4, {\"bi\"},\"chl\"},     \n\
{1,  2, 0.0800, 6.00, 507.5, {\"bi\"},\"chl\"},    \n{1,  2, 0.0900, 6.00, \
518.2, {\"bi\"},\"chl\"},    \n{1,  2, 0.1000, 6.00, 528.6, \
{\"bi\"},\"chl\"},     \n{1,  2, 0.1100, 6.00, 538.8, {\"bi\"},\"chl\"},     \
\n{1,  2, 0.1200, 6.00, 548.9, {\"bi\"},\"chl\"},   \n{1,  2, 0.1300, 6.00, \
558.8, {\"bi\"},\"chl\"},    \n{1,  2, 0.1400, 6.00, 568.8, \
{\"bi\"},\"chl\"},   \n{1,  2, 0.1500, 6.00, 578.7, {\"bi\"},\"chl\"},   \n\
{1,  2, 0.1600, 6.00, 588.7, {\"bi\"},\"chl\"}},  \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["st-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1440, 6.00, 567.8, {\"bi\"},\"st\"},     \n\
{1,  2, 0.1467, 6.00, 578.1, {\"bi\"},\"st\"},    \n{1,  2, 0.1493, 6.00, \
588.6, {\"bi\"},\"st\"},   \n{1,  2, 0.1520, 6.00, 599.4, {\"bi\"},\"st\"},   \
\n{1,  2, 0.1547, 6.00, 610.1, {\"bi\"},\"st\"},  \n{1,  2, 0.1573, 6.00, \
621.4, {\"bi\"},\"st\"},   \n{1,  2, 0.1600, 6.00, 632.5, {\"bi\"},\"st\"}},  \
 \n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["g-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.1580, 6.00, 622.5, {\"bi\"},\"g\"},    \n{1,  \
2, 0.1590, 6.00, 628.0, {\"bi\"},\"g\"},     \n{1,  2, 0.1600, 6.00, 634.1, {\
\"bi\"},\"g\"},    \n{1,  2, 0.1610, 6.00, 640.0, {\"bi\"},\"g\"},    \n{1,  \
2, 0.1620, 6.00, 645.9, {\"bi\"},\"g\"},    \n{1,  2, 0.1630, 6.00, 651.8, \
{\"bi\"},\"g\"},    \n{1,  2, 0.1640, 6.00, 657.8, {\"bi\"},\"g\"}},   \n\n\
{(* ",
    FontWeight->"Plain"],
  StyleBox["bi-ksp",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.0300, 6.00, 494.0, {\"bi\"},\"ksp\"},    \n\
{1,  2, 0.0400, 6.00, 514.8, {\"bi\"},\"ksp\"},    \n{1,  2, 0.0500, 6.00, \
533.7, {\"bi\"},\"ksp\"},     \n{1,  2, 0.0600, 6.00, 551.5, \
{\"bi\"},\"ksp\"},     \n{1,  2, 0.0700, 6.00, 568.6, {\"bi\"},\"ksp\"},    \n\
{1,  2, 0.0800, 6.00, 585.1, {\"bi\"},\"ksp\"},     \n{1,  2, 0.0900, 6.00, \
601.6, {\"bi\"},\"ksp\"},     \n{1,  2, 0.1000, 6.00, 617.8, \
{\"bi\"},\"ksp\"},    \n{1,  2, 0.1100, 6.00, 634.1, {\"bi\"},\"ksp\"},    \n\
{1,  2, 0.1200, 6.00, 650.5, {\"bi\"},\"ksp\"}},   \n\n(* ",
    FontWeight->"Plain"],
  StyleBox["als",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" *)\n{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-chl",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9600, 6.00, 603.6, {\"ky\"},\"chl\"},    \n\
{1,  2, 0.9650, 6.00, 578.6, {\"ky\"},\"chl\"},    \n{1,  2, 0.9700, 6.00, \
552.6, {\"ky\"},\"chl\"},    \n{1,  2, 0.9750, 6.00, 524.8, \
{\"ky\"},\"chl\"},    \n{1,  2, 0.9800, 6.00, 494.4, {\"ky\"},\"chl\"}}, \n\n\
{(* ",
    FontWeight->"Plain"],
  StyleBox["ky-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9635, 6.00, 633.8, {\"ky\"},\"bi\"},    \n{1, \
 2, 0.9635, 6.00, 622.2, {\"ky\"},\"bi\"},    \n{1,  2, 0.9635, 6.00, 614.0, \
{\"ky\"},\"bi\"},     \n{1,  2, 0.9636, 6.00, 605.7, {\"ky\"},\"bi\"},    \n\
{1,  2, 0.9636, 6.00, 597.9, {\"ky\"},\"bi\"},    \n{1,  2, 0.9636, 6.00, \
591.0, {\"ky\"},\"bi\"},    \n{1,  2, 0.9637, 6.00, 584.5, {\"ky\"},\"bi\"},  \
  \n{1,  2, 0.9637, 6.00, 577.8, {\"ky\"},\"bi\"}},\n\n{(* ",
    FontWeight->"Plain"],
  StyleBox["sill-bi",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" edge *)\n{1,  2, 0.9622, 6.00, 655.6, {\"sill\"},\"bi\"},   \n\
{1,  2, 0.9624, 6.00, 650.5, {\"sill\"},\"bi\"},    \n{1,  2, 0.9626, 6.00, \
645.4, {\"sill\"},\"bi\"},     \n{1,  2, 0.9628, 6.00, 640.4, {\"sill\"},\"bi\
\"},    \n{1,  2, 0.9630, 6.00, 635.5, {\"sill\"},\"bi\"},    \n{1,  2, \
0.9632, 6.00, 630.6, {\"sill\"},\"bi\"},    \n{1,  2, 0.9634, 6.00, 625.8, \
{\"sill\"},\"bi\"},    \n{1,  2, 0.9636, 6.00, 621.0, {\"sill\"},\"bi\"}},\n\n\
{{1,  2,     ",
    FontWeight->"Plain"],
  StyleBox["2,    6,   400",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {\"ky\"},\"Q\"},   (* ",
    FontWeight->"Plain"],
  StyleBox["forces drawing properly",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  *)\n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["2,    6,   623.4",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {\"ky\"},\"Q\"}},\n\n{{1,  2,     ",
    FontWeight->"Plain"],
  StyleBox["2,    6,   623.4",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {\"sill\"},\"Q\"},   \n{1,  2,      ",
    FontWeight->"Plain"],
  StyleBox["2,    6,   800",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {\"sill\"},\"Q\"}}  };\n",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["\<\
____________________________________________________________________\
_\
\>", "SmallText",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["assembling data", "Subsubsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell["setupvx;", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing diagrams", "Subsection",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
left = 0; right = 1; bottom = 500; top = 650;
delv = 2; 
makevx[6.00];\
\>", "Input",
  ImageRegion->{{-0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% PlotRegion
0 1 0 1 MPlotRegion
% Scaling calculations
-0 1 -3.33333 0.00666667 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(500)] -0.0125 0 1 0 Msboxa
[(520)] -0.0125 .13333 1 0 Msboxa
[(540)] -0.0125 .26667 1 0 Msboxa
[(560)] -0.0125 .4 1 0 Msboxa
[(580)] -0.0125 .53333 1 0 Msboxa
[(600)] -0.0125 .66667 1 0 Msboxa
[(620)] -0.0125 .8 1 0 Msboxa
[(640)] -0.0125 .93333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(500)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .13333 m
.00625 .13333 L
s
P
[(520)] -0.0125 .13333 1 0 Mshowa
p
.002 w
0 .26667 m
.00625 .26667 L
s
P
[(540)] -0.0125 .26667 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(560)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .53333 m
.00625 .53333 L
s
P
[(580)] -0.0125 .53333 1 0 Mshowa
p
.002 w
0 .66667 m
.00625 .66667 L
s
P
[(600)] -0.0125 .66667 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(620)] -0.0125 .8 1 0 Mshowa
p
.002 w
0 .93333 m
.00625 .93333 L
s
P
[(640)] -0.0125 .93333 1 0 Mshowa
p
.001 w
0 .02667 m
.00375 .02667 L
s
P
p
.001 w
0 .05333 m
.00375 .05333 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .10667 m
.00375 .10667 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18667 m
.00375 .18667 L
s
P
p
.001 w
0 .21333 m
.00375 .21333 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .29333 m
.00375 .29333 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34667 m
.00375 .34667 L
s
P
p
.001 w
0 .37333 m
.00375 .37333 L
s
P
p
.001 w
0 .42667 m
.00375 .42667 L
s
P
p
.001 w
0 .45333 m
.00375 .45333 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .50667 m
.00375 .50667 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58667 m
.00375 .58667 L
s
P
p
.001 w
0 .61333 m
.00375 .61333 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .69333 m
.00375 .69333 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74667 m
.00375 .74667 L
s
P
p
.001 w
0 .77333 m
.00375 .77333 L
s
P
p
.001 w
0 .82667 m
.00375 .82667 L
s
P
p
.001 w
0 .85333 m
.00375 .85333 L
s
P
p
.001 w
0 .88 m
.00375 .88 L
s
P
p
.001 w
0 .90667 m
.00375 .90667 L
s
P
p
.001 w
0 .96 m
.00375 .96 L
s
P
p
.001 w
0 .98667 m
.00375 .98667 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .13333 m
1 .13333 L
s
P
p
.002 w
.99375 .26667 m
1 .26667 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .53333 m
1 .53333 L
s
P
p
.002 w
.99375 .66667 m
1 .66667 L
s
P
p
.002 w
.99375 .8 m
1 .8 L
s
P
p
.002 w
.99375 .93333 m
1 .93333 L
s
P
p
.001 w
.99625 .02667 m
1 .02667 L
s
P
p
.001 w
.99625 .05333 m
1 .05333 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .10667 m
1 .10667 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18667 m
1 .18667 L
s
P
p
.001 w
.99625 .21333 m
1 .21333 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .29333 m
1 .29333 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34667 m
1 .34667 L
s
P
p
.001 w
.99625 .37333 m
1 .37333 L
s
P
p
.001 w
.99625 .42667 m
1 .42667 L
s
P
p
.001 w
.99625 .45333 m
1 .45333 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .50667 m
1 .50667 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58667 m
1 .58667 L
s
P
p
.001 w
.99625 .61333 m
1 .61333 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .69333 m
1 .69333 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74667 m
1 .74667 L
s
P
p
.001 w
.99625 .77333 m
1 .77333 L
s
P
p
.001 w
.99625 .82667 m
1 .82667 L
s
P
p
.001 w
.99625 .85333 m
1 .85333 L
s
P
p
.001 w
.99625 .88 m
1 .88 L
s
P
p
.001 w
.99625 .90667 m
1 .90667 L
s
P
p
.001 w
.99625 .96 m
1 .96 L
s
P
p
.001 w
.99625 .98667 m
1 .98667 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
1 .7 .7 r
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
F
P
p
1 .55 .55 r
p
.1197 1 m
.11848 .98667 L
.11726 .97333 L
.11604 .96 L
.11482 .94667 L
.1136 .93333 L
.11238 .92 L
.11116 .90667 L
.10994 .89333 L
.10872 .88 L
.10749 .86667 L
.10626 .85333 L
.10504 .84 L
.10381 .82667 L
.10258 .81333 L
.10135 .8 L
.10012 .78667 L
.09889 .77333 L
.09765 .76 L
.09641 .74667 L
.09518 .73333 L
.09394 .72 L
.09271 .70667 L
.09148 .69333 L
.09025 .68 L
.08903 .66667 L
.08781 .65333 L
.08659 .64 L
.08538 .62667 L
.08417 .61333 L
.08296 .6 L
.08175 .58667 L
.08054 .57333 L
.07933 .56 L
.07811 .54667 L
.07689 .53333 L
.07568 .52 L
.07446 .50667 L
.07325 .49333 L
.07204 .48 L
.07084 .46667 L
.06964 .45333 L
.06846 .44 L
.06727 .42667 L
.0661 .41333 L
.06492 .4 L
.06376 .38667 L
.06259 .37333 L
.06144 .36 L
.06029 .34667 L
.05914 .33333 L
.058 .32 L
.05686 .30667 L
.05573 .29333 L
.0546 .28 L
.05348 .26667 L
.05237 .25333 L
.05126 .24 L
.05016 .22667 L
.04907 .21333 L
.04799 .2 L
.04691 .18667 L
.04584 .17333 L
.04477 .16 L
.04372 .14667 L
.04268 .13333 L
.04164 .12 L
.04061 .10667 L
.03959 .09333 L
.03859 .08 L
.03759 .06667 L
.0366 .05333 L
.03562 .04 L
.03466 .02667 L
.0337 .01333 L
.03276 0 L
.0732 0 L
.07501 .01342 L
.07683 .02685 L
.07866 .04027 L
.08051 .05369 L
.08237 .06712 L
.08424 .08054 L
.08613 .09396 L
.08802 .10739 L
.08993 .12081 L
.09184 .13423 L
.09377 .14766 L
.0957 .16108 L
.09765 .1745 L
.0996 .18793 L
.10156 .20135 L
.10353 .21477 L
.1055 .2282 L
.10748 .24162 L
.10946 .25505 L
.11145 .26847 L
.11343 .28189 L
.11542 .29532 L
.11742 .30874 L
.11943 .32216 L
.12145 .33559 L
.12348 .34901 L
.12551 .36243 L
.12755 .37586 L
.12959 .38928 L
.13161 .4027 L
.13362 .41613 L
.13563 .42955 L
.13764 .44297 L
.13966 .4564 L
.14169 .46982 L
.14372 .48324 L
.14576 .49667 L
.14578 .49667 L
.14631 .51044 L
.14683 .52421 L
.14735 .53797 L
.14786 .55174 L
.14837 .56551 L
.14888 .57928 L
.14939 .59305 L
.1499 .60682 L
.15042 .62059 L
.15094 .63436 L
.15145 .64813 L
.15197 .6619 L
.1525 .67567 L
.15302 .68944 L
.15355 .70321 L
.15407 .71697 L
.15458 .73074 L
.15507 .74451 L
.15555 .75828 L
.15602 .77205 L
.15649 .78582 L
.15696 .79959 L
.15744 .81336 L
.15792 .82713 L
.15841 .8409 L
.15891 .85467 L
.15903 .85467 L
.1594 .8692 L
.15975 .88373 L
.16011 .89827 L
.16048 .9128 L
.16085 .92733 L
.16122 .94187 L
.16159 .9564 L
.16196 .97093 L
.16233 .98547 L
.1627 1 L
.1197 1 L
F
.44036 0 m
.44019 .01358 L
.44001 .02715 L
.43984 .04073 L
.43966 .0543 L
.43948 .06788 L
.43931 .08145 L
.43913 .09503 L
.43896 .10861 L
.43878 .12218 L
.43861 .13576 L
.43843 .14933 L
.43826 .16291 L
.43809 .17648 L
.43791 .19006 L
.43774 .20364 L
.43757 .21721 L
.4374 .23079 L
.43722 .24436 L
.43705 .25794 L
.43688 .27152 L
.43671 .28509 L
.43653 .29867 L
.43656 .29867 L
.43559 .31233 L
.43462 .326 L
.43364 .33967 L
.43267 .35333 L
.43169 .367 L
.43072 .38067 L
.42974 .39433 L
.42876 .408 L
.42778 .42167 L
.42679 .43533 L
.42581 .449 L
.42482 .46267 L
.42384 .47633 L
.42285 .49 L
.42278 .49 L
.42095 .47639 L
.41912 .46278 L
.41727 .44917 L
.41539 .43556 L
.4135 .42194 L
.41157 .40833 L
.40962 .39472 L
.40763 .38111 L
.4056 .3675 L
.40355 .35389 L
.40148 .34028 L
.39938 .32667 L
.39727 .31306 L
.39514 .29944 L
.39298 .28583 L
.39079 .27222 L
.38858 .25861 L
.38634 .245 L
.38407 .23139 L
.38178 .21778 L
.37946 .20417 L
.37713 .19056 L
.37478 .17694 L
.37238 .16333 L
.36995 .14972 L
.36744 .13611 L
.3649 .1225 L
.36233 .10889 L
.35974 .09528 L
.35715 .08167 L
.35455 .06806 L
.35191 .05444 L
.34924 .04083 L
.34654 .02722 L
.34378 .01361 L
.34097 0 L
.44036 0 L
F
.97912 0 m
.97879 .01357 L
.97847 .02714 L
.97814 .04071 L
.9778 .05429 L
.97747 .06786 L
.97713 .08143 L
.97679 .095 L
.97645 .10857 L
.97611 .12214 L
.97576 .13571 L
.97541 .14929 L
.97506 .16286 L
.97471 .17643 L
.97436 .19 L
.974 .20357 L
.97364 .21714 L
.97328 .23071 L
.97292 .24429 L
.97255 .25786 L
.97218 .27143 L
.97181 .285 L
.97144 .29857 L
.97107 .31214 L
.9707 .32571 L
.97032 .33929 L
.96994 .35286 L
.96956 .36643 L
.96917 .38 L
.96879 .39357 L
.9684 .40714 L
.96801 .42071 L
.96762 .43429 L
.96723 .44786 L
.96683 .46143 L
.96644 .475 L
.96604 .48857 L
.96564 .50214 L
.96524 .51571 L
.96484 .52929 L
.96444 .54286 L
.96404 .55643 L
.96363 .57 L
.96369 .57 L
.96365 .58404 L
.96362 .59807 L
.9636 .61211 L
.96359 .62615 L
.9636 .64019 L
.9636 .65422 L
.9636 .66826 L
.96361 .6823 L
.9636 .69633 L
.96359 .71037 L
.96357 .72441 L
.96354 .73844 L
.96351 .75248 L
.9635 .76652 L
.96349 .78056 L
.96349 .79459 L
.9635 .80863 L
.9635 .82267 L
1 .82267 L
1 0 L
.97912 0 L
F
.96242 1 m
.9625 .98636 L
.96258 .97272 L
.96266 .95908 L
.96274 .94544 L
.96283 .93179 L
.96291 .91815 L
.96299 .90451 L
.96308 .89087 L
.96316 .87723 L
.96324 .86359 L
.96333 .84995 L
.96341 .83631 L
.9635 .82267 L
1 .82267 L
1 1 L
.96242 1 L
F
P
0 g
p
.004 w
.1197 1 m
.11848 .98667 L
.11726 .97333 L
.11604 .96 L
.11482 .94667 L
.1136 .93333 L
.11238 .92 L
.11116 .90667 L
.10994 .89333 L
.10872 .88 L
.10749 .86667 L
.10626 .85333 L
.10504 .84 L
.10381 .82667 L
.10258 .81333 L
.10135 .8 L
.10012 .78667 L
.09889 .77333 L
.09765 .76 L
.09641 .74667 L
.09518 .73333 L
.09394 .72 L
.09271 .70667 L
.09148 .69333 L
.09025 .68 L
.08903 .66667 L
.08781 .65333 L
.08659 .64 L
.08538 .62667 L
.08417 .61333 L
.08296 .6 L
.08175 .58667 L
.08054 .57333 L
.07933 .56 L
.07811 .54667 L
.07689 .53333 L
.07568 .52 L
.07446 .50667 L
.07325 .49333 L
.07204 .48 L
.07084 .46667 L
.06964 .45333 L
.06846 .44 L
.06727 .42667 L
.0661 .41333 L
.06492 .4 L
.06376 .38667 L
.06259 .37333 L
.06144 .36 L
.06029 .34667 L
Mistroke
.05914 .33333 L
.058 .32 L
.05686 .30667 L
.05573 .29333 L
.0546 .28 L
.05348 .26667 L
.05237 .25333 L
.05126 .24 L
.05016 .22667 L
.04907 .21333 L
.04799 .2 L
.04691 .18667 L
.04584 .17333 L
.04477 .16 L
.04372 .14667 L
.04268 .13333 L
.04164 .12 L
.04061 .10667 L
.03959 .09333 L
.03859 .08 L
.03759 .06667 L
.0366 .05333 L
.03562 .04 L
.03466 .02667 L
.0337 .01333 L
.03276 0 L
.0732 0 L
.07501 .01342 L
.07683 .02685 L
.07866 .04027 L
.08051 .05369 L
.08237 .06712 L
.08424 .08054 L
.08613 .09396 L
.08802 .10739 L
.08993 .12081 L
.09184 .13423 L
.09377 .14766 L
.0957 .16108 L
.09765 .1745 L
.0996 .18793 L
.10156 .20135 L
.10353 .21477 L
.1055 .2282 L
.10748 .24162 L
.10946 .25505 L
.11145 .26847 L
.11343 .28189 L
.11542 .29532 L
.11742 .30874 L
Mistroke
.11943 .32216 L
.12145 .33559 L
.12348 .34901 L
.12551 .36243 L
.12755 .37586 L
.12959 .38928 L
.13161 .4027 L
.13362 .41613 L
.13563 .42955 L
.13764 .44297 L
.13966 .4564 L
.14169 .46982 L
.14372 .48324 L
.14576 .49667 L
.14578 .49667 L
.14631 .51044 L
.14683 .52421 L
.14735 .53797 L
.14786 .55174 L
.14837 .56551 L
.14888 .57928 L
.14939 .59305 L
.1499 .60682 L
.15042 .62059 L
.15094 .63436 L
.15145 .64813 L
.15197 .6619 L
.1525 .67567 L
.15302 .68944 L
.15355 .70321 L
.15407 .71697 L
.15458 .73074 L
.15507 .74451 L
.15555 .75828 L
.15602 .77205 L
.15649 .78582 L
.15696 .79959 L
.15744 .81336 L
.15792 .82713 L
.15841 .8409 L
.15891 .85467 L
.15903 .85467 L
.1594 .8692 L
.15975 .88373 L
.16011 .89827 L
.16048 .9128 L
.16085 .92733 L
.16122 .94187 L
.16159 .9564 L
.16196 .97093 L
Mistroke
.16233 .98547 L
.1627 1 L
.1197 1 L
Mfstroke
.44036 0 m
.44019 .01358 L
.44001 .02715 L
.43984 .04073 L
.43966 .0543 L
.43948 .06788 L
.43931 .08145 L
.43913 .09503 L
.43896 .10861 L
.43878 .12218 L
.43861 .13576 L
.43843 .14933 L
.43826 .16291 L
.43809 .17648 L
.43791 .19006 L
.43774 .20364 L
.43757 .21721 L
.4374 .23079 L
.43722 .24436 L
.43705 .25794 L
.43688 .27152 L
.43671 .28509 L
.43653 .29867 L
.43656 .29867 L
.43559 .31233 L
.43462 .326 L
.43364 .33967 L
.43267 .35333 L
.43169 .367 L
.43072 .38067 L
.42974 .39433 L
.42876 .408 L
.42778 .42167 L
.42679 .43533 L
.42581 .449 L
.42482 .46267 L
.42384 .47633 L
.42285 .49 L
.42278 .49 L
.42095 .47639 L
.41912 .46278 L
.41727 .44917 L
.41539 .43556 L
.4135 .42194 L
.41157 .40833 L
.40962 .39472 L
.40763 .38111 L
.4056 .3675 L
.40355 .35389 L
.40148 .34028 L
Mistroke
.39938 .32667 L
.39727 .31306 L
.39514 .29944 L
.39298 .28583 L
.39079 .27222 L
.38858 .25861 L
.38634 .245 L
.38407 .23139 L
.38178 .21778 L
.37946 .20417 L
.37713 .19056 L
.37478 .17694 L
.37238 .16333 L
.36995 .14972 L
.36744 .13611 L
.3649 .1225 L
.36233 .10889 L
.35974 .09528 L
.35715 .08167 L
.35455 .06806 L
.35191 .05444 L
.34924 .04083 L
.34654 .02722 L
.34378 .01361 L
.34097 0 L
.44036 0 L
Mfstroke
.97912 0 m
.97879 .01357 L
.97847 .02714 L
.97814 .04071 L
.9778 .05429 L
.97747 .06786 L
.97713 .08143 L
.97679 .095 L
.97645 .10857 L
.97611 .12214 L
.97576 .13571 L
.97541 .14929 L
.97506 .16286 L
.97471 .17643 L
.97436 .19 L
.974 .20357 L
.97364 .21714 L
.97328 .23071 L
.97292 .24429 L
.97255 .25786 L
.97218 .27143 L
.97181 .285 L
.97144 .29857 L
.97107 .31214 L
.9707 .32571 L
.97032 .33929 L
.96994 .35286 L
.96956 .36643 L
.96917 .38 L
.96879 .39357 L
.9684 .40714 L
.96801 .42071 L
.96762 .43429 L
.96723 .44786 L
.96683 .46143 L
.96644 .475 L
.96604 .48857 L
.96564 .50214 L
.96524 .51571 L
.96484 .52929 L
.96444 .54286 L
.96404 .55643 L
.96363 .57 L
.96369 .57 L
.96365 .58404 L
.96362 .59807 L
.9636 .61211 L
.96359 .62615 L
.9636 .64019 L
.9636 .65422 L
Mistroke
.9636 .66826 L
.96361 .6823 L
.9636 .69633 L
.96359 .71037 L
.96357 .72441 L
.96354 .73844 L
.96351 .75248 L
.9635 .76652 L
.96349 .78056 L
.96349 .79459 L
.9635 .80863 L
.9635 .82267 L
1 .82267 L
1 0 L
.97912 0 L
Mfstroke
.96242 1 m
.9625 .98636 L
.96258 .97272 L
.96266 .95908 L
.96274 .94544 L
.96283 .93179 L
.96291 .91815 L
.96299 .90451 L
.96308 .89087 L
.96316 .87723 L
.96324 .86359 L
.96333 .84995 L
.96341 .83631 L
.9635 .82267 L
1 .82267 L
1 1 L
.96242 1 L
s
P
P
p
1 g
p
.952 .56533 m
.963 .57 L
.952 .56533 L
F
.59262 .56533 m
.55658 .5516 L
.5082 .53787 L
.44079 .52413 L
.3378 .5104 L
.146 .49667 L
.146 .49667 L
.4225 .49 L
.423 .49 L
.50465 .50507 L
.5604 .52013 L
.59831 .5352 L
.6263 .55027 L
.64962 .56533 L
.59262 .56533 L
F
.17928 .96733 m
.17721 .98367 L
.17515 1 L
.52833 1 L
.56792 .98367 L
.6 .96733 L
.17928 .96733 L
F
.18024 .96733 m
.17765 .95325 L
.17503 .93917 L
.17237 .92508 L
.16963 .911 L
.16655 .89692 L
.16364 .88283 L
.16106 .86875 L
.159 .85467 L
.159 .85467 L
.16682 .86875 L
.17696 .88283 L
.1863 .89692 L
.19524 .911 L
.20403 .92508 L
.21275 .93917 L
.22111 .95325 L
.22894 .96733 L
.18024 .96733 L
F
.59316 .56533 m
.59026 .57888 L
.58728 .59242 L
.58422 .60596 L
.58107 .61951 L
.57782 .63305 L
.57447 .6466 L
.57102 .66014 L
.56745 .67368 L
.56377 .68723 L
.55997 .70077 L
.55603 .71432 L
.55197 .72786 L
.54777 .7414 L
.54343 .75495 L
.53895 .76849 L
.53433 .78204 L
.52956 .79558 L
.52461 .80912 L
.51949 .82267 L
.92934 .82267 L
.93122 .80912 L
.93299 .79558 L
.93466 .78204 L
.93624 .76849 L
.93773 .75495 L
.93913 .7414 L
.94048 .72786 L
.94178 .71432 L
.94303 .70077 L
.94421 .68723 L
.94534 .67368 L
.94642 .66014 L
.94744 .6466 L
.94843 .63305 L
.94936 .61951 L
.95026 .60596 L
.95113 .59242 L
.95195 .57888 L
.95275 .56533 L
.59316 .56533 L
F
.52 .82267 m
.50395 .83713 L
.48722 .8516 L
.46774 .86607 L
.44648 .88053 L
.42184 .895 L
.39421 .90947 L
.36175 .92393 L
.32453 .9384 L
.28152 .95287 L
.2275 .96733 L
.6 .96733 L
.73361 .95287 L
.79862 .9384 L
.83865 .92393 L
.86488 .90947 L
.88263 .895 L
.89678 .88053 L
.90787 .86607 L
.91654 .8516 L
.92336 .83713 L
.92893 .82267 L
.52 .82267 L
F
.60528 0 m
.60221 .01404 L
.59909 .02807 L
.59589 .04211 L
.59263 .05615 L
.58929 .07019 L
.58586 .08422 L
.58233 .09826 L
.57871 .1123 L
.57497 .12633 L
.57112 .14037 L
.56716 .15441 L
.56306 .16844 L
.55885 .18248 L
.55451 .19652 L
.55002 .21056 L
.54535 .22459 L
.54049 .23863 L
.53542 .25267 L
.92061 .25267 L
.9257 .23863 L
.93023 .22459 L
.93448 .21056 L
.93804 .19652 L
.94147 .18248 L
.94462 .16844 L
.94755 .15441 L
.95018 .14037 L
.95266 .12633 L
.95486 .1123 L
.95697 .09826 L
.95898 .08422 L
.96084 .07019 L
.96256 .05615 L
.96423 .04211 L
.96578 .02807 L
.96723 .01404 L
.96861 0 L
.60528 0 L
F
.53572 .25267 m
.50907 .268 L
.47683 .28333 L
.437 .29867 L
.437 .29867 L
.49575 .28333 L
.54 .268 L
.57357 .25267 L
.53572 .25267 L
F
.57298 .25267 m
.57797 .26626 L
.58272 .27986 L
.58725 .29345 L
.59159 .30704 L
.59573 .32064 L
.59969 .33423 L
.60349 .34783 L
.60715 .36142 L
.61065 .37501 L
.61403 .38861 L
.61728 .4022 L
.62041 .4158 L
.62347 .42939 L
.62644 .44299 L
.6293 .45658 L
.63208 .47017 L
.63478 .48377 L
.63739 .49736 L
.63993 .51096 L
.6424 .52455 L
.6448 .53814 L
.64715 .55174 L
.64943 .56533 L
.954 .56533 L
.95335 .55174 L
.95268 .53814 L
.95197 .52455 L
.95123 .51096 L
.95045 .49736 L
.9496 .48377 L
.94869 .47017 L
.94774 .45658 L
.94675 .44299 L
.94571 .42939 L
.94458 .4158 L
.94335 .4022 L
.94205 .38861 L
.94068 .37501 L
.93919 .36142 L
.93756 .34783 L
.93578 .33423 L
.93383 .32064 L
.93169 .30704 L
.9293 .29345 L
.92666 .27986 L
.92377 .26626 L
.92053 .25267 L
.57298 .25267 L
F
P
0 g
p
.004 w
.952 .56533 m
.963 .57 L
s
.952 .56533 m
0 0 rlineto
.59262 .56533 m
.55658 .5516 L
.5082 .53787 L
.44079 .52413 L
.3378 .5104 L
.146 .49667 L
.146 .49667 L
.4225 .49 L
.423 .49 L
.50465 .50507 L
.5604 .52013 L
.59831 .5352 L
.6263 .55027 L
.64962 .56533 L
.59262 .56533 L
s
.17928 .96733 m
.17721 .98367 L
.17515 1 L
.52833 1 L
.56792 .98367 L
.6 .96733 L
.17928 .96733 L
s
.18024 .96733 m
.17765 .95325 L
.17503 .93917 L
.17237 .92508 L
.16963 .911 L
.16655 .89692 L
.16364 .88283 L
.16106 .86875 L
.159 .85467 L
.159 .85467 L
.16682 .86875 L
.17696 .88283 L
.1863 .89692 L
.19524 .911 L
.20403 .92508 L
.21275 .93917 L
.22111 .95325 L
.22894 .96733 L
.18024 .96733 L
s
.59316 .56533 m
.59026 .57888 L
.58728 .59242 L
.58422 .60596 L
.58107 .61951 L
.57782 .63305 L
.57447 .6466 L
.57102 .66014 L
.56745 .67368 L
.56377 .68723 L
.55997 .70077 L
.55603 .71432 L
.55197 .72786 L
.54777 .7414 L
.54343 .75495 L
.53895 .76849 L
.53433 .78204 L
.52956 .79558 L
.52461 .80912 L
.51949 .82267 L
.92934 .82267 L
.93122 .80912 L
.93299 .79558 L
.93466 .78204 L
.93624 .76849 L
.93773 .75495 L
.93913 .7414 L
.94048 .72786 L
.94178 .71432 L
.94303 .70077 L
.94421 .68723 L
.94534 .67368 L
.94642 .66014 L
.94744 .6466 L
.94843 .63305 L
.94936 .61951 L
.95026 .60596 L
.95113 .59242 L
.95195 .57888 L
.95275 .56533 L
.59316 .56533 L
s
.52 .82267 m
.50395 .83713 L
.48722 .8516 L
.46774 .86607 L
.44648 .88053 L
.42184 .895 L
.39421 .90947 L
.36175 .92393 L
.32453 .9384 L
.28152 .95287 L
.2275 .96733 L
.6 .96733 L
.73361 .95287 L
.79862 .9384 L
.83865 .92393 L
.86488 .90947 L
.88263 .895 L
.89678 .88053 L
.90787 .86607 L
.91654 .8516 L
.92336 .83713 L
.92893 .82267 L
.52 .82267 L
s
.60528 0 m
.60221 .01404 L
.59909 .02807 L
.59589 .04211 L
.59263 .05615 L
.58929 .07019 L
.58586 .08422 L
.58233 .09826 L
.57871 .1123 L
.57497 .12633 L
.57112 .14037 L
.56716 .15441 L
.56306 .16844 L
.55885 .18248 L
.55451 .19652 L
.55002 .21056 L
.54535 .22459 L
.54049 .23863 L
.53542 .25267 L
.92061 .25267 L
.9257 .23863 L
.93023 .22459 L
.93448 .21056 L
.93804 .19652 L
.94147 .18248 L
.94462 .16844 L
.94755 .15441 L
.95018 .14037 L
.95266 .12633 L
.95486 .1123 L
.95697 .09826 L
.95898 .08422 L
.96084 .07019 L
.96256 .05615 L
.96423 .04211 L
.96578 .02807 L
.96723 .01404 L
.96861 0 L
.60528 0 L
s
.53572 .25267 m
.50907 .268 L
.47683 .28333 L
.437 .29867 L
.437 .29867 L
.49575 .28333 L
.54 .268 L
.57357 .25267 L
.53572 .25267 L
s
.57298 .25267 m
.57797 .26626 L
.58272 .27986 L
.58725 .29345 L
.59159 .30704 L
.59573 .32064 L
.59969 .33423 L
.60349 .34783 L
.60715 .36142 L
.61065 .37501 L
.61403 .38861 L
.61728 .4022 L
.62041 .4158 L
.62347 .42939 L
.62644 .44299 L
.6293 .45658 L
.63208 .47017 L
.63478 .48377 L
.63739 .49736 L
.63993 .51096 L
.6424 .52455 L
.6448 .53814 L
.64715 .55174 L
.64943 .56533 L
.954 .56533 L
.95335 .55174 L
.95268 .53814 L
.95197 .52455 L
.95123 .51096 L
.95045 .49736 L
.9496 .48377 L
.94869 .47017 L
.94774 .45658 L
.94675 .44299 L
.94571 .42939 L
.94458 .4158 L
.94335 .4022 L
.94205 .38861 L
.94068 .37501 L
.93919 .36142 L
.93756 .34783 L
.93578 .33423 L
.93383 .32064 L
.93169 .30704 L
.9293 .29345 L
.92666 .27986 L
.92377 .26626 L
.92053 .25267 L
.57298 .25267 L
s
P
P
p
.004 w
.51949 .82267 m
1 .82267 L
s
P
p
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
p
p
/Helvetica findfont 14 scalefont setfont
[(P = 6.)] .01 .9 -1 0 Mshowa
P
p
/Times-Bold findfont 22 scalefont setfont
[(AFM)] .01 .94667 -1 0 Mshowa
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 450},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{-0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001`Q000`40O003h00Oogoo`goo003oOoo3
Ool00?mool=oo`00ogoo`goo003oOoo3Ool00?mool=oo`00ogoo`goo003oOoo3Ool006Aoo`8000Ao
o`04001oogooOol50016Ool20004Ool00`00Oomoo`03Ool30015Ool20004Ool00`00Oomoo`02Ool3
0017Ool20004Ool00`00Oomoo`02Ool3001;Ool30004Ool006=oo`04001oogoo0008Ool01000Oomo
o`00AGoo00@007ooOol000Yoo`03001oogoo04=oo`04001oogoo0007Ool01@00Oomoogoo0000AGoo
00@007ooOol000Moo`05001oogooOol0001;Ool00`00Oomoo`03Ool006=oo`04001oogoo0009Ool0
0`00Oomoo`15Ool01000Oomoo`001goo1@00A7oo00@007ooOol000Moo`05001oogooOol00015Ool0
1000Oomoo`001goo00D007ooOomoo`0004]oo`03001oogoo00=oo`00Hgoo00@007ooOol000Yoo`03
001oogoo04Aoo`04001oogoo0007Ool01000Oomoo`00AGoo00@007ooOol000Moo`@004Ioo`04001o
ogoo0008Ool3001<Ool00`00Oomoo`03Ool006=oo`04001oogoo0007Ool01@00Oomoogoo0000AGoo
00@007ooOol000Qoo`03001oo`0004Eoo`04001oogoo0007Ool00`00Oomoo`17Ool01000Oomoo`00
1goo00D007ooOomoo`0004]oo`03001oogoo00=oo`00Hgoo00@007ooOol000Moo`05001oogooOol0
0015Ool01000Oomoo`002Goo0P00AGoo00@007ooOol000Qoo`03001oogoo04Ioo`04001oogoo0007
Ool01@00Oomoogoo0000BWoo0P001Goo001TOol20009Ool30017Ool2000;Ool00`00Oomoo`14Ool2
000:Ool20017Ool20009Ool3001<Ool00`00Oomoo`03Ool00?mool=oo`00ogoo`goo003oOoo3Ool0
0?mool=oo`0000Aoo`00000000Aoo`8000Aoo`800?mook=oo`0000D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`00ogoo/Woo0004Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo0?mook1oo`0017oo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`04Oooo002X0004
Ool000@000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<007kFO]H02gkF00<007haOS403Wha
00<007kFO]H0KWkF00<007haOS409gha00<007kFO]H0@gkF00<007ooOol0UWoo00<007kFO]H00WkF
00<007haOS401Gha00<007ooOol00Woo00000`00Oomoo`04Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001neWkF00]neP03001n<Gha00in<@03001neWkF06ineP03001n<Gha02Mn<@03001neWkF
049neP03001oogoo09Moo`03001neWkF009neP03001n<Gha00En<@03001oogoo009oo`001@000goo
0P0017oo0P001goo00<007kFO]H02gkF00<007haOS403Wha00<007kFO]H0KgkF00<007haOS409Wha
00<007kFO]H0@WkF00<007ooOol0Ugoo00<007kFO]H00WkF00<007haOS401Gha00<007ooOol00Woo
000GOol00`00O]IneP0;O]H00`00OS5n<@0>OS400`00O]IneP1_O]H00`00OS5n<@0VOS400`00O]In
eP12O]H00`00Oomoo`2GOol00`00O]IneP02O]H00`00OS5n<@05OS400`00Oomoo`02Ool001Moo`03
001neWkF00]neP03001n<Gha00in<@03001neWkF06mneP03001n<Gha02In<@03001neWkF045neP03
001oogoo09Qoo`03001neWkF009neP03001n<Gha00En<@03001oogoo009oo`005goo00<007kFO]H0
2gkF00<007haOS403Wha00<007kFO]H0KgkF00<007haOS409Wha00<007kFO]H0@GkF00<007ooOol0
V7oo00<007kFO]H00WkF00<007haOS401Gha00<007ooOol00Woo000GOol00`00O]IneP0;O]H00`00
OS5n<@0>OS400`00O]IneP1_O]H00`00OS5n<@0VOS400`00O]IneP11O]H00`00Oomoo`2HOol00`00
O]IneP02O]H00`00OS5n<@05OS400`00Oomoo`02Ool001Moo`03001neWkF00]neP03001n<Gha00in
<@03001neWkF06mneP03001n<Gha02In<@03001neWkF045neP03001oogoo09Qoo`03001neWkF009n
eP03001n<Gha00En<@03001oogoo009oo`005goo00<007kFO]H02gkF00<007haOS403gha00<007kF
O]H0KgkF00<007haOS409Gha00<007kFO]H0@GkF00<007ooOol0V7oo00D007kFO]IneP0000Qn<@03
001oogoo009oo`005goo00<007kFO]H02gkF00<007haOS403gha00<007kFO]H0KgkF00<007haOS40
9Gha00<007kFO]H0@7kF00<007ooOol0V7oo00<007kFO]H00WkF00<007haOS401Wha00<007ooOol0
0Woo000GOol00`00O]IneP0;O]H00`00OS5n<@0?OS400`00O]IneP1_O]H00`00OS5n<@0UOS400`00
O]IneP10O]H00`00Oomoo`2HOol00`00O]IneP02O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Mo
o`03001neWkF00]neP03001n<Gha00mn<@03001neWkF06mneP03001n<Gha02En<@03001neWkF041n
eP03001oogoo09Qoo`03001neWkF009neP03001n<Gha00In<@03001oogoo009oo`005goo00<007kF
O]H02gkF00<007haOS403gha00<007kFO]H0KgkF00<007haOS409Gha00<007kFO]H0@7kF00<007oo
Ool0V7oo00<007kFO]H00WkF00<007haOS401Wha00<007ooOol00Woo000GOol00`00O]IneP0;O]H0
0`00OS5n<@0?OS400`00O]IneP1_O]H00`00OS5n<@0UOS400`00O]IneP10O]H00`00Oomoo`2HOol0
0`00O]IneP02O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF00aneP03001n<Gha
00mn<@03001neWkF06mneP03001n<Gha02An<@03001neWkF03mneP03001oogoo09Qoo`03001neWkF
00=neP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H037kF00<007haOS403gha00<0
07kFO]H0KgkF00<007haOS4097ha00<007kFO]H0?gkF00<007ooOol0V7oo00<007kFO]H00gkF00<0
07haOS401Wha00<007ooOol00Woo000GOol00`00O]IneP0<O]H00`00OS5n<@0?OS400`00O]IneP1_
O]H00`00OS5n<@0TOS400`00O]IneP0oO]H00`00Oomoo`2HOol00`00O]IneP03O]H00`00OS5n<@06
OS400`00Oomoo`02Ool001Moo`03001neWkF00aneP03001n<Gha00mn<@03001neWkF06mneP03001n
<Gha02An<@03001neWkF03mneP03001oogoo09Qoo`03001neWkF00=neP03001n<Gha00In<@03001o
ogoo009oo`005goo00<007kFO]H037kF00<007haOS403gha00<007kFO]H0L7kF00<007haOS408gha
00<007kFO]H0?WkF00<007ooOol0VGoo00<007kFO]H00gkF00<007haOS401Wha00<007ooOol00Woo
000GOol00`00O]IneP0<O]H00`00OS5n<@0@OS400`00O]IneP1_O]H00`00OS5n<@0SOS400`00O]In
eP0nO]H00`00Oomoo`2IOol00`00O]IneP03O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03
001neWkF00aneP03001n<Gha011n<@03001neWkF06mneP03001n<Gha02=n<@03001neWkF03ineP03
001oogoo09Uoo`03001neWkF00=neP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H0
37kF00<007haOS4047ha00<007kFO]H0L7kF00<007haOS408Wha00<007kFO]H0?GkF00<007ooOol0
VWoo00<007kFO]H00gkF00<007haOS401Wha00<007ooOol00Woo000GOol00`00O]IneP0<O]H00`00
OS5n<@0@OS400`00O]IneP1`O]H00`00OS5n<@0ROS400`00O]IneP0mO]H00`00Oomoo`2JOol00`00
O]IneP03O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF00aneP03001n<Gha011n
<@03001neWkF071neP03001n<Gha029n<@03001neWkF03eneP03001oogoo09Yoo`03001neWkF00=n
eP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H037kF00<007haOS4047ha00<007kF
O]H0L7kF00<007haOS408Wha00<007kFO]H0?GkF00<007ooOol0VWoo00<007kFO]H00gkF00<007ha
OS401Wha00<007ooOol00Woo000GOol00`00O]IneP0=O]H00`00OS5n<@0@OS400`00O]IneP1`O]H0
0`00OS5n<@0QOS400`00O]IneP0mO]H00`00Oomoo`2JOol00`00O]IneP03O]H00`00OS5n<@06OS40
0`00Oomoo`02Ool001Moo`03001neWkF00eneP03001n<Gha011n<@03001neWkF071neP03001n<Gha
025n<@03001neWkF03aneP03001oogoo09Yoo`03001neWkF00AneP03001n<Gha00In<@03001oogoo
009oo`005goo00<007kFO]H03GkF00<007haOS4047ha00<007kFO]H0L7kF00<007haOS408Gha00<0
07kFO]H0?7kF00<007ooOol0VWoo00<007kFO]H017kF00<007haOS401Wha00<007ooOol00Woo000G
Ool00`00O]IneP0=O]H00`00OS5n<@0@OS400`00O]IneP1`O]H00`00OS5n<@0QOS400`00O]IneP0l
O]H00`00Oomoo`2JOol00`00O]IneP04O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001n
eWkF00eneP03001n<Gha011n<@03001neWkF071neP03001n<Gha025n<@03001neWkF03aneP03001o
ogoo09Yoo`03001neWkF00AneP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H03GkF
00<007haOS4047ha00<007kFO]H0L7kF00<007haOS408Gha00<007kFO]H0>gkF00<007ooOol0Vgoo
00<007kFO]H017kF00<007haOS401Wha00<007ooOol00Woo000GOol00`00O]IneP0=O]H00`00OS5n
<@0@OS400`00O]IneP1aO]H00`00OS5n<@0OOS400`00O]IneP0lO]H00`00Oomoo`2KOol00`00O]In
eP04O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF00eneP03001n<Gha011n<@03
001neWkF075neP03001n<Gha01mn<@03001neWkF03aneP03001oogoo09Yoo`03001neWkF00EneP03
001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H03GkF00<007haOS4047ha00<007kFO]H0
LGkF00<007haOS407gha00<007kFO]H0>gkF00<007ooOol0Vgoo00<007kFO]H01GkF00<007haOS40
1Wha00<007ooOol00Woo000GOol00`00O]IneP0=O]H00`00OS5n<@0@OS400`00O]IneP1aO]H00`00
OS5n<@0OOS400`00O]IneP0kO]H00`00Oomoo`2KOol00`00O]IneP05O]H00`00OS5n<@06OS400`00
Oomoo`02Ool001Moo`03001neWkF00eneP03001n<Gha011n<@03001neWkF075neP03001n<Gha01mn
<@03001neWkF03]neP03001oogoo09]oo`03001neWkF00EneP03001n<Gha00In<@03001oogoo009o
o`005goo00<007kFO]H03WkF00<007haOS4047ha00<007kFO]H0L7kF00<007haOS407gha00<007kF
O]H0>gkF00<007ooOol0Vgoo00<007kFO]H01GkF00<007haOS401Wha00<007ooOol00Woo000GOol0
0`00O]IneP0>O]H00`00OS5n<@0@OS400`00O]IneP1aO]H00`00OS5n<@0NOS400`00O]IneP0kO]H0
0`00Oomoo`2KOol00`00O]IneP05O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF
00ineP03001n<Gha011n<@03001neWkF075neP03001n<Gha01in<@03001neWkF03YneP03001oogoo
09]oo`03001neWkF00IneP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H03WkF00<0
07haOS4047ha00<007kFO]H0LGkF00<007haOS407Wha00<007kFO]H0>WkF00<007ooOol0Vgoo00<0
07kFO]H01WkF00<007haOS401Wha00<007ooOol00Woo000GOol00`00O]IneP0>O]H00`00OS5n<@0@
OS400`00O]IneP1aO]H00`00OS5n<@0NOS400`00O]IneP0jO]H00`00Oomoo`2KOol00`00O]IneP06
O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF00ineP03001n<Gha011n<@03001n
eWkF075neP03001n<Gha01in<@03001neWkF03YneP03001oogoo09]oo`03001neWkF00IneP03001n
<Gha00In<@03001oogoo009oo`005goo00<007kFO]H03WkF00<007haOS404Gha00<007kFO]H0L7kF
00<007haOS407Wha00<007kFO]H0>GkF00<007ooOol0W7oo00<007kFO]H01WkF00<007haOS401Wha
00<007ooOol00Woo000GOol00`00O]IneP0>O]H00`00OS5n<@0AOS400`00O]IneP1aO]H00`00OS5n
<@0MOS400`00O]IneP0iO]H00`00Oomoo`2LOol00`00O]IneP06O]H00`00OS5n<@06OS400`00Oomo
o`02Ool001Moo`03001neWkF00ineP03001n<Gha015n<@03001neWkF075neP03001n<Gha01en<@03
001neWkF03UneP03001oogoo09]oo`03001neWkF00MneP03001n<Gha00In<@03001oogoo009oo`00
5goo00<007kFO]H03WkF00<007haOS404Gha00<007kFO]H0LGkF00<007haOS407Gha00<007kFO]H0
>7kF00<007ooOol0W7oo00<007kFO]H01gkF00<007haOS401Wha00<007ooOol00Woo000GOol00`00
O]IneP0>O]H00`00OS5n<@0AOS400`00O]IneP1aO]H00`00OS5n<@0MOS400`00O]IneP0hO]H00`00
Oomoo`2LOol00`00O]IneP07O]H00`00OS5n<@06OS400`00Oomoo`02Ool001Moo`03001neWkF00in
eP03001n<Gha015n<@03001neWkF075neP03001n<Gha01en<@03001neWkF03QneP03001oogoo09ao
o`03001neWkF00MneP03001n<Gha00In<@03001oogoo009oo`005goo00<007kFO]H03WkF00<007ha
OS404Wha00<007kFO]H0LGkF00<007haOS4077ha00<007kFO]H0>7kF00<007ooOol0W7oo00<007kF
O]H01WkF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0>O]H00`00OS5n<@0BOS40
0`00O]IneP1aO]H00`00OS5n<@0LOS400`00O]IneP0hO]H00`00Oomoo`2LOol00`00O]IneP06O]H0
0`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF00ineP03001n<Gha019n<@03001neWkF
075neP03001n<Gha01an<@03001neWkF03MneP03001oogoo09aoo`03001neWkF00MneP03001n<Gha
00Mn<@03001oogoo009oo`005goo00<007kFO]H03WkF00<007haOS404Wha00<007kFO]H0LGkF00<0
07haOS4077ha00<007kFO]H0=gkF00<007ooOol0W7oo00<007kFO]H01gkF00<007haOS401gha00<0
07ooOol00Woo000GOol00`00O]IneP0>O]H00`00OS5n<@0BOS400`00O]IneP1aO]H00`00OS5n<@0L
OS400`00O]IneP0gO]H00`00Oomoo`2LOol00`00O]IneP07O]H00`00OS5n<@07OS400`00Oomoo`02
Ool00004Ool000000002Ool50003Ool20007Ool00`00O]IneP0?O]H00`00OS5n<@0BOS400`00O]In
eP1`O]H00`00OS5n<@0LOS400`00O]IneP0gO]H00`00Oomoo`2LOol00`00O]IneP07O]H00`00OS5n
<@07OS400`00Oomoo`02Ool00005001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Io
o`03001neWkF00mneP03001n<Gha019n<@03001neWkF075neP03001n<Gha01]n<@03001neWkF03In
eP03001oogoo09eoo`03001neWkF00MneP03001n<Gha00Mn<@03001oogoo009oo`0017oo00D007oo
Oomoo`0000Aoo`04001oogoo0006Ool00`00O]IneP0?O]H00`00OS5n<@0BOS400`00O]IneP1aO]H0
0`00OS5n<@0KOS400`00O]IneP0fO]H00`00Oomoo`2MOol00`00O]IneP07O]H00`00OS5n<@07OS40
0`00Oomoo`02Ool000Aoo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00
O]IneP0?O]H00`00OS5n<@0BOS400`00O]IneP1aO]H00`00OS5n<@0KOS400`00O]IneP0fO]H00`00
Oomoo`2LOol00`00O]IneP08O]H00`00OS5n<@07OS400`00Oomoo`02Ool000@0009oo`05001oogoo
Ool00002Ool01000Oomoo`001Woo00<007kFO]H03gkF00<007haOS404Wha00<007kFO]H0LGkF00<0
07haOS406gha00<007kFO]H0=GkF00<007ooOol0WGoo00<007kFO]H027kF00<007haOS401gha00<0
07ooOol00Woo00000`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol000Ioo`03001neWkF
00mneP03001n<Gha019n<@03001neWkF075neP03001n<Gha01]n<@03001neWkF03EneP03001oogoo
09eoo`03001neWkF00QneP03001n<Gha00Mn<@03001oogoo009oo`001@000Woo0`0017oo0P001goo
00<007kFO]H03gkF00<007haOS404Wha00<007kFO]H0LGkF00<007haOS406gha00<007kFO]H0=GkF
00<007ooOol0WGoo00<007kFO]H027kF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]In
eP0?O]H00`00OS5n<@0BOS400`00O]IneP1bO]H00`00OS5n<@0JOS400`00O]IneP0eO]H00`00Oomo
o`2MOol00`00O]IneP08O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF00mneP03
001n<Gha019n<@03001neWkF079neP03001n<Gha01Yn<@03001neWkF03EneP03001oogoo09eoo`03
001neWkF00QneP03001n<Gha00Mn<@03001oogoo009oo`005goo00<007kFO]H03gkF00<007haOS40
4Wha00<007kFO]H0LWkF00<007haOS406Wha00<007kFO]H0=7kF00<007ooOol0WGoo00<007kFO]H0
2GkF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0?O]H00`00OS5n<@0BOS400`00
O]IneP1bO]H00`00OS5n<@0JOS400`00O]IneP0dO]H00`00Oomoo`2MOol00`00O]IneP09O]H00`00
OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF011neP03001n<Gha015n<@03001neWkF079n
eP03001n<Gha01Yn<@03001neWkF03AneP03001oogoo09eoo`03001neWkF00UneP03001n<Gha00Mn
<@03001oogoo009oo`005goo00<007kFO]H047kF00<007haOS404Wha00<007kFO]H0LGkF00<007ha
OS406Wha00<007kFO]H0=7kF00<007ooOol0WGoo00<007kFO]H02GkF00<007haOS401gha00<007oo
Ool00Woo000GOol00`00O]IneP0@O]H00`00OS5n<@0BOS400`00O]IneP1bO]H00`00OS5n<@0IOS40
0`00O]IneP0cO]H00`00Oomoo`2NOol00`00O]IneP09O]H00`00OS5n<@07OS400`00Oomoo`02Ool0
01Moo`03001neWkF011neP03001n<Gha019n<@03001neWkF079neP03001n<Gha01Un<@03001neWkF
03=neP03001oogoo09ioo`03001neWkF00UneP03001n<Gha00Mn<@03001oogoo009oo`005goo00<0
07kFO]H047kF00<007haOS404Wha00<007kFO]H0LWkF00<007haOS406Gha00<007kFO]H0<gkF00<0
07ooOol0WGoo00<007kFO]H02WkF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0@
O]H00`00OS5n<@0BOS400`00O]IneP1bO]H00`00OS5n<@0IOS400`00O]IneP0bO]H00`00Oomoo`2N
Ool00`00O]IneP0:O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF011neP03001n
<Gha01=n<@03001neWkF075neP03001n<Gha01Un<@03001neWkF039neP03001oogoo09ioo`03001n
eWkF00YneP03001n<Gha00Mn<@03001oogoo009oo`005goo00<007kFO]H047kF00<007haOS404gha
00<007kFO]H0LWkF00<007haOS4067ha00<007kFO]H0<WkF00<007ooOol0WWoo00<007kFO]H02WkF
00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0@O]H00`00OS5n<@0COS400`00O]In
eP1bO]H00`00OS5n<@0HOS400`00O]IneP0aO]H00`00Oomoo`2OOol00`00O]IneP0:O]H00`00OS5n
<@07OS400`00Oomoo`02Ool001Moo`03001neWkF011neP03001n<Gha01=n<@03001neWkF079neP03
001n<Gha01Qn<@03001neWkF035neP03001oogoo09moo`03001neWkF00YneP03001n<Gha00Mn<@03
001oogoo009oo`005goo00<007kFO]H047kF00<007haOS404gha00<007kFO]H0LWkF00<007haOS40
67ha00<007kFO]H0<GkF00<007ooOol0WWoo00<007kFO]H02gkF00<007haOS401gha00<007ooOol0
0Woo000GOol00`00O]IneP0@O]H00`00OS5n<@0COS400`00O]IneP1bO]H00`00OS5n<@0HOS400`00
O]IneP0`O]H00`00Oomoo`2OOol00`00O]IneP0;O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Mo
o`03001neWkF015neP03001n<Gha01=n<@03001neWkF075neP03001n<Gha01Qn<@03001neWkF031n
eP03001oogoo09moo`03001neWkF00]neP03001n<Gha00Mn<@03001oogoo009oo`005goo00<007kF
O]H04GkF00<007haOS404gha00<007kFO]H0LWkF00<007haOS405gha00<007kFO]H0<7kF00<007oo
Ool0Wgoo00<007kFO]H02gkF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0AO]H0
0`00OS5n<@0COS400`00O]IneP1bO]H00`00OS5n<@0GOS400`00O]IneP0_O]H00`00Oomoo`2OOol0
0`00O]IneP0<O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF015neP03001n<Gha
01=n<@03001neWkF079neP03001n<Gha01Mn<@03001neWkF02mneP03001oogoo09moo`03001neWkF
00aneP03001n<Gha00Mn<@03001oogoo009oo`005goo00<007kFO]H04GkF00<007haOS404gha00<0
07kFO]H0LWkF00<007haOS405gha00<007kFO]H0;gkF00<007ooOol0Wgoo00<007kFO]H037kF00<0
07haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0AO]H00`00OS5n<@0COS400`00O]IneP1b
O]H00`00OS5n<@0GOS400`00O]IneP0^O]H00`00Oomoo`2OOol00`00O]IneP0=O]H00`00OS5n<@07
OS400`00Oomoo`02Ool001Moo`03001neWkF015neP03001n<Gha01An<@03001neWkF075neP03001n
<Gha01Mn<@03001neWkF02ineP03001oogoo09moo`03001neWkF00eneP03001n<Gha00Mn<@03001o
ogoo009oo`005goo00<007kFO]H04GkF00<007haOS4057ha00<007kFO]H0LWkF00<007haOS405Wha
00<007kFO]H0;WkF00<007ooOol0Wgoo00<007kFO]H03GkF00<007haOS401gha00<007ooOol00Woo
000GOol00`00O]IneP0AO]H00`00OS5n<@0DOS400`00O]IneP1bO]H00`00OS5n<@0FOS400`00O]In
eP0]O]H00`00Oomoo`2POol00`00O]IneP0=O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03
001neWkF015neP03001n<Gha01An<@03001neWkF079neP03001n<Gha01In<@03001neWkF02eneP03
001oogoo0:1oo`03001neWkF00eneP03001n<Gha00Mn<@03001oogoo009oo`005goo00<007kFO]H0
4GkF00<007haOS4057ha00<007kFO]H0LWkF00<007haOS405Wha00<007kFO]H0;GkF00<007ooOol0
Wgoo00<007kFO]H03WkF00<007haOS401gha00<007ooOol00Woo000GOol00`00O]IneP0BO]H00`00
OS5n<@0DOS400`00O]IneP1aO]H00`00OS5n<@0FOS400`00O]IneP0/O]H00`00Oomoo`2POol00`00
O]IneP0>O]H00`00OS5n<@07OS400`00Oomoo`02Ool001Moo`03001neWkF019neP03001n<Gha01An
<@03001neWkF075neP03001n<Gha01In<@03001neWkF02aneP03001oogoo0:1oo`03001neWkF00en
eP03001n<Gha00Qn<@03001oogoo009oo`005goo00<007kFO]H04WkF00<007haOS4057ha00<007kF
O]H0LWkF00<007haOS405Gha00<007kFO]H0;7kF00<007ooOol0X7oo00<007kFO]H03GkF00<007ha
OS4027ha00<007ooOol00Woo000GOol00`00O]IneP0BO]H00`00OS5n<@0DOS400`00O]IneP1bO]H0
0`00OS5n<@0EOS400`00O]IneP0[O]H00`00Oomoo`2POol00`00O]IneP0>O]H00`00OS5n<@08OS40
0`00Oomoo`02Ool001Moo`03001neWkF019neP03001n<Gha01An<@03001neWkF079neP03001n<Gha
01En<@03001neWkF02]neP03001oogoo0:1oo`03001neWkF00ineP03001n<Gha00Qn<@03001oogoo
009oo`005goo00<007kFO]H04WkF00<007haOS4057ha00<007kFO]H0LWkF00<007haOS405Gha00<0
07kFO]H0:gkF00<007ooOol0X7oo00<007kFO]H03WkF00<007haOS4027ha00<007ooOol00Woo000G
Ool00`00O]IneP0BO]H00`00OS5n<@0DOS400`00O]IneP1bO]H00`00OS5n<@0EOS400`00O]IneP0Z
O]H00`00Oomoo`2POol00`00O]IneP0?O]H00`00OS5n<@08OS400`00Oomoo`02Ool001Moo`03001n
eWkF019neP03001n<Gha01An<@03001neWkF07=neP03001n<Gha01An<@03001neWkF02YneP03001o
ogoo0:1oo`03001neWkF00mneP03001n<Gha00Qn<@03001oogoo009oo`005goo00<007kFO]H04WkF
00<007haOS4057ha00<007kFO]H0LgkF00<007haOS4057ha00<007kFO]H0:WkF00<007ooOol0X7oo
00<007kFO]H03gkF00<007haOS4027ha00<007ooOol00Woo000GOol00`00O]IneP0BO]H00`00OS5n
<@0DOS400`00O]IneP1cO]H00`00OS5n<@0DOS400`00O]IneP0YO]H00`00Oomoo`2POol00`00O]In
eP0@O]H00`00OS5n<@08OS400`00Oomoo`02Ool001Moo`03001neWkF019neP03001n<Gha01An<@03
001neWkF07=neP03001n<Gha01An<@03001neWkF02UneP03001oogoo0:1oo`03001neWkF011neP03
001n<Gha00Qn<@03001oogoo009oo`005goo00<007kFO]H04WkF00<007haOS4057ha00<007kFO]H0
LgkF00<007haOS4057ha00<007kFO]H0:GkF00<007ooOol0X7oo00<007kFO]H047kF00<007haOS40
27ha00<007ooOol00Woo000GOol00`00O]IneP0BO]H00`00OS5n<@0EOS400`00O]IneP1bO]H00`00
OS5n<@0DOS400`00O]IneP0XO]H00`00Oomoo`2POol00`00O]IneP0AO]H00`00OS5n<@08OS400`00
Oomoo`02Ool001Moo`03001neWkF019neP03001n<Gha01En<@03001neWkF07=neP03001n<Gha01=n
<@03001neWkF02QneP03001oogoo0:1oo`03001neWkF015neP03001n<Gha00Qn<@03001oogoo009o
o`005goo00<007kFO]H04WkF00<007haOS405Gha00<007kFO]H0LgkF00<007haOS404gha00<007kF
O]H0:7kF00<007ooOol0X7oo00<007kFO]H04GkF00<007haOS4027ha00<007ooOol00Woo000GOol0
0`00O]IneP0BO]H00`00OS5n<@0EOS400`00O]IneP1cO]H00`00OS5n<@0COS400`00O]IneP0WO]H0
0`00Oomoo`2POol00`00O]IneP0BO]H00`00OS5n<@08OS400`00Oomoo`02Ool001Moo`03001neWkF
019neP03001n<Gha01En<@03001neWkF07=neP03001n<Gha01=n<@03001neWkF02MneP03001oogoo
0:1oo`03001neWkF019neP03001n<Gha00Qn<@03001oogoo009oo`005goo00<007kFO]H04gkF00<0
07haOS405Gha00<007kFO]H0LWkF00<007haOS404gha00<007kFO]H09gkF00<007ooOol0X7oo00<0
07kFO]H04WkF00<007haOS4027ha00<007ooOol00Woo000GOol00`00O]IneP0CO]H00`00OS5n<@0E
OS400`00O]IneP1bO]H00`00OS5n<@0COS400`00O]IneP0UO]JU000EO]H00`00OS5n<@08OS400`00
Oomoo`02Ool001Moo`03001neWkF01=neP03001n<Gha01En<@03001neWkF07=neP03001n<Gha019n
<@03001neWkF02AneP03001oogoo00aoo`800003O]H007oo095oo`03001neWkF01=neP03001n<Gha
00Qn<@03001oogoo009oo`005goo00<007kFO]H04gkF00<007haOS405Gha00<007kFO]H0LgkF00<0
07haOS404Wha00<007kFO]H08WkF0P003Goo0P0017kF00<007ooOol0Sgoo00<007kFO]H04gkF00<0
07haOS4027ha00<007ooOol00Woo000GOol00`00O]IneP0CO]H00`00OS5n<@0EOS400`00O]IneP1c
O]H00`00OS5n<@0BOS400`00O]IneP0PO]H2000=Ool20006O]H00`00Oomoo`2?Ool00`00O]IneP0C
O]H00`00OS5n<@08OS400`00Oomoo`02Ool00004Ool000000004Ool30003Ool20007Ool00`00O]In
eP0CO]H00`00OS5n<@0EOS400`00O]IneP1cO]H00`00OS5n<@0BOS400`00O]IneP0OO]H00`00Oomo
o`0;Ool20008O]H00`00Oomoo`2@Ool00`00O]IneP0BO]H00`00OS5n<@08OS400`00Oomoo`02Ool0
0005001oogooOol00004Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007kFO]H04gkF00<0
07haOS405Wha00<007kFO]H0LWkF00<007haOS404Wha00<007kFO]H07GkF0P0037oo0P002gkF00<0
07ooOol0Sgoo00<007kFO]H04WkF00<007haOS4027ha00<007ooOol00Woo0004Ool00`00Ool00004
0002Ool01000Oomoo`001Woo00<007kFO]H04gkF00<007haOS405Wha00<007kFO]H0LWkF00<007ha
OS404Gha00<007kFO]H07GkF00<007ooOol02Woo0P003GkF00<007ooOol0Sgoo00<007kFO]H04WkF
00<007haOS4027ha00<007ooOol00Woo0004Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00<0
07ooOol017oo00<007kFO]H04gkF00<007haOS405Wha00<007kFO]H0LgkF00<007haOS4047ha00<0
07kFO]H06gkF0P002Woo0`003gkF00<007ooOol0Sgoo00<007kFO]H04WkF00<007haOS4027ha00<0
07ooOol00Woo00040003Ool00`00Ool00003Ool01000Oomoo`001Woo00<007kFO]H04gkF00<007ha
OS405Wha00<007kFO]H0LgkF00<007haOS4047ha00<007kFO]H067kF0`002Goo0`004gkF00<007oo
Ool0SWoo00<007kFO]H04WkF00<007haOS4027ha00<007ooOol00Woo00000`00Oomoo`05Ool20003
Ool01000Oomoo`001Woo00<007kFO]H04gkF00<007haOS405Wha00<007kFO]H0LgkF00<007haOS40
47ha00<007kFO]H05WkF0P002Goo0`005WkF00<007ooOol0SWoo00<007kFO]H04WkF00<007haOS40
27ha00<007ooOol00Woo00050004Ool00`00Oomoo`02Ool20007Ool00`00O]IneP0DO]H00`00OS5n
<@0EOS400`00O]IneP1cO]H00`00OS5n<@0@OS400`00O]IneP0DO]H20008Ool3000IO]H00`00Oomo
o`2?Ool00`00O]IneP0AO]H00`00OS5n<@08OS400`00Oomoo`02Ool001Moo`03001neWkF01AneP03
001n<Gha01In<@03001neWkF079neP03001n<Gha011n<@03001neWkF015neP<000Moo`<001eneP03
001oogoo08ioo`03001neWkF015neP03001n<Gha00Qn<@03001oogoo009oo`005goo00<007kFO]H0
57kF00<007haOS405Wha00<007kFO]H0LWkF00<007haOS4047ha00<007kFO]H03gkF0P001goo0`00
87kF00<007ooOol0SWoo00<007kFO]H04GkF00<007haOS4027ha00<007ooOol00Woo000GOol00`00
O]IneP0DO]H00`00OS5n<@0FOS400`00O]IneP1cO]H00`00OS5n<@0?OS400`00O]IneP0=O]H20005
Ool4000SO]H00`00Oomoo`2>Ool00`00O]IneP0AO]H00`00OS5n<@08OS400`00Oomoo`02Ool001Mo
o`03001neWkF01AneP03001n<Gha01In<@03001neWkF07=neP03001n<Gha00mn<@03001neWkF00]n
eP8000Aoo`<002QneP03001oogoo08ioo`03001neWkF011neP03001n<Gha00Qn<@03001oogoo009o
o`005goo00<007kFO]H057kF00<007haOS405Wha00<007kFO]H0LgkF00<007haOS403gha00<007kF
O]H027kF0`000Woo1000:gkF00<007ooOol0SWoo00<007kFO]H047kF00<007haOS4027ha00<007oo
Ool00Woo000GOol00`00O]IneP0DO]H00`00OS5n<@0FOS400`00O]IneP1cO]H00`00OS5n<@0?OS40
0`00O]IneP06O]H20002Ool3000_O]H00`00Oomoo`2>Ool00`00O]IneP0@O]H00`00OS5n<@08OS40
0`00Oomoo`02Ool001Moo`03001neWkF01AneP03001n<Gha01Mn<@03001neWkF079neP03001n<Gha
00mn<@03001neWkF00AneP800004Ool00000000cO]H00`00Oomoo`2>Ool00`00O]IneP0?O]H00`00
OS5n<@08OS400`00Oomoo`02Ool001Moo`03001neWkF01AneP03001n<Gha01Mn<@03001neWkF07=n
eP03001n<Gha00in<@04001neWkFO]H6000fO]H00`00Oomoo`2>Ool00`00O]IneP0>O]H00`00OS5n
<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01AneP03001n<Gha01Mn<@03001neWkF07=neP03
001n<Gha00in<@03001neP0000<003YneP03001oogoo08ioo`03001neWkF00ineP03001n<Gha00Un
<@03001oogoo009oo`005goo00<007kFO]H057kF00<007haOS405gha00<007kFO]H0LgkF00<007ha
OS403Wha0`00?WkF00<007ooOol0SGoo00<007kFO]H03WkF00<007haOS402Gha00<007ooOol00Woo
000GOol00`00O]IneP0EO]H00`00OS5n<@0FOS400`00O]IneP1cO]H00`00OS5n<@0>OS400`00O]In
eP0nO]H00`00Oomoo`2>Ool00`00O]IneP0=O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03
001neWkF01EneP03001n<Gha01In<@03001neWkF07=neP03001n<Gha00in<@03001neWkF03ineP03
001oogoo08ioo`03001neWkF00eneP03001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H0
5GkF00<007haOS405Wha00<007kFO]H0LgkF00<007haOS403Wha00<007kFO]H0?gkF00<007ooOol0
SGoo00<007kFO]H03GkF00<007haOS402Gha00<007ooOol00Woo000GOol00`00O]IneP0EO]H00`00
OS5n<@0FOS400`00O]IneP1dO]H00`00OS5n<@0=OS400`00O]IneP0oO]H00`00Oomoo`2=Ool00`00
O]IneP0=O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01EneP03001n<Gha01In
<@03001neWkF07AneP03001n<Gha00en<@03001neWkF041neP03001oogoo08aoo`03001neWkF00en
eP03001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05GkF00<007haOS405Wha00<007kF
O]H0M7kF00<007haOS403Gha00<007kFO]H0@7kF00<007ooOol0S7oo00<007kFO]H03GkF00<007ha
OS402Gha00<007ooOol00Woo000GOol00`00O]IneP0EO]H00`00OS5n<@0FOS400`00O]IneP1dO]H0
0`00OS5n<@0=OS400`00O]IneP10O]H00`00Oomoo`2=Ool00`00O]IneP0<O]H00`00OS5n<@09OS40
0`00Oomoo`02Ool001Moo`03001neWkF01EneP03001n<Gha01Mn<@03001neWkF07=neP03001n<Gha
00en<@03001neWkF045neP03001oogoo08aoo`03001neWkF00aneP03001n<Gha00Un<@03001oogoo
009oo`005goo00<007kFO]H05GkF00<007haOS405gha00<007kFO]H0LgkF00<007haOS403Gha00<0
07kFO]H0@GkF00<007ooOol0S7oo00<007kFO]H037kF00<007haOS402Gha00<007ooOol00Woo000G
Ool00`00O]IneP0EO]H00`00OS5n<@0GOS400`00O]IneP1dO]H00`00OS5n<@0<OS400`00O]IneP11
O]H00`00Oomoo`2<Ool00`00O]IneP0<O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001n
eWkF01EneP03001n<Gha01Mn<@03001neWkF07AneP03001n<Gha00an<@03001neWkF045neP03001o
ogoo08aoo`03001neWkF00aneP03001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05GkF
00<007haOS405gha00<007kFO]H0M7kF00<007haOS4037ha00<007kFO]H0@GkF00<007ooOol0S7oo
00<007kFO]H037kF00<007haOS402Gha00<007ooOol00Woo000GOol00`00O]IneP0FO]H00`00OS5n
<@0FOS400`00O]IneP1dO]H00`00OS5n<@0<OS400`00O]IneP12O]H00`00Oomoo`2;Ool00`00O]In
eP0<O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01IneP03001n<Gha01Mn<@03
001neWkF07=neP03001n<Gha00an<@03001neWkF049neP03001oogoo08]oo`03001neWkF00aneP03
001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05WkF00<007haOS405gha00<007kFO]H0
LgkF00<007haOS402gha00<007kFO]H0@gkF00<007ooOol0Rgoo00<007kFO]H037kF00<007haOS40
2Gha00<007ooOol00Woo000GOol00`00O]IneP0FO]H00`00OS5n<@0GOS400`00O]IneP1cO]H00`00
OS5n<@0;OS400`00O]IneP13O]H00`00Oomoo`2;Ool00`00O]IneP0<O]H00`00OS5n<@09OS400`00
Oomoo`02Ool001Moo`03001neWkF01IneP03001n<Gha01Mn<@03001neWkF07=neP03001n<Gha00]n
<@03001neWkF04AneP03001oogoo08Yoo`03001neWkF00aneP03001n<Gha00Un<@03001oogoo009o
o`005goo00<007kFO]H05WkF00<007haOS405gha00<007kFO]H0LgkF00<007haOS402gha00<007kF
O]H0A7kF00<007ooOol0RWoo00<007kFO]H037kF00<007haOS402Gha00<007ooOol00Woo000GOol0
0`00O]IneP0FO]H00`00OS5n<@0HOS400`00O]IneP1bO]H00`00OS5n<@0;OS400`00O]IneP14O]H0
0`00Oomoo`2;Ool00`00O]IneP0;O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF
01IneP03001n<Gha01Qn<@03001neWkF079neP03001n<Gha00]n<@03001neWkF04EneP03001oogoo
08Yoo`03001neWkF00]neP03001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05WkF00<0
07haOS4067ha00<007kFO]H0LgkF00<007haOS402Wha00<007kFO]H0AGkF00<007ooOol0RWoo00<0
07kFO]H02gkF00<007haOS402Gha00<007ooOol00Woo000GOol00`00O]IneP0FO]H00`00OS5n<@0H
OS400`00O]IneP1cO]H00`00OS5n<@0:OS400`00O]IneP15O]H00`00Oomoo`2:Ool00`00O]IneP0;
O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01IneP03001n<Gha01Qn<@03001n
eWkF07=neP03001n<Gha00Yn<@03001neWkF04EneP03001oogoo08Yoo`03001neWkF00]neP03001n
<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05gkF00<007haOS405gha00<007kFO]H0LgkF
00<007haOS402Wha00<007kFO]H0AWkF00<007ooOol0RWoo00<007kFO]H02WkF00<007haOS402Gha
00<007ooOol00Woo000GOol00`00O]IneP0GO]H00`00OS5n<@0HOS400`00O]IneP1bO]H00`00OS5n
<@0:OS400`00O]IneP16O]H00`00Oomoo`2:Ool00`00O]IneP0:O]H00`00OS5n<@09OS400`00Oomo
o`02Ool001Moo`03001neWkF01MneP03001n<Gha01Qn<@03001neWkF079neP03001n<Gha00Yn<@03
001neWkF04IneP03001oogoo08Yoo`03001neWkF00YneP03001n<Gha00Un<@03001oogoo009oo`00
5goo00<007kFO]H05gkF00<007haOS4067ha00<007kFO]H0LgkF00<007haOS4027ha00<007kFO]H0
AgkF00<007ooOol0RWoo00<007kFO]H02WkF00<007haOS402Gha00<007ooOol00Woo000GOol00`00
O]IneP0GO]H00`00OS5n<@0HOS400`00O]IneP1cO]H00`00OS5n<@08OS400`00O]IneP18O]H00`00
Oomoo`29Ool00`00O]IneP0:O]H00`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01Mn
eP03001n<Gha01Qn<@03001neWkF07=neP03001n<Gha00Qn<@03001neWkF04QneP03001oogoo08Uo
o`03001neWkF00YneP03001n<Gha00Un<@03001oogoo009oo`005goo00<007kFO]H05gkF00<007ha
OS4067ha00<007kFO]H0LgkF00<007haOS4027ha00<007kFO]H0B7kF00<007ooOol0RGoo00<007kF
O]H02WkF00<007haOS402Gha00<007ooOol00Woo000GOol00`00O]IneP0GO]H00`00OS5n<@0IOS40
0`00O]IneP1bO]H00`00OS5n<@08OS400`00O]IneP19O]H00`00Oomoo`28Ool00`00O]IneP0:O]H0
0`00OS5n<@09OS400`00Oomoo`02Ool001Moo`03001neWkF01MneP03001n<Gha01Un<@03001neWkF
079neP03001n<Gha00Qn<@03001neWkF04UneP03001oogoo08Qoo`03001neWkF00UneP03001n<Gha
00Yn<@03001oogoo009oo`005goo00<007kFO]H05gkF00<007haOS406Gha00<007kFO]H0LgkF00<0
07haOS401gha00<007kFO]H0BGkF00<007ooOol0R7oo00<007kFO]H02GkF00<007haOS402Wha00<0
07ooOol00Woo000GOol00`00O]IneP0GO]H00`00OS5n<@0IOS400`00O]IneP1cO]H00`00OS5n<@07
OS400`00O]IneP19O]H00`00Oomoo`28Ool00`00O]IneP09O]H00`00OS5n<@0:OS400`00Oomoo`02
Ool001Moo`03001neWkF01QneP03001n<Gha01Qn<@03001neWkF07=neP03001n<Gha00Mn<@03001n
eWkF04UneP03001oogoo08Qoo`03001neWkF00UneP03001n<Gha00Yn<@03001oogoo009oo`005goo
00<007kFO]H067kF00<007haOS406Gha00<007kFO]H0LWkF00<007haOS401gha00<007kFO]H0BWkF
00<007ooOol0R7oo00<007kFO]H027kF00<007haOS402Wha00<007ooOol00Woo000GOol00`00O]In
eP0HO]H00`00OS5n<@0IOS400`00O]IneP1bO]H00`00OS5n<@07OS400`00O]IneP1:O]H00`00Oomo
o`28Ool00`00O]IneP08O]H00`00OS5n<@0:OS400`00Oomoo`02Ool001Moo`03001neWkF01QneP03
001n<Gha01Un<@03001neWkF079neP03001n<Gha00In<@03001neWkF04]neP03001oogoo08Qoo`03
001neWkF00QneP03001n<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H067kF00<007haOS40
6Gha00<007kFO]H0LgkF00<007haOS401Gha00<007kFO]H0BgkF00<007ooOol0R7oo00<007kFO]H0
27kF00<007haOS402Wha00<007ooOol00Woo000017oo000000000goo0`0017oo0P001goo00<007kF
O]H067kF00<007haOS406Gha00<007kFO]H0LgkF00<007haOS401Gha00<007kFO]H0C7kF00<007oo
Ool0Qgoo00<007kFO]H027kF00<007haOS402Wha00<007ooOol00Woo00001`00Oomoogoo001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00O]IneP0HO]H00`00OS5n<@0IOS400`00O]In
eP1cO]H00`00OS5n<@05OS400`00O]IneP1<O]H00`00Oomoo`27Ool00`00O]IneP08O]H00`00OS5n
<@0:OS400`00Oomoo`02Ool000Aoo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`04Ool0
0`00O]IneP0HO]H00`00OS5n<@0IOS400`00O]IneP1cO]H00`00OS5n<@05OS400`00O]IneP1<O]H0
0`00Oomoo`28Ool00`00O]IneP07O]H00`00OS5n<@0:OS400`00Oomoo`02Ool000Aoo`03001oo`00
00<000=oo`04001oogoo0006Ool00`00O]IneP0HO]H00`00OS5n<@0IOS400`00O]IneP1cO]H00`00
OS5n<@05OS400`00O]IneP1=O]H00`00Oomoo`27Ool00`00O]IneP07O]H00`00OS5n<@0:OS400`00
Oomoo`02Ool000@0009oo`03001oogoo00Aoo`04001oogoo0006Ool00`00O]IneP0HO]H00`00OS5n
<@0IOS400`00O]IneP1dO]H00`00OS5n<@04OS400`00O]IneP1=O]H00`00Oomoo`27Ool00`00O]In
eP07O]H00`00OS5n<@0:OS400`00Oomoo`02Ool00003001oogoo00Aoo`03001oogoo00=oo`04001o
ogoo0006Ool00`00O]IneP0HO]H00`00OS5n<@0IOS400`00O]IneP1dO]H00`00OS5n<@04OS400`00
O]IneP1=O]H00`00Oomoo`27Ool00`00O]IneP07O]H00`00OS5n<@0:OS400`00Oomoo`02Ool000D0
00=oo`8000Aoo`8000Moo`03001neWkF01UneP03001n<Gha01Qn<@03001neWkF07AneP03001n<Gha
00An<@03001neWkF04eneP03001oogoo08Moo`03001neWkF00MneP03001n<Gha00Yn<@03001oogoo
009oo`005goo00<007kFO]H06GkF00<007haOS4067ha00<007kFO]H0M7kF00<007haOS4017ha00<0
07kFO]H0CWkF00<007ooOol0QWoo00<007kFO]H01gkF00<007haOS402Wha00<007ooOol00Woo000G
Ool00`00O]IneP0IO]H00`00OS5n<@0IOS400`00O]IneP1cO]H00`00OS5n<@04OS400`00O]IneP1>
O]H00`00Oomoo`26Ool00`00O]IneP07O]H00`00OS5n<@0:OS400`00Oomoo`02Ool001Moo`03001n
eWkF01UneP03001n<Gha01Un<@03001neWkF07=neP03001n<Gha00An<@03001neWkF04ineP03001o
ogoo08Ioo`03001neWkF00MneP03001n<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06GkF
00<007haOS406Gha00<007kFO]H0M7kF00<007haOS400gha00<007kFO]H0CWkF00<007ooOol0QWoo
00<007kFO]H01gkF00<007haOS402Wha00<007ooOol00Woo000GOol00`00O]IneP0IO]H00`00OS5n
<@0IOS400`00O]IneP1dO]H00`00OS5n<@03OS400`00O]IneP1>O]H00`00Oomoo`26Ool00`00O]In
eP07O]H00`00OS5n<@0:OS400`00Oomoo`02Ool001Moo`03001neWkF01UneP03001n<Gha01Un<@03
001neWkF07AneP03001n<Gha00=n<@03001neWkF04ineP03001oogoo08Ioo`03001neWkF00MneP03
001n<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06GkF00<007haOS406Wha00<007kFO]H0
LgkF00<007haOS400gha00<007kFO]H0CgkF00<007ooOol0QWoo00<007kFO]H01WkF00<007haOS40
2Wha00<007ooOol00Woo000GOol00`00O]IneP0IO]H00`00OS5n<@0JOS400`00O]IneP1cO]H00`00
OS5n<@03OS400`00O]IneP1?O]H00`00Oomoo`26Ool00`00O]IneP06O]H00`00OS5n<@0:OS400`00
Oomoo`02Ool001Moo`03001neWkF01UneP03001n<Gha01Yn<@03001neWkF07=neP03001n<Gha00=n
<@03001neWkF04mneP03001oogoo08Ioo`03001neWkF00IneP03001n<Gha00Yn<@03001oogoo009o
o`005goo00<007kFO]H06GkF00<007haOS406Wha00<007kFO]H0LgkF00<007haOS400Wha00<007kF
O]H0D7kF00<007ooOol0QWoo00<007kFO]H01WkF00<007haOS402Wha00<007ooOol00Woo000GOol0
0`00O]IneP0IO]H00`00OS5n<@0JOS400`00O]IneP1cO]H00`00OS5n<@02OS400`00O]IneP1AO]H0
0`00Oomoo`25Ool00`00O]IneP06O]H00`00OS5n<@0:OS400`00Oomoo`02Ool001Moo`03001neWkF
01YneP03001n<Gha01Un<@03001neWkF07=neP03001n<Gha009n<@03001neWkF055neP03001oogoo
08Eoo`03001neWkF00IneP03001n<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06WkF00<0
07haOS406Wha00<007kFO]H0LWkF00<007haOS400Wha00<007kFO]H0DGkF00<007ooOol0QGoo00<0
07kFO]H01WkF00<007haOS402Wha00<007ooOol00Woo000GOol00`00O]IneP0JO]H00`00OS5n<@0J
OS400`00O]IneP1bO]H00`00OS5n<@02OS400`00O]IneP1BO]H00`00Oomoo`24Ool00`00O]IneP06
O]H00`00OS5n<@0:OS400`00Oomoo`02Ool001Moo`03001neWkF01YneP03001n<Gha01Yn<@03001n
eWkF079neP03001n<Gha009n<@03001neWkF059neP03001oogoo08Aoo`03001neWkF00IneP03001n
<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06WkF00<007haOS406Wha00<007kFO]H0LgkF
00D007haOS5n<@0005AneP03001oogoo08Aoo`03001neWkF00IneP03001n<Gha00Yn<@03001oogoo
009oo`005goo00<007kFO]H06WkF00<007haOS406Wha00<007kFO]H0LgkF00D007haOS5n<@0005An
eP03001oogoo08Aoo`03001neWkF00IneP03001n<Gha00Yn<@03001oogoo009oo`005goo00<007kF
O]H06WkF00<007haOS406Wha00<007kFO]H0LgkF00D007haOS5n<@0005AneP03001oogoo08Aoo`03
001neWkF00IneP03001n<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06WkF00<007haOS40
6gha00<007kFO]H0LWkF00D007haOS5n<@0005EneP03001oogoo08=oo`03001neWkF00IneP03001n
<Gha00Yn<@03001oogoo009oo`005goo00<007kFO]H06WkF00<007haOS406gha00<007kFO]H0LWkF
00D007haOS5n<@0005EneP03001oogoo08=oo`03001neWkF00IneP03001n<Gha00Yn<@03001oogoo
009oo`005goo00<007kFO]H06WkF00<007haOS406gha00<007kFO]H0LgkF00<007ha0000EWkF00<0
07ooOol0Pgoo00<007kFO]H01GkF00<007haOS402gha00<007ooOol00Woo000GOol00`00O]IneP0J
O]H00`00OS5n<@0KOS400`00O]IneP1cO]H00`00OS40001FO]H00`00Oomoo`23Ool00`00O]IneP05
O]H00`00OS5n<@0;OS400`00Oomoo`02Ool001Moo`03001neWkF01]neP03001n<Gha01Yn<@03001n
eWkF07=neP03001n<@0005IneP03001oogoo08=oo`03001neWkF00EneP03001n<Gha00]n<@03001o
ogoo009oo`005goo00<007kFO]H06gkF00<007haOS406gha00<007kFO]H0LWkF00<007ha0000EgkF
00<007ooOol0Pgoo00<007kFO]H017kF00<007haOS402gha00<007ooOol00Woo000GOol00`00O]In
eP0KO]H00`00OS5n<@0KOS400`00O]IneP1bO]H00`00OS40001GO]H00`00Oomoo`23Ool00`00O]In
eP04O]H00`00OS5n<@0;OS400`00Oomoo`02Ool001Moo`03001neWkF01]neP03001n<Gha01]n<@03
001neWkF079neP03001n<@0005MneP03001oogoo08=oo`03001neWkF00AneP03001n<Gha00]n<@03
001oogoo009oo`005goo00<007kFO]H06gkF00<007haOS406gha00<007kFO]H0LgkF0P00EgkF00<0
07ooOol0Pgoo00<007kFO]H017kF00<007haOS402gha00<007ooOol00Woo000GOol00`00O]IneP0K
O]H00`00OS5n<@0KOS400`00O]IneP1cO]H2001GO]H00`00Oomoo`23Ool00`00O]IneP04O]H00`00
OS5n<@0;OS400`00Oomoo`02Ool001Moo`03001neWkF01]neP03001n<Gha01]n<@03001neWkF07=n
eP8005MneP03001oogoo08=oo`03001neWkF00AneP03001n<Gha00]n<@03001oogoo009oo`005goo
00<007kFO]H06gkF00<007haOS4077ha00<007kFO]H0LWkF0P00F7kF00<007ooOol0PWoo00<007kF
O]H017kF00<007haOS402gha00<007ooOol00Woo000GOol00`00O]IneP0KO]H00`00OS5n<@0LOS40
0`00O]IneP1bO]H2001HO]H00`00Oomoo`22Ool00`00O]IneP04O]H00`00OS5n<@0;OS400`00Oomo
o`02Ool001Moo`03001neWkF01]neP03001n<Gha01an<@03001neWkF079neP8005QneP03001oogoo
089oo`03001neWkF00AneP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H06gkF00<0
07haOS4077ha00<007kFO]H0LgkF00<007kFO]H0EWkF00<007ooOol0PWoo00<007kFO]H017kF00<0
07haOS402gha00<007ooOol00Woo000GOol00`00O]IneP0LO]H00`00OS5n<@0KOS400`00O]IneP1c
O]H00`00O]IneP1FO]H00`00Oomoo`22Ool00`00O]IneP04O]H00`00OS5n<@0;OS400`00Oomoo`02
Ool001Moo`03001neWkF01aneP03001n<Gha01]n<@03001neWkF05mneQP005EneP03001oogoo089o
o`03001neWkF00AneP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H077kF00<007ha
OS406gha00<007kFO]H0>7kF9`0067oo1P00D7kF00<007ooOol0PWoo00<007kFO]H00gkF00<007ha
OS402gha00<007ooOol00Woo000GOol00`00O]IneP0LO]H00`00OS5n<@0KOS400`00O]IneP0AO]HW
0015Ool5001;O]H00`00Oomoo`22Ool00`00O]IneP03O]H00`00OS5n<@0;OS400`00Oomoo`02Ool0
01Moo`03001neWkF01aneP03001n<Gha01]n<A@0075oo`H004EneP03001oogoo089oo`03001neWkF
00=neP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H077kF00<007haOS406gha00<0
07kFO]H01gkF4000LGoo1P00?gkF00<007ooOol0PWoo00<007kFO]H00gkF00<007haOS402gha00<0
07ooOol00Woo000GOol00`00O]IneP0LO]H00`00OS5n<@0KOS400`00O]IneP0GO]HA001VOol5000j
O]H00`00Oomoo`22Ool00`00O]IneP03O]H00`00OS5n<@0;OS400`00Oomoo`02Ool001Moo`03001n
eWkF01aneP03001n<Gha01an<@03001neWkF02MneQ0005]oo`D003EneP03001oogoo089oo`03001n
eWkF00=neP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H077kF00<007haOS4077ha
00<007kFO]H0=gkF4000D7oo0`00<gkF00<007ooOol0PGoo00<007kFO]H00gkF00<007haOS402gha
00<007ooOol00Woo000GOol00`00O]IneP0LO]H00`00OS5n<@0LOS400`00O]IneP17O]H<0017Ool4
000_O]H00`00Oomoo`21Ool00`00O]IneP03O]H00`00OS5n<@0;OS400`00Oomoo`02Ool001Moo`03
001neWkF01aneP03001n<Gha01an<@03001neWkF05=nePL004Aoo`<002aneP03001oogoo085oo`03
001neWkF00=neP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H07GkF00<007haOS40
6gha00<007kFO]H0FWkF1`00@7oo0`00:GkF00<007ooOol0PGoo00<007kFO]H00gkF00<007haOS40
2gha00<007ooOol00Woo000GOol00`00O]IneP0MO]H00`00OS5n<@0KOS400`00O]IneP1QO]H7000l
Ool4000UO]H00`00Oomoo`21Ool00`00O]IneP03O]H00`00OS5n<@0;OS400`00Oomoo`02Ool001Mo
o`03001neWkF01eneP03001n<Gha01]n<@03001neWkF06QnePL003Uoo`<002=neP03001oogoo081o
o`03001neWkF00=neP03001n<Gha00]n<@03001oogoo009oo`005goo00<007kFO]H07GkF00<007ha
OS406gha00<007kFO]H0KgkF1`00=Goo0`0087kF00<007ooOol0P7oo00<007kFO]H00gkF00<007ha
OS402gha00<007ooOol00Woo000GOol00`00O]IneP0MO]H00`00OS5n<@0KOS400`00O]IneP1fO]H6
000bOol3000MO]H00`00Oomoo`20Ool00`00O]IneP03O]H00`00OS5n<@0;OS400`00Oomoo`02Ool0
01Moo`03001neWkF01eneP03001n<Gha01]n<@03001neWkF07anePD0031oo`<001YneP03001oogoo
081oo`03001neWkF00=neP03001n<Gha00]n<@03001oogoo009oo`0000Aoo`00000000=oo`<000Ao
o`8000Moo`03001neWkF01eneP03001n<Gha01]n<@03001neWkF085nePD002ioo`8001QneP03001o
ogoo081oo`03001neWkF00=neP03001n<Gha00]n<@03001oogoo009oo`0000L007ooOomoo`00Ool0
0003Ool01000Oomoo`000Woo00<007ooOol017oo00<007kFO]H07GkF00<007haOS406gha00<007kF
O]H0QWkF1@00:goo0`005GkF00<007ooOol0P7oo00<007kFO]H00gkF00<007haOS402gha00<007oo
Ool00Woo0004Ool00`00Ool00003Ool01000Oomoo`000Woo00<007ooOol017oo00<007kFO]H07GkF
00<007haOS406gha00<007kFO]H0RgkF1@00:Goo0`004gkF00<007ooOol0Ogoo00<007kFO]H00gkF
00<007haOS402gha00<007ooOol00Woo0004Ool00`00Oomoo`030003Ool01000Oomoo`001Woo00<0
07kFO]H07GkF00<007haOS406gha00<007kFO]H0T7kF1@009goo0P004GkF00<007ooOol0Ogoo00<0
07kFO]H00gkF00<007haOS402gha00<007ooOol00Woo00040002Ool01@00Oomoogoo00000Woo00@0
07ooOol000Ioo`03001neWkF01eneP03001n<Gha01]n<@03001neWkF09EneP@002Eoo`8000mneP03
001oogoo07moo`03001neWkF009neP03001n<Gha00an<@03001oogoo009oo`0000<007ooOol00goo
00D007ooOomoo`00009oo`04001oogoo0006Ool00`00O]IneP0MO]H00`00OS5n<@0KOS400`00O]In
eP2IO]H3000TOol2000=O]H00`00Oomoo`1oOol00`00O]IneP02O]H00`00OS5n<@0<OS400`00Oomo
o`02Ool000D0009oo`<000Aoo`8000Moo`03001neWkF01ineP03001n<Gha01Yn<@03001neWkF09an
eP<002=oo`8000]neP03001oogoo07moo`03001neWkF009neP03001n<Gha00an<@03001oogoo009o
o`005goo00<007kFO]H07WkF00<007haOS406Wha00<007kFO]H0WgkF10008Goo0P002GkF00<007oo
Ool0Ogoo00<007kFO]H00WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0NO]H0
0`00OS5n<@0JOS400`00O]IneP2SO]H3000POol20008O]H00`00Oomoo`1oOol01@00O]IneWkF0000
3Wha00<007ooOol00Woo000GOol00`00O]IneP0NO]H00`00OS5n<@0JOS400`00O]IneP2VO]H3000O
Ool20006O]H00`00Oomoo`1oOol01@00O]IneWkF00003Wha00<007ooOol00Woo000GOol00`00O]In
eP0NO]H00`00OS5n<@0JOS400`00O]IneP2YO]H3000NOol00`00O]IneP03O]H00`00Oomoo`1oOol0
1@00O]IneWkF00003Wha00<007ooOol00Woo000GOol00`00O]IneP0NO]H00`00OS5n<@0JOS400`00
O]IneP2/O]H3000LOol00`00O]IneP02O]H00`00Oomoo`1oOol01@00O]IneWkF00003Wha00<007oo
Ool00Woo000GOol00`00O]IneP0NO]H00`00OS5n<@0JOS400`00O]IneP2_O]H2000KOol20002O]H0
0`00Oomoo`1oOol01@00O]IneWkF00003Wha00<007ooOol00Woo000GOol00`00O]IneP0NO]H00`00
OS5n<@0JOS400`00O]IneP2aO]H3000JOol00`00O]H00021Ool01@00O]IneWkF00003Wha00<007oo
Ool00Woo000GOol00`00O]IneP0NO]H00`00OS5n<@0KOS400`00O]IneP2cO]H2000IOol00`00O]H0
0020Ool01@00O]IneWkF00003Wha00<007ooOol00Woo000GOol00`00O]IneP0NO]H00`00OS5n<@0K
OS400`00O]IneP2eO]H3000GOol20020Ool01@00O]IneWkF00003Wha00<007ooOol00Woo000GOol0
0`00O]IneP0NO]H00`00OS5n<@0KOS400`00O]IneP2hO]JJ0003O]H00`00OS5n<@0<OS400`00Oomo
o`02Ool001Moo`03001neWkF01mneP03001n<Gha01Yn<@03001neWkF0;UneP03001oogoo09Eoo`D0
00in<@03001oogoo009oo`005goo00<007kFO]H07gkF00<007haOS406Wha00<007kFO]H0^7kF00<0
07ooOol0UWoo00D007kFO]IneP0000in<@03001oogoo009oo`005goo00<007kFO]H07gkF00<007ha
OS406Wha00<007kFO]H0^7kF00<007ooOol0UGoo00<007kFO]H00WkF00<007haOS4037ha00<007oo
Ool00Woo000GOol00`00O]IneP0OO]H00`00OS5n<@0JOS400`00O]IneP2hO]H00`00Oomoo`2EOol0
0`00O]IneP02O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF01mneP03001n<Gha
01Yn<@03001neWkF0;MneP03001oogoo09Ioo`03001neWkF009neP03001n<Gha00an<@03001oogoo
009oo`005goo00<007kFO]H07gkF00<007haOS406Wha00<007kFO]H0]gkF00<007ooOol0UWoo00<0
07kFO]H00WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0OO]H00`00OS5n<@0J
OS400`00O]IneP2gO]H00`00Oomoo`2FOol00`00O]IneP02O]H00`00OS5n<@0<OS400`00Oomoo`02
Ool001Moo`03001neWkF01mneP03001n<Gha01Yn<@03001neWkF0;MneP03001oogoo09Ioo`03001n
eWkF009neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H07gkF00<007haOS406Wha
00<007kFO]H0]WkF00<007ooOol0Ugoo00<007kFO]H00WkF00<007haOS4037ha00<007ooOol00Woo
000GOol00`00O]IneP0OO]H00`00OS5n<@0JOS400`00O]IneP2fO]H00`00Oomoo`2GOol00`00O]In
eP02O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF01mneP03001n<Gha01Yn<@03
001neWkF0;IneP03001oogoo09Moo`03001neWkF009neP03001n<Gha00an<@03001oogoo009oo`00
5goo00<007kFO]H087kF00<007haOS406Gha00<007kFO]H0]WkF00<007ooOol0Ugoo00<007kFO]H0
0WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0PO]H00`00OS5n<@0IOS400`00
O]IneP2fO]H00`00Oomoo`2GOol00`00O]IneP02O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Mo
o`03001neWkF021neP03001n<Gha01Un<@03001neWkF0;IneP03001oogoo09Moo`03001neWkF009n
eP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H087kF00<007haOS406Gha00<007kF
O]H0]GkF00<007ooOol0Ugoo00<007kFO]H00gkF00<007haOS4037ha00<007ooOol00Woo000GOol0
0`00O]IneP0PO]H00`00OS5n<@0IOS400`00O]IneP2eO]H00`00Oomoo`2GOol00`00O]IneP03O]H0
0`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF021neP03001n<Gha01Un<@03001neWkF
0;EneP03001oogoo09Moo`03001neWkF00=neP03001n<Gha00an<@03001oogoo009oo`005goo00<0
07kFO]H087kF00<007haOS406Gha00<007kFO]H0]GkF00<007ooOol0Ugoo00<007kFO]H00gkF00<0
07haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0PO]H00`00OS5n<@0IOS400`00O]IneP2d
O]H00`00Oomoo`2HOol00`00O]IneP03O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001n
eWkF021neP03001n<Gha01Un<@03001neWkF0;AneP03001oogoo09Qoo`03001neWkF00=neP03001n
<Gha00an<@03001oogoo009oo`005goo00<007kFO]H087kF00<007haOS406Gha00<007kFO]H0]7kF
00<007ooOol0V7oo00<007kFO]H00gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]In
eP0PO]H00`00OS5n<@0IOS400`00O]IneP2cO]H00`00Oomoo`2IOol00`00O]IneP03O]H00`00OS5n
<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF021neP03001n<Gha01Un<@03001neWkF0;=neP03
001oogoo09Uoo`03001neWkF00=neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0
8GkF00<007haOS4067ha00<007kFO]H0/gkF00<007ooOol0VGoo00<007kFO]H00gkF00<007haOS40
37ha00<007ooOol00Woo000GOol00`00O]IneP0QO]H00`00OS5n<@0HOS400`00O]IneP2cO]H00`00
Oomoo`2IOol00`00O]IneP03O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF025n
eP03001n<Gha01Qn<@03001neWkF0;9neP03001oogoo09Yoo`03001neWkF00=neP03001n<Gha00an
<@03001oogoo009oo`005goo00<007kFO]H08GkF00<007haOS406Gha00<007kFO]H0/GkF00<007oo
Ool0VWoo00<007kFO]H00gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0QO]H0
0`00OS5n<@0IOS400`00O]IneP2aO]H00`00Oomoo`2JOol00`00O]IneP03O]H00`00OS5n<@0<OS40
0`00Oomoo`02Ool001Moo`03001neWkF025neP03001n<Gha01Un<@03001neWkF0;5neP03001oogoo
09Yoo`03001neWkF00=neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H08GkF00<0
07haOS406Gha00<007kFO]H0/GkF00<007ooOol0VWoo00<007kFO]H00gkF00<007haOS4037ha00<0
07ooOol00Woo000GOol00`00O]IneP0QO]H00`00OS5n<@0IOS400`00O]IneP2aO]H00`00Oomoo`2J
Ool00`00O]IneP03O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF025neP03001n
<Gha01Un<@03001neWkF0;1neP03001oogoo09Yoo`03001neWkF00AneP03001n<Gha00an<@03001o
ogoo009oo`005goo00<007kFO]H08GkF00<007haOS406Gha00<007kFO]H0/7kF00<007ooOol0VWoo
00<007kFO]H017kF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0QO]H00`00OS5n
<@0IOS400`00O]IneP2`O]H00`00Oomoo`2JOol00`00O]IneP04O]H00`00OS5n<@0<OS400`00Oomo
o`02Ool001Moo`03001neWkF029neP03001n<Gha01Qn<@03001neWkF0;1neP03001oogoo09Yoo`03
001neWkF00AneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H08WkF00<007haOS40
67ha00<007kFO]H0[gkF00<007ooOol0Vgoo00<007kFO]H017kF00<007haOS4037ha00<007ooOol0
0Woo000GOol00`00O]IneP0RO]H00`00OS5n<@0HOS400`00O]IneP2_O]H00`00Oomoo`2KOol00`00
O]IneP04O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF029neP03001n<Gha01Qn
<@03001neWkF0:mneP03001oogoo09]oo`03001neWkF00AneP03001n<Gha00an<@03001oogoo009o
o`005goo00<007kFO]H08WkF00<007haOS4067ha00<007kFO]H0[WkF00<007ooOol0W7oo00<007kF
O]H017kF00<007haOS4037ha00<007ooOol00Woo000017oo0000000017oo0P0017oo0P001goo00<0
07kFO]H08WkF00<007haOS4067ha00<007kFO]H0[WkF00<007ooOol0W7oo00<007kFO]H017kF00<0
07haOS4037ha00<007ooOol00Woo00001@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo
0006Ool00`00O]IneP0RO]H00`00OS5n<@0HOS400`00O]IneP2^O]H00`00Oomoo`2LOol00`00O]In
eP04O]H00`00OS5n<@0<OS400`00Oomoo`02Ool00005001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Ioo`03001neWkF029neP03001n<Gha01Qn<@03001neWkF0:ineP03001oogoo09ao
o`03001neWkF00AneP03001n<Gha00an<@03001oogoo009oo`0010000goo00@007ooOol0009oo`04
001oogoo0006Ool00`00O]IneP0RO]H00`00OS5n<@0HOS400`00O]IneP2]O]H00`00Oomoo`2LOol0
0`00O]IneP05O]H00`00OS5n<@0<OS400`00Oomoo`02Ool00003001oogoo00Aoo`04001oogoo0002
Ool01000Oomoo`001Woo00<007kFO]H08WkF00<007haOS4067ha00<007kFO]H0[GkF00<007ooOol0
W7oo00<007kFO]H01GkF00<007haOS4037ha00<007ooOol00Woo00000goo001oo`04Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03001neWkF029neP03001n<Gha01Qn<@03001neWkF0:eneP03001o
ogoo09aoo`03001neWkF00EneP03001n<Gha00an<@03001oogoo009oo`000Woo0P0017oo0P0017oo
0P001goo00<007kFO]H08gkF00<007haOS405gha00<007kFO]H0[GkF00<007ooOol0W7oo00<007kF
O]H01GkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0SO]H00`00OS5n<@0GOS40
0`00O]IneP2/O]H00`00Oomoo`2MOol00`00O]IneP05O]H00`00OS5n<@0<OS400`00Oomoo`02Ool0
01Moo`03001neWkF02=neP03001n<Gha01Mn<@03001neWkF0:aneP03001oogoo09eoo`03001neWkF
00EneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H08gkF00<007haOS405gha00<0
07kFO]H0[7kF00<007ooOol0WGoo00<007kFO]H01GkF00<007haOS4037ha00<007ooOol00Woo000G
Ool00`00O]IneP0SO]H00`00OS5n<@0GOS400`00O]IneP2[O]H00`00Oomoo`2NOol00`00O]IneP05
O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02=neP03001n<Gha01Mn<@03001n
eWkF0:]neP03001oogoo09ioo`03001neWkF00EneP03001n<Gha00an<@03001oogoo009oo`005goo
00<007kFO]H08gkF00<007haOS405gha00<007kFO]H0ZgkF00<007ooOol0WWoo00<007kFO]H01GkF
00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0SO]H00`00OS5n<@0GOS400`00O]In
eP2ZO]H00`00Oomoo`2OOol00`00O]IneP05O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03
001neWkF02=neP03001n<Gha01Mn<@03001neWkF0:YneP03001oogoo09moo`03001neWkF00EneP03
001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H08gkF00<007haOS405gha00<007kFO]H0
ZWkF00<007ooOol0WWoo00<007kFO]H01WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00
O]IneP0SO]H00`00OS5n<@0HOS400`00O]IneP2XO]H00`00Oomoo`2OOol00`00O]IneP06O]H00`00
OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02AneP03001n<Gha01Mn<@03001neWkF0:Qn
eP03001oogoo09moo`03001neWkF00IneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kF
O]H097kF00<007haOS405gha00<007kFO]H0Z7kF00<007ooOol0Wgoo00<007kFO]H01WkF00<007ha
OS4037ha00<007ooOol00Woo000GOol00`00O]IneP0TO]H00`00OS5n<@0GOS400`00O]IneP2XO]H0
0`00Oomoo`2OOol00`00O]IneP06O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF
02AneP03001n<Gha01Mn<@03001neWkF0:QneP03001oogoo09moo`03001neWkF00IneP03001n<Gha
00an<@03001oogoo009oo`005goo00<007kFO]H097kF00<007haOS405gha00<007kFO]H0YgkF00<0
07ooOol0X7oo00<007kFO]H01WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0T
O]H00`00OS5n<@0GOS400`00O]IneP2WO]H00`00Oomoo`2POol00`00O]IneP06O]H00`00OS5n<@0<
OS400`00Oomoo`02Ool001Moo`03001neWkF02AneP03001n<Gha01Mn<@03001neWkF0:MneP03001o
ogoo0:1oo`03001neWkF00IneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H097kF
00<007haOS405gha00<007kFO]H0YgkF00<007ooOol0X7oo00<007kFO]H01WkF00<007haOS4037ha
00<007ooOol00Woo000GOol00`00O]IneP0TO]H00`00OS5n<@0GOS400`00O]IneP2VO]H00`00Oomo
o`2QOol00`00O]IneP06O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02AneP03
001n<Gha01Mn<@03001neWkF0:IneP03001oogoo0:1oo`03001neWkF00MneP03001n<Gha00an<@03
001oogoo009oo`005goo00<007kFO]H097kF00<007haOS405gha00<007kFO]H0YWkF00<007ooOol0
X7oo00<007kFO]H01gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0TO]H00`00
OS5n<@0GOS400`00O]IneP2UO]H00`00Oomoo`2QOol00`00O]IneP07O]H00`00OS5n<@0<OS400`00
Oomoo`02Ool001Moo`03001neWkF02EneP03001n<Gha01In<@03001neWkF0:EneP03001oogoo0:5o
o`03001neWkF00MneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H09GkF00<007ha
OS405Wha00<007kFO]H0Y7kF00<007ooOol0XWoo00<007kFO]H01gkF00<007haOS4037ha00<007oo
Ool00Woo000GOol00`00O]IneP0UO]H00`00OS5n<@0FOS400`00O]IneP2TO]H00`00Oomoo`2ROol0
0`00O]IneP07O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02EneP03001n<Gha
01In<@03001neWkF0:AneP03001oogoo0:9oo`03001neWkF00MneP03001n<Gha00an<@03001oogoo
009oo`005goo00<007kFO]H09GkF00<007haOS405Wha00<007kFO]H0XgkF00<007ooOol0Xgoo00<0
07kFO]H01gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0VO]H00`00OS5n<@0E
OS400`00O]IneP2SO]H00`00Oomoo`2SOol00`00O]IneP07O]H00`00OS5n<@0<OS400`00Oomoo`02
Ool001Moo`03001neWkF02IneP03001n<Gha01En<@03001neWkF0:=neP03001oogoo0:=oo`03001n
eWkF00MneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H09WkF00<007haOS405Gha
00<007kFO]H0XgkF00<007ooOol0Xgoo00<007kFO]H01gkF00<007haOS4037ha00<007ooOol00Woo
000GOol00`00O]IneP0VO]H00`00OS5n<@0EOS400`00O]IneP2SO]H00`00Oomoo`2SOol00`00O]In
eP07O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02IneP03001n<Gha01En<@03
001neWkF0:9neP03001oogoo0:=oo`03001neWkF00QneP03001n<Gha00an<@03001oogoo009oo`00
5goo00<007kFO]H09WkF00<007haOS405Wha00<007kFO]H0XGkF00<007ooOol0Xgoo00<007kFO]H0
27kF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0VO]H00`00OS5n<@0FOS400`00
O]IneP2QO]H00`00Oomoo`2SOol00`00O]IneP08O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Mo
o`03001neWkF02IneP03001n<Gha01In<@03001neWkF0:5neP03001oogoo0:=oo`03001neWkF00Qn
eP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H09WkF00<007haOS405Wha00<007kF
O]H0X7kF00<007ooOol0Y7oo00<007kFO]H027kF00<007haOS4037ha00<007ooOol00Woo000GOol0
0`00O]IneP0VO]H00`00OS5n<@0FOS400`00O]IneP2PO]H00`00Oomoo`2TOol00`00O]IneP08O]H0
0`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02IneP03001n<Gha01In<@03001neWkF
0:1neP03001oogoo0:Aoo`03001neWkF00QneP03001n<Gha00an<@03001oogoo009oo`005goo00<0
07kFO]H09WkF00<007haOS405Wha00<007kFO]H0WgkF00<007ooOol0YGoo00<007kFO]H027kF00<0
07haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0WO]H00`00OS5n<@0EOS400`00O]IneP2O
O]H00`00Oomoo`2UOol00`00O]IneP08O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001n
eWkF02MneP03001n<Gha01En<@03001neWkF09mneP03001oogoo0:Eoo`03001neWkF00QneP03001n
<Gha00an<@03001oogoo009oo`005goo00<007kFO]H09gkF00<007haOS405Gha00<007kFO]H0WWkF
00<007ooOol0YWoo00<007kFO]H027kF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]In
eP0WO]H00`00OS5n<@0EOS400`00O]IneP2NO]H00`00Oomoo`2UOol00`00O]IneP09O]H00`00OS5n
<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02MneP03001n<Gha01En<@03001neWkF09ineP03
001oogoo0:Eoo`03001neWkF00UneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0
9gkF00<007haOS405Gha00<007kFO]H0WGkF00<007ooOol0YWoo00<007kFO]H02GkF00<007haOS40
37ha00<007ooOol00Woo000GOol00`00O]IneP0WO]H00`00OS5n<@0EOS400`00O]IneP2MO]H00`00
Oomoo`2VOol00`00O]IneP09O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02Mn
eP03001n<Gha01En<@03001neWkF09aneP03001oogoo0:Moo`03001neWkF00UneP03001n<Gha00an
<@03001oogoo009oo`005goo00<007kFO]H09gkF00<007haOS405Gha00<007kFO]H0W7kF00<007oo
Ool0Ygoo00<007kFO]H02GkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0WO]H0
0`00OS5n<@0EOS400`00O]IneP2LO]H00`00Oomoo`2VOol00`00O]IneP0:O]H00`00OS5n<@0<OS40
0`00Oomoo`02Ool00004Ool000000002Ool50003Ool20007Ool00`00O]IneP0WO]H00`00OS5n<@0E
OS400`00O]IneP2KO]H00`00Oomoo`2WOol00`00O]IneP0:O]H00`00OS5n<@0<OS400`00Oomoo`02
Ool00005001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001neWkF02QneP03
001n<Gha01An<@03001neWkF09]neP03001oogoo0:Moo`03001neWkF00YneP03001n<Gha00an<@03
001oogoo009oo`0000D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0006Ool00`00O]In
eP0XO]H00`00OS5n<@0DOS400`00O]IneP2KO]H00`00Oomoo`2WOol00`00O]IneP0:O]H00`00OS5n
<@0<OS400`00Oomoo`02Ool000@000Eoo`05001oogooOol00002Ool00`00Oomoo`04Ool00`00O]In
eP0XO]H00`00OS5n<@0DOS400`00O]IneP2JO]H00`00Oomoo`2XOol00`00O]IneP0:O]H00`00OS5n
<@0<OS400`00Oomoo`02Ool00003001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`001Woo
00<007kFO]H0:7kF00<007haOS4057ha00<007kFO]H0VWkF00<007ooOol0Z7oo00<007kFO]H02WkF
00<007haOS4037ha00<007ooOol00Woo00000goo001oo`03Ool01@00Oomoogoo00000Woo00@007oo
Ool000Ioo`03001neWkF02QneP03001n<Gha01An<@03001neWkF09YneP03001oogoo0:Moo`03001n
eWkF00]neP03001n<Gha00an<@03001oogoo009oo`000Woo0P000goo0`0017oo0P001goo00<007kF
O]H0:7kF00<007haOS4057ha00<007kFO]H0VGkF00<007ooOol0Z7oo00<007kFO]H02gkF00<007ha
OS4037ha00<007ooOol00Woo000GOol00`00O]IneP0XO]H00`00OS5n<@0DOS400`00O]IneP2IO]H0
0`00Oomoo`2XOol00`00O]IneP0;O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF
02QneP03001n<Gha01An<@03001neWkF09UneP03001oogoo0:Qoo`03001neWkF00]neP03001n<Gha
00an<@03001oogoo009oo`005goo00<007kFO]H0:7kF00<007haOS4057ha00<007kFO]H0V7kF00<0
07ooOol0ZGoo00<007kFO]H02gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0X
O]H00`00OS5n<@0DOS400`00O]IneP2GO]H00`00Oomoo`2ZOol00`00O]IneP0;O]H00`00OS5n<@0<
OS400`00Oomoo`02Ool001Moo`03001neWkF02QneP03001n<Gha01An<@03001neWkF09MneP03001o
ogoo0:Yoo`03001neWkF00]neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0:GkF
00<007haOS4057ha00<007kFO]H0UGkFc00017oo000GOol00`00O]IneP0YO]H00`00OS5n<@0DOS40
0`00O]IneP2EO]H00`00Oomoo`2ZOol00`00O]IneP0<O]H00`00OS5n<@0<OS400`00Oomoo`02Ool0
01Moo`03001neWkF02UneP03001n<Gha01An<@03001neWkF09AneP03001oogoo0:]oo`03001neWkF
00aneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0:GkF00<007haOS4057ha00<0
07kFO]H0TgkF00<007ooOol0Zgoo00<007kFO]H03GkF00<007haOS4037ha00<007ooOol00Woo000G
Ool00`00O]IneP0YO]H00`00OS5n<@0DOS400`00O]IneP2BO]H00`00Oomoo`2/Ool00`00O]IneP0=
O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02UneP03001n<Gha01An<@03001n
eWkF095neP03001oogoo0:eoo`03001neWkF00eneP03001n<Gha00an<@03001oogoo009oo`005goo
00<007kFO]H0:GkF00<007haOS4057ha00<007kFO]H0T7kF00<007ooOol0[Goo00<007kFO]H03WkF
00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0YO]H00`00OS5n<@0DOS400`00O]In
eP2>O]H2002`Ool00`00O]IneP0>O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF
02UneP03001n<Gha01An<@03001neWkF08eneP03001oogoo0;1oo`03001neWkF00ineP03001n<Gha
00an<@03001oogoo009oo`005goo00<007kFO]H0:GkF00<007haOS4057ha00<007kFO]H0S7kF00<0
07ooOol0/7oo00<007kFO]H03gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0Y
O]H00`00OS5n<@0DOS400`00O]IneP2;O]H00`00Oomoo`2aOol00`00O]IneP0?O]H00`00OS5n<@0<
OS400`00Oomoo`02Ool001Moo`03001neWkF02YneP03001n<Gha01=n<@03001neWkF08YneP03001o
ogoo0;5oo`03001neWkF011neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0:WkF
00<007haOS404gha00<007kFO]H0RGkF00<007ooOol0/Woo00<007kFO]H047kF00<007haOS4037ha
00<007ooOol00Woo000GOol00`00O]IneP0ZO]H00`00OS5n<@0COS400`00O]IneP27O]H2002dOol0
0`00O]IneP0AO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02YneP03001n<Gha
01=n<@03001neWkF08IneP03001oogoo0;Aoo`03001neWkF015neP03001n<Gha00an<@03001oogoo
009oo`005goo00<007kFO]H0:WkF00<007haOS404gha00<007kFO]H0QGkF00<007ooOol0]7oo00<0
07kFO]H04WkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0ZO]H00`00OS5n<@0C
OS420024O]H2002gOol00`00O]IneP0BO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001n
eWkF02YneP03001n<Gha01=n<@8008=neP03001oogoo0;Ioo`03001neWkF01=neP03001n<Gha00an
<@03001oogoo009oo`005goo00<007kFO]H0:WkF00<007haOS404gha0`00PGkF00<007ooOol0]goo
00<007kFO]H04gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0ZO]H00`00OS5n
<@0COS43001oO]H2002iOol00`00O]IneP0DO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03
001neWkF02YneP03001n<Gha01=n<@800003Ool007kF07aneP03001oogoo0;Uoo`03001neWkF01An
eP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0:WkF00<007haOS404gha0P0000=o
o`00O]H0NWkF0P00^goo00<007kFO]H05GkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00
O]IneP0ZO]H00`00OS5n<@0COS420002Ool00`00O]IneP1gO]H00`00Oomoo`2jOol00`00O]IneP0F
O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02]neP03001n<Gha019n<@8000=o
o`03001neWkF07AneP800;aoo`03001neWkF01MneP03001n<Gha00an<@03001oogoo009oo`005goo
00<007kFO]H0:gkF00<007haOS404Wha00<007kF00000goo00<007kFO]H0LWkF00<007ooOol0^goo
00<007kFO]H067kF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0[O]H00`00OS5n
<@0BOS400`00O]H00004Ool00`00O]IneP1_O]H2002mOol00`00O]IneP0IO]H00`00OS5n<@0<OS40
0`00Oomoo`02Ool001Moo`03001neWkF02]neP03001n<Gha019n<@03001neP0000Eoo`03001neWkF
06aneP800;ioo`03001neWkF01YneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0
:gkF00<007haOS404Wha00<007kF00001Goo00<007kFO]H0JWkF0P00_goo00<007kFO]H06gkF00<0
07haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0[O]H00`00OS5n<@0BOS400`00O]H00006
Ool00`00O]IneP1XO]H00`00Oomoo`2nOol00`00O]IneP0LO]H00`00OS5n<@0<OS400`00Oomoo`02
Ool001Moo`03001neWkF02]neP03001n<Gha019n<@03001neP0000Moo`03001neWkF06EneP800<1o
o`03001neWkF01eneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H00WkF00<007kF
O]H05gkF00E9[@00000004V]009neP03001neWkF00EneP03001n<Gha019n<@04001neWkF0006Ool0
0`00O]IneP1SO]H20031Ool00`00O]IneP0NO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03
001neWkF009neP03001neWkF01IneP07BJd004V]O]I9[@00BJd02GkF00<007haOS404Wha00@007kF
O]H000Moo`03001neWkF061neP800<5oo`80025neP03001n<Gha00an<@03001oogoo009oo`005goo
00<007kFO]H00WkF00<007kFO]H02GkF1`001WkF00<004V]O]H00WkF00=9[@00O]H027kF00<007ha
OS404Wha00@007kFO]H000Qoo`03001neWkF05eneP800<9oo`03001neWkF025neP03001n<Gha00an
<@03001oogoo009oo`005goo00<007kFO]H00WkF00<007kFO]H05WkF00<007:DO]H00WkF00=9[@00
O]H027kF00<007haOS404Wha00@007kFO]H000Qoo`03001neWkF05]neP800<=oo`03001neWkF029n
eP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H00WkF1@0000<@@V8aO]H04GkF00L0
022UJW=neTV]0019[@0:O]H00`00OS5n<@0AOS401000O]IneP002Goo00<007kFO]H0F7kF0P00`goo
0P009GkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP02O]H01`00O]IneWkFLY@a
222U00EnePL000IneP03001AcPPQ00800003BJeneWkF00UneP03001n<Gha015n<@04001neWkF0009
Ool00`00O]IneP1FO]H20034Ool00`00O]IneP0UO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Mo
o`03001neWkF009neP03001neWkF00=neP03001neWkF011neP0368AJ47kF00ineP03001n<Gha019n
<@04001neWkF0009Ool00`00O]IneP1CO]H20035Ool00`00O]IneP0VO]H00`00OS5n<@0<OS400`00
Oomoo`02Ool001Moo`03001neWkF009neP03001neWkF00=neP03001neWkF011neP03@F/XigkF009n
eP03BJd007kF00UneP03001n<Gha019n<@04001neWkF0009Ool00`00O]IneP1AO]H20035Ool2000Y
O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF009neP07001neWkFO]IbU3488:D0
4WkF00MbU000@F]neTV]0019[@0:O]H00`00OS5n<@0BOS401000O]IneP002Woo00<007kFO]H0CWkF
0P00aGoo0P00:gkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP02O]H500000a12
HS5neP0BO]H01F8a68@00000BJd02gkF00<007haOS404Wha00@007kFO]H000Yoo`03001neWkF04an
eP800<Eoo`8002eneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0;7kF00<007ha
OS404Wha00D007kFO]IneP0000Yoo`03001neWkF04QneP<00<Ioo`03001neWkF02eneP03001n<Gha
00an<@03001oogoo009oo`005goo00<007kFO]H0;7kF00<007haOS404Wha00D007kFO]IneP0000]o
o`03001neWkF04EneP800<Moo`80031neP03001n<Gha00an<@03001oogoo009oo`005goo00<007kF
O]H0;7kF00<007haOS404Wha00D007kFO]IneP0000]oo`03001neWkF04=neP800<Moo`80039neP03
001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0;7kF00<007haOS404Wha00<007kFO]H0
0WkF00<007ooOol02Goo00<007kFO]H0@7kF0P00agoo0P00=7kF00<007haOS4037ha00<007ooOol0
0Woo000GOol00`00O]IneP0/O]H00`00OS5n<@0BOS400`00O]IneP02O]H00`00Oomoo`0:Ool00`00
O]IneP0lO]H30036Ool3000fO]H00`00OS5n<@0<OS400`00Oomoo`02Ool00004Ool000000004Ool3
0003Ool20007Ool00`00O]IneP0]O]H00`00OS5n<@0AOS400`00O]IneP02O]H00`00Oomoo`0:Ool0
0`00O]IneP0iO]H30036Ool3000iO]H00`00OS5n<@0<OS400`00Oomoo`02Ool00005001oogooOol0
0004Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007kFO]H0;GkF00<007haOS404Gha00<0
07kFO]H00WkF00<007ooOol02goo00<007kFO]H0=WkF0P00aWoo0`00?7kF00<007haOS4037ha00<0
07ooOol00Woo00001P00Oomoogoo001oo`D0009oo`04001oogoo0006Ool00`00O]IneP0]O]H00`00
OS5n<@0AOS400`00O]IneP02O]H00`00Oomoo`0<Ool00`00O]IneP0bO]H30035Ool3000oO]H00`00
OS5n<@0<OS400`00Oomoo`02Ool000@0009oo`04001oogoo0003Ool01000Oomoo`001Woo00@007kF
O]IneP@000AnePL00003O]H0000000D000InePD000=neP03BJd007:D00=nePL000in<@03001neWkF
00=neP03001oogoo00]oo`03001neWkF02mneP<00<Eoo`<0049neP03001n<Gha00an<@03001oogoo
009oo`0000<007ooOol017oo00<007oo00000goo00@007ooOol000Ioo`07001neWkFO]IZL`PQ:>L0
1WkF00IZL`0000000112LY@2O]H01D5[00000000DLh027kF00=J4000FQ0017kF00<@@P00>DX017kF
100000=IS7haOS403Gha00<007kFO]H00gkF00<007ooOol037oo00<007kFO]H0;7kF0P00aGoo0`00
AGkF00<007haOS4037ha00<007ooOol00Woo00000goo001oo`05Ool20003Ool01000Oomoo`001Woo
00<007kFO]H00WkF00=9[AR4O]H01GkF00EZL`000000068a00AneP<000YneP03001neWkF009neP04
HS4000002244O]H4000@OS400`00O]IneP03O]H00`00Oomoo`0=Ool00`00O]IneP0XO]H30032Ool5
0018O]H00`00OS5n<@0<OS400`00Oomoo`02Ool0009oo`8000Eoo`03001oogoo009oo`8000Moo`03
001neWkF00=neP03225ZLgkF00AneP04:>L00000:>L5O]H3000:O]H00`00O]IneP02O]H01BSW0000
0000BJd00gkF100047ha00<007kFO]H00gkF00<007ooOol03Goo00<007kFO]H09GkF0`00`Goo1000
CGkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP03O]H00c480000000700000f8a
O]IneP03O]H30004O]H00bSWO]IneP03O]H01@00O]IneWkFLY@00`0000=1JaR4O]H00WkF100047ha
00<007kFO]H00gkF00<007ooOol03Woo00<007kFO]H08GkF0`00_goo1@00DGkF00<007haOS4037ha
00<007ooOol00Woo000GOol00`00O]IneP03O]H00f8a449neP03O]H0145[000001R41WkF0`000gkF
00=ZL`00O]H017kF00D007kFO]IneTV]00800004449nePPQHS42O]H4000@OS400`00O]IneP03O]H0
0`00Oomoo`0>Ool00`00O]IneP0NO]H3002nOol4001FO]H00`00OS5n<@0<OS400`00Oomoo`02Ool0
01Moo`03001neWkF00AneP03225ZLgkF009neP0422400000BJd6O]H300001GkFLYAAcQ1200001GkF
00D007kFO]IneQ1200800004BJeneTV]:>L2O]H4000@OS400`00O]IneP04O]H00`00Oomoo`0>Ool0
0`00O]IneP0JO]H3002lOol5001JO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF
00AneP05<@Q1JgkFO]IJ40030007O]H80005O]H01000O]IneV8a0`0000IbU7kFLY@007:DO]H4000@
OS400`00O]IneP04O]H00`00Oomoo`0>Ool00`00O]IneP0FO]H4002iOol6001OO]H00`00OS5n<@0<
OS400`00Oomoo`02Ool001Moo`03001neWkF00AneP05HS4@@WkFO]HPY@0200000cU:O]IneP05O]H3
00001GkFLYAAcQ1200001GkF00@007kFO]HXi`800006:>MneWkFO]Ha23U:0WkF0`0047ha00<007kF
O]H017kF00<007ooOol03goo00<007kFO]H04WkF0`00]Goo2000IGkF00<007haOS4037ha00<007oo
Ool00Woo000GOol00`00O]IneP05O]H00`PQJW=ZL`0300000fYcO]IneP05O]H30003O]H00f8a001n
eP04O]H00`00O]IbU00300001VYcO]IneWkFJW<88@9neP<0011n<@03001neWkF00AneP03001oogoo
00moo`03001neWkF00mneP<00;1oo`P006eneP03001n<Gha00an<@03001oogoo009oo`005goo00<0
07kFO]H01GkF00<a200000000P0000<XigkFO]H01WkF0`0017kF00<PYGkFO]H00gkF00<007kFBJd0
0P0000<HQ7kFO]H00gkF00<PYDV]O]H00`0047ha00<007kFO]H017kF00<007ooOol047oo00<007kF
O]H02WkF1000ZWoo2@00MGkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP05O]H0
0f8a0000000200000eX@O]IneP06O]H30007O]H01R2UO]IneP00O]H@@P800003BJeneWkF00=neP03
FQ0HQ7kF00<0011n<@03001neWkF00AneP03001oogoo015oo`03001neWkF00IneP<00:Ioo`P007in
eP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H01WkF00@88@0000088@UneP<000In
eP06HS4007kFO]H0068a0`001gkF00<88F8a00000P0047ha00<007kFO]H01GkF00<007ooOol047oo
00<007kFO]H00gkF0`00XGoo2000QWkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]In
eP06O]H01348000004V]27kF00E1J`000000068a00=neP08FQ0iBP00001neUX@000Xi`800003<@Qn
eWkF00EneP03BJdXi`0000800003FHan<Gha00en<@03001neWkF00EneP03001oogoo015oo`03001n
eP00008009aoo`P008ineP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H01WkF00AR
<@00001bU0MneQ<00003JW=neWkF00EneP03LY@0000000@000in<@03001neWkF00Ene[D009IneP03
001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0;WkF00<007haOS4047ha00<007kFO]H0
1GkF00<007ooOol0Zgoo0P00VgkF00<007haOS4037ha00<007ooOol00Woo000GOol00`00O]IneP0^
O]H00`00OS5n<@0@OS400`00O]IneP05O]H00`00Oomoo`2YOol2002MO]H00`00OS5n<@0<OS400`00
Oomoo`02Ool001Moo`03001neWkF02ineP03001n<Gha011n<@03001neWkF00EneP03001oogoo0:Io
o`<009mneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0;WkF00<007haOS4047ha
00<007kFO]H017kF00<007ooOol0YGoo0P00XWkF00<007haOS4037ha00<007ooOol00Woo000GOol0
0`00O]IneP0^O]H00`00OS5n<@0@OS400`00O]IneP04O]H00`00Oomoo`2SOol2002TO]H00`00OS5n
<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02mneP03001n<Gha00mn<@03001neWkF00AneP03
001oogoo0:5oo`800:IneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kFO]H0;gkF00<0
07haOS403gha00<007kFO]H017kF00<007ooOol0WWoo0`00Z7kF00<007haOS4037ha00<007ooOol0
0Woo000GOol00`00O]IneP0_O]H00`00OS5n<@0?OS400`00O]IneP04O]H00`00Oomoo`2LOol2002[
O]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02mneP03001n<Gha00mn<@03001n
eWkF00AneP03001oogoo09Uoo`<00:eneP03001n<Gha00an<@03001oogoo009oo`005goo00<007kF
O]H0;gkF00<007haOS403gha00<007kFO]H00gkF00<007ooOol0V7oo0P00/7kF00<007haOS4037ha
00<007ooOol00Woo000GOol00`00O]IneP0_O]H00`00OS5n<@0@OS400`00O]IneP02O]H00`00Oomo
o`2FOol2002bO]H00`00OS5n<@0<OS400`00Oomoo`02Ool001Moo`03001neWkF02mneP03001n<Gha
011n<@03001neWkF009neP03001oogoo09=oo`<00;AneP03001n<Gha00an<@03001oogoo009oo`00
5gooo`00Z00017oo003oOoo3Ool00?mool=oo`00ogoo`goo003oOoo3Ool00?mool=oo`00\
\>"],
  ImageRangeCache->{{{0, 449}, {449, 0}} -> {-0.0550873, 492.483, 0.00236568, \
0.354852}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{654, 803},
WindowMargins->{{81, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000Gd000400@00000000000000040801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 137, 5, 67, "Section"],

Cell[CellGroupData[{
Cell[1889, 61, 73, 1, 63, "Subsection"],
Cell[1965, 64, 423, 11, 68, "Input"],
Cell[2391, 77, 95, 1, 46, "Text"],
Cell[2489, 80, 693, 19, 77, "Input"],
Cell[3185, 101, 67, 1, 46, "Text"],
Cell[3255, 104, 987, 28, 168, "Input"],
Cell[4245, 134, 66, 1, 46, "Text"],
Cell[4314, 137, 843, 17, 142, "Input"],
Cell[5160, 156, 58, 1, 46, "Text"],
Cell[5221, 159, 673, 14, 142, "Input"],
Cell[5897, 175, 97, 1, 46, "Text"],
Cell[5997, 178, 375, 11, 64, "Input"],
Cell[6375, 191, 97, 1, 46, "Text"],
Cell[6475, 194, 284, 9, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6796, 208, 73, 1, 47, "Subsection"],
Cell[6872, 211, 85, 1, 46, "Text"],
Cell[6960, 214, 131, 4, 38, "Input"],
Cell[7094, 220, 92, 4, 38, "Input"],
Cell[7189, 226, 69, 1, 25, "Input"],
Cell[7261, 229, 91, 1, 46, "Text"],
Cell[7355, 232, 485, 12, 129, "Input"],
Cell[7843, 246, 132, 4, 62, "Text"],
Cell[7978, 252, 425, 11, 103, "Input"],
Cell[8406, 265, 160, 4, 62, "Text"],
Cell[8569, 271, 3567, 75, 766, "Input"],
Cell[12139, 348, 93, 1, 46, "Text"],
Cell[12235, 351, 375, 11, 64, "Input"],
Cell[12613, 364, 97, 1, 46, "Text"],
Cell[12713, 367, 284, 9, 38, "Input"],
Cell[13000, 378, 122, 4, 46, "Text"],
Cell[13125, 384, 2992, 61, 688, "Input"],
Cell[16120, 447, 82, 1, 46, "Text"],
Cell[16205, 450, 7189, 151, 1507, "Input"],
Cell[23397, 603, 122, 4, 46, "Text"],
Cell[23522, 609, 1635, 35, 350, "Input"],
Cell[25160, 646, 8165, 172, 1598, "Input"],
Cell[33328, 820, 77, 1, 46, "Text"],
Cell[33408, 823, 503, 13, 77, "Input"],
Cell[33914, 838, 73, 1, 46, "Text"],
Cell[33990, 841, 487, 13, 77, "Input"],
Cell[34480, 856, 99, 1, 46, "Text"],
Cell[34582, 859, 3498, 71, 636, "Input"],
Cell[38083, 932, 86, 1, 46, "Text"],
Cell[38172, 935, 884, 28, 67, "Input"],
Cell[39059, 965, 61, 1, 46, "Text"],
Cell[39123, 968, 2448, 50, 480, "Input"],
Cell[41574, 1020, 62, 1, 46, "Text"],
Cell[41639, 1023, 8247, 136, 1884, "Input"],
Cell[49889, 1161, 62, 1, 46, "Text"],
Cell[49954, 1164, 731, 15, 155, "Input"]
}, Closed]],
Cell[50700, 1182, 106, 1, 46, "Text"],

Cell[CellGroupData[{
Cell[50831, 1187, 67, 1, 63, "Subsection"],
Cell[50901, 1190, 67, 1, 25, "Input"],
Cell[50971, 1193, 134, 4, 38, "Input"],
Cell[51108, 1199, 512, 12, 103, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51657, 1216, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[51749, 1221, 65, 1, 61, "Subsubsection"],
Cell[51817, 1224, 397, 14, 168, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52251, 1243, 70, 1, 47, "Subsubsection"],
Cell[52324, 1246, 334, 8, 77, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52695, 1259, 64, 1, 47, "Subsubsection"],
Cell[52762, 1262, 16927, 320, 3314, "Input"],
Cell[69692, 1584, 6981, 150, 70, "Input"],
Cell[76676, 1736, 134, 4, 70, "SmallText"]
}, Closed]],

Cell[CellGroupData[{
Cell[76847, 1745, 74, 1, 47, "Subsubsection"],
Cell[76924, 1748, 59, 1, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[77032, 1755, 72, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[77129, 1760, 129, 5, 51, "Input"],
Cell[77261, 1767, 85535, 2747, 458, 22137, 1960, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

