(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    123332,       3045]*)
(*NotebookOutlinePosition[    124412,       3079]*)
(*  CellTagsIndexPosition[    124368,       3075]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
\[CapitalDelta]PT - calculating differences in pressure and \
temperature\
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}},
  FontFamily->"Palatino",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell[TextData[StyleBox["Worley & Powell (1999)",
  FontSize->14]], "Subsubtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["as is...", "Text"],

Cell["\[Copyright] bw/rp 2001", "SmallText"],

Cell["\<\
Please look at the \"ReadMe\" file before using this code.

Feel free to have a look at the code in the \"General functions\" cells, but \
be careful about changing things.

Don't forget to \"activate\" the \"General functions\" before trying to \
perform calculations!!\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["general functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Off[General::spell]; Off[General::spell1];
R = 0.0083144;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["format", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
format[x_?NumberQ,n_Integer,_?TrueQ]:=
\t   Module[{m=N[10^n]},Round[m x]/m];
format[x_?NumberQ,n_Integer,___]:=N[x,n];
format[x_,___]:=x;

SetAttributes[format,{Listable}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["remove", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
loses rows on omission of end-members, jj
(m are the multipliers on the pre-existing reactions to produce the new \
reaction - 
so doing similar on a,b,c should be on)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[remove];
remove[jj_]:=
   (ncv=Length[name]; nr=Length[r]; 
    Map[(j=#;  {nr,ncv} = Dimensions[r];
         ii = Range[ncv];
         ii[[1]]=j; ii[[j]]:=1;
         rc = Transpose[Transpose[r][[ii]]];
         pos1 = Flatten[Position[Transpose[rc][[1]],_?((#!=0)&)]];
         cpos1 = Complement[Range[nr],pos1];
         rccp = rc[[cpos1]];
         rp = rc[[pos1]];
         rr = RowReduce[rp];
         posk = Flatten[Position[Transpose[rr][[1]],_?((#==0)&)]];
         m = Map[Flatten[NullSpace[Transpose[Join[{rr[[#]]},rp]]]]&,
                 posk];
         rrp = Map[-Drop[#,1].rp/#[[1]]&,m];
         rrc = Join[rccp,rrp];
         Transpose[Transpose[rrc][[ii]]]
        )&, jj]);\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["avP, avT and avPT", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
mikhails calculates avP, avT, avPT and related sorts of \"simple\" \
non-linear least squares problems \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[mikhails];

mikhails[eq_List, thetavars_List, guess:{_?NumberQ...},
                  xxvars_List, xx:{_?NumberQ...},
                  varxx:{{_?NumberQ...}...},
                  print_:True] :=
                  
  Module[{theta = guess,subs,A,B,f,We,xtx,xty,del,
          sigfit,vtheta,sdtheta,corpt, it = 0, maxit = 30},
  
    FixedPoint[(dummy=#; it++;
                subs = Join[Thread[xxvars->xx], 
                            Thread[thetavars->theta]];
                A = Map[D[eq,#]&,xxvars] /. subs;
                B = Map[D[eq,#]&,thetavars] /. subs;
                f = eq /. subs;
                We = Inverse[Transpose[A].varxx.A];
                xtx = B.We.Transpose[B];
                xty = B.We.f;
                del = Inverse[xtx].xty;
                theta -= del;
                format[del,4,True] )&,0,maxit];
    
    e = varxx.A.We.(Transpose[B].del - f);
    sigfit = Sqrt[e.Inverse[varxx].e/(Length[f]-1)];
    vtheta = If[sigfit>1,sigfit^2,1] Inverse[xtx]; 
    sdtheta = Array[Sqrt[vtheta[[#,#]]]&,Length[theta]];
    corpt = DiagonalMatrix[1/sdtheta].vtheta.DiagonalMatrix[1/sdtheta];
    
If[Length[thetavars]==1,
  If[print,
     Array[Print[\"av \",thetavars[[#]],\" = \",format[theta[[#]],2,True],
             \"; sd = \",format[sdtheta[[#]],2,True] ]&, 
           Length[theta]];
     Print[\"   sigfit = \",format[sigfit,3,True],\"\"] ], 
  If[print,
     Array[Print[\"av \",thetavars[[#]],\" = \",format[theta[[#]],2,True],
             \"; sd = \",format[sdtheta[[#]],2,True] ]&, 
           Length[theta]];
     Print[\"   sigfit = \",format[sigfit,3,True],\"\"];
     Print[\"   cor = \",format[corpt[[1,2]],2,True],\"\"] ] ];
         
    {theta,vtheta,sigfit}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Special mikhails just gives result, for use in finding jacobians \
using finite differences. Specific for avP.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[miks];

miks[eq_List, thetavars_List, guess:{_?NumberQ...},
                  xxvars_List, xx:{_?NumberQ...},
                  varxx:{{_?NumberQ...}...}] :=
                  
  Module[{theta = guess,subs,A,B,f,We,xtx,xty,del,
          sigfit,vtheta,sdtheta, it = 0, maxit = 30},
  
    FixedPoint[(dummy=#; it++;
                subs = Join[Thread[xxvars->xx], 
                            Thread[thetavars->theta]];
                A = Map[D[eq,#]&,xxvars] /. subs;
                B = Map[D[eq,#]&,thetavars] /. subs;
                f = eq /. subs;
                We = Inverse[Transpose[A].varxx.A];
                xtx = B.We.Transpose[B];
                xty = B.We.f;
                del = Inverse[xtx].xty;
                theta -= del;
                format[del,4,True] )&,0,maxit];
    
    e = varxx.A.We.(Transpose[B].del - f);
    sigfit = Sqrt[e.Inverse[varxx].e/(Length[f]-1)];
    vtheta = If[sigfit>1,sigfit^2,1] Inverse[xtx]; 
    sdtheta = Array[Sqrt[vtheta[[#,#]]]&,Length[theta]];
    
    theta[[1]]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Special mikhails just gives result, for use in finding jacobians \
using finite differences. Specific for avPT.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[miksPT];

miksPT[eq_List, thetavars_List, guess:{_?NumberQ...},
                  xxvars_List, xx:{_?NumberQ...},
                  varxx:{{_?NumberQ...}...}] :=
                  
  Module[{theta = guess,subs,A,B,f,We,xtx,xty,del,
          sigfit,vtheta,sdtheta, it = 0, maxit = 30},
  
    FixedPoint[(dummy=#; it++;
                subs = Join[Thread[xxvars->xx], 
                            Thread[thetavars->theta]];
                A = Map[D[eq,#]&,xxvars] /. subs;
                B = Map[D[eq,#]&,thetavars] /. subs;
                f = eq /. subs;
                We = Inverse[Transpose[A].varxx.A];
                xtx = B.We.Transpose[B];
                xty = B.We.f;
                del = Inverse[xtx].xty;
                theta -= del;
                format[del,4,True] )&,0,maxit];
    
    e = varxx.A.We.(Transpose[B].del - f);
    sigfit = Sqrt[e.Inverse[varxx].e/(Length[f]-1)];
    vtheta = If[sigfit>1,sigfit^2,1] Inverse[xtx]; 
    sdtheta = Array[Sqrt[vtheta[[#,#]]]&,Length[theta]];
    
    theta];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["recalc constants", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
oxname = {\"SiO2\",\"TiO2\",\"Al2O3\",\"FeO\",\"MnO\",\"MgO\",\"CaO\
\",
          \"Na2O\", \"K2O\"};
mw =     {60.09, 79.90, 101.94, 71.85,70.94,40.32,56.08,
           61.98, 94.20};
mo =     {    2, 2, 3, 1, 1, 1, 1, 1, 1};
mm =     {    1, 1, 2, 1, 1, 1, 1, 2, 2};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
These number/name equalities only refer to the cations, for which \
Fe3+ has been calculated, note there are only 9 oxides in the original input \
analyses as Fe2O3 is unknown.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Si=1; Ti=2; Al=3; Fe3=4; Fe2=5; Mn=6; Mg=7; Ca=8; Na=9; K=10;\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["recalc functions", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
recalc gets passed a vector of weight%, and the number of oxygens \
to be used in the recalculation, and returns the cations\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[recalc];
recalc[w_, n_]:=
    Module[
       {mp,
        mw = {60.09, 79.90, 101.94, 71.85,70.94,40.32,56.08,
              61.98, 94.20},
        mo = { 2, 2, 3, 1, 1, 1, 1, 1, 1},
        mm = { 1, 1, 2, 1, 1, 1, 1, 2, 2} },
        mp = w/mw;
        f = n/Apply[Plus, mp mo];
        f mp mm];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
recalcall, does the same as recalc, but for the situation where \
Fe2O3 is in the original vector of wt%'s, Useful for phases like feldspar, \
where all Fe is Fe2O3 and is calculated using xcalc. Therefore by the time \
recalc is called, the analysis contains Fe2O3.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[recalcall];
recalcall[w_,n_] :=
    Module[
      {mp,
       mw = {60.09, 79.90, 101.94, 159.70, 71.85, 70.94, 40.32, 
             56.08, 61.98, 94.20},
       mo = { 2, 2, 3, 3, 1, 1, 1, 1, 1, 1},
       mm = { 1, 1, 2, 2, 1, 1, 1, 1, 2, 2}},
        mp = w/mw;
        f = n/Apply[Plus, mp mo];
        f mp mm ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
xcalc gets passed a vector of weight%, and a proportion of FeO to \
be converted to Fe2O3, and returns the weight% with the corresponding FeO and \
Fe2O3\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[xcalc];
xcalc[w_, x_]:=
    Module[{ww = Insert[w,0,4]},
        If[x>0 && x<1.00001,
           ww[[Fe3]] = 1.111343 x w[[4]];
           ww[[Fe2]] = (1-x) w[[4]]];
        ww];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["incr[q_, n_, del_] := (qq = q; qq[[n]] += del; qq);", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\"recalcfe\" is a recalculation function suitable for minerals with \
no vacancies, such as garnet, pyroxenes, spinel, ilmenite.... The function is \
passed a vector of wt%'s (w), the number of oxygens (n), the ideal cation sum \
(csum) and the maximum ratio of Fe3+ to Fe2+ (xmax), and returns a vector of \
cations with Fe reallocated to Fe3+ and Fe2+.  The general equation used to \
allocate Fe3+ is from Droop (1987). As far as I can tell this is the same \
method used by Tim in the DS5 AX. The FeO and Fe2O3 wt%'s are also \
readjusted, so this code can easily be altered to return a table of \
recalculated oxides and cations. Following AX, this function will also work \
for chlorites\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[recalcfe];
recalcfe[w_,n_,csum_,xmax_] :=
 Module[{cat1,cat2,s,f,xfe3, ww = Insert[w,0,4]},
\t\t    cat1 = Insert[recalc[w,n], 0, 4];
\t\t    s = Apply[Plus,cat1];
\t\tIf[s>csum,
\t\t       f = 2 n(1-(csum/s));
\t\t       cat2 = cat1(csum/s);
\t\t\t      xfe3 = f/(f + (cat2[[Fe2]]-f));
\t(* replaces old Fe3+ and Fe2+ with f and (Fe2+ - f),
\t\t\t\tas long as xfe3 < xmax *)\t\t
\t\t\t     If[xfe3<xmax,  cat2[[Fe3]] = f;
\t\t\t\t       cat2[[Fe2]] = cat2[[Fe2]]-f; 
\t          xfe3 = cat2[[Fe3]]/(cat2[[Fe3]]+ cat2[[Fe2]]);,
   \t            xfe3 = xmax;
\t(* normalises the cations according to the value of xmax *)
\t\t\t\t            cat2 = cat1 (1 - ((xfe3 cat1[[Fe2]])/(2 n)));
\t\t\t             cat2[[Fe3]] = xfe3 cat2[[Fe2]];
\t\t\t             cat2[[Fe2]] = (1-xfe3)cat2[[Fe2]]];
\t\t
\t\t              ww[[Fe3]] =  1.111343 xfe3 w[[4]];
\t\t              ww[[Fe2]] = (1-xfe3) w[[4]];
\t\t                cat2,
\t\t\t       cat1]  ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\"recalcfev\" is a recalculation function suitable for minerals \
with vacancies in their structural formulae, such as micas and amphiboles. \
The function is passed a vector of wt%'s (w), the number of oxygens (n), the \
ideal cation sum (csum) and the maximum ratio of Fe3+ to Fe2+ (xmax), and \
returns a vector of cations with Fe reallocated to Fe3+ and Fe2+. The general \
equation used to allocate Fe3+ is from Droop (1987). As far as I can tell \
this is the same method used by Tim in the DS5 AX. As it stands the function \
is specifically set up to deal with micas, the specific line of code is:
 s = Apply[Plus,Drop[cat1, -2]],
 which adds up the cations in the first pass of recalc for comparison with \
the ideal sum, csum. The FeO and Fe2O3 wt%'s are also readjusted, so this \
code can easily be altered to return a table of recalculated oxides and \
cations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[recalcfev];
recalcfev[w_,n_,csum_,xmax_] :=
 Module[{cat1,cat2,s,f,xfe3, ww = Insert[w,0,4]},
\t\t    cat1 = Insert[recalc[w,n], 0, 4];
\t\t    s = Apply[Plus,Drop[cat1, -2]];
\t\tIf[s>csum,
\t\t       f = 2 n(1-(csum/s));
\t\t       cat2 = cat1(csum/s);
\t\t\t   xfe3 = f/(f + (cat2[[Fe2]]-f));
\t(* replaces old Fe3+ and Fe2+ with f and (Fe2+ - f),
\t\t\t\tas long as xfe3 < xmax *)\t\t
\t\t\t     If[xfe3<xmax,  cat2[[Fe3]] = f;
\t\t\t        cat2[[Fe2]] = cat2[[Fe2]]-f; 
\t          xfe3 = cat2[[Fe3]]/(cat2[[Fe3]]+ cat2[[Fe2]]);,
   \t            xfe3 = xmax;
\t(* normalises the cations according to the value of xmax *)
\t\t\t\t            cat2 = cat1 (1 - ((xfe3 cat1[[Fe2]])/(2 n)));
\t\t\t             cat2[[Fe3]] = xfe3 cat2[[Fe2]];
\t\t\t             cat2[[Fe2]] = (1-xfe3)cat2[[Fe2]]];
\t\t
\t\t              ww[[Fe3]] =  1.111343 xfe3 w[[4]];
\t\t              ww[[Fe2]] = (1-xfe3) w[[4]];
\t\t                cat2,
\t\t\t       cat1]  ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["A-x functions (still need chlorite, cpx, and amphibole)", \
"Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
garnet - quaternary model:
returns activities of, {pyrope, grossular, almandine}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsg];
wvarsg = {wcamg,wfemg,wcafe,wcamn,wfemn,wmgmn};
Clear[wvecg];
wvecg[t_]  := { 41.4-0.0188 (t+273), 2.5, 0, 0, 0, 0};

Clear[gax];
gax[wt_,t_,wvars_List, wvec_, ends_] :=
   Module[{ xca,xfe,xmg, c,sum,xg,zg,sg,  xsub, wsub,
\t\t\t         rtlngpy,rtlngalm,rtlnggr,rtlngspss},
\t
\t rtlngpy   = wcamg xca(1-xmg) - wcafe xca xfe - wcamn xca xmn
               + wfemg xfe (1-xmg) - wfemn xfe xmn
\t\t\t\t\t          - wmgmn (1-xmg) xmn;
     rtlngalm  = - wcamg xca xmg + wcafe xca (1-xfe) - wcamn xca xmn
                 + wfemg (1-xfe) xmg + wfemn (1-xfe) xmn
\t\t\t\t\t            - wmgmn xmg xmn;
     rtlnggr   = wcamg (1-xca)xmg + wcafe (1-xca)xfe
               + wcamn (1-xca) xmn - wfemg xfe xmg
               - wfemn xfe xmn - wmgmn xmg xmn;
     rtlngspss = - wcamg xca xmg - wcafe xca xfe + wcamn xca (1-xmn)
\t\t               - wfemg xfe xmg + wfemn xfe (1-xmn)
\t\t\t\t\t            + wmgmn xmg (1-xmn);
\t\t
\t xsub = {xfe -> xg, xca -> zg, xmn -> sg, xmg -> (1-xg-zg-sg)};
\t wsub = Thread[wvars->wvec];
\t\t
\tc = recalcfe[wt,12,8,1];
    sum = c[[Mg]]+c[[Fe2]]+c[[Ca]]+c[[Mn]];
    xg  = c[[Fe2]]/sum;
    zg  = c[[Ca]]/sum;
    sg  = c[[Mn]]/sum;
\t\t
\tFlatten[{If[MemberQ[ends, py],
\t  ((1-xg-zg-sg)^3 Exp[rtlngpy/(R (t+273)) /. xsub /. wsub]),{}],
\t If[MemberQ[ends, gr],
\t  (zg^3 Exp[rtlnggr/(R (t+273)) /. xsub /. wsub]),{}],
\t If[MemberQ[ends, alm],
\t  (xg^3 Exp[rtlngalm/(R (t+273)) /. xsub /. wsub]), {}]  }]];\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
cordierite - regular anhydrous ternary model:
returns activities of, {cordierite, fe-cordierite, mn-cordierite}.\
\>", \
"Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarscd];
wvarscd = {wcdfcd, wcdmncd, wfcdmncd};
Clear[wveccd];
wveccd = {3.0, 3.0, 0};

Clear[cdax];
cdax[wt_,t_,wvars_List, wvec_, ends_] :=
   Module[{ c,x,mn,R = 0.0083144, psub, wsub,
            aidealcd, aidealfcd, aidealmncd,
\t\t\t         rtlngcd, rtlngfcd, rtlngmncd},
\t
\t rtlngcd   = wcdfcd pfcd (1 - pcd) + wcdmncd pmncd (1 - pcd) -
\t\t         wfcdmncd pfcd pmncd;
     rtlngfcd  = wcdfcd pcd (1 - pfcd) - wcdmncd pcd pmncd +
                 wfcdmncd pmncd (1 - pfcd);
     rtlngmncd = - wcdfcd pcd pfcd + wcdmncd pcd (1 - pmncd) +
                 wfcdmncd pfcd (1 - pmncd);
\t\t
\t\tpsub = {pcd -> (1 - x - mn), pfcd -> x, pmncd -> mn};
\t wsub = Thread[wvars -> wvec];
\t\t
\t\t  c = recalcfe[wt,18,11,0.2];
    x   = c[[Fe2]]/(c[[Fe2]] + c[[Mg]] + c[[Mn]]);
    mn  = c[[Mn]]/(c[[Fe2]] + c[[Mg]] + c[[Mn]]);
    
    aidealcd   = (1 - x - mn)^2;
    aidealfcd  = x^2;
    aidealmncd = mn^2;

\t\t
   Flatten[{If[MemberQ[ends, cd],
\t (aidealcd Exp[rtlngcd/(R (t+273)) /. psub /. wsub]), {}],
\tIf[MemberQ[ends, fcd],
\t (aidealfcd Exp[rtlngfcd/(R (t+273)) /. psub /. wsub]), {}],
\tIf[MemberQ[ends, mncd],
\t (aidealmncd Exp[rtlngmncd/(R (t+273)) /. psub /. wsub]), {}] }]];\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Staurolite - 4 site Fe-Mg ideal mixing
{staurolite, Fe-staurolite}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsst];
wvarsst = {wstfst};
Clear[wvecst];
wvecst = {0};

Clear[stax];
stax[wt_, t_, wvars_List, wvec_, ends_] :=
   Module[{c, x, aidealst, aidealfst},
     
     rtlngst  = wstfst pfst (1 - pst);
     rtlngfst = wstfst pst (1 - pfst);
   
     psub = {pst -> 1 - x, pfst -> x};  
     wsub = Thread[wvars -> wvec];
     c = recalcall[xcalc[wt,0],46];
     x = c[[Fe2]]/(c[[Mg]] + c[[Fe2]]);
     
     aidealst  = ((1 - x)(1 - c[[Mn]]))^4;
     aidealfst = (x (1 - c[[Mn]]))^4;
   
   Flatten[{If[MemberQ[ends, mst],
     (aidealst Exp[rtlngst/(R (t+273)) /. psub /. wsub]), {}],
    If[MemberQ[ends, fst],
\t (aidealfst Exp[rtlngfst/(R (t+273)) /. psub /. wsub]), {}]} ] ];\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
biotite - symmetric formalism
returns activities of, {phlogopite, annite, eastonite}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[wvarsbi];\nwvarsbi = \
{wphlann,wphlobi,wphleast,wanneast,wobieast,wobiann,Hbi};\nClear[wvecbi];\n\
wvecbi =  {  9, 3, 10, -1, 10, 6, 32.2};\n\nClear[biax];\n",
    FontWeight->"Plain"],
  StyleBox["biax",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[wt_, t_, wvars_List, wvec_, ends_] :=\n\t\
Module[{xbulk,y,xvm2,n,n1=1,n2=2,c,\n\t        aidealphl, aidealann, \
aidealeast,\n\t\t   rtlngphl, rtlngann, rtlngeast, rtlngobi,\n\t\t   wsub, \
psub, ineq, R = 0.0083144,\n\t\t   xm1,xm2,xfem1,xfem2,xmgm1,xmgm2},\n\t\t(* \
RTlngamma expressions *)\n        rtlngphl  = pann(1-pphl)wphlann + \
pobi(1-pphl)wphlobi \n        \t\t\t       + peast(1-pphl)wphleast - peast \
pann wanneast\n                  - pobi peast wobieast - pobi pann wobiann;\n \
       rtlngann  = pphl (1-pann) wphlann + pobi(1-pann)wobiann\n              \
    + peast(1-pann)wanneast - pobi pphl wphlobi\n                  - pobi \
peast wobieast - peast pphl wphleast;\n        rtlngeast = \
pphl(1-peast)wphleast + pann(1-peast)wanneast\n                  + \
pobi(1-peast)wobieast - pphl pann wphlann\n                  - pobi pann \
wobiann - pobi pphl wphlobi;\n        rtlngobi  = pann (1-pobi)wobiann + pphl \
(1-pobi) wphlobi\n                  + peast (1-pobi) wobieast - pphl pann \
wphlann\n                  - pphl peast wphleast - pann peast wanneast;\t\t\t\
\t\t\t\n\t\t    \n\t\t    wsub = Thread[wvars->wvec];\n        psub = {pphl \
-> (1-y)(1-xbulk)-(n/n1), pann -> xbulk - (n/n2),\n                peast ->y,\
\n\t               pobi -> n/n1 + n/n2 - xbulk y};\n  (* where pobi comes \
from pobi = 1-pphl-pann-peast *)\n         c = recalcfev[wt,11,6.9,0.15];\n  \
(* fill up the 4 Tsites then any Al left goes to M1 *)\n         y    = \
(c[[Al]] + c[[Si]])-4;\n         xbulk    = c[[Fe2]]/(c[[Fe2]] + c[[Mg]]);\n  \
       xvm2 = 3-(y+c[[Ti]]+c[[Fe3]]+c[[Fe2]]+c[[Mn]]+c[[Mg]]);\n\t\t(* \
solving internal equilibrium, 3obi = 2phl+ ann for n,\n\t\t   32.2 = DeltaH \
of the reaction *)\n   ineq = Hbi + 2 R (t + 273)Log[(pann \
pphl)/((1-pann)(1-pphl-peast))]\n\t\t\t   + 2(rtlngphl) + rtlngann - \
3(rtlngobi) /. wsub /. psub;\t\t\n\t\t\n\t    \t  n = n/. FindRoot[ineq, \
{n,0.04,0.05}];\n\t\t(* using n to calculate equilibrium values of x1 and x2 \
*)\n\t\t      xm1 = xbulk + n/(n1 (1-y));\n\t\t      xm2 = xbulk - n/n2;\n    \
    xfem2 = xm2 (1 - xvm2/2 - c[[Mn]]/2);\n        xmgm2 = (1 - xm2)(1 - \
xvm2/2 - c[[Mn]]/2);\n        xfem1 = xm1 (1 - y - c[[Fe3]] - c[[Ti]]);\n     \
   xmgm1 = (1 - xm1) (1 - y - c[[Fe3]] - c[[Ti]]);\n         \n        \
aidealphl = xmgm1 xmgm2^2 (1 + y) (1 - y);\n        aidealann = xfem1 xfem2^2 \
(1 + y) (1 - y);\n        aidealeast = 1/4 y xmgm2^2 (1 + y)^2;\n        \n\
Flatten[{If[MemberQ[ends, phl],\n   (aidealphl Exp[rtlngphl/(R (t + 273)) /. \
wsub] /. psub), {}],\n  If[MemberQ[ends, ann],\n   (aidealann  \
Exp[rtlngann/(R (t + 273)) /. wsub] /. psub), {}],\n  If[MemberQ[ends, east],\
\n   (aidealeast Exp[rtlngeast/(R (t + 273)) /. wsub ] /. psub),{}] }] ];\t\t\
",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["orthopyroxene in FMAS - includes order-disorder of Fe-Mg", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsopx];
wvarsopx = {wenfs, wenfm, wenmt, wfsfm, wfsmt, wmtfm, Hopx};
Clear[wvecopx];
wvecopx =  {6.8, 4.5, 0, 4.5, -1.0, 1.2, -13.9};

Clear[opxax];
opxax[wt_,t_,wvars_List,wvec_, ends_] :=
 Module[{aiden, aidfs, aidmgts, aidfm,
         aidealen, aidealfs, aidealmgts, aidealfm,
         rtlngen, rtlngfs, rtlngmgts, rtlngfm,
         psub, wsub, pen, pfs, pmt, pfm,
         xbulk, y, Q, c, ineq, xm1, xm2,
         xfem1, xmgm1, xfem2, xmgm2,  R = 0.0083144},
         
(* RTlngamma expressions *)
    rtlngen    = wenfs pfs (1 - pen) + wenfm pfm (1 - pen) +
                 wenmt pmt (1 - pen) - wfsfm pfs pfm - 
                 wfsmt pfs pmt - wmtfm pmt pfm;
    rtlngfs    = wenfs pen (1 - pfs) - wenfm pen pfm -
                 wenmt pen pmt + wfsfm pfm (1 - pfs) +
                 wfsmt pmt (1 - pfs) - wmtfm pmt pfm;
    rtlngmgts  = - wenfs pen pfs - wenfm pen pfm +
                 wenmt pen (1 - pmt) - wfsfm pfs pfm +
                 wfsmt pfs (1 - pmt) + wmtfm pfm (1 - pmt);
    rtlngfm    = - wenfs pen pfs + wenfm pen (1 - pfm) -
                 wenmt pen pmt + wfsfm pfs (1 - pfm) -
                 wfsmt pfs pmt + wmtfm pmt (1 - pfm);
                 
    psub = {pmt -> y, pfs -> (xbulk - 1/2 Q) (1 - y),
            pen -> 1 - (xbulk + 1/2 Q) - y,
            pfm -> (xbulk + 1/2 Q) - ((xbulk - 1/2 Q) (1 - y))};
    wsub = Thread[wvars -> wvec];
    
    c = recalcfe[wt,6,4,1];
    y = (c[[Si]] + c[[Al]]) - 2;
    xbulk = c[[Fe2]]/(c[[Fe2]] + c[[Mg]]);
    
    ineq = Hopx + R (t + 273) Log[((1 - xbulk + 1/2 Q)
     (xbulk + 1/2 Q))/((xbulk - 1/2 Q) (1 - xbulk - 1/2 Q))] +
     2(rtlngfm) - rtlngen - rtlngfs /. psub /. wsub;
     
    Q = Q/. FindRoot[ineq, {Q, 0.2, 0.3}];
    
 (* where xm1 and xm2 are defined as:
       nfe/(nfe + nmg) on the m1 and m2 sites. Note xm2 is
       equivalent to the site fraction, but not xm1 as Al is
       also present on the m1 site *)
    xm1 = xbulk - Q/2;
    xm2 = xbulk + Q/2;
    
 (* up to here everything has ignored the minor components,
       here they are introduced into the site fraction expressions,
       so that they contribute to the configurational entropy *)
    xfem1 = xm1 (1 - y - c[[Ti]] - c[[Fe3]]);
    xmgm1 = (1 - xm1) (1 - y - c[[Ti]] - c[[Fe3]]);
    xfem2 = xm2 (1 - c[[Mn]] - c[[Ca]]);
    xmgm2 = (1 - xm2) (1 - c[[Mn]] - c[[Ca]]);
 
 (* ideal activity expressions including minor components *)   
    aidealen   = xmgm1 xmgm2;
    aidealfs   = xfem1 xfem2;
    aidealmgts = y xfem2;
    aidealfm   = xmgm1 xfem2;
    
  Flatten[{If[MemberQ[ends, en],
    (aidealen Exp[rtlngen/(R (t + 273))  /. wsub /. psub]), {}],
   If[MemberQ[ends, fs],
    (aidealfs Exp[rtlngfs/(R (t + 273)) /. wsub /. psub]), {}],
   If[MemberQ[ends, mgts],
    (aidealmgts Exp[rtlngmgts/(R (t + 273)) /. wsub /. psub]), {}]}] ];\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
muscovite - non-ideal N-K-Vacancy mixing
returns activities of {muscovite, celadonite}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsmu];
wvarsmu = {wmupa, wcelpa, wpafcel, Ipa, wnav, wkv,
           wmucel, wmufcel, wfcelcel};
Clear[wvecmu];
wvecmu[p_] := {12.0 + 0.4 p, 14.0 + 0.2 p, 14.0 + 0.2 p,
\t\t             1.42 + 0.4 p, 14, 14, 0, 0, 0};

Clear[muax];
muax[wt_,t_,p_,wvars_List,wvec_, ends_] :=
\tModule[{x,y,z,v,c,R,  aidealmu,aidealcel,aidealfcel,aidealpa,
\t\t            pmu,pcel,pfcel,ppa,
\t\t\t\t          rtlngmu,rtlngcel,rtlngfcel,rtlngpa,
\t\t            wsub,psub},
  (* ideal activity expressions *)
        aidealmu   = (1-z-v)y^2(2-y);
        aidealcel  = 1/4(1-z-v)(1-y)(1-x)(2-y)^2;
        aidealfcel = 1/4(1-z-v)(1-y)x(2-y)^2;
        aidealpa   = z y^2 (2-y);
  (* RTlngamma expressions *)
        rtlngmu   = wmupa ppa (1-pmu) - wcelpa ppa pcel
\t\t\t\t  - wpafcel ppa pfcel+ (1-pmu)pcel wmucel
                  + (1-pmu)pfcel wmufcel - pfcel pcel wfcelcel
\t\t                - wnav ppa pv + wkv (1-pmu) pv;
        rtlngcel  = - wmupa pmu ppa + wcelpa ppa (1-pcel)
\t\t\t\t    - wpafcel ppa pfcel+ pmu(1-pcel)wmucel
                    - pmu pfcel wmufcel + pfcel(1-pcel)wfcelcel
\t\t                  - wnav ppa pv - wkv pmu pv;
        rtlngfcel = - wmupa pmu ppa - wcelpa ppa pcel
\t\t\t\t\t+ wpafcel ppa (1-pfcel)- pmu pcel wmucel
                    + pmu(1-pfcel)wmufcel + pcel(1-pfcel)wfcelcel
\t\t            - wnav ppa pv - wkv pmu pv;
        rtlngpa   = wmupa pmu (1-ppa) +  wcelpa pcel (1-ppa)
                  + wpafcel pfcel (1-ppa)- pmu pcel wmucel
                  - pmu pfcel wmufcel - pfcel pcel wfcelcel + Ipa 
\t\t                + wnav (1-ppa) pv - wkv pmu pv; 
\t\t
\t\t        psub = {ppa -> z , pmu -> y-z, pv -> v,
\t\t\t\t              pcel -> (1-x)(1-y-v), pfcel -> x(1-y-v)};
\t\t        wsub = Thread[wvars->wvec];
\t\t    c = recalcfev[wt,11,6.05,0.7];
\t\t    nAlT1  = 4 - (c[[Si]] + 1/2(c[[Ti]]) + 1/2(c[[Fe3]]));
\t\t    nAlM2b = 1 - ( 1/2(c[[Ti]]) + 1/2(c[[Fe3]]));
\t\t    nAlM2a = c[[Al]] - (nAlT1 + nAlM2b);
        y =nAlM2a/(nAlM2a + c[[Fe2]] + c[[Mg]]);
        x = c[[Fe2]]/(c[[Fe2]]+ c[[Mg]]);
\t\t      v = 1 - (c[[Na]]+ c[[K]]);
        z = c[[Na]];
\t\t      R = 0.0083144;
\t\t
  Flatten[{If[MemberQ[ends, mu],
    ((aidealmu)Exp[rtlngmu/(R (t + 273)) /. wsub /. psub]), {}],
   If[MemberQ[ends, cel],
    ((aidealcel)Exp[rtlngcel/(R  (t + 273)) /. wsub /. psub]), {}],
   If[MemberQ[ends, fcel],
    ((aidealfcel) Exp[rtlngfcel/(R  (t + 273)) /. wsub /. psub]),{}],
   If[MemberQ[ends, pa],
    ((aidealpa) Exp[rtlngpa/(R  (t + 273)) /. wsub /. psub]),{}]} ]];\
\>", \
"Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Plagioclase - H&P 1993--model 1
returns the activity of {anorthite}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsplag];
wvarsplag  = {Ian};
Clear[wvecplag];
wvecplag[t_] := { 6.01 - 0.0035 (t + 273)}

Clear[plagax];
plagax[wt_,t_,wvars_List,wvec_, ends_] :=
\t Module[{x,c,R,  aidealan,aidealab,rtlngan, isub},
\t\t(* ideal activity expressions *)\t\t
\t\t      aidealan = x;
        aidealab = (1-x);
\t\t(* RTlngamma expressions *)
\t\t      rtlngan = Ian;
\t\t
\t\t      isub = Thread[wvars->wvec];
\t\t
\t\t   c = recalcall[xcalc[wt,1],8];
     x = c[[Ca]]/(c[[Ca]] + c[[Na]]);
\t   \tR = 0.0083144; 
\t\t
\tFlatten[{If[MemberQ[ends, an],
\t  (aidealan Exp[rtlngan/(R(t + 273)) /. isub]), {}],
\t If[MemberQ[ends, ab],
\t  (aidealab), {}]} ]];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
K-feldspar - Subregular model
returns the activities of {san}\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[wvarsksp];
wvarsksp = {w1,w2};
Clear[wvecksp];
wvecksp[t_,p_] := {26.5 - 0.01825 (t + 273) + 0.387 p,
                   32.1 - 0.01614 (t + 273) + 0.469 p};
                   
Clear[kspax];
kspax[wt_, t_, p_, wvars_List, wvec_] :=
  Module[{x, c, R = 0.0083144, wsub,
          aidealksp, aidealab, rtlngksp, rtlngab},
 (* RTlngamma expressions *)
     rtlngksp = x^2(w1 + 2(1 - x)(w2 - w1));
     rtlngab  = (1 - x)^2(w2 + 2 x(w1 - w2));
     
     wsub = Thread[wvars -> wvec];
     c = recalcall[xcalc[wt,1],8];
     x = c[[Na]]/(c[[Na]] + c[[K]]);
 
 (* ideal activity expressions including the contribution
    of Ca to the configurational entropy term  *)
     aidealksp = (1 - x) (1 - c[[Ca]]);
     aidealab  = x (1 - c[[Ca]]);
     
  {aidealksp Exp[rtlngksp/(R(t + 273)) /. wsub]}];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["General functions for ",
    FontWeight->"Plain"],
  StyleBox["\[Sigma]",
    FontWeight->"Plain"],
  StyleBox["lna",
    FontWeight->"Plain"]
}], "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["analytical contribution - ie oxides", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[siglnax];
siglnax[phase_,comp_,t_,p_,ends_] :=
\tModule[{jacobian,covx,covy,del,afac,bfac, lna, lnad, phased},
\t\tafac = 0.01; bfac = 0.05; del = 0.02; 
\t\tjacobian =
\t   Array[(phased = phase[comp];
\t\t      phased[[#]] += del;
\t\tWhich[TrueQ[phase==MU],
\t\t\tlna = Log[muax[phase[comp],t,p, wvarsmu,wvecmu[p],ends]];
            lnad = Log[muax[phased,t,p, wvarsmu,wvecmu[p],ends]],
\t\t  TrueQ[phase==BI],
\t\t\tlna =  Log[biax[phase[comp],t, wvarsbi,wvecbi,ends]];
\t\t\tlnad =  Log[biax[phased,t, wvarsbi,wvecbi,ends]],
\t\t  TrueQ[phase==G],
\t\t\tlna = Log[gax[phase[comp],t, wvarsg,wvecg[t],ends]];
\t\t\tlnad =  Log[gax[phased,t, wvarsg,wvecg[t],ends]],
\t\t  TrueQ[phase==CHL],
\t\t\tlna = Log[chlax[phase[comp],t, wvarschl,wvecchl,ends]];
\t\t\tlnad = Log[chlax[phased,t, wvarschl,wvecchl,ends]],
\t\t  TrueQ[phase==PLAG],
\t\t\tlna = Log[plagax[phase[comp],t, wvarsplag,wvecplag[t],ends]];
\t\t\tlnad = Log[plagax[phased,t, wvarsplag,wvecplag[t],ends]],
\t\t  TrueQ[phase==KSP],
\t\t\tlna = Log[kspax[phase[comp],t,p, wvarsksp,wvecksp[t,p]]];
            lnad = Log[kspax[phased,t,p, wvarsksp,wvecksp[t,p]]],
          TrueQ[phase==CD],
\t\t\tlna = Log[cdax[phase[comp],t, wvarscd,wveccd,ends]];
            lnad = Log[cdax[phased,t, wvarscd,wveccd,ends]],
          TrueQ[phase==ST],
\t\t\tlna = Log[stax[phase[comp],t, wvarsst,wvecst,ends]];
            lnad = Log[stax[phase,t, wvarsst,wvecst,ends]],
          TrueQ[phase==OPX],
\t\t\tlna = Log[opxax[phase[comp],t, wvarsopx,wvecopx,ends]];
            lnad = Log[opxax[phased,t, wvarsopx,wvecopx,ends]]];
\t\t  (lnad - lna)/del)&, Length[oxname]];
\t\t
\t\tcovx = DiagonalMatrix[(afac phase[comp] + bfac)^2];
\t\t
\t\tcovy =  Transpose[jacobian].covx.jacobian;  
\t\t
\t\t Array[Sqrt[covy[[#,#]]]&, Length[lna]]   ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["a-x contributions - ie from w's", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
lw function to calculate the length of the w vector depending upon \
the phase of interest.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[lw];
lw[phase_] :=
\t  Which[TrueQ[phase==MU],      Length[wvarsmu],
\t\t       TrueQ[phase==BI],   Length[wvarsbi],
\t\t       TrueQ[phase==G],    Length[wvarsg],
\t\t       TrueQ[phase==CHL],  Length[wvarschl],
\t\t       TrueQ[phase==PLAG], Length[wvarsplag],
\t\t       TrueQ[phase==KSP],  Length[wvarsksp],
\t\t       TrueQ[phase==CD],   Length[wvarscd],
\t\t       TrueQ[phase==ST],   Length[wvarsst],
\t\t       TrueQ[phase==OPX],  Length[wvarsopx]  ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[siglnaw];
siglnaw[phase_,comp_,t_,p_,ends_] :=
\tModule[{del,wfac,jacobian,covx,wvecd,lna,lnad,n},
\t\tdel = 0.02; wfac = 1;
\t\tjacobian =
\t   Array[(
\t    Which[
\t     TrueQ[phase==MU],
\t\t\twvecd = wvecmu[p];
\t\t    wvecd[[#]] += del;
\t\t    n = 3;
\t\t\tlna = Log[muax[phase[comp],t,p, wvarsmu,wvecmu[p],ends]];
\t\t    lnad = Log[muax[phase[comp],t,p, wvarsmu,wvecd,ends]],
\t\t TrueQ[phase==BI],
\t\t\twvecd = wvecbi;
\t\t    wvecd[[#]] += del;
\t\t    n = 3;
\t\t\tlna =  Log[biax[phase[comp],t, wvarsbi,wvecbi,ends]];
\t\t\tlnad =  Log[biax[phase[comp],t, wvarsbi,wvecd,ends]],
\t\t TrueQ[phase==G],
\t\t\twvecd = wvecg[t];
\t\t    wvecd[[#]] += del;
\t\t    n = 3;
\t\t\tlna = Log[gax[phase[comp],t, wvarsg,wvecg[t],ends]];
\t\t\tlnad =  Log[gax[phase[comp],t, wvarsg,wvecd,ends]],
\t\t TrueQ[phase==CHL],
\t\t\twvecd = wvecchl;
\t\t    wvecd[[#]] += del;
\t\t    n = 5;
\t\t\tlna = Log[chlax[phase[comp],t, wvarschl,wvecchl,ends]];
\t\t\tlnad = Log[chlax[phase[comp],t, wvarschl,wvecd,ends]],
\t\t TrueQ[phase==KSP],
\t\t\twvecd = wvecksp[t,p];
\t\t    wvecd[[#]] += del;
\t\t    n = 1;
\t\t\tlna = Log[kspax[phase[comp],t,p, wvarsksp,wvecksp[t,p]]];
\t\t\tlnad = Log[kspax[phase[comp],t,p, wvarsksp,wvecd]],
\t\t TrueQ[phase==CD],
\t\t\twvecd = wveccd;
\t\t    wvecd[[#]] += del;
\t\t    n = 2;
\t\t\tlna = Log[cdax[phase[comp],t, wvarscd,wveccd,ends]];
\t\t\tlnad = Log[cdax[phase[comp],t, wvarscd,wvecd,ends]],
\t\t TrueQ[phase==ST],
\t\t\twvecd = wvecst;
\t\t    wvecd[[#]] += del;
\t\t    n = 4;
\t\t\tlna = Log[stax[phase[comp],t, wvarsst,wvecst,ends]];
\t\t\tlnad = Log[stax[phase[comp],t, wvarsst,wvecd,ends]],
\t\t TrueQ[phase==OPX],
\t\t\twvecd = wvecopx;
\t\t    wvecd[[#]] += del;
\t\t    n = 2;
\t\t\tlna = Log[opxax[phase[comp],t,p, wvarsopx,wvecopx,ends]];
\t\t\tlnad = Log[opxax[phase[comp],t,p, wvarsopx,wvecd,ends]],
\t\t TrueQ[phase==PLAG],
\t\t\twvecd = wvecplag[t];
\t\t    wvecd += del;
\t\t    n = 1;
\t\t\tlna = Log[plagax[phase[comp],t, wvarsplag,wvecplag[t],ends]];
\t\t\tlnad = Log[plagax[phase[comp],t, wvarsplag,wvecd,ends]]  ];
\t\t (lnad - lna)/del)&, lw[phase]];
\t\t
\t\tcovx = DiagonalMatrix[Table[(n wfac)^2,{lw[phase]}]];
\t\tcovy = Transpose[jacobian].covx.jacobian;  
\t\t
\t\t Array[Sqrt[covy[[#,#]]]&, Length[lna]]  ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["combined contribution from oxides and w's", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When adding the uncertainty contributions from multiple sources, 
it is necessary to add the Vy terms before taking the square root to get \
\[Sigma]. This can be done, by adding the actual Vy terms or simply by: \
(siglnax^2 + siglnaw^2)^1/2  instead of
siglnax + siglnaw.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["General functions for setting up calculation", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[positions];\n",
    FontWeight->"Plain"],
  StyleBox["positions",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ends_] := (\nClear[posMU]; Clear[posBI]; Clear[posG]; \
Clear[posPLAG];\nClear[posQ]; Clear[posKY]; Clear[posKSP]; Clear[posCD];\n\
Clear[posST]; Clear[posOPX];\nposMU = Flatten[\n    \
{Position[ends,mu],Position[ends,cel],Position[ends,pa]}];\nposBI = Flatten[\n\
    {Position[ends,phl],Position[ends,ann],Position[ends,east]}];\nposG  = \
Flatten[\n    {Position[ends,py],Position[ends,gr],Position[ends,alm]}];\n\
posPLAG = Flatten[\n    {Position[ends,an],Position[ends,ab]}]; \nposKSP = \
Flatten[Position[ends, san]];\nposCD = Flatten[\n    \
{Position[ends,cd],Position[ends,fcd],Position[ends,mncd]}];\nposST = \
Flatten[\n    {Position[ends,mst],Position[ends,fst]}];\nposOPX = Flatten[\n  \
  {Position[ends,en],Position[ends,fs],Position[ends,mgts]}];\nposQ = \
Flatten[Position[ends, q]];\nposKY = Flatten[Position[ends, ky]];\nposSILL = \
Flatten[Position[ends, sill]]; \nposAND = Flatten[Position[ends, and]];   );",
    
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[posphase];\n",
    FontWeight->"Plain"],
  StyleBox["posphase",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_] := \n      Which[TrueQ[phase==MU],   posMU,\n            \
TrueQ[phase==BI],   posBI,\n            TrueQ[phase==G],    posG,\n           \
 TrueQ[phase==CHL],  posCHL,\n            TrueQ[phase==PLAG], posPLAG,\n      \
      TrueQ[phase==KSP],  posKSP,\n            TrueQ[phase==CD],   posCD,\n   \
         TrueQ[phase==ST],   posST,\n            TrueQ[phase==OPX],  posOPX,\n\
            TrueQ[phase==Q],    posQ,\n            TrueQ[phase==KY],   posKY,\
\n            TrueQ[phase==SILL], posSILL,\n            TrueQ[phase==AND],  \
posAND ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[lnavector];\n",
    FontWeight->"Plain"],
  StyleBox["lnavector",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ends_] :=(\nClear[namevec];\nnamevec = ends;\n\
If[MemberQ[namevec, mu],\n   namevec = ReplacePart[namevec, mu /. \n          \
     mu->lnamu, Position[ends,mu]], {}];\nIf[MemberQ[namevec, cel],\n   \
namevec = ReplacePart[namevec, cel /. \n               cel->lnacel, \
Position[ends,cel]], {}];\nIf[MemberQ[namevec, pa],\n   namevec = \
ReplacePart[namevec, pa /. \n               pa->lnapa, Position[ends,pa]], \
{}];\nIf[MemberQ[namevec, phl],\n   namevec = ReplacePart[namevec, phl /. \n  \
             phl->lnaphl, Position[ends,phl]], {}];\nIf[MemberQ[namevec, \
ann],\n   namevec = ReplacePart[namevec, ann /. \n               ann->lnaann, \
Position[ends,ann]], {}];\nIf[MemberQ[namevec, east],\n   namevec = \
ReplacePart[namevec, east /. \n               east->lnaeast, \
Position[ends,east]], {}];\nIf[MemberQ[namevec, py],\n   namevec = \
ReplacePart[namevec, py /. \n               py->lnapy, Position[ends,py]], \
{}];\nIf[MemberQ[namevec, gr],\n   namevec = ReplacePart[namevec, gr /. \n    \
           gr->lnagr, Position[ends,gr]], {}];\nIf[MemberQ[namevec, alm],\n   \
namevec = ReplacePart[namevec, alm /. \n               alm->lnaalm, \
Position[ends,alm]], {}];\nIf[MemberQ[namevec, an],\n   namevec = \
ReplacePart[namevec, an /. \n               an->lnaan, Position[ends,an]], \
{}];\nIf[MemberQ[namevec, ab],\n   namevec = ReplacePart[namevec, ab /. \n    \
           ab->lnaab, Position[ends,ab]], {}];\nIf[MemberQ[namevec, cd],\n   \
namevec = ReplacePart[namevec, cd /. \n               cd->lnacd, \
Position[ends,cd]], {}];\nIf[MemberQ[namevec, fcd],\n   namevec = \
ReplacePart[namevec, fcd /. \n               fcd->lnafcd, \
Position[ends,fcd]], {}];\nIf[MemberQ[namevec, mncd],\n   namevec = \
ReplacePart[namevec, mncd /. \n               mncd->lnamncd, \
Position[ends,mncd]], {}];\nIf[MemberQ[namevec, mst],\n   namevec = \
ReplacePart[namevec, mst /. \n               mst->lnamst, \
Position[ends,mst]], {}];\nIf[MemberQ[namevec, fst],\n   namevec = \
ReplacePart[namevec, fst /. \n               fst->lnafst, \
Position[ends,fst]], {}];\nIf[MemberQ[namevec, en],\n   namevec = \
ReplacePart[namevec, en /. \n               en->lnaen, Position[ends,en]], \
{}];\nIf[MemberQ[namevec, fs],\n   namevec = ReplacePart[namevec, fs /. \n    \
           fs->lnafs, Position[ends,fs]], {}];\nIf[MemberQ[namevec, mgts],\n  \
 namevec = ReplacePart[namevec, mgts /. \n               mgts->lnamgts, \
Position[ends,mgts]], {}];\nIf[MemberQ[namevec, san],\n   namevec = \
ReplacePart[namevec, san /. \n               san->lnasan, \
Position[ends,san]], {}];\nIf[MemberQ[namevec, q],\n   namevec = \
ReplacePart[namevec, q /. \n               q->lnaq, Position[ends,q]], {}];\n\
If[MemberQ[namevec, ky],\n   namevec = ReplacePart[namevec, ky /. \n          \
     ky->lnaky, Position[ends,ky]], {}];\nIf[MemberQ[namevec, sill],\n   \
namevec = ReplacePart[namevec, sill /. \n               sill->lnasill, \
Position[ends,sill]], {}];\nIf[MemberQ[namevec, and],\n   namevec = \
ReplacePart[namevec, and /. \n               and->lnaand, \
Position[ends,and]], {}]; )",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[lnass];\n",
    FontWeight->"Plain"],
  StyleBox["lnass",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_,comp_,t_,p_,ends_] := (\n  Which[\n    TrueQ[phase==MU],\n\
      Log[muax[phase[comp],t,p, wvarsmu,wvecmu[p],ends]],\n    \
TrueQ[phase==BI],\n      Log[biax[phase[comp],t, wvarsbi,wvecbi,ends]],\n    \
TrueQ[phase==G],\n      Log[gax[phase[comp],t, wvarsg,wvecg[t],ends]],\n    \
TrueQ[phase==CHL],\n      Log[chlax[phase[comp],t, wvarschl,wvecchl,ends]],\n \
   TrueQ[phase==PLAG],\n      Log[plagax[phase[comp],t, \
wvarsplag,wvecplag[t],ends]],\n    TrueQ[phase==KSP],\n      \
Log[kspax[phase[comp],t,p, wvarsksp,wvecksp[t,p]]],\n    TrueQ[phase==CD],\n  \
    Log[cdax[phase[comp],t, wvarscd,wveccd,ends]],\n    TrueQ[phase==ST],\n   \
   Log[stax[phase[comp],t, wvarsst,wvecst,ends]],\n    TrueQ[phase==OPX],\n   \
   Log[opxax[phase[comp],t, wvarsopx,wvecopx,ends]] ]\n);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[replacelna];\n",
    FontWeight->"Plain"],
  StyleBox["replacelna",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[lnaoriginal_, phase_, lnadd_] :=\n Module[{phaserange},\n  ( \
phaserange = \n       Flatten[{Take[posphase[phase],1], \
Take[posphase[phase],-1]}];\n       \n   Flatten[Insert[Drop[lnaoriginal, \
phaserange], \n                        lnadd, posphase[phase][[1]]]] )];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avPT];\n",
    FontWeight->"Plain"],
  StyleBox["avPT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (t + 273) + c p + R \n              (t + 273) r.lnavec;\n   \n\
   miksPT[eq, {p,t}, {pp,tt}, Join[lnavec, avec], \n                          \
    Join[lna,aa], varxx]  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avP];\n",
    FontWeight->"Plain"],
  StyleBox["avP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_,tc_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (tc + 273) + c p + R \n              (tc + 273) r.lnavec;\n   \
\n   miksPT[eq, {p}, {pp}, Join[lnavec, avec], \n                             \
 Join[lna,aa], varxx]  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avPTfull];\n",
    FontWeight->"Plain"],
  StyleBox["avPTfull",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (t + 273) + c p + R \n              (t + 273) r.lnavec;\n   \n\
   mikhails[eq, {p,t}, {pp,tt}, Join[lnavec, avec], \n                        \
      Join[lna,aa], varxx];  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avPfull];\n",
    FontWeight->"Plain"],
  StyleBox["avPfull",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_, tc_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (tc + 273) + c p + R \n              (tc + 273) r.lnavec;\n   \
\n   mikhails[eq, {p}, {pp}, Join[lnavec, avec], \n                           \
   Join[lna,aa], varxx];  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avPTsetup];\n",
    FontWeight->"Plain"],
  StyleBox["avPTsetup",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (t + 273) + c p + R \n              (t + 273) r.lnavec;\n   \n\
   {lnavec, avec, lna, sdlna, varxx, eq}  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[avPsetup];\n",
    FontWeight->"Plain"],
  StyleBox["avPsetup",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample_, tc_, tt_, pp_, setup_] :=\n  \
Module[{ends,r,aa,b,c,cova,anals,nonss,\n          \
lnavec,avec,lna,sdlna,varxx,eq},\n  \n   {ends,r,aa,b,c,cova,anals,nonss} = \
setup;\n   \n   lnavector[ends];\n   lnavec = namevec;\n   avec = Array[a, \
Length[r]];\n   positions[ends];\n      \n   lna = \
Flatten[{Map[lnass[#,sample,tt,pp,ends]&, anals], \n                   \
Table[0, {Length[nonss]}]}];\n   sdlna = Flatten[\n           \
{Sqrt[Flatten[Map[siglnax[#,sample,tt,pp,ends]&, anals]]^2\n            + \
Flatten[Map[siglnaw[#,sample,tt,pp,ends]&, anals]]^2],\n            \
Table[0.0001, {Length[nonss]}]}];\n   varxx =  Join[Map[Join[#, \
Table[0,{Length[cova]}]]&, \n              DiagonalMatrix[sdlna^2]],\n        \
      Map[Join[Table[0,{Length[sdlna]}],#]&, cova]];  \n                   \n \
  eq = avec + b (tc + 273) + c p + R \n              (tc + 273) r.lnavec;\n   \
\n   {lnavec, avec, lna, sdlna, varxx, eq}  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullr];\n",
    FontWeight->"Plain"],
  StyleBox["fullr",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[allends_, ends_, rr_] := \n Module[{diffends, posdiff, ldiff, \
rnew},\n    diffends = Complement[allends,ends];\n    posdiff = \
Sort[Flatten[Map[Position[allends, #]&, diffends]]];\n    ldiff = \
Length[posdiff];\n  \n   Array[(rnew = rr[[#]]; \n        Do[rnew = \
Insert[rnew,0,posdiff[[i]]], {i,ldiff}];\n        rnew )&, Length[rr]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["general functions for jacobians for DeltaP ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianx1];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianx1",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,phase_,tc_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        phased, lnadd, lnad,del},\n\t\
\t     del = 0.02;\n{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set1];    \n \
\n Flatten[\n\tArray[(phased = phase[comp1];\n\t\t      phased[[#]] += del;\n \
 lnadd = \n    Which[\n     TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends1]],\n     TrueQ[phase==BI],\n\t      \
Log[biax[phased,tt, wvarsbi,wvecbi,ends1]],\n     TrueQ[phase==CHL],\n\t      \
Log[chlax[phased,tt, wvarschl,wvecchl,ends1]],\n     TrueQ[phase==G],\n\t     \
 Log[gax[phased,tt, wvarsg,wvecg[tt],ends1]],\n     TrueQ[phase==PLAG],\n     \
  Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends1]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends1]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends1]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends1]] ];\n     \n   lnad = replacelna[lna1, phase, lnadd];\n\n\t(( \
refP2 - miks[eq1, {p}, {pp}, Join[lnavec1, avec1], \n             \
Join[lnad,aa1], varxx1])\n\t\t\t            \t- refdelP)/del)&, \
Length[oxname]] ]  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianx2];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianx2",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp2_,phase_,tc_,tt_,pp_,set2_] :=\n\t\
Module[{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        phased, lnadd, lnad,del},\n\t\
\t    del = 0.02;\n{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPsetup[comp2,tc,tt,pp,set2];    \n \
 \n  Flatten[\n\t Array[(phased = phase[comp2];\n\t\t       phased[[#]] += \
del;\n  lnadd = \n    Which[\n     TrueQ[phase==MU],\n\t      \
Log[muax[phased,tt,pp, wvarsmu,wvecmu[pp],ends2]],\n     TrueQ[phase==BI],\n\t\
      Log[biax[phased,tt, wvarsbi,wvecbi,ends2]],\n     TrueQ[phase==CHL],\n\t\
      Log[chlax[phased,tt, wvarschl,wvecchl,ends2]],\n     TrueQ[phase==G],\n\
\t      Log[gax[phased,tt, wvarsg,wvecg[tt],ends2]],\n     \
TrueQ[phase==PLAG],\n       Log[plagax[phased,tt, \
wvarsplag,wvecplag[tt],ends2]],\n     TrueQ[phase==KSP],\n       \
Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\n     TrueQ[phase==CD],\n  \
     Log[cdax[phased,tt, wvarscd, wveccd,ends2]],\n     TrueQ[phase==ST],\n   \
    Log[stax[phased,tt, wvarsst, wvecst,ends2]],\n     TrueQ[phase==OPX],\n   \
    Log[opxax[phased,tt, wvaropx, wvecopx,ends2]] ];\n     \n   lnad = \
replacelna[lna2, phase, lnadd];\n\n\t(( miks[eq2, {p}, {pp}, Join[lnavec2, \
avec2],\n\t\t     Join[ lnad,aa2], varxx2] - refP1)\n\t\t\t\t    - \
refdelP)/del)&,   Length[oxname]] ]  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianw];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianw",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,phase_,tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        lnad1,lnad2, lnadd1, lnadd2, \
del,\n\t        wvecd},\n\t\t       del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPsetup[comp2,tc,tt,pp,set2];    \n\
\nFlatten[\n\tArray[({lnadd1,lnadd2} = \n\t Which[\n\t  TrueQ[phase==MU],\n\t\
\t   wvecd = wvecmu[pp];\n\t   \twvecd[[#]] += del;\n\t   \t\
{If[phase[comp1]=={}, {},\n\t   \t Log[muax[phase[comp1],tt,pp, \
wvarsmu,wvecd,ends1]]],\n\t   \tIf[phase[comp2]=={}, {},\n\t   \t \
Log[muax[phase[comp2],tt,pp, wvarsmu,wvecd,ends2]]]},\n\t  TrueQ[phase==BI],\n\
\t   \twvecd = wvecbi;\n   \t\twvecd[[#]] += del;\n   \t\t\
{If[phase[comp1]=={}, {},\n   \t\t Log[biax[phase[comp1],tt, \
wvarsbi,wvecd,ends1]]],\n\t   \tIf[phase[comp2]=={}, {},\n   \t\t \
Log[biax[phase[comp2],tt, wvarsbi,wvecd,ends2]]]},\n\t  TrueQ[phase==G],\n\t  \
 \twvecd = wvecg[tt];\n\t   \twvecd[[#]] += del;\n\t   \t\
{If[phase[comp1]=={}, {},\n   \t\t Log[gax[phase[comp1],tt, \
wvarsg,wvecd,ends1]]],\n   \t\tIf[phase[comp2]=={}, {},\n   \t\t \
Log[gax[phase[comp2],tt, wvarsg,wvecd,ends2]]]},\n\t  TrueQ[phase==CHL],\n   \
\t\twvecd = wvecchl;\n   \t\twvecd[[#]] += del;\n   \t\t{If[phase[comp1]=={}, \
{},\n   \t\t Log[chlax[phase[comp1],tt, wvarschl,wvecd,ends1]]],\n   \t\t\
If[phase[comp2]=={}, {},\n   \t\t Log[chlax[phase[comp2],tt, \
wvarschl,wvecd,ends2]]]},\n\t  TrueQ[phase==PLAG],\n\t   \twvecd = \
wvecplag[tt];\n\t   \twvecd += del;\n\t   \t{If[phase[comp1]=={}, {},\n   \t\t\
 Log[plagax[phase[comp1],tt, wvarsplag,wvecd,ends1]]],\n   \t\t\
If[phase[comp2]=={}, {},\n   \t\t Log[plagax[phase[comp2],tt, \
wvarsplag,wvecd,ends2]]]},\n\t  TrueQ[phase==KSP],\n\t   \twvecd = \
wvecksp[tt,pp];\n\t   \twvecd[[#]] += del;\n   \t\t{If[phase[comp1]=={}, {},\n\
\t   \t Log[kspax[phase[comp1],tt,pp, wvarsksp,wvecd]]],\n\t   \t\
If[phase[comp2]=={}, {},\n\t   \t Log[kspax[phase[comp2],tt,pp, \
wvarsksp,wvecd]]]},\n\t  TrueQ[phase==CD],\n\t   \twvecd = wveccd;\n\t   \t\
wvecd[[#]] += del;\n   \t\t{If[phase[comp1]=={}, {},\n   \t\t \
Log[cdax[phase[comp1],tt, wvarscd,wvecd,ends1]]],\n   \t\t\
If[phase[comp2]=={}, {},\n   \t\t Log[cdax[phase[comp2],tt, \
wvarscd,wvecd,ends2]]]},\n\t  TrueQ[phase==ST],\n   \t\twvecd = wvecst;\n   \t\
\twvecd += del;\n   \t\t{If[phase[comp1]=={}, {},\n\t   \t \
Log[stax[phase[comp1],tt, wvarsst,wvecd,ends1]]],\n\t   \t\
If[phase[comp2]=={}, {},\n\t   \t Log[stax[phase[comp2],tt, \
wvarsst,wvecd,ends2]]]},\n\t  TrueQ[phase==OPX],\n\t   \twvecd = wvecopx;\n\t \
  \twvecd[[#]] += del;\n   \t\t{If[phase[comp1]=={}, {},\n   \t\t \
Log[opxax[phase[comp1],tt, wvarsopx,wvecd,ends1]]],\n   \t\t\
If[phase[comp2]=={}, {},\n   \t\t Log[opxax[phase[comp2],tt, \
wvarsopx,wvecd,ends2]]]} ];\n\t\t\t\t\n\tlnad1 = If[lnadd1=={}, lna1,\n\t\t\t \
  replacelna[lna1, phase, lnadd1]];\n\tlnad2 = If[lnadd2=={}, lna2,\n\t\t\t   \
replacelna[lna2, phase, lnadd2]];\n\t\t\t\t        \n\t(( miks[eq2, {p}, \
{pp}, Join[lnavec2, avec2],\n\t\t       Join[lnad2,aa2], varxx2] -\n\t  \t\
miks[eq1, {p}, {pp}, Join[lnavec1, avec1],\n\t\t\t     \tJoin[lnad1,aa1], \
varxx1])\n\t\t\t\t\t     - refdelP)/del)&, lw[phase]]  ] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobiana];\n",
    FontWeight->"Plain"],
  StyleBox["jacobiana",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, ad},\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPsetup[comp2,tc,tt,pp,set2];    \n\
\n\t        del = 0.02;\n\t Flatten[\n\t\tArray[(ad = aa1;\n\t\t\t      \
ad[[#]] += del;\n\t((miks[eq2, {p}, {pp}, Join[lnavec2, avec2],\n\t\t      \
Join[lna2,ad], varxx2] -\n\t   miks[eq1, {p}, {pp}, Join[lnavec1, avec1],\n\t\
\t\t   Join[lna1,ad], varxx1])\n\t\t\t\t\t- refdelP)/del)&, Length[avec1]]  ] \
];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianhfull];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianhfull",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, aa1d, aa2d, hd, rr1, \
rr2},\n{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPsetup[comp2,tc,tt,pp,set2];    \n\
\n\t        del = 0.002;\n\t        rr1 = fullr[endmembers, ends1, r1];\n\t   \
     rr2 = fullr[endmembers, ends2, r2];\n\t        Clear[hd];\n\t Flatten[\n \
 Array[(hd = Table[0, {Length[endmembers]}];\n         hd[[#]] += del;\n      \
   aa1d = aa1 + rr1.hd;\n         aa2d = aa2 + rr2.hd;\n       \n   \
((miks[eq2, {p}, {pp}, Join[lnavec2, avec2],\n\t\t      Join[lna2,aa2d], \
varxx2] -\n    \tmiks[eq1, {p}, {pp}, Join[lnavec1, avec1],\n\t\t\t     \
Join[lna1,aa1d], varxx1])\n\t\t\t       - refdelP)/del)&, Length[endmembers]] \
] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["general functions for jacobians for DeltaPT ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianx1PT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianx1PT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,phase_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        phased, lnadd, lnad,del},\n\t\
\t     del = 0.02;\n{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\t\
\t     \nArray[(phased = phase[comp1];\n\t   phased[[#]] += del;\n  lnadd = \n\
    Which[\n     TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends1]],\n     TrueQ[phase==BI],\n\t      \
Log[biax[phased,tt, wvarsbi,wvecbi,ends1]],\n     TrueQ[phase==CHL],\n\t      \
Log[chlax[phased,tt, wvarschl,wvecchl,ends1]],\n     TrueQ[phase==G],\n\t     \
 Log[gax[phased,tt, wvarsg, wvecg[tt],ends1]],\n     TrueQ[phase==PLAG],\n    \
   Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends1]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends1]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends1]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends1]] ];\n     \n   lnad = replacelna[",
    FontWeight->"Plain"],
  StyleBox["lna1",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", phase, lnadd];\n\n\t(( refPT2 - miksPT[",
    FontWeight->"Plain"],
  StyleBox["eq1",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", {p,t}, {pp,tt}, Join[lnavec1, avec1], \n               \
Join[lnad,aa1], varxx1])\n\t\t\t\t  - refdelPT)/del)&, Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianx2PT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianx2PT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp2_,phase_,tt_,pp_,set2_] :=\n\t\
Module[{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        phased, lnadd, lnad,del},\n\t\
\t    del = 0.02;\n{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\t Array[(phased = phase[comp2];\n\t\t    phased[[#]] += del;\n  lnadd = \n   \
 Which[\n     TrueQ[phase==MU],\n\t   Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends2]],\n     TrueQ[phase==BI],\n\t   Log[biax[phased,tt, \
wvarsbi,wvecbi,ends2]],\n     TrueQ[phase==CHL],\n\t   Log[chlax[phased,tt, \
wvarschl,wvecchl,ends2]],\n     TrueQ[phase==G],\n\t   Log[gax[phased,tt, \
wvarsg,wvecg[tt],ends2]],\n     TrueQ[phase==PLAG],\n       \
Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends2]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends2]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends2]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends2]] ];\n     \n   lnad = replacelna[lna2, phase, lnadd];\n\n\t(( \
miksPT[eq2, {p,t}, {pp,tt}, Join[lnavec2, avec2],\n\t\t       Join[lnad,aa2], \
varxx2] - refPT1) -\t\t            \n              refdelPT)/del)&,   \
Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianwPT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianwPT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,phase_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        lnad1,lnad2, lnadd1, lnadd2, \
del,\n\t        wvecd},\n\t\t       del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\tArray[({lnadd1,lnadd2} = \n\t Which[\n\t  TrueQ[phase==MU],\n\t\twvecd = \
wvecmu[pp];\n\t\twvecd[[#]] += del;\n\t\t{If[phase[comp1]=={}, {},\n\t\t \
Log[muax[phase[comp1],tt,pp, wvarsmu,wvecd,ends1]]],\n\t\t\
If[phase[comp2]=={}, {},\n\t\t Log[muax[phase[comp2],tt,pp, \
wvarsmu,wvecd,ends2]]]},\n\t  TrueQ[phase==BI],\n\t\twvecd = wvecbi;\n\t\t\
wvecd[[#]] += del;\n\t\t{If[phase[comp1]=={}, {},\n\t\t \
Log[biax[phase[comp1],tt, wvarsbi,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, \
{},\n\t\t Log[biax[phase[comp2],tt, wvarsbi,wvecd,ends2]]]},\n\t  \
TrueQ[phase==G],\n\t\twvecd = wvecg[tt];\n\t\twvecd[[#]] += del;\n\t\t\
{If[phase[comp1]=={}, {},\n\t\t Log[gax[phase[comp1],tt, \
wvarsg,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, {},\n\t\t \
Log[gax[phase[comp2],tt, wvarsg,wvecd,ends2]]]},\n\t  TrueQ[phase==CHL],\n\t\t\
wvecd = wvecchl;\n\t\twvecd[[#]] += del;\n\t\t{If[phase[comp1]=={}, {},\n\t\t \
Log[chlax[phase[comp1],tt, wvarschl,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, \
{},\n\t\t Log[chlax[phase[comp2],tt, wvarschl,wvecd,ends2]]]},\n\t  \
TrueQ[phase==PLAG],\n\t\twvecd = wvecplag[tt];\n\t\twvecd += del;\n\t\t\
{If[phase[comp1]=={}, {},\n\t\t Log[plagax[phase[comp1],tt, \
wvarsplag,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, {},\n\t\t \
Log[plagax[phase[comp2],tt, wvarsplag,wvecd,ends2]]]},\n\t  \
TrueQ[phase==KSP],\n\t\twvecd = wvecksp[tt,pp];\n\t\twvecd[[#]] += del;\n\t\t\
{If[phase[comp1]=={}, {},\n\t\t Log[kspax[phase[comp1],tt,pp, \
wvarsksp,wvecd]]],\n\t\tIf[phase[comp2]=={}, {},\n\t\t \
Log[kspax[phase[comp2],tt,pp, wvarsksp,wvecd]]]},\n\t  TrueQ[phase==CD],\n\t\t\
wvecd = wveccd;\n\t\twvecd[[#]] += del;\n\t\t{If[phase[comp1]=={}, {},\n\t\t \
Log[cdax[phase[comp1],tt, wvarscd,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, \
{},\n\t\t Log[cdax[phase[comp2],tt, wvarscd,wvecd,ends2]]]},\n\t  \
TrueQ[phase==ST],\n\t\twvecd = wvecst;\n\t\twvecd += del;\n\t\t\
{If[phase[comp1]=={}, {},\n\t\t Log[stax[phase[comp1],tt, \
wvarsst,wvecd,ends1]]],\n\t\tIf[phase[comp2]=={}, {},\n\t\t \
Log[stax[phase[comp2],tt, wvarsst,wvecd,ends2]]]},\n\t  TrueQ[phase==OPX],\n\t\
\twvecd = wvecopx;\n\t\twvecd[[#]] += del;\n\t\t{If[phase[comp1]=={}, {},\n\t\
\t Log[opxax[phase[comp1],tt, wvarsopx,wvecd,ends1]]],\n\t\t\
If[phase[comp2]=={}, {},\n\t\t Log[opxax[phase[comp2],tt, \
wvarsopx,wvecd,ends2]]]} ];\n\t\t\t\t\n\tlnad1 = If[lnadd1=={}, lna1,\n\t\t\t \
  replacelna[lna1, phase, lnadd1]];\n\tlnad2 = If[lnadd2=={}, lna2,\n\t\t\t   \
replacelna[lna2, phase, lnadd2]];\n\t\t\t\t        \n\t(( miksPT[eq2, {p,t}, \
{pp,tt}, Join[lnavec2, avec2],\n\t\t       Join[lnad2,aa2], varxx2] -\n\t\t\
miksPT[eq1, {p,t}, {pp,tt}, Join[lnavec1, avec1],\n\t\t\t\tJoin[lnad1,aa1], \
varxx1])\n\t\t\t\t\t - refdelPT)/del)&, lw[phase]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianaPT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianaPT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, ad},\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\t        del = 0.02;\n\t\tArray[(ad = aa1;\n\t\t\t   ad[[#]] += del;\n\t\
((miksPT[eq2, {p,t}, {pp,tt}, Join[lnavec2, avec2],\n\t\t      Join[lna2,ad], \
varxx2] -\n\t   miksPT[eq1, {p,t}, {pp,tt}, Join[lnavec1, avec1],\n\t\t\t   \
Join[lna1,ad], varxx1])\n\t\t\t\t\t- refdelPT)/del)&, Length[avec1]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobiana1PT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobiana1PT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        del, ad},\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\n\
\t        del = 0.02;\n\t\tArray[(ad = aa1;\n\t\t\t   ad[[#]] += del;\n\t\
((refPT2 -\n\t   miksPT[eq1, {p,t}, {pp,tt}, Join[lnavec1, avec1],\n\t\t\t   \
Join[lna1,ad], varxx1])\n\t\t\t\t\t- refdelPT)/del)&, Length[avec1]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobiana2PT];\n",
    FontWeight->"Plain"],
  StyleBox["jacobiana2PT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp2_,tt_,pp_,set2_] :=\n\t\
Module[{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, ad},\n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\t        del = 0.02;\n\t\tArray[(ad = aa2;\n\t\t\t      ad[[#]] += del;\n\t\
((miksPT[eq2, {p,t}, {pp,tt}, Join[lnavec2, avec2],\n\t\t      Join[lna2,ad], \
varxx2] - refPT1)\n\t\t\t\t\t- refdelPT)/del)&, Length[avec2]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["jacobianaPTfull is obselete", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianaPTfull];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianaPTfull",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, ad},\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\t        del = 0.02;\n\t\tArray[(ad = aa1;\n\t\t\t   ad[[#]] += del;\n\t\
((miksPT[eq2, {p,t}, {pp,tt}, Join[lnavec2, avec2],\n\t\t      Join[lna2,ad], \
varxx2] -\n\t   miksPT[eq1, {p,t}, {pp,tt}, Join[lnavec1, avec1],\n\t\t\t   \
Join[lna1,ad], varxx1])\n\t\t\t\t\t- refdelPT)/del)&, Length[avec1]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianhPTfull];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianhPTfull",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[comp1_,comp2_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavec2,avec2,lna2,sdlna2,varxx2,eq2,\n\t        del, aa1d, aa2d, hd, rr1, \
rr2},\n{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPTsetup[comp1,tt,pp,set1];    \n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavec2,avec2,lna2,sdlna2,varxx2,eq2} = avPTsetup[comp2,tt,pp,set2];    \n\n\
\t        del = 0.002;\n\t        rr1 = fullr[endmembers, ends1, r1];\n\t     \
   rr2 = fullr[endmembers, ends2, r2];\n\t        Clear[hd];\n  Array[(hd = \
Table[0, {Length[endmembers]}];\n         hd[[#]] += del;\n         aa1d = \
aa1 + rr1.hd;\n         aa2d = aa2 + rr2.hd;\n       \n   ((miksPT[eq2, \
{p,t}, {pp,tt}, Join[lnavec2, avec2],\n\t\t      Join[lna2,aa2d], varxx2] -\n \
   \tmiksPT[eq1, {p,t}, {pp,tt}, Join[lnavec1, avec1],\n\t\t\t     \
Join[lna1,aa1d], varxx1])\n\t\t\t       - refdelPT)/del)&, \
Length[endmembers]]  ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
functions for calculating jacobians for Vp  -  same \
assemblage\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianxdP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianxdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comp1_,phase_,tc_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        phased, lnadd, \
lnad,del,refdP},\n\t\t     del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set1];\n\
refdP =  avP[comp1,tc,tt,pp,set1] - avP[compb,tc,tt,pp,set1];\n\t\t     \n\
Array[(phased = phase[comp1];\n\t   phased[[#]] += del;\n  lnadd = \n    \
Which[\n     TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends1]],\n     TrueQ[phase==BI],\n\t      \
Log[biax[phased,tt, wvarsbi,wvecbi,ends1]],\n     TrueQ[phase==CHL],\n\t      \
Log[chlax[phased,tt, wvarschl,wvecchl,ends1]],\n     TrueQ[phase==G],\n\t     \
 Log[gax[phased,tt, wvarsg, wvecg[tt],ends1]],\n     TrueQ[phase==PLAG],\n    \
   Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends1]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends1]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends1]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends1]] ];\n     \n   lnad = replacelna[",
    FontWeight->"Plain"],
  StyleBox["lna1",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[", phase, lnadd];\n\n\t\
((miks[eq1,{p},{pp},Join[lnavec1,avec1],Join[lnad,aa1],varxx1] -\n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnab,aa1],varxxb]) -\n  \
refdP)/del)&, Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianxbdP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianxbdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_,phase_,tc_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        phased, \
lnadd,fs,lnad,del,refdP},\n\t\t     del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs = \
Map[avPsetup[#,tc,tt,pp,set1]&, comps];  \nrefdP = Flatten[Map[\n         \
(avP[#,tc,tt,pp,set1] - avP[compb,tc,tt,pp,set1])&, comps]];  \n\t\t     \n\
Array[(phased = phase[compb];\n\t   phased[[#]] += del;\n  lnadd = \n    \
Which[\n     TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends1]],\n     TrueQ[phase==BI],\n\t      \
Log[biax[phased,tt, wvarsbi,wvecbi,ends1]],\n     TrueQ[phase==CHL],\n\t      \
Log[chlax[phased,tt, wvarschl,wvecchl,ends1]],\n     TrueQ[phase==G],\n\t     \
 Log[gax[phased,tt, wvarsg, wvecg[tt],ends1]],\n     TrueQ[phase==PLAG],\n    \
   Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends1]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends1]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends1]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends1]] ];\n     \n   lnad = replacelna[lnab, phase, lnadd];\n\n\
(Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n               \
Join[fs[[#,3]],aa1],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnad,aa1],varxxb])&,\n       \
Range[Length[comps]]] - refdP)/del)&, Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianxsdP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianxsdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_,phase_,tc_,tt_,pp_,set1_] := (\nMap[Flatten[#]&, \n\
 Transpose[Map[jacobianxdP[compb,#,phase,tc,tt,pp,set1]&,\n           \
comps]]] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[vyxx];\n",
    FontWeight->"Plain"],
  StyleBox["vyxx",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_,phase_,tc_,tt_,pp_,set1_] :=\n  Module[{vv,zeros},\
\n   \nvv = Flatten[Map[Transpose[jacobianxdP[compb,#,phase,tc,tt,pp,set1]].\n\
covx[#,phase].jacobianxdP[compb,#,phase,tc,tt,pp,set1]&, comps]];\n\nzeros = \
Table[0,{Length[comps]},{Length[comps]}];\n\n\
Array[ReplacePart[zeros[[#]],vv[[#]],#]&, Length[comps]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianwdP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianwdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,phase_,tc_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        lnadb,lnaddb,del,\n\t        \
wvecd,fs,lnadds,refdP},\n\t\t       del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs = \
Map[avPsetup[#,tc,tt,pp,set1]&, comps];\nrefdP = Flatten[Map[\n         \
(avP[#,tc,tt,pp,set1] - avP[compb,tc,tt,pp,set1])&, comps]];  \n\n\
Array[({lnaddb,lnadds} = \n\t Which[\n\t  TrueQ[phase==MU],\n\t\t   wvecd = \
wvecmu[pp];\n\t   \twvecd[[#]] += del;\n\t   \t{Log[muax[phase[compb],tt,pp, \
wvarsmu,wvecd,ends1]],\n\t   \t Map[Log[muax[phase[#],tt,pp, \
wvarsmu,wvecd,ends1]]&, comps]},\n\t  TrueQ[phase==BI],\n\t   \twvecd = \
wvecbi;\n   \t\twvecd[[#]] += del;\n   \t\t{Log[biax[phase[compb],tt, \
wvarsbi,wvecd,ends1]],\n\t   \t Map[Log[biax[phase[#],tt, \
wvarsbi,wvecd,ends1]]&, comps]},\n\t  TrueQ[phase==G],\n\t   \twvecd = \
wvecg[tt];\n\t   \twvecd[[#]] += del;\n\t   \t{Log[gax[phase[compb],tt, \
wvarsg,wvecd,ends1]],\n   \t\t Map[Log[gax[phase[#],tt, \
wvarsg,wvecd,ends1]]&, comps]},\n\t  TrueQ[phase==CHL],\n   \t\twvecd = \
wvecchl;\n   \t\twvecd[[#]] += del;\n   \t\t{Log[chlax[phase[compb],tt, \
wvarschl,wvecd,ends1]],\n   \t\t Map[Log[chlax[phase[#],tt, \
wvarschl,wvecd,ends1]]&, comps]},\n\t  TrueQ[phase==PLAG],\n\t   \twvecd = \
wvecplag[tt];\n\t   \twvecd += del;\n\t   \t{Log[plagax[phase[compb],tt, \
wvarsplag,wvecd,ends1]],\n   \t\t Map[Log[plagax[phase[#],tt, \
wvarsplag,wvecd,ends1]]&, comps]},\n\t  TrueQ[phase==KSP],\n\t   \twvecd = \
wvecksp[tt,pp];\n\t   \twvecd[[#]] += del;\n   \t\t\
{Log[kspax[phase[compb],tt,pp, wvarsksp,wvecd]],\n\t   \t \
Map[Log[kspax[phase[#],tt,pp, wvarsksp,wvecd]]&, comps]},\n\t  \
TrueQ[phase==CD],\n\t   \twvecd = wveccd;\n\t   \twvecd[[#]] += del;\n   \t\t\
{Log[cdax[phase[compb],tt, wvarscd,wvecd,ends1]],\n   \t\t \
Map[Log[cdax[phase[#],tt, wvarscd,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==ST],\n   \t\twvecd = wvecst;\n   \t\twvecd += del;\n   \t\t\
{Log[stax[phase[compb],tt, wvarsst,wvecd,ends1]],\n\t   \t \
Map[Log[stax[phase[#],tt, wvarsst,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==OPX],\n\t   \twvecd = wvecopx;\n\t   \twvecd[[#]] += del;\n   \t\
\t{Log[opxax[phase[compb],tt, wvarsopx,wvecd,ends1]],\n   \t\t \
Map[Log[opxax[phase[#],tt, wvarsopx,wvecd,ends1]]&, comps]} ];\n\t\t\t\t\n\t\
lnadb = replacelna[lnab, phase, lnaddb];\n\tlnads = \
Array[replacelna[fs[[#,3]], phase, lnadds[[#]]]&, \n\t            \
Length[comps]];\n\t\t\t\t        \n\
(Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n               \
Join[lnads[[#]],aa1],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnadb,aa1],varxxb])&,\n       \
Range[Length[comps]]] - refdP)/del)&, lw[phase]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianadP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianadP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,tc_,tt_,pp_,set1_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        del, ad, refdP},\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs = \
Map[avPsetup[#,tc,tt,pp,set1]&, comps];\nrefdP = Flatten[Map[\n         \
(avP[#,tc,tt,pp,set1] - avP[compb,tc,tt,pp,set1])&, comps]];  \ndel = 0.02;\n\
\n\tArray[(ad = aa1;\n\t\t\t      ad[[#]] += del;\n\
(Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n               \
Join[fs[[#,3]],ad],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnab,ad],varxxb])&,\n       \
Range[Length[comps]]] - refdP)/del)&, Length[avecb]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[vdP];\n",
    FontWeight->"Plain"],
  StyleBox["vdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,tc_,tt_,pp_,set1_,ssphases_] := \n  \
Module[{vyxdP,vybdP,vywdP,vyadP},\n  \n  vyxdP = \
Map[vyxx[compb,comps,#,tc,tt,pp,set1]&, ssphases];\n  vybdP = Map[Transpose[\n\
           jacobianxbdP[compb,comps,#,tc,tt,pp,set1]].\n           \
covx[compb,#].\n           jacobianxbdP[compb,comps,#,tc,tt,pp,set1]&,\n      \
     ssphases];\n  vywdP = Map[Transpose[\n           \
jacobianwdP[compb,comps,#,tc,tt,pp,set1]].\n           \
covw[#].jacobianwdP[compb,comps,#,tc,tt,pp,set1]&, \n           ssphases];\n  \
vyadP = Transpose[\n           jacobianadP[compb,comps,tc,tt,pp,set1]].\n     \
      cova1.jacobianadP[compb,comps,tc,tt,pp,set1];\n           \n  \
Apply[Plus, Join[vyxdP,vybdP,vywdP,vyadP]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
functions for calculating jacobians for Vp  -  different \
assemblages (non ss)\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianxdPd];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianxdPd",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comp1_,phase_,tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        \
lnavec1,avec1,lna1,sdlna1,varxx1,eq1,\n\t        phased, lnadd, \
lnad,del,refdP},\n\t\t     del = 0.02;\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\n\
{lnavec1,avec1,lna1,sdlna1,varxx1,eq1} = avPsetup[comp1,tc,tt,pp,set2];\n\
refdP =  avP[comp1,tc,tt,pp,set2] - avP[compb,tc,tt,pp,set1];\n\t\t     \n\
Array[(phased = phase[comp1];\n\t   phased[[#]] += del;\n  lnadd = \n    \
Which[\n     TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, \
wvarsmu,wvecmu[pp],ends2]],\n     TrueQ[phase==BI],\n\t      \
Log[biax[phased,tt, wvarsbi,wvecbi,ends2]],\n     TrueQ[phase==CHL],\n\t      \
Log[chlax[phased,tt, wvarschl,wvecchl,ends2]],\n     TrueQ[phase==G],\n\t     \
 Log[gax[phased,tt, wvarsg, wvecg[tt],ends2]],\n     TrueQ[phase==PLAG],\n    \
   Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends2]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends2]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends2]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends2]] ];\n     \n   lnad = replacelna[lna1, phase, lnadd];\n\n\t\
((miks[eq1,{p},{pp},Join[lnavec1,avec1],Join[lnad,aa2],varxx1] -\n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnab,aa1],varxxb]) -\n  \
refdP)/del)&, Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[vyxxdP];\n",
    FontWeight->"Plain"],
  StyleBox["vyxxdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_,samediff_,phase_,tc_,tt_,pp_,set1_,set2_] :=\n  \
Module[{ass1,ass2,vv,vv1,vv2,zeros},\n  \nass1 = Range[samediff[[1]]];\nass2 \
= Table[samediff[[1]] + i, {i,samediff[[2]]}];\n   \nvv1 = \
Flatten[Map[Transpose[\n  \
jacobianxdPd[compb,comps[[#]],phase,tc,tt,pp,set1,set1]].\n  \
covx[comps[[#]],phase].\n  \
jacobianxdPd[compb,comps[[#]],phase,tc,tt,pp,set1,set1]&, ass1]];\n  \nvv2 = \
Flatten[Map[Transpose[\n  \
jacobianxdPd[compb,comps[[#]],phase,tc,tt,pp,set1,set2]].\n  \
covx[comps[[#]],phase].\n  \
jacobianxdPd[compb,comps[[#]],phase,tc,tt,pp,set1,set2]&, ass2]];\n\nvv = \
Join[vv1,vv2];\n\nzeros = Table[0,{Length[comps]},{Length[comps]}];\n\n\
Array[ReplacePart[zeros[[#]],vv[[#]],#]&, Length[comps]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianxbdPd];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianxbdPd",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_,samediff_,phase_,\n              \
tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n        \t\
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        phased, \
lnadd,fs,fs1,fs2,ass1,ass2,lnad,del,\n\t        refdP1,refdP2,refdP},\n\t\t   \
  del = 0.02;\n\t\t     \nass1 = Range[samediff[[1]]];\nass2 = \
Table[samediff[[1]] + i, {i,samediff[[2]]}];\n\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs1 \
= Map[avPsetup[comps[[#]],tc,tt,pp,set1]&, ass1];  \nfs2 = \
Map[avPsetup[comps[[#]],tc,tt,pp,set2]&, ass2];\nfs = Join[fs1,fs2];\nrefdP1 \
= Flatten[Map[\n         (avP[comps[[#]],tc,tt,pp,set1] - \
avP[compb,tc,tt,pp,set1])&, \n         ass1]];  \nrefdP2 = Flatten[Map[\n     \
    (avP[comps[[#]],tc,tt,pp,set2] - avP[compb,tc,tt,pp,set1])&, \n         \
ass2]];  \nrefdP = Join[refdP1,refdP2];\n\t\t     \nArray[(phased = \
phase[compb];\n\t   phased[[#]] += del;\n  lnadd = \n    Which[\n     \
TrueQ[phase==MU],\n\t      Log[muax[phased,tt,pp, wvarsmu,wvecmu[pp],ends1]],\
\n     TrueQ[phase==BI],\n\t      Log[biax[phased,tt, wvarsbi,wvecbi,ends1]],\
\n     TrueQ[phase==CHL],\n\t      Log[chlax[phased,tt, \
wvarschl,wvecchl,ends1]],\n     TrueQ[phase==G],\n\t      Log[gax[phased,tt, \
wvarsg, wvecg[tt],ends1]],\n     TrueQ[phase==PLAG],\n       \
Log[plagax[phased,tt, wvarsplag,wvecplag[tt],ends1]],\n     \
TrueQ[phase==KSP],\n       Log[kspax[phased,tt,pp, wvarsksp,wvecksp[tt,pp]]],\
\n     TrueQ[phase==CD],\n       Log[cdax[phased,tt, wvarscd, wveccd,ends1]],\
\n     TrueQ[phase==ST],\n       Log[stax[phased,tt, wvarsst, wvecst,ends1]],\
\n     TrueQ[phase==OPX],\n       Log[opxax[phased,tt, wvaropx, \
wvecopx,ends1]] ];\n     \n   lnad = replacelna[lnab, phase, lnadd];\n\n\
(Join[\n Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n            \
   Join[fs[[#,3]],aa1],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnad,aa1],varxxb])&,\n       \
ass1],\n      Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n       \
        Join[fs[[#,3]],aa2],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnad,aa1],varxxb])&,\n       \
ass2]] - refdP)/del)&, Length[oxname]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianwdPd];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianwdPd",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,samediff_,\n             \
phase_,tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n        \t\
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        lnadb,lnaddb,del,\n\t        \
wvecd,fs,fs1,fs2,lnadds,refdP1,refdP2,refdP},\n\t\t       del = 0.02;\nass1 = \
Range[samediff[[1]]];\nass2 = Table[samediff[[1]] + i, {i,samediff[[2]]}];\n\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs1 \
= Map[avPsetup[comps[[#]],tc,tt,pp,set1]&, ass1];  \nfs2 = \
Map[avPsetup[comps[[#]],tc,tt,pp,set2]&, ass2];\nfs = Join[fs1,fs2];\nrefdP1 \
= Flatten[Map[\n         (avP[comps[[#]],tc,tt,pp,set1] - \
avP[compb,tc,tt,pp,set1])&, \n         ass1]];  \nrefdP2 = Flatten[Map[\n     \
    (avP[comps[[#]],tc,tt,pp,set2] - avP[compb,tc,tt,pp,set1])&, \n         \
ass2]];  \nrefdP = Join[refdP1,refdP2];\n\nArray[({lnaddb,lnadds} = \n\t \
Which[\n\t  TrueQ[phase==MU],\n\t\t   wvecd = wvecmu[pp];\n\t   \twvecd[[#]] \
+= del;\n\t   \t{Log[muax[phase[compb],tt,pp, wvarsmu,wvecd,ends1]],\n\t   \t \
Map[Log[muax[phase[#],tt,pp, wvarsmu,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==BI],\n\t   \twvecd = wvecbi;\n   \t\twvecd[[#]] += del;\n   \t\t\
{Log[biax[phase[compb],tt, wvarsbi,wvecd,ends1]],\n\t   \t \
Map[Log[biax[phase[#],tt, wvarsbi,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==G],\n\t   \twvecd = wvecg[tt];\n\t   \twvecd[[#]] += del;\n\t   \
\t{Log[gax[phase[compb],tt, wvarsg,wvecd,ends1]],\n   \t\t \
Map[Log[gax[phase[#],tt, wvarsg,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==CHL],\n   \t\twvecd = wvecchl;\n   \t\twvecd[[#]] += del;\n   \t\
\t{Log[chlax[phase[compb],tt, wvarschl,wvecd,ends1]],\n   \t\t \
Map[Log[chlax[phase[#],tt, wvarschl,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==PLAG],\n\t   \twvecd = wvecplag[tt];\n\t   \twvecd += del;\n\t   \
\t{Log[plagax[phase[compb],tt, wvarsplag,wvecd,ends1]],\n   \t\t \
Map[Log[plagax[phase[#],tt, wvarsplag,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==KSP],\n\t   \twvecd = wvecksp[tt,pp];\n\t   \twvecd[[#]] += del;\
\n   \t\t{Log[kspax[phase[compb],tt,pp, wvarsksp,wvecd]],\n\t   \t \
Map[Log[kspax[phase[#],tt,pp, wvarsksp,wvecd]]&, comps]},\n\t  \
TrueQ[phase==CD],\n\t   \twvecd = wveccd;\n\t   \twvecd[[#]] += del;\n   \t\t\
{Log[cdax[phase[compb],tt, wvarscd,wvecd,ends1]],\n   \t\t \
Map[Log[cdax[phase[#],tt, wvarscd,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==ST],\n   \t\twvecd = wvecst;\n   \t\twvecd += del;\n   \t\t\
{Log[stax[phase[compb],tt, wvarsst,wvecd,ends1]],\n\t   \t \
Map[Log[stax[phase[#],tt, wvarsst,wvecd,ends1]]&, comps]},\n\t  \
TrueQ[phase==OPX],\n\t   \twvecd = wvecopx;\n\t   \twvecd[[#]] += del;\n   \t\
\t{Log[opxax[phase[compb],tt, wvarsopx,wvecd,ends1]],\n   \t\t \
Map[Log[opxax[phase[#],tt, wvarsopx,wvecd,ends1]]&, comps]} ];\n\t\t\t\t\n\t\
lnadb = replacelna[lnab, phase, lnaddb];\n\tlnads = \
Array[replacelna[fs[[#,3]], phase, lnadds[[#]]]&, \n\t            \
Length[comps]];\n\t\t\t\t        \n(Join[\n \
Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n               \
Join[lnads[[#]],aa1],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnadb,aa1],varxxb])&,\n       \
ass1],\n      Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n       \
        Join[lnads[[#]],aa2],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnadb,aa1],varxxb])&,\n       \
ass2]] - refdP)/del)&, lw[phase]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[jacobianhdP];\n",
    FontWeight->"Plain"],
  StyleBox["jacobianhdP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,samediff_,\n            \
tc_,tt_,pp_,set1_,set2_] :=\n\t\
Module[{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1,\n\t        \
ends2,r2,aa2,b2,c2,cova2,anals2,nonss2,\n\t        \
lnavecb,avecb,lnab,sdlnab,varxxb,eqb,\n\t        del, ad, refdP},\nass1 = \
Range[samediff[[1]]];\nass2 = Table[samediff[[1]] + i, {i,samediff[[2]]}];\n\n\
{ends1,r1,aa1,b1,c1,cova1,anals1,nonss1} = set1;\n\
{ends2,r2,aa2,b2,c2,cova2,anals2,nonss2} = set2;\n\
{lnavecb,avecb,lnab,sdlnab,varxxb,eqb} = avPsetup[compb,tc,tt,pp,set1];\nfs1 \
= Map[avPsetup[comps[[#]],tc,tt,pp,set1]&, ass1];  \nfs2 = \
Map[avPsetup[comps[[#]],tc,tt,pp,set2]&, ass2];\nfs = Join[fs1,fs2];\nrefdP1 \
= Flatten[Map[\n         (avP[comps[[#]],tc,tt,pp,set1] - \
avP[compb,tc,tt,pp,set1])&, \n         ass1]];  \nrefdP2 = Flatten[Map[\n     \
    (avP[comps[[#]],tc,tt,pp,set2] - avP[compb,tc,tt,pp,set1])&, \n         \
ass2]];  \nrefdP = Join[refdP1,refdP2];\n       del = 0.02;\n       rr1 = \
fullr[endmembers, ends1, r1];\n\t      rr2 = fullr[endmembers, ends2, r2];\n\t\
\n\tArray[(hd = Table[0, {Length[endmembers]}];\n         hd[[#]] += del;\n   \
      aa1d = aa1 + rr1.hd;\n         aa2d = aa2 + rr2.hd;\n       \n(Join[\n \
Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n               \
Join[fs[[#,3]],aa1d],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnab,aa1d],varxxb])&,\n       \
ass1],\n      Map[(miks[fs[[#,6]],{p},{pp},Join[fs[[#,1]],fs[[#,2]]],\n       \
        Join[fs[[#,3]],aa2d],fs[[#,5]]] - \n   \
miks[eqb,{p},{pp},Join[lnavecb,avecb],Join[lnab,aa1d],varxxb])&,\n       \
ass2]] - refdP)/del)&, Length[endmembers]]   ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[vdPd];\n",
    FontWeight->"Plain"],
  StyleBox["vdPd",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[compb_,comps_List,samediff_,\n     \
tc_,tt_,pp_,set1_,set2_,ssphases_] := \n  Module[{vyxdP,vybdP,vywdP,vyadP},\n \
 \n  vyxdP = Map[vyxxdP[compb,comps,samediff,#,tc,tt,pp,set1,set2]&, \n       \
       ssphases];\n  vybdP = Map[Transpose[\n           \
jacobianxbdPd[compb,comps,samediff,#,tc,tt,pp,set1,set2]].\n           \
covx[compb,#].\n           \
jacobianxbdPd[compb,comps,samediff,#,tc,tt,pp,set1,set2]&,\n           \
ssphases];\n  vywdP = Map[Transpose[\n           \
jacobianwdPd[compb,comps,samediff,#,tc,tt,pp,set1,set2]].\n           \
covw[#].\n           \
jacobianwdPd[compb,comps,samediff,#,tc,tt,pp,set1,set2]&, \n           \
ssphases];\n  vyadP = Transpose[\n           \
jacobianhdP[compb,comps,samediff,tc,tt,pp,set1,set2]].\n           vhfull.\n  \
         jacobianhdP[compb,comps,samediff,tc,tt,pp,set1,set2];\n           \n \
 Apply[Plus, Join[vyxdP,vybdP,vywdP,{vyadP}]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Covariance matrices ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
These are also incorporated into the \[Sigma]lna functions\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[covx];
covx[comp_,phase_] :=
\tModule[{afac,bfac,cov},
\t    afac = 0.01; bfac = 0.05;
\t\tcov = DiagonalMatrix[(afac phase[comp] + bfac)^2] ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[varx];
varx[comp_,phase_] :=
  Module[{afac,bfac},
     afac = 0.01; bfac = 0.05;
     afac phase[comp] + bfac
  ]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[covw];
covw[phase_] :=
\tModule[{wfac, cov, n},
\t\twfac = 1;
\t\tcov = 
\t\tWhich[TrueQ[phase==MU], n = 3,
\t          TrueQ[phase==BI], n = 3,
\t          TrueQ[phase==G], n = 3,
\t          TrueQ[phase==CHL], n = 5,
\t          TrueQ[phase==PLAG], n = 1,
\t          TrueQ[phase==KSP], n = 1,
\t          TrueQ[phase==CD], n = 2,
\t          TrueQ[phase==ST], n = 4,
\t          TrueQ[phase==OPX], n = 2 ];
         DiagonalMatrix[Table[(n wfac)^2,{lw[phase]}]]  ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Single functions for calculating ",
    FontWeight->"Plain"],
  StyleBox["\[Sigma]",
    FontWeight->"Plain"],
  StyleBox["delP",
    FontWeight->"Plain"]
}], "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Function for calculating \[Sigma]delPT for two identical \
assemblages\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[deltaP];\n",
    FontWeight->"Plain"],
  StyleBox["deltaP",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tc_, tt_, pp_, set_] :=\n\
Module[{vyx1,vyx2,vyw,vya,vp,corpt,sdpt,dp,dt,cova},\n\n refP1 = avP[sample1, \
tc, tt, pp, set];\n refP2 = avP[sample2, tc, tt, pp, set];\n refdelP = refP2 \
- refP1;\n \n cova = set[[6]];\n \n vyx1 = \
Map[jacobianx1[sample1,#,tc,tt,pp,set].\n        \
covx[sample1,#].jacobianx1[sample1,#,tc,tt,pp,set]&, anals];\n        \n vyx2 \
= Map[jacobianx2[sample2,#,tc,tt,pp,set].\n        \
covx[sample2,#].jacobianx2[sample2,#,tc,tt,pp,set]&, anals];\n        \n vyw \
=  Map[jacobianw[sample1,sample2,#,tc,tt,pp,set,set].\n\t   \
covw[#].jacobianw[sample1,sample2,#,tc,tt,pp,set,set]&, anals]; \n\t\t\n vya \
= jacobiana[sample1,sample2,tc,tt,pp,set,set].\n        \
cova.jacobiana[sample1,sample2,tc,tt,pp,set,set];  \n        \n vp = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vya}]];\n sdp = Sqrt[vp];\n dp = \
refdelP[[1]];\n \n  Print[\"Delta P = \",format[dp,1,True],\" \[PlusMinus] \
\", \n                   format[2 sdp,1,True],\" kbar\"]   ] ;",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Function for calculating \[Sigma]delPT for two non-identical \
assemblages, set up to only work when the different phases are non-solid \
solution minerals, ie. ky versus sill.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[deltaPd];\n",
    FontWeight->"Plain"],
  StyleBox["deltaPd",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tc_, tt_, pp_, set1_, set2_] :=\n\
Module[{vyx1,vyx2,vyw,vyh,vp,sdp,dp},\n\n refP1 = avP[sample1, tc, tt, pp, \
set1];\n refP2 = avP[sample2, tc, tt, pp, set2];\n refdelP = refP2 - refP1;\n \
\n vyx1 = Map[jacobianx1[sample1,#,tc,tt,pp,set1].\n        \
covx[sample1,#].jacobianx1[sample1,#,tc,tt,pp,set1]&, anals];\n        \n \
vyx2 = Map[jacobianx2[sample2,#,tc,tt,pp,set2].\n        \
covx[sample2,#].jacobianx2[sample2,#,tc,tt,pp,set2]&, anals];\n        \n vyw \
=  Map[jacobianw[sample1,sample2,#,tc,tt,pp,set1,set2].\n\t   \
covw[#].jacobianw[sample1,sample2,#,tc,tt,pp,set1,set2]&, anals]; \n\t\t\n \
vyh = jacobianhfull[sample1,sample2,tc,tt,pp,set1,set2].\n        \
vhfull.jacobianhfull[sample1,sample2,tc,tt,pp,set1,set2];  \n        \n vp = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vyh}]];\n sdp = Sqrt[vp];\n dp = \
refdelP[[1]];\n \n  Print[\"Delta P = \",format[dp,1,True],\" \[PlusMinus] \
\", \n                   format[2 sdp,1,True],\" kbar\"] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Single functions for calculating ",
    FontWeight->"Plain"],
  StyleBox["\[Sigma]",
    FontWeight->"Plain"],
  StyleBox["delPT",
    FontWeight->"Plain"]
}], "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Function for calculating \[Sigma]delPT for two identical \
assemblages\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[deltaPT];
deltaPT[sample1_, sample2_, anals_, tt_, pp_, set_] :=
Module[{vyx1,vyx2,vyw,vya,vpt,corpt,sdpt,dp,dt,cova},

 refPT1 = avPT[sample1, tt, pp, set];
 refPT2 = avPT[sample2, tt, pp, set];
 refdelPT = refPT2 - refPT1;
 
 cova = set[[6]];
 
 vyx1 = Map[Transpose[jacobianx1PT[sample1,#,tt,pp,set]].
        covx[sample1,#].jacobianx1PT[sample1,#,tt,pp,set]&, anals];
        
 vyx2 = Map[Transpose[jacobianx2PT[sample2,#,tt,pp,set]].
        covx[sample2,#].jacobianx2PT[sample2,#,tt,pp,set]&, anals];
        
 vyw =  Map[Transpose[
        jacobianwPT[sample1,sample2,#,tt,pp,set,set]].
\t   covw[#].jacobianwPT[sample1,sample2,#,tt,pp,set,set]&, anals]; 
\t\t
 vya = Transpose[jacobianaPT[sample1,sample2,tt,pp,set,set]].
        cova.jacobianaPT[sample1,sample2,tt,pp,set,set];  
        
 vpt = Apply[Plus, Join[vyx1,vyx2,vyw,{vya}]];
 
 sdpt = Array[Sqrt[vpt[[#,#]]]&, Length[vpt]];
 corpt = DiagonalMatrix[1/sdpt].vpt.DiagonalMatrix[1/sdpt];
 {dp,dt} = refdelPT;

 Print[\"Delta P = \",format[dp,1,True],\" \[PlusMinus] \", 
                   format[2 sdpt[[1]],1,True],\" kbar\"];
 Print[\"Delta T = \",format[dt,1,True],\" \[PlusMinus] \",
                   format[2 sdpt[[2]],1,True],\" \[Degree]C\",
      \",  cor = \", format[corpt[[1,2]],3,True] ] ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Function for calculating \[Sigma]delPT for two non-identical \
assemblages, set up to only work when the different phases are non-solid \
solution minerals, ie. ky versus sill.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Clear[deltaPTd];
deltaPTd[sample1_, sample2_, anals_, tt_, pp_, set1_, set2_] :=
Module[{vyx1,vyx2,vyw,vyh,vpt,corpt,sdpt,dp,dt},

 refPT1 = avPT[sample1, tt, pp, set1];
 refPT2 = avPT[sample2, tt, pp, set2];
 refdelPT = refPT2 - refPT1;
   
 vyx1 = Map[Transpose[jacobianx1PT[sample1,#,tt,pp,set1]].
        covx[sample1,#].jacobianx1PT[sample1,#,tt,pp,set1]&, anals];
        
 vyx2 = Map[Transpose[jacobianx2PT[sample2,#,tt,pp,set2]].
        covx[sample2,#].jacobianx2PT[sample2,#,tt,pp,set2]&, anals];
        
 vyw =  Map[Transpose[
        jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]].
\t   covw[#].jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]&, anals]; 
\t\t
 vyh = Transpose[jacobianhPTfull[sample1,sample2,tt,pp,set1,set2]].
        vhfull.jacobianhPTfull[sample1,sample2,tt,pp,set1,set2];  
        
 vpt = Apply[Plus, Join[vyx1,vyx2,vyw,{vyh}]];
 
 sdpt = Array[Sqrt[vpt[[#,#]]]&, Length[vpt]];
 corpt = DiagonalMatrix[1/sdpt].vpt.DiagonalMatrix[1/sdpt];
 {dp,dt} = refdelPT;

 Print[\"Delta P = \",format[dp,1,True],\" \[PlusMinus] \", 
                   format[2 sdpt[[1]],1,True],\" kbar\"];
 Print[\"Delta T = \",format[dt,1,True],\" \[PlusMinus] \",
                   format[2 sdpt[[2]],1,True],\" \[Degree]C\",
      \",  cor = \", format[corpt[[1,2]],3,True] ] ];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[vdelPT];\n",
    FontWeight->"Plain"],
  StyleBox["vdelPT",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tt_, pp_, set_] :=\n\
Module[{vyx1,vyx2,vyw,vya,vpt,corpt,sdpt,dp,dt,sdp,sdt,laxis,saxis},\n\n \
refPT1 = avPT[sample1, tt, pp, set];\n refPT2 = avPT[sample2, tt, pp, set];\n \
refdelPT = refPT2 - refPT1;\n \n vyx1 = \
Map[Transpose[jacobianx1PT[sample1,#,tt,pp,set]].\n        \
covx[sample1,#].jacobianx1PT[sample1,#,tt,pp,set]&, anals];\n        \n vyx2 \
= Map[Transpose[jacobianx2PT[sample2,#,tt,pp,set]].\n        \
covx[sample2,#].jacobianx2PT[sample2,#,tt,pp,set]&, anals];\n        \n vyw = \
 Map[Transpose[\n        jacobianwPT[sample1,sample2,#,tt,pp,set,set]].\n\t   \
covw[#].jacobianwPT[sample1,sample2,#,tt,pp,set,set]&, anals]; \n\t\t\n vya = \
Transpose[jacobianaPT[sample1,sample2,tt,pp,set,set]].\n        \
cova1.jacobianaPT[sample1,sample2,tt,pp,set,set];  \n        \n vpt = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vya}]];\n \n sdpt = Array[Sqrt[vpt[[#,#]]]&, \
Length[vpt]];\n corpt = DiagonalMatrix[1/sdpt].vpt.DiagonalMatrix[1/sdpt];\n \
{dp,dt} = refdelPT;\n Print[\"V",
    FontWeight->"Plain"],
  StyleBox["\[CapitalDelta]",
    FontWeight->"Plain"],
  StyleBox["pt = \",MatrixForm[vpt]] ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plotting functions", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* returns distance above MCT, Delta T, max T, min T \n   from \
Delta PT calculations *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nClear[xtinfo];\n",
    FontWeight->"Plain"],
  StyleBox["xtinfo",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tt_, pp_, set1_, set2_] :=\n\
Module[{vyx1,vyx2,vyw,vyh,vpt,corpt,sdpt,dp,dt,tinfo},\n\n refPT1 = \
avPT[sample1, tt, pp, set1];\n refPT2 = avPT[sample2, tt, pp, set2];\n \
refdelPT = refPT2 - refPT1;\n \n vyx1 = \
Map[Transpose[jacobianx1PT[sample1,#,tt,pp,set1]].\n        \
covx[sample1,#].jacobianx1PT[sample1,#,tt,pp,set1]&, anals];\n        \n vyx2 \
= Map[Transpose[jacobianx2PT[sample2,#,tt,pp,set2]].\n        \
covx[sample2,#].jacobianx2PT[sample2,#,tt,pp,set2]&, anals];\n        \n vyw \
=  Map[Transpose[\n        jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]].\n\
\t   covw[#].jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]&, anals]; \n\t\t\n\
 vyh = Transpose[jacobianhPTfull[sample1,sample2,tt,pp,set1,set2]].\n        \
vhfull.jacobianhPTfull[sample1,sample2,tt,pp,set1,set2];  \n        \n vpt = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vyh}]];\n \n sdpt = Array[Sqrt[vpt[[#,#]]]&, \
Length[vpt]];\n corpt = DiagonalMatrix[1/sdpt].vpt.DiagonalMatrix[1/sdpt];\n \
{dp,dt} = refdelPT;\n \ntinfo = {x[sample2], dt, dt + 2 sdpt[[2]], dt - 2 \
sdpt[[2]]} ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* returns distance above MCT, Delta P, max P, min P \n   from \
Delta P calculations *)\n",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Clear[xpinfo];\n",
    FontWeight->"Plain"],
  StyleBox["xpinfo",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tc_, tt_, pp_, set1_, set2_] :=\n\
Module[{vyx1,vyx2,vyw,vyh,vp,sdp,dp,pinfo},\n\n refP1 = avP[sample1, tc, tt, \
pp, set1];\n refP2 = avP[sample2, tc, tt, pp, set2];\n refdelP = refP2 - \
refP1;\n \n vyx1 = Map[jacobianx1[sample1,#,tc,tt,pp,set1].\n        \
covx[sample1,#].jacobianx1[sample1,#,tc,tt,pp,set1]&, anals];\n        \n \
vyx2 = Map[jacobianx2[sample2,#,tc,tt,pp,set2].\n        \
covx[sample2,#].jacobianx2[sample2,#,tc,tt,pp,set2]&, anals];\n        \n vyw \
=  Map[jacobianw[sample1,sample2,#,tc,tt,pp,set1,set2].\n\t   \
covw[#].jacobianw[sample1,sample2,#,tc,tt,pp,set1,set2]&, anals]; \n\t\t\n \
vyh = jacobianhfull[sample1,sample2,tc,tt,pp,set1,set2].\n        \
vhfull.jacobianhfull[sample1,sample2,tc,tt,pp,set1,set2];  \n        \n vp = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vyh}]];\n sdp = Sqrt[vp];\n dp = \
refdelP[[1]];\n \n pinfo = {x[sample2], dp, dp + 2 sdp, dp - 2 sdp} ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(* returns Delta P, max P, and min P, Delta T, max T, min T \n   \
from Delta PT calculations *)",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nClear[ptinfo];\n",
    FontWeight->"Plain"],
  StyleBox["ptinfo",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[sample1_, sample2_, anals_, tt_, pp_, set1_, set2_] :=\n\
Module[{vyx1,vyx2,vyw,vyh,vpt,corpt,sdpt,dp,dt,ptinfo},\n\n refPT1 = \
avPT[sample1, tt, pp, set1];\n refPT2 = avPT[sample2, tt, pp, set2];\n \
refdelPT = refPT2 - refPT1;\n \n vyx1 = \
Map[Transpose[jacobianx1PT[sample1,#,tt,pp,set1]].\n        \
covx[sample1,#].jacobianx1PT[sample1,#,tt,pp,set1]&, anals];\n        \n vyx2 \
= Map[Transpose[jacobianx2PT[sample2,#,tt,pp,set2]].\n        \
covx[sample2,#].jacobianx2PT[sample2,#,tt,pp,set2]&, anals];\n        \n vyw \
=  Map[Transpose[\n        jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]].\n\
\t   covw[#].jacobianwPT[sample1,sample2,#,tt,pp,set1,set2]&, anals]; \n\t\t\n\
 vyh = Transpose[jacobianhPTfull[sample1,sample2,tt,pp,set1,set2]].\n        \
vhfull.jacobianhPTfull[sample1,sample2,tt,pp,set1,set2];  \n        \n vpt = \
Apply[Plus, Join[vyx1,vyx2,vyw,{vyh}]];\n \n sdpt = Array[Sqrt[vpt[[#,#]]]&, \
Length[vpt]];\n corpt = DiagonalMatrix[1/sdpt].vpt.DiagonalMatrix[1/sdpt];\n \
{dp,dt} = refdelPT;\n \nptinfo = {dp, dp + 2 sdpt[[1]], dp - 2 sdpt[[1]],\n   \
       dt, dt + 2 sdpt[[2]], dt - 2 sdpt[[2]], corpt[[1,2]]} ];",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["points",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := (\n   Point[{info[[1]], info[[2]]}] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["vbar",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := (\n   Line[{{info[[1]], info[[3]]}, {info[[1]], \
info[[4]]}}]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["hbars",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := (\n  {Line[{{info[[1]]-0.05, info[[3]]}, \
{info[[1]]+0.05, info[[3]]}}],\n   Line[{{info[[1]]-0.05, info[[4]]}, \
{info[[1]]+0.05, info[[4]]}}]} );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["analyses", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MU[t1]   ^= {47.32, 0.00, 35.88,  0.91, 0.00,  0.61, 0.00, 1.26, \
10.02};
BI[t1]   ^= {34.90, 0.00, 19.28, 18.33, 0.00, 13.13, 0.00, 0.00, 10.36};
G[t1]    ^= {37.65, 0.00, 21.29, 32.41, 0.74,  3.45, 4.45, 0.00,  0.00};
PLAG[t1] ^= {59.72, 0.00, 25.52,  0.00, 0.00,  0.00, 7.12, 7.64,  \
0.00};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MU[t2]   ^= {47.63, 0.00, 35.37,  1.00, 0.00,  0.77, 0.00, 1.33,  \
9.90};
BI[t2]   ^= {34.86, 0.00, 18.68, 20.06, 0.00, 12.14, 0.00, 0.00, 10.27};
G[t2]    ^= {37.70, 0.00, 21.32, 31.70, 0.59,  3.29, 5.39, 0.00,  0.00};
PLAG[t2] ^= {62.07, 0.00, 23.93,  0.00, 0.00,  0.00, 5.27, 8.73,  \
0.00};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["set up - identical assemblages", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Independent set of reactions
1)  gr + q + 2ky = 3an
2)  mu + 2phl + 6q = 3cel + py
3)  3cel + 4phl + 12ky = 7mu + 5py
4)  2east + 6q = mu + cel + py
5)  ann + 3an = mu + gr + alm

Thermodata linearised wrt P and T and P = 8 kbar and T = 550\[Degree]C\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
name = {mu,cel,phl,ann,east,py,gr,alm,an,q,ky};

r = {
  {  0,   0,   0,   0,   0,   0,  -1,   0,   3,  -1,  -2},
  { -1,   3,  -2,   0,   0,   1,   0,   0,   0,  -6,   0},
  {  7,  -3,  -4,   0,   0,   5,   0,   0,   0,   0, -12},
  {  1,   1,   0,   0,  -2,   1,   0,   0,   0,  -6,   0},
  {  1,   0,   0,  -1,   0,   0,   1,   1,  -3,   0,   0}};

{aa,b,c,lnK,sdlnK}=Transpose[{
  {  42.43,  -0.14028,    6.420,    3.694,    0.687},
  {  75.51,   0.05635,   -3.962,  -12.905,    1.637},
  { 228.36,  -0.21890,    0.302,   -7.387,    3.718},
  {  55.20,   0.00250,   -3.460,   -4.711,    1.020},
  { -45.69,   0.13692,   -7.317,   -1.383,    0.841}}];

cova = {
  {    0.3717,     0.0099,     0.0243,     0.0034,    -0.3666},
  {    0.0099,     6.9945,    -0.6191,     2.9580,     1.0492},
  {    0.0243,    -0.6191,    14.3043,     1.1385,     2.2311},
  {    0.0034,     2.9580,     1.1385,    49.4729,     0.6753},
  {   -0.3666,     1.0492,     2.2311,     0.6753,     1.8992}};
  
Clear[MU]; Clear[BI]; Clear[G]; Clear[PLAG];
ssphases = {MU,BI,G,PLAG};
nssphases = {q,ky};
  
setup = {name, r, aa, b, c, cova, ssphases, nssphases};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["set up - different assemblages", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Independent set of reactions
1)  gr + q + 2ky = 3an
2)  mu + 2phl + 6q = 3cel + py
3)  3cel + 4phl + 12ky = 7mu + 5py
4)  2east + 6q = mu + cel + py
5)  ann + 3an = mu + gr + alm

Thermodata linearised wrt P and T and P = 8 kbar and T = 550\[Degree]C\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
name1 = {mu,cel,phl,ann,east,py,gr,alm,an,q,ky};

r1 = {
  {  0,   0,   0,   0,   0,   0,  -1,   0,   3,  -1,  -2},
  { -1,   3,  -2,   0,   0,   1,   0,   0,   0,  -6,   0},
  {  7,  -3,  -4,   0,   0,   5,   0,   0,   0,   0, -12},
  {  1,   1,   0,   0,  -2,   1,   0,   0,   0,  -6,   0},
  {  1,   0,   0,  -1,   0,   0,   1,   1,  -3,   0,   0}};

{aa1,b1,c1,lnK,sdlnK}=Transpose[{
  {  42.43,  -0.14028,    6.420,    3.694,    0.687},
  {  75.51,   0.05635,   -3.962,  -12.905,    1.637},
  { 228.36,  -0.21890,    0.302,   -7.387,    3.718},
  {  55.20,   0.00250,   -3.460,   -4.711,    1.020},
  { -45.69,   0.13692,   -7.317,   -1.383,    0.841}}];

cova1 = {
  {    0.3717,     0.0099,     0.0243,     0.0034,    -0.3666},
  {    0.0099,     6.9945,    -0.6191,     2.9580,     1.0492},
  {    0.0243,    -0.6191,    14.3043,     1.1385,     2.2311},
  {    0.0034,     2.9580,     1.1385,    49.4729,     0.6753},
  {   -0.3666,     1.0492,     2.2311,     0.6753,     1.8992}};
  
Clear[MU]; Clear[BI]; Clear[G]; Clear[PLAG];
ssphases1 = {MU,BI,G,PLAG};
nssphases1 = {q,ky};
    
setup1 = {name1, r1, aa1, b1, c1, cova1, ssphases1, nssphases1};\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\


Independent set of reactions
1)  gr + q + 2sill = 3an
2)  mu + 2phl + 6q = 3cel + py
3)  3cel + 2sill = 2mu + phl + 5q
4)  2east + 6q = mu + cel + py
5)  ann + 3an = mu + gr + alm

Thermodata linearised wrt P and T and P = 8 kbar and T = 550\[Degree]C\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
name2 = {mu,cel,phl,ann,east,py,gr,alm,an,q,sill};

r2 = {
  {  0,   0,   0,   0,   0,   0,  -1,   0,   3,  -1,  -2},
  { -1,   3,  -2,   0,   0,   1,   0,   0,   0,  -6,   0},
  {  2,  -3,   1,   0,   0,   0,   0,   0,   0,   5,  -2},
  {  1,   1,   0,   0,  -2,   1,   0,   0,   0,  -6,   0},
  {  1,   0,   0,  -1,   0,   0,   1,   1,  -3,   0,   0}};

{aa2,b2,c2,lnK,sdlnK}=Transpose[{
  {  27.69,  -0.11615,    5.333,    3.694,    0.687},
  {  75.51,   0.05635,   -3.962,  -12.905,    1.637},
  { -39.60,  -0.05931,    2.265,    9.523,    1.431},
  {  55.20,   0.00250,   -3.460,   -4.711,    1.020},
  { -45.69,   0.13692,   -7.317,   -1.383,    0.841}}];

cova2 = {
  {    0.3847,    -0.0068,     0.0157,    -0.0021,    -0.3760},
  {   -0.0068,     6.9945,    -5.9487,     2.9580,     1.0492},
  {    0.0157,    -5.9487,     5.4534,    -2.2807,    -0.5119},
  {   -0.0021,     2.9580,    -2.2807,    49.4729,     0.6753},
  {   -0.3760,     1.0492,    -0.5119,     0.6753,     1.8992}};
  
Clear[MU]; Clear[BI]; Clear[G]; Clear[PLAG];
ssphases2 = {MU,BI,G,PLAG};
nssphases2 = {q,sill};
  
setup2 = {name2, r2, aa2, b2, c2, cova2, ssphases2, nssphases2};\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
endmembers = {mu, cel, phl, ann, east, py, gr, alm, an, q, ky, \
sill};
vhfull = 
{{   9.2452,   8.3562,   8.2988,   8.4796,   9.2421,   0.0653,   
     0.3282,   0.2440,   0.4079,  -0.1526,   0.5313,   0.5320},
 {   8.3562,   9.2136,   8.5036,   8.3506,   8.2544,   0.2866,   
     0.0080,   0.1340,   0.0092,   0.1130,  -0.0487,  -0.0459},
 {   8.2988,   8.5036,   9.4923,   8.6458,   9.1725,   0.7196,  
    -0.1838,  -0.1260,  -0.0980,  -0.0571,  -0.0272,  -0.0273},
 {   8.4796,   8.3506,   8.6458,  10.9203,   8.6454,  -0.3233,  
    -0.0169,   1.0191,  -0.0296,  -0.0388,  -0.0155,  -0.0161},
 {   9.2421,   8.2544,   9.1725,   8.6454,  22.1292,   0.5133,   
     0.1350,  -0.0152,   0.2994,  -0.3232,   0.5502,   0.5508},
 {   0.0653,   0.2866,   0.7196,  -0.3233,   0.5133,   1.5936,   
     0.1861,   0.5454,   0.3470,   0.1383,   0.3637,   0.3641},
 {   0.3282,   0.0080,  -0.1838,  -0.0169,   0.1350,   0.1861,   
     2.5715,   0.3536,   1.1180,   0.0435,   0.3304,   0.3292},
 {   0.2440,   0.1340,  -0.1260,   1.0191,  -0.0152,   0.5454,   
     0.3536,   1.7426,   0.4143,   0.1567,   0.3737,   0.3734},
 {   0.4079,   0.0092,  -0.0980,  -0.0296,   0.2994,   0.3470,   
     1.1180,   0.4143,   0.7056,   0.0287,   0.4155,   0.4138},
 {  -0.1526,   0.1130,  -0.0571,  -0.0388,  -0.3232,   0.1383,
     0.0435,   0.1567,   0.0287,   0.1241,  -0.0410,  -0.0410},
 {   0.5313,  -0.0487,  -0.0272,  -0.0155,   0.5502,   0.3637,
     0.3304,   0.3737,   0.4155,  -0.0410,   0.4867,   0.4846},
 {   0.5320,  -0.0459,  -0.0273,  -0.0161,   0.5508,   0.3641,
     0.3292,   0.3734,   0.4138,  -0.0410,   0.4846,   0.4863}};\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["calculations - identical assemblages", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Average-PT", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Average-PT function, ",
  StyleBox["avPTfull[iden,t,p,setup]",
    FontColor->RGBColor[1, 0, 0]],
  ":\n\niden = identifies the assemblage, ie. as in the \"Analyses\" section, \
PHASE[iden] ^= {SiO2,TiO2,...};\n\nt = temperature estimate, this is for the \
calculation of end-member activities, you are also prompted for this when \
using AX.\n\np = pressure estimate, again for activity calculations\n\nsetup \
= calls the correct setup summary from the \"Setup\" input."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["avPTfull[t1,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 7.77; sd = 0.9
av t = 563.06; sd = 44.69
   sigfit = 1.156
   cor = 0.73\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["avPTfull[t2,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 9.29; sd = 0.85
av t = 580.71; sd = 40.47
   sigfit = 0.658
   cor = 0.78\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[TextData[{
  "Delta-PT function, ",
  StyleBox["deltaPT[iden#1,iden#2,minerals,t,p,setup]",
    FontColor->RGBColor[1, 0, 0]],
  ":\n\niden#1 = identifier for assemblage#1\niden#2 = identifier for \
assemblage#2\nminerals = vector of solid-solution phases (from \"Setup\" \
input)\nt = temperature estimate\np = temperature estimate\nsetup = calls the \
correct setup summary from the \"Setup\" input."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["deltaPT[t1,t2,ssphases,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Delta P = 1.5 \[PlusMinus] 0.6 kbar
Delta T = 17.7 \[PlusMinus] 30.7 \[Degree]C,  cor = 0.905\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Average-P at T = 550\[Degree]C", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Average-P function ",
  StyleBox["avPfull[iden,t#1,t#2,p,setup]",
    FontColor->RGBColor[1, 0, 0]],
  ":\n\nExactly the same as Average-PT function except that there are two \
temperature values which must be input.\n\nt#1 = temperature at which \
Average-P is calculated\nt#2 = temperature estimate for activity \
calculations.\n\nNOTE: t#1 and t#2 do not HAVE to be the same."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["avPfull[t1,550,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 7.57; sd = 0.62
   sigfit = 1.177\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["avPfull[t2,550,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 8.79; sd = 0.52
   sigfit = 0.779\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[TextData[{
  "Delta-P function, ",
  StyleBox["deltaPT[iden#1,iden#2,minerals,t#1,t#2,p,setup]",
    FontColor->RGBColor[1, 0, 0]],
  ":\n\nAgain exactly the same as the DeltaPT function, but with the two \
input temperatures.\n\nt#1 = temperature at which Average-P is calculated\n\
t#2 = temperature estimate for activity calculations."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["deltaP[t1,t2,ssphases,550,550,8,setup]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Delta P = 1.2 \[PlusMinus] 0.2 kbar", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["calculations - different assemblages", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Average-PT", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note: the setup called for each of the two Average-PT functions is \
different.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["avPTfull[t1,550,8,setup1]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 7.77; sd = 0.9
av t = 563.06; sd = 44.69
   sigfit = 1.156
   cor = 0.73\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["avPTfull[t2,550,8,setup2]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 8.36; sd = 1.49
av t = 555.6; sd = 79.27
   sigfit = 1.859
   cor = 0.78\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[TextData[{
  "Delta-PT function for different assemblages.\n",
  StyleBox["deltaPTd[iden#1,iden#2,minerals,t,p,setup#1,setup#2]",
    FontColor->RGBColor[1, 0, 0]],
  ":\n\nThe same as the \"deltaPT\" function except that two \"setup\" \
summaries are required.\nsetup#1 refers to the setup for iden#1,\nsetup#2 \
refers to the setup for iden#2."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["deltaPTd[t1,t2,ssphases1,550,8,setup1,setup2]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Delta P = 0.6 \[PlusMinus] 0.8 kbar
Delta T = -7.5 \[PlusMinus] 36.1 \[Degree]C,  cor = 0.803\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Average-P at T = 550\[Degree]C", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["avPfull[t1,550,550,8,setup1]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 7.57; sd = 0.62
   sigfit = 1.177\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["avPfull[t2,550,550,8,setup2]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
av p = 8.28; sd = 0.93
   sigfit = 1.869\
\>", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
Again the Delta-P function for different assemblages is the same as \
that for identical assemblages, except for the two \"setup\" summaries.\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["deltaPd[t1,t2,ssphases1,550,550,8,setup1,setup2]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Delta P = 0.7 \[PlusMinus] 0.5 kbar", "Print",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{613, 640},
WindowMargins->{{213, Automatic}, {38, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000cP2>?ogoo<3@@960dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000008000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 217, 7, 144, "Title"],
Cell[1925, 59, 114, 2, 53, "Subsubtitle"],
Cell[2042, 63, 24, 0, 46, "Text"],
Cell[2069, 65, 44, 0, 44, "SmallText"],
Cell[2116, 67, 327, 9, 142, "Text"],

Cell[CellGroupData[{
Cell[2468, 80, 69, 1, 67, "Section"],
Cell[2540, 83, 115, 4, 38, "Input"],

Cell[CellGroupData[{
Cell[2680, 91, 64, 1, 61, "Subsubsection"],
Cell[2747, 94, 231, 8, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3015, 107, 64, 1, 47, "Subsubsection"],
Cell[3082, 110, 224, 6, 70, "Text"],
Cell[3309, 118, 758, 21, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4104, 144, 75, 1, 47, "Subsubsection"],
Cell[4182, 147, 160, 4, 70, "Text"],
Cell[4345, 153, 1779, 45, 70, "Input"],
Cell[6127, 200, 167, 4, 70, "Text"],
Cell[6297, 206, 1091, 30, 70, "Input"],
Cell[7391, 238, 168, 4, 70, "Text"],
Cell[7562, 244, 1090, 30, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8689, 279, 74, 1, 47, "Subsubsection"],
Cell[8766, 282, 327, 9, 70, "Input"],
Cell[9096, 293, 233, 5, 70, "Text"],
Cell[9332, 300, 121, 4, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9490, 309, 74, 1, 47, "Subsubsection"],
Cell[9567, 312, 181, 4, 70, "Text"],
Cell[9751, 318, 362, 13, 70, "Input"],
Cell[10116, 333, 323, 6, 70, "Text"],
Cell[10442, 341, 381, 13, 70, "Input"],
Cell[10826, 356, 210, 5, 70, "Text"],
Cell[11039, 363, 242, 9, 70, "Input"],
Cell[11284, 374, 101, 1, 70, "Input"],
Cell[11388, 377, 750, 12, 70, "Text"],
Cell[12141, 391, 1009, 26, 70, "Input"],
Cell[13153, 419, 931, 15, 70, "Text"],
Cell[14087, 436, 1017, 26, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15141, 467, 115, 2, 66, "Subsubsection"],
Cell[15259, 471, 141, 4, 70, "Special1"],
Cell[15403, 477, 1518, 41, 70, "Input"],
Cell[16924, 520, 175, 5, 70, "Special1"],
Cell[17102, 527, 1262, 39, 70, "Input"],
Cell[18367, 568, 127, 4, 70, "Special1"],
Cell[18497, 574, 744, 27, 70, "Input"],
Cell[19244, 603, 145, 4, 70, "Special1"],
Cell[19392, 609, 3149, 48, 70, "Input"],
Cell[22544, 659, 109, 1, 70, "Special1"],
Cell[22656, 662, 2883, 73, 70, "Input"],
Cell[25542, 737, 147, 4, 70, "Special1"],
Cell[25692, 743, 2582, 60, 70, "Input"],
Cell[28277, 805, 128, 4, 70, "Special1"],
Cell[28408, 811, 703, 26, 70, "Input"],
Cell[29114, 839, 122, 4, 70, "Special1"],
Cell[29239, 845, 858, 26, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[30134, 876, 224, 8, 46, "Subsubsection"],
Cell[30361, 886, 88, 1, 70, "Special1"],
Cell[30452, 889, 1853, 43, 70, "Input"],
Cell[32308, 934, 84, 1, 70, "Special1"],
Cell[32395, 937, 148, 4, 70, "Text"],
Cell[32546, 943, 523, 13, 70, "Input"],
Cell[33072, 958, 2338, 69, 70, "Input"],
Cell[35413, 1029, 94, 1, 70, "Special1"],
Cell[35510, 1032, 330, 7, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[35877, 1044, 102, 1, 66, "Subsubsection"],
Cell[35982, 1047, 1181, 22, 70, "Input"],
Cell[37166, 1071, 797, 16, 70, "Input"],
Cell[37966, 1089, 3338, 52, 70, "Input"],
Cell[41307, 1143, 1025, 19, 70, "Input"],
Cell[42335, 1164, 517, 12, 70, "Input"],
Cell[42855, 1178, 1229, 23, 70, "Input"],
Cell[44087, 1203, 1228, 23, 70, "Input"],
Cell[45318, 1228, 1240, 23, 70, "Input"],
Cell[46561, 1253, 1240, 23, 70, "Input"],
Cell[47804, 1278, 1175, 22, 70, "Input"],
Cell[48982, 1302, 1180, 22, 70, "Input"],
Cell[50165, 1326, 579, 13, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[50781, 1344, 101, 1, 66, "Subsubsection"],
Cell[50885, 1347, 1646, 28, 70, "Input"],
Cell[52534, 1377, 1639, 28, 70, "Input"],
Cell[54176, 1407, 3774, 60, 70, "Input"],
Cell[57953, 1469, 1094, 22, 70, "Input"],
Cell[59050, 1493, 1355, 25, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60442, 1523, 102, 1, 66, "Subsubsection"],
Cell[60547, 1526, 1863, 36, 70, "Input"],
Cell[62413, 1564, 1635, 28, 70, "Input"],
Cell[64051, 1594, 3595, 57, 70, "Input"],
Cell[67649, 1653, 1086, 21, 70, "Input"],
Cell[68738, 1676, 763, 16, 70, "Input"],
Cell[69504, 1694, 761, 16, 70, "Input"],
Cell[70268, 1712, 76, 1, 70, "Text"],
Cell[70347, 1715, 1094, 21, 70, "Input"],
Cell[71444, 1738, 1352, 25, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[72833, 1768, 130, 4, 66, "Subsubsection"],
Cell[72966, 1774, 1973, 37, 70, "Input"],
Cell[74942, 1813, 1888, 32, 70, "Input"],
Cell[76833, 1847, 402, 11, 70, "Input"],
Cell[77238, 1860, 567, 13, 70, "Input"],
Cell[77808, 1875, 3112, 51, 70, "Input"],
Cell[80923, 1928, 1007, 20, 70, "Input"],
Cell[81933, 1950, 958, 19, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82928, 1974, 145, 4, 66, "Subsubsection"],
Cell[83076, 1980, 1970, 34, 70, "Input"],
Cell[85049, 2016, 971, 21, 70, "Input"],
Cell[86023, 2039, 2626, 44, 70, "Input"],
Cell[88652, 2085, 3816, 61, 70, "Input"],
Cell[92471, 2148, 1894, 33, 70, "Input"],
Cell[94368, 2183, 1140, 23, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[95545, 2211, 78, 1, 47, "Subsubsection"],
Cell[95626, 2214, 117, 4, 70, "Text"],
Cell[95746, 2220, 207, 7, 70, "Input"],
Cell[95956, 2229, 178, 8, 70, "Input"],
Cell[96137, 2239, 532, 17, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[96706, 2261, 236, 8, 46, "Subsubsection"],
Cell[96945, 2271, 127, 4, 70, "Text"],
Cell[97075, 2277, 1238, 23, 70, "Input"],
Cell[98316, 2302, 233, 5, 70, "Text"],
Cell[98552, 2309, 1230, 22, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[99819, 2336, 237, 8, 46, "Subsubsection"],
Cell[100059, 2346, 127, 4, 70, "Text"],
Cell[100189, 2352, 1336, 36, 70, "Input"],
Cell[101528, 2390, 233, 5, 70, "Text"],
Cell[101764, 2397, 1347, 34, 70, "Input"],
Cell[103114, 2433, 1381, 27, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[104532, 2465, 76, 1, 47, "Subsubsection"],
Cell[104611, 2468, 1498, 28, 70, "Input"],
Cell[106112, 2498, 1333, 25, 70, "Input"],
Cell[107448, 2525, 1560, 28, 70, "Input"],
Cell[109011, 2555, 231, 7, 70, "Input"],
Cell[109245, 2564, 255, 8, 70, "Input"],
Cell[109503, 2574, 340, 9, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[109892, 2589, 60, 1, 47, "Section"],
Cell[109955, 2592, 353, 8, 70, "Input"],
Cell[110311, 2602, 353, 8, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[110701, 2615, 82, 1, 47, "Section"],
Cell[110786, 2618, 309, 11, 158, "Text"],
Cell[111098, 2631, 1197, 30, 376, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[112332, 2666, 82, 1, 47, "Section"],
Cell[112417, 2669, 309, 11, 70, "Text"],
Cell[112729, 2682, 1218, 31, 70, "Input"],
Cell[113950, 2715, 312, 13, 70, "Text"],
Cell[114265, 2730, 1220, 31, 70, "Input"],
Cell[115488, 2763, 1691, 30, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[117216, 2798, 88, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[117329, 2803, 65, 1, 63, "Subsection"],
Cell[117397, 2806, 536, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[117958, 2820, 74, 1, 70, "Input"],
Cell[118035, 2823, 137, 6, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118209, 2834, 74, 1, 70, "Input"],
Cell[118286, 2837, 138, 6, 70, "Print"]
}, Open  ]],
Cell[118439, 2846, 452, 9, 70, "Text"],

Cell[CellGroupData[{
Cell[118916, 2859, 85, 1, 70, "Input"],
Cell[119004, 2862, 151, 4, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[119204, 2872, 85, 1, 47, "Subsection"],
Cell[119292, 2875, 443, 9, 70, "Text"],

Cell[CellGroupData[{
Cell[119760, 2888, 77, 1, 70, "Input"],
Cell[119840, 2891, 98, 4, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119975, 2900, 77, 1, 70, "Input"],
Cell[120055, 2903, 98, 4, 70, "Print"]
}, Open  ]],
Cell[120168, 2910, 388, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[120581, 2922, 88, 1, 70, "Input"],
Cell[120672, 2925, 85, 1, 70, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[120818, 2933, 88, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[120931, 2938, 65, 1, 63, "Subsection"],
Cell[120999, 2941, 136, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[121160, 2949, 75, 1, 70, "Input"],
Cell[121238, 2952, 137, 6, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121412, 2963, 75, 1, 70, "Input"],
Cell[121490, 2966, 137, 6, 70, "Print"]
}, Open  ]],
Cell[121642, 2975, 396, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[122063, 2987, 95, 1, 70, "Input"],
Cell[122161, 2990, 151, 4, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[122361, 3000, 85, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[122471, 3005, 78, 1, 70, "Input"],
Cell[122552, 3008, 98, 4, 70, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122687, 3017, 78, 1, 70, "Input"],
Cell[122768, 3020, 98, 4, 70, "Print"]
}, Open  ]],
Cell[122881, 3027, 200, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[123106, 3036, 98, 1, 70, "Input"],
Cell[123207, 3039, 85, 1, 70, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

