(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35756,       1306]*)
(*NotebookOutlinePosition[     36628,       1334]*)
(*  CellTagsIndexPosition[     36584,       1330]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->12],

Cell[StyleData[All, "Condensed"],
  PageWidth->WindowWidth,
  CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->8],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{24, 10}, {20, 40}},
  LineSpacing->{1, 0},
  FontSize->44],

Cell[StyleData["Title", "Condensed"],
  CellMargins->{{8, 10}, {4, 8}},
  FontSize->20],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {12, 30}},
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->24],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->36],

Cell[StyleData["Subtitle", "Condensed"],
  CellMargins->{{8, 10}, {4, 4}},
  FontSize->14],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {20, 15}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{24, 10}, {20, 20}},
  LineSpacing->{1, 0},
  FontSize->24],

Cell[StyleData["Subsubtitle", "Condensed"],
  CellMargins->{{8, 10}, {8, 8}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {12, 8}},
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  PageWidth->PaperWidth,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{13, 5}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Palatino",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False,
  "Masked"->False,
  "CompatibilityType"->0,
  "RotationAngle"->0}],

Cell[StyleData["Section", "Presentation"],
  PageWidth->PaperWidth,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{13, 5}, {11, 32}},
  LineSpacing->{1, 0}],

Cell[StyleData["Section", "Condensed"],
  PageWidth->PaperWidth,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{13, 5}, {6, 12}}],

Cell[StyleData["Section", "Printout"],
  PageWidth->PaperWidth,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{13, 5}, {7, 22}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  PageWidth->PaperWidth,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{13, 5}, {8, 20}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Subsection", "Presentation"],
  PageWidth->PaperWidth,
  CellFrame->{{0, 0}, {0, 0.5}},
  CellDingbat->None,
  CellMargins->{{13, 5}, {11, 32}},
  LineSpacing->{1, 0},
  FontSize->22],

Cell[StyleData["Subsection", "Condensed"],
  PageWidth->PaperWidth,
  CellFrame->{{0, 0}, {0, 0.5}},
  CellDingbat->None,
  CellMargins->{{13, 5}, {6, 12}},
  FontSize->12],

Cell[StyleData["Subsection", "Printout"],
  PageWidth->PaperWidth,
  CellFrame->{{0, 0}, {0, 0.5}},
  CellDingbat->None,
  CellMargins->{{13, 5}, {7, 22}},
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  PageWidth->300,
  CellFrame->True,
  CellDingbat->None,
  CellMargins->{{14, 5}, {8, 18}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  DefaultNewInlineCellStyle->"None",
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"Subsubsection",
  FontFamily->"Palatino",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],

Cell[StyleData["Subsubsection", "Presentation"],
  PageWidth->PaperWidth,
  CellDingbat->None,
  CellMargins->{{14, 5}, {11, 26}},
  LineSpacing->{1, 0}],

Cell[StyleData["Subsubsection", "Condensed"],
  PageWidth->PaperWidth,
  CellDingbat->None,
  CellMargins->{{14, 5}, {6, 12}}],

Cell[StyleData["Subsubsection", "Printout"],
  PageWidth->PaperWidth,
  CellDingbat->None,
  CellMargins->{{14, 5}, {7, 14}}]
}, Closed]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  GeneratedCell->True,
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  PageWidth->PaperWidth,
  CellMargins->{{12, 6}, {7, 7}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica"},
  Hyphenation->True,
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Courier",
  FontSize->12,
  Background->RGBColor[0.730007, 1, 0.945983]],

Cell[StyleData["Text", "Presentation"],
  PageWidth->PaperWidth,
  CellMargins->{{24, 6}, {10, 10}},
  LineSpacing->{1, 5}],

Cell[StyleData["Text", "Condensed"],
  PageWidth->PaperWidth,
  CellMargins->{{8, 6}, {6, 6}},
  LineSpacing->{1, 1}],

Cell[StyleData["Text", "Printout"],
  PageWidth->PaperWidth,
  CellMargins->{{2, 6}, {6, 6}},
  TextJustification->0.5]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  PageWidth->PaperWidth,
  CellMargins->{{12, 6}, {6, 6}},
  DefaultNewInlineCellStyle->"None",
  Hyphenation->True,
  LineSpacing->{1, 3},
  LanguageCategory->"NaturalLanguage",
  CounterIncrements->"SmallText",
  FontFamily->"Courier",
  FontSize->12,
  Background->RGBColor[0.923064, 1, 0.23003]],

Cell[StyleData["SmallText", "Presentation"],
  PageWidth->PaperWidth,
  CellMargins->{{24, 6}, {8, 8}},
  LineSpacing->{1, 5}],

Cell[StyleData["SmallText", "Condensed"],
  PageWidth->PaperWidth,
  CellMargins->{{8, 6}, {5, 5}},
  LineSpacing->{1, 2}],

Cell[StyleData["SmallText", "Printout"],
  PageWidth->PaperWidth,
  CellMargins->{{2, 6}, {5, 5}},
  TextJustification->0.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  PageWidth->Infinity,
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Monaco",
  FontSize->9,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False,
  "Masked"->False,
  "CompatibilityType"->0,
  "RotationAngle"->0}],

Cell[StyleData["Input", "Presentation"],
  PageWidth->Infinity,
  CellMargins->{{72, Inherited}, {8, 10}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Input", "Condensed"],
  PageWidth->Infinity,
  CellMargins->{{40, 10}, {2, 3}},
  FontSize->11],

Cell[StyleData["Input", "Printout"],
  PageWidth->Infinity,
  CellMargins->{{39, 0}, {4, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->9]
}, Open  ]],

Cell[StyleData["InputOnly"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{47, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output",
  FontFamily->"Monaco",
  FontSize->9],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{72, Inherited}, {10, 8}},
  LineSpacing->{1, 0}],

Cell[StyleData["Output", "Condensed"],
  CellMargins->{{41, Inherited}, {3, 2}}],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{39, 0}, {6, 4}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->11,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Message", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->7,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  LineSpacing->{1, 0},
  FontSize->16],

Cell[StyleData["Print", "Condensed"],
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontSize->11],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{4, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  LanguageCategory->None,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{43, Inherited}, {Inherited, 0}},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->10],

Cell[StyleData["Graphics", "Presentation"],
  ImageMargins->{{62, Inherited}, {Inherited, 0}}],

Cell[StyleData["Graphics", "Condensed"],
  ImageMargins->{{38, Inherited}, {Inherited, 0}},
  Magnification->0.6],

Cell[StyleData["Graphics", "Printout"],
  ImageMargins->{{30, Inherited}, {Inherited, 0}},
  Magnification->0.8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->12],

Cell[StyleData["CellLabel", "Condensed"],
  FontSize->9],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "EnhancedPrintout"],
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["InlineFormula"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->1,
  SingleLetterItalics->True],

Cell[StyleData["InlineFormula", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["InlineFormula", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["InlineFormula", "Printout"],
  CellMargins->{{2, 0}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{42, Inherited}, {Inherited, Inherited}},
  CellHorizontalScrolling->True,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Presentation"],
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["DisplayFormula", "Condensed"],
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  LanguageCategory->"Formula",
  ScriptLevel->1,
  FontFamily->"Courier"],

Cell[StyleData["Program", "Presentation"],
  CellMargins->{{24, 10}, {10, 10}},
  LineSpacing->{1, 5},
  FontSize->16],

Cell[StyleData["Program", "Condensed"],
  CellMargins->{{8, 10}, {6, 6}},
  LineSpacing->{1, 1},
  FontSize->11],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{2, 0}, {6, 6}},
  FontSize->9]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"],
  FontSize->16],

Cell[StyleData["Hyperlink", "Condensed"],
  FontSize->11],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"],
  FontSize->16],

Cell[StyleData["MainBookLink", "Condensed"],
  FontSize->11],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"],
  FontSize->16],

Cell[StyleData["AddOnsLink", "Condensed"],
  FontSize->11],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"],
  FontSize->16],

Cell[StyleData["RefGuideLink", "Condensed"],
  FontSize->11],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"],
  FontSize->16],

Cell[StyleData["GettingStartedLink", "Condensed"],
  FontSize->11],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"],
  FontSize->16],

Cell[StyleData["OtherInformationLink", "Condensed"],
  FontSize->11],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  DefaultNewInlineCellStyle->"None",
  LanguageCategory->"NaturalLanguage",
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  DefaultNewInlineCellStyle->"None",
  LanguageCategory->"NaturalLanguage",
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects \
in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Placeholder->True,
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[0.890623, 0.864698, 0.384756],
  TagBoxOptions->{Editable->False,
  Selectable->False,
  StripWrapperBoxes->False}],

Cell[StyleData["Placeholder", "Presentation"]],

Cell[StyleData["Placeholder", "Condensed"]],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PrimaryPlaceholder"],
  StyleMenuListing->None,
  DrawHighlighted->True,
  FontSlant->"Italic",
  Background->RGBColor[0.912505, 0.891798, 0.507774],
  TagBoxOptions->{Editable->False,
  Selectable->False,
  StripWrapperBoxes->False}],

Cell[StyleData["PrimaryPlaceholder", "Presentation"]],

Cell[StyleData["PrimaryPlaceholder", "Condensed"]],

Cell[StyleData["PrimaryPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  Hyphenation->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  InputAutoReplacements->{},
  AllowInlineCells->False,
  Hyphenation->False,
  StyleMenuListing->None,
  FontFamily->"Monaco"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Monaco",
  FontSize->9],

Cell[StyleData["StandardForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic Styles", "Section"],

Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],

Cell[StyleData["UnmatchedBracket"],
  StyleMenuListing->None,
  FontColor->RGBColor[0.760006, 0.330007, 0.8]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->"RulerBar",
WindowSize->{593, 708},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`_mooh/=<`Tj0fL5N`?P0080004/0B`000000]P2:001
0000I00000000`<30?l00BL?00400@00000000000000060<01T1T000000<2000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 37, 0, 61, "Subtitle"],
Cell[1779, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1997, 61, 42, 0, 50, "Section"],
Cell[2042, 63, 140, 3, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2185, 68, 146, 3, 70, 36, 0, "StyleData", "All", "Presentation"],
Cell[2334, 73, 141, 3, 70, 33, 0, "StyleData", "All", "Condensed"],
Cell[2478, 78, 186, 4, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2701, 87, 35, 0, 30, "Section"],
Cell[2739, 89, 101, 3, 70, "Text"],
Cell[2843, 94, 426, 11, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3306, 110, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[3369, 114, 1067, 25, 112, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[4439, 141, 116, 3, 70, 40, 0, "StyleData", "Title", "Presentation"],
Cell[4558, 146, 87, 2, 70, 37, 0, "StyleData", "Title", "Condensed"],
Cell[4648, 150, 88, 2, 70, 36, 0, "StyleData", "Title", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4773, 157, 1035, 24, 64, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[5811, 183, 119, 3, 70, 43, 0, "StyleData", "Subtitle", "Presentation"],
Cell[5933, 188, 90, 2, 70, 40, 0, "StyleData", "Subtitle", "Condensed"],
Cell[6026, 192, 90, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6153, 199, 1037, 24, 56, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[7193, 225, 122, 3, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[7318, 230, 93, 2, 70, 43, 0, "StyleData", "Subsubtitle", "Condensed"],
Cell[7414, 234, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7544, 241, 1364, 38, 61, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[8911, 281, 166, 5, 70, 42, 0, "StyleData", "Section", "Presentation"],
Cell[9080, 288, 139, 4, 70, 39, 0, "StyleData", "Section", "Condensed"],
Cell[9222, 294, 138, 4, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9397, 303, 1097, 28, 61, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[10497, 333, 199, 6, 70, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[10699, 341, 172, 5, 70, 42, 0, "StyleData", "Subsection", "Condensed"],
Cell[10874, 348, 171, 5, 70, 41, 0, "StyleData", "Subsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11082, 358, 1050, 27, 61, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[12135, 387, 153, 4, 70, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[12291, 393, 126, 3, 70, 45, 0, "StyleData", "Subsubsection", \
"Condensed"],
Cell[12420, 398, 125, 3, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]],
Cell[12560, 404, 308, 10, 8, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12905, 419, 39, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[12969, 423, 887, 22, 70, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[13859, 447, 123, 3, 70, 39, 0, "StyleData", "Text", "Presentation"],
Cell[13985, 452, 117, 3, 70, 36, 0, "StyleData", "Text", "Condensed"],
Cell[14105, 457, 119, 3, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14261, 465, 328, 10, 70, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[14592, 477, 126, 3, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[14721, 482, 122, 3, 70, 41, 0, "StyleData", "SmallText", "Condensed"],
Cell[14846, 487, 124, 3, 70, 40, 0, "StyleData", "SmallText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15019, 496, 42, 0, 30, "Section"],
Cell[15064, 498, 364, 6, 62, "Text"],

Cell[CellGroupData[{
Cell[15453, 508, 829, 28, 39, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[16285, 538, 145, 4, 54, 40, 0, "StyleData", "Input", "Presentation"],
Cell[16433, 544, 111, 3, 35, 37, 0, "StyleData", "Input", "Condensed"],
Cell[16547, 549, 153, 4, 37, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],
Cell[16715, 556, 485, 14, 38, 28, 0, "StyleData", "InputOnly", "All",
  CounterIncrements->"Input",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[17225, 574, 528, 16, 39, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[17756, 592, 107, 2, 45, 41, 0, "StyleData", "Output", "Presentation"],
Cell[17866, 596, 80, 1, 32, 38, 0, "StyleData", "Output", "Condensed"],
Cell[17949, 599, 71, 1, 37, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18057, 605, 521, 15, 35, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[18581, 622, 139, 3, 70, 42, 0, "StyleData", "Message", "Presentation"],
Cell[18723, 627, 113, 2, 70, 39, 0, "StyleData", "Message", "Condensed"],
Cell[18839, 631, 138, 3, 70, 38, 0, "StyleData", "Message", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19014, 639, 502, 14, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[19519, 655, 137, 3, 70, 40, 0, "StyleData", "Print", "Presentation"],
Cell[19659, 660, 111, 2, 70, 37, 0, "StyleData", "Print", "Condensed"],
Cell[19773, 664, 109, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19919, 671, 506, 15, 35, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[20428, 688, 94, 1, 70, 43, 0, "StyleData", "Graphics", "Presentation"],
Cell[20525, 691, 113, 2, 70, 40, 0, "StyleData", "Graphics", "Condensed"],
Cell[20641, 695, 112, 2, 70, 39, 0, "StyleData", "Graphics", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20790, 702, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[20921, 708, 60, 1, 70, 44, 0, "StyleData", "CellLabel", "Presentation"],
Cell[20984, 711, 56, 1, 70, 41, 0, "StyleData", "CellLabel", "Condensed"],
Cell[21043, 714, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21222, 724, 36, 0, 50, "Section"],
Cell[21261, 726, 121, 3, 70, "Text"],
Cell[21385, 731, 92, 3, 70, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[21480, 736, 69, 2, 70, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[21552, 740, 70, 2, 70, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[21625, 744, 115, 4, 70, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[21743, 750, 116, 4, 70, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[21862, 756, 114, 4, 70, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[21979, 762, 116, 4, 70, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[22098, 768, 117, 4, 70, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[22218, 774, 118, 4, 70, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[22339, 780, 116, 4, 70, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[22458, 786, 118, 4, 70, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[22579, 792, 119, 4, 70, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[22701, 798, 120, 4, 70, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[22824, 804, 118, 4, 70, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[22945, 810, 120, 4, 70, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[23090, 818, 138, 5, 70, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[23231, 825, 149, 5, 70, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None],
Cell[23383, 832, 154, 5, 70, 43, 0, "StyleData", "SO10", "EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[23586, 843, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[23654, 847, 244, 6, 70, 32, 0, "StyleData", "InlineFormula", "All"],
Cell[23901, 855, 124, 3, 70, 48, 0, "StyleData", "InlineFormula", \
"Presentation"],
Cell[24028, 860, 118, 3, 70, 45, 0, "StyleData", "InlineFormula", \
"Condensed"],
Cell[24149, 865, 93, 2, 70, 44, 0, "StyleData", "InlineFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24279, 872, 370, 8, 70, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[24652, 882, 88, 2, 70, 49, 0, "StyleData", "DisplayFormula", \
"Presentation"],
Cell[24743, 886, 85, 2, 70, 46, 0, "StyleData", "DisplayFormula", \
"Condensed"],
Cell[24831, 890, 61, 1, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24929, 896, 202, 6, 70, 26, 0, "StyleData", "Program", "All"],
Cell[25134, 904, 118, 3, 70, 42, 0, "StyleData", "Program", "Presentation"],
Cell[25255, 909, 112, 3, 70, 39, 0, "StyleData", "Program", "Condensed"],
Cell[25370, 914, 86, 2, 70, 38, 0, "StyleData", "Program", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25505, 922, 35, 0, 30, "Section"],
Cell[25543, 924, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[25752, 932, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26057, 942, 60, 1, 70, 44, 0, "StyleData", "Hyperlink", "Presentation"],
Cell[26120, 945, 57, 1, 70, 41, 0, "StyleData", "Hyperlink", "Condensed"],
Cell[26180, 948, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[26318, 954, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[26447, 961, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[26766, 971, 63, 1, 70, 47, 0, "StyleData", "MainBookLink", \
"Presentation"],
Cell[26832, 974, 60, 1, 70, 44, 0, "StyleData", "MainBookLink", "Condensed"],
Cell[26895, 977, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27058, 985, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27398, 996, 61, 1, 70, 45, 0, "StyleData", "AddOnsLink", \
"Presentation"],
Cell[27462, 999, 58, 1, 70, 42, 0, "StyleData", "AddOnsLink", "Condensed"],
Cell[27523, 1002, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27684, 1010, 341, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28028, 1021, 63, 1, 70, 47, 0, "StyleData", "RefGuideLink", \
"Presentation"],
Cell[28094, 1024, 60, 1, 70, 44, 0, "StyleData", "RefGuideLink", \
"Condensed"],
Cell[28157, 1027, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28320, 1035, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28651, 1045, 69, 1, 70, 53, 0, "StyleData", "GettingStartedLink", \
"Presentation"],
Cell[28723, 1048, 66, 1, 70, 50, 0, "StyleData", "GettingStartedLink", \
"Condensed"],
Cell[28792, 1051, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28961, 1059, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29296, 1069, 71, 1, 70, 55, 0, "StyleData", "OtherInformationLink", \
"Presentation"],
Cell[29370, 1072, 68, 1, 70, 52, 0, "StyleData", "OtherInformationLink", \
"Condensed"],
Cell[29441, 1075, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29624, 1084, 49, 0, 30, "Section"],
Cell[29676, 1086, 199, 6, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[29878, 1094, 198, 6, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[30079, 1102, 127, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[30243, 1111, 33, 0, 30, "Section"],
Cell[30279, 1113, 121, 3, 70, "Text"],
Cell[30403, 1118, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30632, 1125, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30930, 1134, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31333, 1145, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31723, 1156, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[32161, 1170, 37, 0, 30, "Section"],
Cell[32201, 1172, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[32341, 1179, 238, 7, 70, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[32582, 1188, 46, 0, 70, 46, 0, "StyleData", "Placeholder", \
"Presentation"],
Cell[32631, 1190, 43, 0, 70, 43, 0, "StyleData", "Placeholder", "Condensed"],
Cell[32677, 1192, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32756, 1197, 250, 7, 70, 37, 0, "StyleData", "PrimaryPlaceholder", "All",
  
  StyleMenuListing->None],
Cell[33009, 1206, 53, 0, 70, 53, 0, "StyleData", "PrimaryPlaceholder", \
"Presentation"],
Cell[33065, 1208, 50, 0, 70, 50, 0, "StyleData", "PrimaryPlaceholder", \
"Condensed"],
Cell[33118, 1210, 49, 0, 70, 49, 0, "StyleData", "PrimaryPlaceholder", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33216, 1216, 36, 0, 30, "Section"],
Cell[33255, 1218, 305, 5, 70, "Text"],
Cell[33563, 1225, 336, 11, 70, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[33902, 1238, 156, 5, 70, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[34061, 1245, 165, 6, 70, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[34229, 1253, 292, 7, 70, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[34524, 1262, 363, 9, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[34890, 1273, 115, 3, 70, "Text"],
Cell[35008, 1278, 96, 3, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[35107, 1283, 104, 2, 70, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[35248, 1290, 35, 0, 30, "Section"],
Cell[35286, 1292, 330, 6, 70, "Text"],
Cell[35619, 1300, 109, 2, 70, 35, 0, "StyleData", "UnmatchedBracket", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

