(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1124229,      50501]*)
(*NotebookOutlinePosition[   1125307,      50535]*)
(*  CellTagsIndexPosition[   1125263,      50531]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["nck (white et al. 2001)", "Title",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]],

Cell[TextData[{
  "the raw ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " drawings ",
  StyleBox["sans",
    FontSlant->"Italic"],
  " labelling - look in white et al. (2001) for the finished article"
}], "Text"],

Cell["plotfun.nb needs to have been run before anything in here...", \
"SmallText"],

Cell[CellGroupData[{

Cell["PT projection", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[" als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}, {10, 790}, {12, 880}, {14, 968}, 
  {16, 1054}, {18, 1139}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Invariants data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\

(*------------------------------*)
(*  st ctd g chl ky  *) 

i1={14.61, 603.6}//Reverse;

(*------------------------------*)
(*  bi st g chl ky  *) 

i2={11.61, 642.3}//Reverse;

(*------------------------------*)
(*  bi st ctd g chl  *) 

i3={4.04, 536.8}//Reverse;

(*------------------------------*)
(*  bi cd g opx liq ksp sill  *) 

i4={8.93, 886.0}//Reverse;

(*------------------------------*)
(*  bi cd g opx liq ksp H2O  *) 

i5={1.64, 752.2}//Reverse;

(*------------------------------*)
(*  bi cd g sp ksp sill H2O  *) 

i6={3.27, 729.4}//Reverse;

(*------------------------------*)
(*  bi cd g liq ksp sill H2O  *) 

i7={3.04, 723.5}//Reverse;

(*------------------------------*)
(*  bi cd g sp liq ksp H2O [opx mu sill] *) 

i101={2.95, 724.9}//Reverse;

(*------------------------------*)
(*  cd g opx sp liq ksp sill [bi mu H2O] *) 

i102={6.93, 1045.9}//Reverse;

(*------------------------------*)
(*  bi cd g sp liq ksp sill [opx H20 mu] *) 

i103={3.23, 726.6}//Reverse;

(*------------------------------*)
(*  bi cd g sp liq sill H2O [opx ksp mu] *) 

i104={3.21, 725.0}//Reverse;

(*------------------------------*)
(*  bi cd g opx liq sill H2O [mu ksp sp] *) 

i10={10.63, 845.7}//Reverse;

(*------------------------------*)
(*  bi cd sp liq ksp sill H2O [opx g mu] *) 

i105={3.10, 723.1}//Reverse;

(*------------------------------*)
(*  bi g sp liq ksp sill H2O [opx cd mu] *) 

i106={3.18, 722.5}//Reverse;

(*------------------------------*)
(*  bi cd mu liq ksp sill H2O [opx g sp] *) 

i107={5.30, 714.5}//Reverse;

(*------------------------------*)
(*  bi g mu liq ksp sill H2O [opx cd sp] *) 

i108={4.98, 714.6}//Reverse;

(*------------------------------*)
(*  chl cd g opx ky H2O  *) 

i8={8.85, 710.3}//Reverse;

(*------------------------------*)
(*  chl cd st g ky H2O  *) 

i9={7.47, 673.7}//Reverse;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["subsystem uni end data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[TextData[{
  StyleBox["\ne5={15.80, 576.0}//Reverse;",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["e10={3.80, 600.8}//Reverse;",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["e12={1.51, 484.1}//Reverse;\ne13={1.30, 493.0}//Reverse;\n\
e15={3.47, 528.0}//Reverse;\ne16={5.05, 597.9}//Reverse;",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["e18={3.48, 528.2}//Reverse;",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["e19={4.05, 535.0}//Reverse;",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Als/reaction x-over data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\

ksu2={7.55, 678.2}//Reverse;
kau6={3.61, 488.2}//Reverse;
ksu9={5.74, 594.8}//Reverse;
sau13={3.15, 549.2}//Reverse;
sau16={3.08, 554.1}//Reverse;

(*------------------------------*)
(*  bi g mu liq ky sill H2O  *) 

ksu146={9.59, 771.6}//Reverse;
(*------------------------------*)
(*  bi g mu liq ksp ky sill  *) 

ksu147={10.57, 815.8}//Reverse;
(*------------------------------*)
(*  bi g opx liq ky sill H2O  *) 

ksu149={11.33, 850.0}//Reverse;
(*------------------------------*)
(*  bi g opx liq ksp ky sill  *) 

ksu106={12.93, 920.7}//Reverse;

(*------------------------------*)
(*  cd g opx ky sill H2O  *) 

ksu151={10.12, 795.6}//Reverse;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["subsolidus univariant data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\

(*------------------------------*)
(*  bi g chl ky  *) 

u1={{11.00, 638.2},
{11.25, 639.9},
{11.50, 641.6},
{11.75, 643.3},
{12.00, 644.9},
{12.25, 646.5},
{12.50, 648.1},
{12.75, 649.7},
{13.00, 651.2},
{13.25, 652.8},
{13.50, 654.3},
{13.75, 655.8},
{14.00, 657.3},
{14.25, 658.7},
{14.50, 660.2},
{14.75, 661.6},
{15.00, 663.0},
{15.25, 664.4},
{15.50, 665.8},
{15.75, 667.2},
{16.00, 668.5}};
(*------------------------------*)
(*  bi st g ky  *) 

u2={{6.00, 685.5},
{6.20, 684.8},
{6.40, 684.0},
{6.60, 683.2},
{6.80, 682.3},
{7.00, 681.3},
{7.20, 680.2},
{7.40, 679.1},
{7.60, 677.9},
{7.80, 676.6},
{8.00, 675.3},
{8.20, 673.9},
{8.40, 672.5},
{8.60, 671.0},
{8.80, 669.4},
{9.00, 667.8},
{9.20, 666.1},
{9.40, 664.4},
{9.60, 662.6},
{9.80, 660.8},
{10.00, 659.0},
{10.20, 657.0},
{10.40, 655.1},
{10.60, 653.1},
{10.80, 651.0},
{11.00, 648.9},
{11.20, 646.8},
{11.40, 644.6},
{11.60, 642.4},
{11.80, 640.1},
{12.00, 637.8}};
(*------------------------------*)
(*  st g chl ky  *) 

u3={{11.00, 648.5},
{11.20, 646.5},
{11.40, 644.5},
{11.60, 642.4},
{11.80, 640.2},
{12.00, 638.0},
{12.20, 635.7},
{12.40, 633.4},
{12.60, 631.0},
{12.80, 628.6},
{13.00, 626.0},
{13.20, 623.5},
{13.40, 620.9},
{13.60, 618.2},
{13.80, 615.4},
{14.00, 612.6},
{14.20, 609.8},
{14.40, 606.8},
{14.60, 603.8},
{14.80, 600.8},
{15.00, 597.7}};
(*------------------------------*)
(*  ctd g chl ky  *) 

u4={{14.00, 602.8},
{14.20, 603.1},
{14.40, 603.4},
{14.60, 603.6},
{14.80, 603.8},
{15.00, 604.1},
{15.20, 604.3},
{15.40, 604.5},
{15.60, 604.7},
{15.80, 604.8},
{16.00, 605.0},
{16.20, 605.2},
{16.40, 605.3}};
(*------------------------------*)
(*  st ctd g ky  *) 

u5={{14.00, 613.0},
{14.15, 610.9},
{14.30, 608.7},
{14.45, 606.4},
{14.60, 603.9},
{14.75, 601.2},
{14.90, 598.4},
{15.05, 595.4},
{15.20, 592.1},
{15.35, 588.6},
{15.50, 584.8},
{15.65, 580.6},
{15.80, 576.0}};
(*------------------------------*)
(*  st ctd chl ky  *) 

u6={{2.00, 461.0},
{2.40, 468.2},
{2.80, 475.0},
{3.20, 481.6},
{3.60, 487.9},
{4.00, 494.1},
{4.40, 500.0},
{4.80, 505.7},
{5.20, 511.2},
{5.60, 516.6},
{6.00, 521.8},
{6.40, 526.8},
{6.80, 531.6},
{7.20, 536.3},
{7.60, 540.8},
{8.00, 545.2},
{8.40, 549.5},
{8.80, 553.7},
{9.20, 557.7},
{9.60, 561.7},
{10.00, 565.5},
{10.40, 569.3},
{10.80, 572.9},
{11.20, 576.5},
{11.60, 580.0},
{12.00, 583.4},
{12.40, 586.7},
{12.80, 589.9},
{13.20, 593.1},
{13.60, 596.1},
{14.00, 599.1},
{14.40, 602.1},
{14.80, 604.9},
{15.00, 606.3}};
(*------------------------------*)
(*  st ctd g chl  *) 

u7={{4.00, 536.4},
{4.25, 538.9},
{4.50, 541.3},
{4.75, 543.6},
{5.00, 545.9},
{5.25, 548.0},
{5.50, 550.2},
{5.75, 552.2},
{6.00, 554.2},
{6.25, 556.2},
{6.50, 558.1},
{6.75, 559.9},
{7.00, 561.7},
{7.25, 563.5},
{7.50, 565.2},
{7.75, 566.9},
{8.00, 568.6},
{8.25, 570.2},
{8.50, 571.7},
{8.75, 573.3},
{9.00, 574.8},
{9.25, 576.3},
{9.50, 577.8},
{9.75, 579.2},
{10.00, 580.6},
{10.25, 582.0},
{10.50, 583.4},
{10.75, 584.7},
{11.00, 586.1},
{11.25, 587.4},
{11.50, 588.7},
{11.75, 590.0},
{12.00, 591.2},
{12.25, 592.5}};
(*------------------------------*)
(*  bi st g chl  *) 

u8={{4.00, 535.6},
{4.50, 549.3},
{4.75, 555.3},
{5.00, 560.9},
{5.25, 566.1},
{5.50, 570.9},
{5.75, 575.4},
{6.00, 579.6},
{6.25, 583.5},
{6.50, 587.3},
{6.75, 590.8},
{7.00, 594.2},
{7.25, 597.4},
{7.50, 600.6},
{7.75, 603.6},
{8.00, 606.5},
{8.25, 609.3},
{8.50, 612.0},
{8.75, 614.7},
{9.00, 617.3},
{9.25, 619.9},
{9.50, 622.4},
{9.75, 624.9},
{10.00, 627.3},
{10.25, 629.7},
{10.50, 632.1},
{10.75, 634.5},
{11.00, 636.8},
{11.25, 639.1},
{11.50, 641.4},
{11.75, 643.6},
{12.00, 645.9}};
(*------------------------------*)
(*  bi st chl ky  *) 

u9={{5.00, 586.9},
{5.20, 589.2},
{5.40, 591.4},
{5.60, 593.5},
{5.80, 595.7},
{6.00, 597.7},
{6.20, 599.7},
{6.40, 601.7},
{6.60, 603.7},
{6.80, 605.5},
{7.00, 607.4},
{7.20, 609.2},
{7.40, 611.0},
{7.60, 612.8},
{7.80, 614.5},
{8.00, 616.2},
{8.20, 617.8},
{8.40, 619.4},
{8.60, 621.0},
{8.80, 622.6},
{9.00, 624.2},
{9.20, 625.7},
{9.40, 627.2},
{9.60, 628.6},
{9.80, 630.1},
{10.00, 631.5},
{10.20, 632.9},
{10.40, 634.3},
{10.60, 635.7},
{10.80, 637.0},
{11.00, 638.4},
{11.20, 639.7},
{11.40, 641.0},
{11.60, 642.3},
{11.80, 643.6},
{12.00, 644.8}};
(*------------------------------*)
(*  bi st g sill  *) 

u10={{3.80, 600.8},
{3.90, 603.0},
{4.00, 605.1},
{4.10, 607.3},
{4.20, 609.5},
{4.30, 611.6},
{4.40, 613.7},
{4.50, 615.9},
{4.60, 618.0},
{4.70, 620.1},
{4.80, 622.2},
{4.90, 624.3},
{5.00, 626.4},
{5.10, 628.5},
{5.20, 630.6},
{5.30, 632.7},
{5.40, 634.7},
{5.50, 636.8},
{5.60, 638.9},
{5.70, 640.9},
{5.80, 643.0},
{5.90, 645.0},
{6.00, 647.1},
{6.10, 649.1},
{6.20, 651.1},
{6.30, 653.2},
{6.40, 655.2},
{6.50, 657.2},
{6.60, 659.2},
{6.70, 661.3},
{6.80, 663.3},
{6.90, 665.3},
{7.00, 667.3},
{7.10, 669.3},
{7.20, 671.3},
{7.30, 673.3},
{7.40, 675.3},
{7.50, 677.3},
{7.60, 679.3},
{7.70, 681.3},
{7.80, 683.3},
{7.90, 685.3},
{8.00, 687.3}};
(*------------------------------*)
(*  st ctd chl and  *) 

u12={{1.60, 484.5},
{1.70, 484.8},
{1.80, 485.2},
{1.90, 485.5},
{2.00, 485.8},
{2.10, 486.0},
{2.20, 486.3},
{2.30, 486.5},
{2.40, 486.7},
{2.50, 486.9},
{2.60, 487.0},
{2.70, 487.2},
{2.80, 487.3},
{2.90, 487.4},
{3.00, 487.5},
{3.10, 487.6},
{3.20, 487.7},
{3.30, 487.8},
{3.40, 487.9},
{3.50, 488.0},
{3.60, 488.1},
{3.70, 488.3},
{3.80, 488.4},
{3.90, 488.5},
{4.00, 488.6}};
(*------------------------------*)
(*  bi st chl and  *) 

u13={{1.40, 496.5},
{1.50, 500.0},
{1.60, 503.5},
{1.70, 506.9},
{1.80, 510.2},
{1.90, 513.5},
{2.00, 516.7},
{2.10, 519.9},
{2.20, 523.0},
{2.30, 526.0},
{2.40, 529.0},
{2.50, 531.9},
{2.60, 534.7},
{2.70, 537.5},
{2.80, 540.2},
{2.90, 542.9},
{3.00, 545.5},
{3.10, 548.0},
{3.20, 550.5},
{3.30, 552.9},
{3.40, 555.3},
{3.50, 557.6},
{3.60, 559.9},
{3.70, 562.1},
{3.80, 564.3},
{3.90, 566.4},
{4.00, 568.5}};
(*------------------------------*)
(*  bi st chl sill  *) 

u14={{2.40, 532.4},
{2.50, 534.8},
{2.60, 537.1},
{2.70, 539.4},
{2.80, 541.7},
{2.90, 543.9},
{3.00, 546.1},
{3.10, 548.3},
{3.20, 550.4},
{3.30, 552.4},
{3.40, 554.5},
{3.50, 556.5},
{3.60, 558.5},
{3.70, 560.4},
{3.80, 562.4},
{3.90, 564.2},
{4.00, 566.1},
{4.10, 567.9},
{4.20, 569.7},
{4.30, 571.5},
{4.40, 573.3},
{4.50, 575.0},
{4.60, 576.7},
{4.70, 578.4},
{4.80, 580.1},
{4.90, 581.7},
{5.00, 583.4},
{5.10, 585.0},
{5.20, 586.6},
{5.30, 588.2},
{5.40, 589.7},
{5.50, 591.3},
{5.60, 592.8},
{5.70, 594.4},
{5.80, 595.9},
{5.90, 597.4},
{6.00, 598.9}};
(*------------------------------*)
(*  bi st ctd chl  *) 

u15={{3.60, 530.1},
{3.65, 530.9},
{3.70, 531.6},
{3.75, 532.4},
{3.80, 533.2},
{3.85, 533.9},
{3.90, 534.7},
{3.95, 535.4},
{4.00, 536.2},
{4.01, 536.3},
{4.02, 536.5},
{4.03, 536.6},
{4.04, 536.8},
{4.05, 536.9},
{4.06, 537.1},
{4.07, 537.2},
{4.08, 537.4},
{4.09, 537.5},
{4.10, 537.7}};

(*------------------------------*)
(*  bi cd chl sill  *) 

u16={{2.00, 529.1},
{2.25, 535.3},
{2.50, 541.2},
{2.75, 546.9},
{3.00, 552.5},
{3.25, 557.9},
{3.50, 563.3},
{3.75, 568.7},
{4.00, 574.2},
{4.25, 579.8},
{4.50, 585.4},
{4.75, 591.1},
{5.00, 596.7}};
(*------------------------------*)
(*  bi cd chl and  *) 

u17={{0.11, 429.5},
{0.21, 454.6},
{0.31, 468.8},
{0.41, 478.0},
{0.51, 484.1},
{0.61, 488.6},
{0.71, 492.4},
{0.81, 495.8},
{0.91, 499.1},
{1.00, 501.9},
{1.25, 509.3},
{1.50, 516.2},
{1.75, 522.8},
{2.00, 529.1},
{2.25, 535.2},
{2.50, 541.1},
{2.75, 546.9},
{3.00, 552.5},
{3.25, 557.9}};
(*------------------------------*)
(*  bi st ctd g  *) 

u18={{3.48, 528.2},
{3.50, 528.5},
{3.52, 528.8},
{3.54, 529.1},
{3.56, 529.5},
{3.58, 529.8},
{3.60, 530.1},
{3.62, 530.4},
{3.64, 530.7},
{3.66, 531.0},
{3.68, 531.3},
{3.70, 531.6},
{3.72, 531.9},
{3.74, 532.3},
{3.76, 532.6},
{3.78, 532.9},
{3.80, 533.2},
{3.82, 533.5},
{3.84, 533.8},
{3.86, 534.1},
{3.88, 534.4},
{3.90, 534.7},
{3.92, 535.0},
{3.94, 535.3},
{3.96, 535.6},
{3.98, 535.9},
{4.00, 536.2},
{4.02, 536.5},
{4.04, 536.8},
{4.06, 537.1},
{4.08, 537.4},
{4.10, 537.7}};
(*------------------------------*)
(*  bi ctd g chl  *) 

u19={{4.05, 535.0},
{4.049, 535.2},
{4.048, 535.4},
{4.047, 535.6},
{4.046, 535.8},
{4.045, 536.0},
{4.044, 536.2},
{4.043, 536.4},
{4.042, 536.6},
{4.041, 536.8},
{4.04, 537.0}};

(*------------------------------*)
(*  st ctd g chl ky  *) 

u20={{3.50, 204.5},
{4.00, 225.1},
{4.50, 245.7},
{5.00, 266.2},
{5.50, 286.7},
{6.00, 307.0},
{6.50, 327.1},
{7.00, 347.0},
{7.50, 366.6},
{8.00, 385.9},
{8.50, 404.8},
{9.00, 423.4},
{9.50, 441.6},
{10.00, 459.4},
{10.50, 476.8},
{11.00, 493.8},
{11.50, 510.3},
{12.00, 526.5},
{12.50, 542.1},
{13.00, 557.4},
{13.50, 572.2},
{14.00, 586.5},
{14.50, 600.5},
{15.00, 614.0},
{15.50, 627.1},
{16.00, 639.8},
{16.50, 652.1},
{17.00, 664.0}};

(*------------------------------*)
(*  bi st g chl mu ky  *) 

u21={{5.00, 244.1},
{5.50, 271.0},
{6.00, 298.5},
{6.50, 326.6},
{7.00, 355.2},
{7.50, 384.3},
{8.00, 413.9},
{8.50, 443.9},
{9.00, 474.4},
{9.50, 505.4},
{10.00, 536.8},
{10.50, 568.9},
{11.00, 601.6},
{11.50, 635.1},
{12.00, 669.5},
{12.50, 705.0},
{13.00, 741.9},
{13.50, 780.5},
{14.00, 821.4},
{14.50, 865.3},
{15.00, 912.9},
{15.50, 962.9}};

(*------------------------------*)
(*  bi st g chl ky H2O  *) 

u22={{4.00, 676.5},
{4.25, 677.3},
{4.50, 677.9},
{4.75, 678.3},
{5.00, 678.6},
{5.25, 678.7},
{5.50, 678.7},
{5.75, 678.5},
{6.00, 678.1},
{6.25, 677.7},
{6.50, 677.1},
{6.75, 676.4},
{7.00, 675.6},
{7.25, 674.6},
{7.50, 673.6},
{7.75, 672.4},
{8.00, 671.2},
{8.25, 669.8},
{8.50, 668.3},
{8.75, 666.8},
{9.00, 665.1},
{9.25, 663.4},
{9.50, 661.5},
{9.75, 659.6},
{10.00, 657.6},
{10.25, 655.4},
{10.50, 653.2},
{10.75, 650.9},
{11.00, 648.5},
{11.25, 646.0},
{11.50, 643.4},
{11.75, 640.8},
{12.00, 638.0}};

(*------------------------------*)
(*  bi st ctd g chl mu  *) 

u23={{2.00, 224.6},
{2.20, 245.1},
{2.40, 237.7},
{2.60, 243.9},
{2.80, 249.8},
{3.00, 255.5},
{3.20, 261.0},
{3.40, 266.3},
{3.60, 271.4},
{3.80, 276.3},
{4.00, 281.0},
{4.20, 285.5},
{4.40, 289.9},
{4.60, 294.1},
{4.80, 298.2},
{5.00, 302.2}};

(*------------------------------*)
(*  bi st ctd g chl H2O  *) 

u24={{3.80, 534.3},
{3.90, 535.4},
{4.00, 536.4}};

(*------------------------------*)
(*  chl g opx ky H2O  *) 

u25 = {{8.00, 705.6},
{8.25, 707.1},
{8.50, 708.5},
{8.75, 709.8},
{9.00, 711.0},
{9.25, 712.1},
{9.50, 713.2},
{9.75, 714.2},
{10.00, 715.1},
{10.25, 716.0},
{10.50, 716.8},
{10.75, 717.5},
{11.00, 718.2},
{11.25, 718.8},
{11.50, 719.3},
{11.75, 719.8},
{12.00, 720.2},
{12.25, 720.6},
{12.50, 720.9},
{12.75, 721.2},
{13.00, 721.5},
{13.25, 721.6},
{13.50, 721.8},
{13.75, 721.9},
{14.00, 721.9},
{14.25, 721.9},
{14.50, 721.9},
{14.75, 721.8},
{15.00, 721.7},
{15.25, 721.6},
{15.50, 721.4},
{15.75, 721.2},
{16.00, 720.9},
{16.25, 720.6},
{16.50, 720.3},
{16.75, 719.9},
{17.00, 719.5}};

(*------------------------------*)
(*  chl cd opx ky H2O  *) 

u26={{8.00, 689.3},
{8.20, 694.3},
{8.40, 699.2},
{8.60, 704.2},
{8.80, 709.1},
{9.00, 714.1},
{9.20, 719.0},
{9.40, 723.9},
{9.60, 728.8}};


(*------------------------------*)
(*  chl cd g opx H2O  *) 

u27={{0.50, 523.4},
{0.75, 537.3},
{1.00, 547.1},
{1.25, 555.6},
{1.50, 563.2},
{1.75, 570.4},
{2.00, 577.2},
{2.25, 583.7},
{2.50, 589.9},
{2.75, 596.0},
{3.00, 601.8},
{3.25, 607.5},
{3.50, 613.0},
{3.75, 618.4},
{4.00, 623.7},
{4.25, 628.9},
{4.50, 633.9},
{4.75, 638.9},
{5.00, 643.9},
{5.25, 648.7},
{5.50, 653.5},
{5.75, 658.2},
{6.00, 662.8},
{6.25, 667.4},
{6.50, 671.9},
{6.75, 676.3},
{7.00, 680.7},
{7.25, 684.9},
{7.50, 689.1},
{7.75, 693.2},
{8.00, 697.3},
{8.25, 701.2},
{8.50, 705.1},
{8.75, 708.8},
{9.00, 712.5}};

(*------------------------------*)
(*  chl cd g ky H2O  *) 

u28={{6.00, 634.9},
{6.20, 640.1},
{6.40, 645.3},
{6.60, 650.6},
{6.80, 655.8},
{7.00, 661.1},
{7.20, 666.4},
{7.40, 671.7},
{7.60, 677.0},
{7.80, 682.3},
{8.00, 687.7},
{8.20, 693.0},
{8.40, 698.3},
{8.60, 703.7},
{8.80, 709.0},
{9.00, 714.4}};

(*------------------------------*)
(*  chl cd g opx ky  *) 

u29={{4.00, 504.4},
{4.25, 517.1},
{4.50, 529.3},
{4.75, 541.3},
{5.00, 552.9},
{5.25, 564.3},
{5.50, 575.4},
{5.75, 586.3},
{6.00, 597.0},
{6.25, 607.6},
{6.50, 618.0},
{6.75, 628.2},
{7.00, 638.3},
{7.25, 648.3},
{7.50, 658.2},
{7.75, 668.0},
{8.00, 677.8},
{8.25, 687.5},
{8.50, 697.1},
{8.75, 706.6},
{9.00, 716.1}};

(*------------------------------*)
(*  cd st g sill H2O  *) 

u30={{2.00, 560.1},
{2.25, 566.2},
{2.50, 572.1},
{2.75, 577.9},
{3.00, 583.6},
{3.25, 589.2},
{3.50, 594.7},
{3.75, 600.1},
{4.00, 605.5},
{4.25, 610.8},
{4.50, 616.1},
{4.75, 621.3},
{5.00, 626.4},
{5.25, 631.5},
{5.50, 636.6},
{5.75, 641.6},
{6.00, 646.5},
{6.25, 651.4},
{6.50, 656.2},
{6.75, 661.0},
{7.00, 665.7},
{7.25, 670.3},
{7.47, 673.7}};

(*------------------------------*)
(*  chl cd st g H2O  *) 

u31={{2.00, 545.8},
{2.25, 552.0},
{2.50, 558.1},
{2.75, 564.1},
{3.00, 570.0},
{3.25, 576.0},
{3.50, 581.9},
{3.75, 587.7},
{4.00, 593.6},
{4.25, 599.4},
{4.50, 605.2},
{4.75, 611.1},
{5.00, 616.9},
{5.25, 622.6},
{5.50, 628.4},
{5.75, 634.2},
{6.00, 640.0},
{6.25, 645.7},
{6.50, 651.4},
{6.75, 657.2},
{7.00, 662.9},
{7.25, 668.6},
{7.47, 673.7}};

(*------------------------------*)
(*  chl cd st sill H2O  *) 

u32={{2.00, 537.2},
{2.25, 543.6},
{2.50, 550.0},
{2.75, 556.3},
{3.00, 562.6},
{3.25, 568.9},
{3.50, 575.2},
{3.75, 581.4},
{4.00, 587.6},
{4.25, 593.9},
{4.50, 600.1},
{4.75, 606.3},
{5.00, 612.4},
{5.25, 618.6},
{5.50, 624.8},
{5.75, 631.0},
{6.00, 637.1},
{6.25, 643.3},
{6.50, 649.5},
{6.75, 655.6},
{7.00, 661.8},
{7.25, 667.9},
{7.47, 673.7}};

(*------------------------------*)
(*  chl cd st g sill  *) 

u33={{4.25, 503.9},
{4.50, 530.3},
{4.75, 549.6},
{5.00, 565.6},
{5.25, 579.6},
{5.50, 592.3},
{5.75, 604.0},
{6.00, 615.0},
{6.25, 625.5},
{6.50, 635.5},
{6.75, 645.2},
{7.00, 654.7},
{7.25, 663.8},
{7.47, 673.7}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["supersolidus univariant data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\

(*------------------------------*)
(*  bi cd g opx ksp sill  *) 

u101={{2.00, 376.1},
{2.25, 400.3},
{2.50, 424.5},
{2.75, 448.5},
{3.00, 472.3},
{3.25, 495.8},
{3.50, 518.9},
{3.75, 541.6},
{4.00, 563.7},
{4.25, 585.3},
{4.50, 606.2},
{4.75, 626.4},
{5.00, 646.0},
{5.25, 665.0},
{5.50, 683.4},
{5.75, 701.1},
{6.00, 718.4},
{6.25, 735.2},
{6.50, 751.5},
{6.75, 767.2},
{7.00, 782.4},
{7.25, 797.1},
{7.50, 811.4},
{7.75, 825.3},
{8.00, 838.8},
{8.25, 851.9},
{8.50, 864.7},
{8.75, 877.2},
{9.00, 889.4}};

(*------------------------------*)
(*  bi cd g liq ksp sill  *) 

u102={{2.75, 719.3},
{3.00, 723.0},
{3.25, 726.9},
{3.50, 731.1},
{3.75, 735.6},
{4.00, 740.4},
{4.25, 745.5},
{4.50, 751.0},
{4.75, 756.9},
{5.00, 763.1},
{5.25, 769.6},
{5.50, 776.5},
{5.75, 783.6},
{6.00, 791.0},
{6.25, 798.6},
{6.50, 806.4},
{6.75, 814.3},
{7.00, 822.3},
{7.25, 830.4},
{7.50, 838.6},
{7.75, 846.9},
{8.00, 855.1},
{8.25, 863.4},
{8.50, 871.7},
{8.75, 880.0},
{9.00, 888.3}};

(*------------------------------*)
(*  bi cd g opx liq ksp  *) 

u103={{1.00, 738.7},
{1.25, 744.0},
{1.50, 749.3},
{1.75, 754.6},
{2.00, 759.9},
{2.25, 765.2},
{2.50, 770.4},
{2.75, 775.7},
{3.00, 780.9},
{3.25, 786.1},
{3.50, 791.3},
{3.75, 796.4},
{4.00, 801.5},
{4.25, 806.5},
{4.50, 811.4},
{4.75, 816.3},
{5.00, 821.2},
{5.25, 825.9},
{5.50, 830.6},
{5.75, 835.3},
{6.00, 839.9},
{6.25, 844.4},
{6.50, 848.8},
{6.75, 853.1},
{7.00, 857.3},
{7.25, 861.4},
{7.50, 865.4},
{7.75, 869.3},
{8.00, 873.1},
{8.25, 876.7},
{8.50, 880.2},
{8.75, 883.6},
{9.00, 886.9}};

(*------------------------------*)
(*  cd g opx liq ksp sill  *) 

u104={{8.98, 880.0},
{8.79, 900.0},
{8.55, 920.0},
{8.28, 940.0},
{7.98, 960.0},
{7.68, 980.0},
{7.39, 1000.0},
{7.14, 1020.0},
{6.97, 1040.0},
{6.93, 1045.0},
{6.91, 1050.0}};

(*------------------------------*)
(*  bi cd opx liq ksp sill  *) 

u105={{8.50, 875.2},
{8.60, 877.8},
{8.70, 880.3},
{8.80, 882.8},
{8.90, 885.2},
{9.00, 887.6},
{9.10, 890.0},
{9.20, 892.3},
{9.30, 894.5},
{9.40, 896.6},
{9.50, 898.6},
{9.60, 900.6},
{9.70, 902.4},
{9.80, 904.1}};

(*------------------------------*)
(*  bi g opx liq ksp sill  *) 

u106={{8.00, 875.4},
{8.25, 878.3},
{8.50, 881.2},
{8.75, 884.0},
{9.00, 886.7},
{9.25, 889.4},
{9.50, 891.9},
{9.75, 894.4},
{10.00, 896.8},
{10.25, 899.2},
{10.50, 901.5},
{10.75, 903.7},
{11.00, 905.9},
{11.25, 908.0},
{11.50, 910.0},
{11.75, 912.0},
{12.00, 914.0},
{12.25, 915.8},
{12.50, 917.7},
{12.75, 919.5},
{13.00, 921.2},
{13.25, 922.9},
{13.50, 924.5},
{13.75, 926.1},
{14.00, 927.7},
{14.25, 929.2},
{14.50, 930.7},
{14.75, 932.1},
{15.00, 933.5},
{15.25, 934.9},
{15.50, 936.3},
{15.75, 937.7},
{16.00, 939.0},
{16.25, 940.3},
{16.50, 941.7},
{16.75, 943.0}};

(*------------------------------*)
(*  bi cd g opx liq sill  *) 

u107={{6.74, 830.0},
{7.22, 850.0},
{7.88, 870.0}};

(*------------------------------*)
(*  bi cd opx liq ksp H2O  *) 

u108={{0.90, 803.4},
{1.00, 792.9},
{1.10, 784.1},
{1.20, 776.6},
{1.30, 770.0},
{1.40, 764.2},
{1.50, 759.0},
{1.60, 754.1}};

(*------------------------------*)
(*  cd g opx liq ksp H2O  *) 

u109={{1.00, 779.3},
{1.10, 773.5},
{1.20, 768.5},
{1.30, 764.0},
{1.40, 760.0},
{1.50, 756.5},
{1.60, 753.3},
{1.70, 750.4},
{1.80, 747.8},
{1.90, 745.5},
{2.00, 743.3}};

(*------------------------------*)
(*  bi cd g opx ksp H2O  *) 

u110={{0.20, 601.0},
{0.30, 628.6},
{0.40, 648.5},
{0.50, 664.2},
{0.60, 677.0},
{0.70, 688.0},
{0.80, 697.5},
{0.90, 706.0},
{1.00, 713.7},
{1.10, 720.8},
{1.20, 727.4},
{1.30, 733.5},
{1.40, 739.4},
{1.50, 744.9},
{1.60, 750.2},
{1.70, 755.3},
{1.80, 760.3},
{1.90, 765.1},
{2.00, 769.7}};

(*------------------------------*)
(*  bi cd g liq ksp H2O  *) 

u111={{1.40, 759.2},
{1.60, 753.2},
{1.80, 747.9},
{2.00, 743.1},
{2.20, 738.7},
{2.40, 734.7},
{2.60, 731.0},
{2.80, 727.5},
{3.00, 724.1},
{3.20, 720.9}};

(*------------------------------*)
(*  bi g opx liq ksp H2O  *) 

u112={{1.40, 757.7},
{1.50, 755.4},
{1.60, 753.0},
{1.70, 750.8},
{1.80, 748.7}};

(*------------------------------*)
(*  bi cd g opx liq H2O  *) 

u113={{1.00, 741.4},
{1.50, 750.2},
{2.00, 757.0},
{2.50, 763.2},
{3.00, 769.2},
{3.50, 775.0},
{4.00, 780.8},
{4.50, 786.5},
{5.00, 792.1},
{5.50, 797.6},
{6.00, 803.0},
{6.50, 808.4},
{7.00, 813.6},
{7.50, 818.7},
{8.00, 823.6},
{8.50, 828.3},
{9.00, 832.8},
{9.50, 837.0},
{10.00, 841.0},
{10.50, 844.7},
{11.00, 848.2}};

(*------------------------------*)
(*  cd g sp liq ksp H2O  *) 

u114={{2.20, 736.5},
{2.40, 732.8},
{2.60, 729.6},
{2.80, 726.8},
{3.00, 724.4}};

(*------------------------------*)
(*  bi cd g sp ksp H2O  *) 

u115={{2.00, 707.0},
{2.20, 711.5},
{2.40, 715.5},
{2.60, 719.2},
{2.80, 722.5},
{3.00, 725.6}};

(*------------------------------*)
(*  bi cd sp liq ksp H2O  *) 

u116={{2.60, 730.0},
{2.80, 727.0},
{3.00, 724.3},
{3.20, 721.8},
{3.40, 719.6},
{3.60, 717.5},
{3.80, 715.6},
{4.00, 713.8},
{4.20, 712.1},
{4.40, 710.6},
{4.60, 709.1},
{4.80, 707.6},
{5.00, 706.3}};

(*------------------------------*)
(*  bi g sp liq ksp H2O  *) 

u117={{2.60, 729.4},
{2.80, 726.7},
{3.00, 724.4},
{3.20, 722.3},
{3.40, 720.4},
{3.60, 718.6},
{3.80, 717.1},
{4.00, 715.6},
{4.20, 714.3},
{4.40, 713.0},
{4.60, 711.9},
{4.80, 710.8},
{5.00, 709.8}};

(*------------------------------*)
(*  bi cd g sp liq H2O  *) 

u118={{2.60, 724.7},
{2.70, 724.8},
{2.80, 724.8},
{2.90, 724.9},
{3.00, 724.9},
{3.10, 725.0},
{3.20, 725.0},
{3.30, 725.1},
{3.40, 725.1},
{3.50, 725.2},
{3.60, 725.2},
{3.70, 725.3},
{3.80, 725.3},
{3.90, 725.4},
{4.00, 725.4}};

(*------------------------------*)
(*  bi cd g sp liq ksp  *) 

u119={{2.60, 722.7},
{2.70, 723.4},
{2.80, 724.0},
{2.90, 724.6},
{3.00, 725.2},
{3.10, 725.8},
{3.20, 726.4},
{3.30, 727.0},
{3.40, 727.6},
{3.50, 728.2},
{3.60, 728.8},
{3.70, 729.4},
{3.80, 729.9},
{3.90, 730.5},
{4.00, 731.1}};




(*------------------------------*)
(*  g opx sp sill  *) 

u120={{0.50, 493.9},
{1.00, 548.8},
{1.50, 598.2},
{2.00, 642.1},
{2.50, 684.8},
{3.00, 727.2},
{3.50, 769.3},
{4.00, 811.1},
{4.50, 852.5},
{5.00, 893.5},
{5.50, 933.9},
{6.00, 973.8},
{6.50, 1013.0},
{7.00, 1051.4},
{7.50, 1089.0},
{8.00, 1125.6},
{8.50, 1161.4},
{9.00, 1196.2},
{9.50, 1230.0},
{10.00, 1262.8}};

(*------------------------------*)
(*  cd opx sp liq ksp sill  *) 

u121={{6.91, 1040.0},
{6.93, 1045.0},
{6.94, 1050.0},
{6.96, 1055.0},
{6.98, 1060.0},
{7.01, 1065.0},
{7.03, 1070.0},
{7.06, 1075.0},
{7.09, 1080.0},
{7.12, 1085.0}};

(*------------------------------*)
(*  cd g opx sp liq ksp  *) 

u122={{1.75, 906.2},
{2.00, 916.4},
{2.25, 926.0},
{2.50, 934.9},
{2.75, 943.4},
{3.00, 951.3},
{3.25, 958.8},
{3.50, 965.9},
{3.75, 972.6},
{4.00, 979.1},
{4.25, 985.3},
{4.50, 991.3},
{4.75, 997.2},
{5.00, 1003.0},
{5.25, 1008.7},
{5.50, 1014.4},
{5.75, 1020.0},
{6.00, 1025.6},
{6.25, 1031.2},
{6.50, 1036.7},
{6.75, 1042.1},
{7.00, 1047.5}};

(*------------------------------*)
(*  cd g sp liq ksp sill  *) 

u123={{2.25, 652.4},
{2.50, 671.5},
{2.75, 690.5},
{3.00, 709.3},
{3.25, 728.1},
{3.50, 746.8},
{3.75, 765.5},
{4.00, 784.3},
{4.25, 803.2},
{4.50, 822.3},
{4.75, 841.7},
{5.00, 861.5},
{5.25, 881.8},
{5.50, 902.8},
{5.75, 924.7},
{6.00, 947.8},
{6.25, 972.4},
{6.50, 998.5},
{6.75, 1026.0},
{7.00, 1053.9},
{7.25, 1080.7}};

(*------------------------------*)
(*  bi cd sp liq sill H2O  *) 

u124={{2.00, 703.8},
{2.20, 707.4},
{2.40, 711.0},
{2.60, 714.5},
{2.80, 718.0},
{3.00, 721.4},
{3.20, 724.9}};

(*------------------------------*)
(*  bi cd g sp sill H2O  *) 

u125={{1.00, 547.0},
{1.25, 570.5},
{1.50, 592.7},
{1.75, 613.7},
{2.00, 633.3},
{2.25, 652.6},
{2.50, 671.8},
{2.75, 690.7},
{3.00, 709.4},
{3.25, 728.0},
{3.50, 746.4},
{3.75, 764.7},
{4.00, 782.9},
{4.25, 801.0},
{4.50, 818.9},
{4.75, 836.8},
{5.00, 854.5},
{5.25, 872.2},
{5.50, 889.9},
{5.75, 907.5},
{6.00, 925.0},
{6.25, 942.5},
{6.50, 960.0},
{6.75, 977.5},
{7.00, 994.9},
{7.25, 1012.3},
{7.50, 1029.8},
{7.75, 1047.2},
{8.00, 1064.7},
{8.22, 1080.0},
{8.51, 1100.0},
{8.79, 1120.0},
{9.08, 1140.0}};

(*------------------------------*)
(*  bi g sp liq sill H2O  *) 

u126={{3.15, 719.6},
{3.20, 724.1},
{3.25, 728.7},
{3.30, 733.4}};

(*------------------------------*)
(*  bi cd g liq sill H2O  *) 

u127={{3.00, 723.2},
{3.25, 725.4},
{3.50, 727.7},
{3.75, 730.2},
{4.00, 732.9},
{4.25, 735.7},
{4.50, 738.8},
{4.75, 742.1},
{5.00, 745.5},
{5.25, 749.1},
{5.50, 752.9},
{5.75, 756.9},
{6.00, 760.9},
{6.25, 765.1},
{6.50, 769.4},
{6.75, 773.8},
{7.00, 778.2},
{7.25, 782.7},
{7.50, 787.3},
{7.75, 791.8},
{8.00, 796.4},
{8.25, 801.0},
{8.50, 805.7},
{8.75, 810.3},
{9.00, 815.0},
{9.25, 819.6},
{9.50, 824.3},
{9.75, 829.0},
{10.00, 833.7},
{10.25, 838.4},
{10.50, 843.2},
{10.75, 847.9},
{11.00, 852.7},
{11.25, 857.5},
{11.50, 862.3},
{11.75, 867.2},
{12.00, 872.1}};

(*------------------------------*)
(*  bi cd g sp liq sill  *) 

u128={{3.15, 720.0},
{3.21, 725.0},
{3.27, 730.0},
{3.33, 735.0},
{3.38, 740.0}};

(*------------------------------*)
(*  cd sp liq ksp sill H2O  *) 

u129={{2.20, 733.7},
{2.40, 730.7},
{2.60, 728.1},
{2.80, 725.9},
{3.00, 723.9}};

(*------------------------------*)
(*  bi cd sp ksp sill H2O  *) 

u130={{1.80, 673.6},
{2.00, 681.6},
{2.20, 689.5},
{2.40, 697.1},
{2.60, 704.7},
{2.80, 712.1},
{3.00, 719.5}};

(*------------------------------*)
(*  bi sp liq ksp sill H2O  *) 

u131={{2.00, 736.6},
{2.20, 733.1},
{2.40, 730.2},
{2.60, 727.8},
{2.80, 725.6},
{3.00, 723.9},
{3.20, 722.3},
{3.40, 721.0}};


(*------------------------------*)
(*  bi cd liq ksp sill H2O  *) 

u132={{3.00, 723.8},
{3.20, 722.4},
{3.40, 721.1},
{3.60, 720.0},
{3.80, 719.0},
{4.00, 718.2},
{4.20, 717.5},
{4.40, 716.8},
{4.60, 716.2},
{4.80, 715.7},
{5.00, 715.2},
{5.20, 714.7},
{5.40, 714.3},
{5.60, 713.8},
{5.80, 713.4}};

(*------------------------------*)
(*  bi cd sp liq ksp sill  *) 

u133={{3.00, 720.6},
{3.05, 721.9},
{3.10, 723.2},
{3.15, 724.5},
{3.20, 725.8},
{3.25, 727.1},
{3.30, 728.4}};


(*------------------------------*)
(*  bi g sp ksp sill H2O  *) 

u134={{3.04, 711.3},
{3.05, 712.1},
{3.06, 712.9},
{3.07, 713.6},
{3.08, 714.4},
{3.09, 715.2},
{3.10, 716.0},
{3.11, 716.8},
{3.12, 717.6},
{3.13, 718.4},
{3.14, 719.2},
{3.15, 720.0},
{3.16, 720.8},
{3.17, 721.5},
{3.18, 722.3},
{3.19, 723.1},
{3.20, 723.9}};

(*------------------------------*)
(*  bi g liq ksp sill H2O  *) 

u135={{3.00, 723.8},
{3.20, 722.3},
{3.40, 721.0},
{3.60, 719.9},
{3.80, 718.8},
{4.00, 717.9},
{4.20, 717.1},
{4.40, 716.4},
{4.60, 715.7},
{4.80, 715.1},
{5.00, 714.5},
{5.20, 714.0},
{5.40, 713.6},
{5.60, 713.1},
{5.80, 712.7},
{6.00, 712.4}};


(*------------------------------*)
(*  g sp liq ksp sill H2O  *) 

u136={{3.16, 722.4},
{3.17, 722.4},
{3.18, 722.4},
{3.19, 722.501}};

(*------------------------------*)
(*  bi g sp liq ksp sill  *) 

u137={{3.15, 720.0},
{3.21, 725.0},
{3.27, 730.0},
{3.33, 735.0},
{3.38, 740.0}};

(*------------------------------*)
(*  bi mu liq ksp sill H2O  *) 

u138={{5.00, 714.6},
{5.30, 714.5},
{5.40, 714.3}};

(*------------------------------*)
(*  bi cd mu ksp sill H2O  *) 

u139={{1.00, 582.3},
{1.25, 593.2},
{1.50, 603.0},
{1.75, 612.1},
{2.00, 620.8},
{2.25, 629.2},
{2.50, 637.3},
{2.75, 645.1},
{3.00, 652.7},
{3.25, 660.1},
{3.50, 667.3},
{3.75, 674.3},
{4.00, 681.1},
{4.25, 687.8},
{4.50, 694.3},
{4.75, 700.7},
{5.00, 707.0},
{5.25, 713.2},
{5.50, 719.3}};

(*------------------------------*)
(*  bi cd mu liq ksp H2O  *) 

u140={{5.00, 714.4},
{5.20, 714.5},
{5.40, 714.5},
{5.60, 714.4}};

(*------------------------------*)
(*  cd mu liq ksp sill H2O  *) 

u141={{5.00, 714.4},
{5.05, 714.5},
{5.10, 714.6},
{5.15, 714.6},
{5.20, 714.6},
{5.25, 714.5},
{5.30, 714.5},
{5.35, 714.4},
{5.40, 714.3},
{5.45, 714.2}};

(*------------------------------*)
(*  bi cd mu liq sill H2O  *) 

u142={{5.00, 710.9},
{5.25, 713.9},
{5.50, 716.7},
{5.75, 719.6},
{6.00, 722.3},
{6.25, 725.0}};

(*------------------------------*)
(*  bi cd mu liq ksp sill  *) 

u143={{5.00, 709.4},
{5.10, 711.1},
{5.20, 712.7},
{5.30, 714.4},
{5.40, 716.1},
{5.50, 717.7},
{5.60, 719.4},
{5.70, 721.0},
{5.80, 722.6},
{5.90, 724.3},
{6.00, 725.9},
{6.10, 727.4}};

(*------------------------------*)
(*  bi g mu liq ksp H2O  *) 

u144={{4.00, 713.1},
{4.25, 713.7},
{4.50, 714.1},
{4.75, 714.4},
{5.00, 714.6},
{5.25, 714.7},
{5.50, 714.7},
{5.75, 714.7},
{6.00, 714.6},
{6.25, 714.6},
{6.50, 714.5},
{6.75, 714.5},
{7.00, 714.4}};

(*------------------------------*)
(*  g mu liq ksp sill H2O  *) 

u145={{4.90, 714.1},
{4.92, 714.2},
{4.93, 714.2},
{4.94, 714.3},
{4.95, 714.3},
{4.96, 714.4},
{4.97, 714.5},
{4.98, 714.6}};

(*------------------------------*)
(*  bi g mu liq sill H2O  *) 

u146={{5.00, 714.9},
{5.25, 718.1},
{5.50, 721.4},
{5.75, 724.5},
{6.00, 727.7},
{6.25, 730.8},
{6.50, 733.9},
{6.75, 737.0},
{7.00, 740.1},
{7.25, 743.2},
{7.50, 746.2},
{7.75, 749.3},
{8.00, 752.3},
{8.25, 755.4},
{8.50, 758.4},
{8.75, 761.4},
{9.00, 764.5},
{9.25, 767.5},
{9.50, 770.5},
{9.75, 773.5},
{10.00, 776.5},
{10.25, 779.5},
{10.50, 782.5},
{10.75, 785.5},
{11.00, 788.5}};

(*------------------------------*)
(*  bi g mu liq ksp sill  *) 

u147={{5.00, 715.0},
{5.25, 719.8},
{5.50, 724.6},
{5.75, 729.4},
{6.00, 734.1},
{6.25, 738.8},
{6.50, 743.5},
{6.75, 748.1},
{7.00, 752.7},
{7.25, 757.3},
{7.50, 761.8},
{7.75, 766.3},
{8.00, 770.8},
{8.25, 775.3},
{8.50, 779.7},
{8.75, 784.2},
{9.00, 788.6},
{9.25, 793.0},
{9.50, 797.3},
{9.75, 801.7},
{10.00, 806.0},
{10.25, 810.3},
{10.50, 814.6},
{10.75, 818.9},
{11.00, 823.1},
{11.25, 827.4},
{11.50, 831.6},
{11.75, 835.8},
{12.00, 840.0}};

(*------------------------------*)
(*  bi g mu ksp sill H2O  *) 

u148={{4.80, 709.6},
{4.90, 712.4},
{5.00, 715.2}};

(*------------------------------*)
(*  bi g opx liq sill H2O  *) 

u149={{10.00, 841.6},
{10.20, 842.9},
{10.40, 844.2},
{10.60, 845.5},
{10.80, 846.7},
{11.00, 847.9},
{11.20, 849.2},
{11.40, 850.4},
{11.60, 851.6},
{11.80, 852.8},
{12.00, 854.0}};

(*------------------------------*)
(*  bi cd opx liq sill H2O  *) 

u150={{10.00, 835.9},
{10.20, 839.1},
{10.40, 842.2},
{10.60, 845.2},
{10.80, 848.1},
{11.00, 850.9},
{11.20, 853.6}};

(*------------------------------*)
(*  cd g opx sill H2O  *) 

u151={{9.07, 700.0},
{9.30, 720.0},
{9.52, 740.0},
{9.74, 760.0},
{9.96, 780.0},
{10.17, 800.0},
{10.37, 820.0},
{10.58, 840.0},
{10.77, 860.0},
{10.97, 880.0},
{11.16, 900.0},
{11.35, 920.0},
{11.53, 940.0},
{11.72, 960.0},
{11.90, 980.0},
{12.07, 1000.0},
{12.25, 1020.0},
{12.42, 1040.0},
{12.59, 1060.0},
{12.75, 1080.0},
{12.92, 1100.0},
{13.08, 1120.0},
{13.24, 1140.0}};


(*------------------------------*)
(*  bi cd g sp ksp sill  *) 

u152={{0.20, 461.2},
{0.40, 484.3},
{0.60, 506.1},
{0.80, 527.0},
{1.00, 546.9},
{1.20, 565.9},
{1.40, 584.1},
{1.60, 601.6},
{1.80, 618.0},
{2.00, 633.7},
{2.20, 649.3},
{2.40, 664.6},
{2.60, 679.8},
{2.80, 694.8},
{3.00, 709.7},
{3.20, 724.4},
{3.40, 738.9},
{3.60, 753.2},
{3.80, 767.4},
{4.00, 781.4}};

(*------------------------------*)
(*  bi g mu liq ky H2O  *) 

u153={{8.00, 756.0},
{8.50, 760.9},
{9.00, 765.8},
{9.50, 770.7},
{10.00, 775.6},
{10.50, 780.4},
{11.00, 785.2},
{11.50, 790.1},
{12.00, 794.9},
{12.50, 799.8},
{13.00, 804.6},
{13.50, 809.5},
{14.00, 814.4},
{14.50, 819.3},
{15.00, 824.3},
{15.50, 829.3},
{16.00, 834.3},
{16.50, 839.3},
{17.00, 844.4}};

(*------------------------------*)
(*  bi g mu liq ksp ky  *) 

u154={{8.00, 778.8},
{8.50, 786.1},
{9.00, 793.4},
{9.50, 800.6},
{10.00, 807.7},
{10.50, 814.8},
{11.00, 821.8},
{11.50, 828.8},
{12.00, 835.7},
{12.50, 842.6},
{13.00, 849.4},
{13.50, 856.2},
{14.00, 862.9},
{14.50, 869.7},
{15.00, 876.3},
{15.50, 883.0},
{16.00, 889.6},
{16.50, 896.1},
{17.00, 902.7}};

(*------------------------------*)
(*  bi g opx liq ky H2O  *) 

u155={{10.00, 842.0},
{10.50, 845.1},
{11.00, 848.1},
{11.50, 850.9},
{12.00, 853.7},
{12.50, 856.6},
{13.00, 859.4},
{13.50, 862.1},
{14.00, 864.8},
{14.50, 867.5},
{15.00, 870.1},
{15.50, 872.6},
{16.00, 875.1},
{16.50, 877.5},
{17.00, 879.9}};

(*------------------------------*)
(*  bi g opx liq ksp ky  *) 

u156={{10.00, 898.8},
{10.50, 903.1},
{11.00, 907.1},
{11.50, 910.9},
{12.00, 914.5},
{12.50, 917.9},
{13.00, 921.2},
{13.50, 924.2},
{14.00, 927.2},
{14.50, 929.9},
{15.00, 932.6},
{15.50, 935.2},
{16.00, 937.9},
{16.50, 940.4},
{17.00, 942.9}};

(*------------------------------*)
(*  cd g opx ky H2O  *) 

u157={{7.90, 650.0},
{8.06, 660.0},
{8.22, 670.0},
{8.38, 680.0},
{8.53, 690.0},
{8.69, 700.0},
{8.84, 710.0},
{8.99, 720.0},
{9.15, 730.0},
{9.30, 740.0},
{9.45, 750.0},
{9.60, 760.0},
{9.75, 770.0},
{9.89, 780.0},
{10.04, 790.0},
{10.18, 800.0},
{10.33, 810.0},
{10.47, 820.0},
{10.62, 830.0},
{10.76, 840.0},
{10.90, 850.0}};










\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["CKFMASH Invariants data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\


(*------------------------------*)
(*  liq bi cd g opx ky H2O  *) 

cki10={10.82, 819.2}//Reverse;

(*------------------------------*)
(*  liq bi cd g opx ksp sill  *) 

cki4={9.13, 881.3}//Reverse;
(*------------------------------*)
(*  liq cd g opx sp ksp sill  *) 

(*------------------------------*)
(*  liq bi cd g opx ksp H2O  *) 

cki5={1.45, 750.8}//Reverse;
(*------------------------------*)
(*  liq bi cd g sp ksp H2O  *) 

cki101={4.04, 703.3}//Reverse;
(*------------------------------*)
(*  liq bi cd sp ksp sill H2O  *) 

cki105={2.92, 716.0}//Reverse;
(*------------------------------*)
(*  liq bi g sp ksp sill H2O  *) 

cki106={2.46, 721.0}//Reverse;
(*------------------------------*)
(*  liq bi cd g sp sill H2O  *) 

cki104={2.28, 705.5}//Reverse;
(*------------------------------*)
(*  liq bi cd g sp ksp sill  *) 

cki103={2.17, 697.5}//Reverse;
(*------------------------------*)
(*  liq bi g mu ksp sill H2O  *) 

cki108={4.72, 705.4}//Reverse;
(*------------------------------*)
(*  liq bi cd mu ksp sill H2O  *) 

cki107={4.94, 704.9}//Reverse;

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH Invariants data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\

(*------------------------------*)
(*  liq ksp pl bi cd g sp sill q H2O  *) 

ncki1={2.33, 686.9}//Reverse;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH univariants data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 0.500008]],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi cd g opx sill q  *) 

ncku1 = {{8.50, 841.5},
{8.55, 844.8},
{8.60, 848.2},
{8.65, 851.5},
{8.70, 854.8},
{8.75, 858.0},
{8.80, 861.2},
{8.85, 864.3},
{8.90, 867.4},
{8.95, 870.5},
{9.00, 873.6},
{9.05, 876.7},
{9.10, 879.8}};

(*------------------------------*)
(*  liq pl bi cd g opx ky q H2O  *) 

ncku2 = {{8.09, 660.0},
{8.19, 665.0},
{8.29, 670.0},
{8.39, 675.0},
{8.49, 680.0},
{8.58, 685.0},
{8.68, 690.0},
{8.77, 695.0},
{8.86, 700.0},
{8.95, 705.0},
{9.04, 710.0},
{9.13, 715.0},
{9.22, 720.0},
{9.30, 725.0},
{9.39, 730.0},
{9.47, 735.0},
{9.56, 740.0},
{9.64, 745.0},
{9.72, 750.0},
{9.80, 755.0},
{9.88, 760.0},
{9.96, 765.0},
{10.04, 770.0},
{10.12, 775.0},
{10.20, 780.0},
{10.28, 785.0},
{10.36, 790.0},
{10.44, 795.0},
{10.52, 800.0},
{10.60, 805.0},
{10.67, 810.0},
{10.75, 815.0}};


(*------------------------------*)
(*  liq ksp pl bi cd g opx q H2O  *) 

ncku3 = {{1.36, 740.1},
{1.37, 741.3},
{1.38, 742.5},
{1.39, 743.6},
{1.40, 744.8},
{1.41, 745.9},
{1.42, 747.0},
{1.43, 748.1},
{1.44, 749.3},
{1.45, 750.4}};

(*------------------------------*)
(*  liq ksp pl bi cd g sp q H2O  *) 

ncku4 = {{1.90, 677.6},
{2.00, 680.3},
{2.10, 682.6},
{2.20, 684.6},
{2.30, 686.4},
{2.40, 688.1},
{2.50, 689.6},
{2.60, 690.9},
{2.70, 692.2},
{2.80, 693.4},
{2.90, 694.5},
{3.00, 695.6},
{3.10, 696.5},
{3.20, 697.4},
{3.30, 698.3},
{3.40, 699.1},
{3.50, 699.8},
{3.60, 700.6},
{3.70, 701.2},
{3.80, 701.9},
{3.90, 702.5},
{4.00, 703.0}};

(*------------------------------*)
(*  liq ksp pl bi cd sp sill q H2O  *) 

ncku5={{2.05, 668.5},
{2.10, 672.9},
{2.15, 676.4},
{2.20, 679.6},
{2.25, 682.5},
{2.30, 685.4},
{2.35, 688.1},
{2.40, 690.8},
{2.45, 693.4},
{2.50, 695.9},
{2.55, 698.4},
{2.60, 700.9},
{2.65, 703.3},
{2.70, 705.8},
{2.75, 708.2},
{2.80, 710.5},
{2.85, 712.9},
{2.90, 715.2}};

(*------------------------------*)
(*  liq ksp pl bi g sp sill q H2O  *) 

ncku6 = {{2.35, 693.6},
{2.40, 706.5},
{2.45, 718.1}};

(*------------------------------*)
(*  liq pl bi cd g sp sill q H2O  *) 

ncku7 = {{2.30, 698.7},
{2.35, 676.2}};

(*------------------------------*)
(*  liq ksp pl bi cd g sp sill q  *) 

ncku8 = {{2.20, 695.6},
{2.25, 692.0},
{2.30, 688.6},
{2.35, 685.5},
{2.40, 682.8},
{2.45, 680.6},
{2.50, 679.3}};

(*------------------------------*)
(*  liq ksp pl bi g mu sill q H2O  *) 

ncku9 = {{3.95, 677.9},
{4.00, 679.8},
{4.05, 681.6},
{4.10, 683.5},
{4.15, 685.3},
{4.20, 687.1},
{4.25, 688.9},
{4.30, 690.7},
{4.35, 692.4},
{4.40, 694.2},
{4.45, 696.0},
{4.50, 697.7},
{4.55, 699.5},
{4.60, 701.2},
{4.65, 702.9},
{4.70, 704.6}};

(*------------------------------*)
(*  liq ksp pl bi cd g sill q H2O  *) 

ncku10 = {{2.10, 679.6},
{2.20, 682.9},
{2.30, 686.1},
{2.40, 689.0},
{2.50, 691.8},
{2.60, 694.5},
{2.70, 697.2},
{2.80, 699.8},
{2.90, 702.4},
{3.00, 704.9},
{3.10, 707.5},
{3.20, 710.0},
{3.30, 712.6}};

(*------------------------------*)
(*  ksp pl bi cd g sp sill q H2O  *) 

ncku11 = {{2.00, 680.5},
{2.10, 682.8},
{2.20, 684.8},
{2.30, 686.5},
{2.40, 687.8},
{2.50, 688.7},
{2.60, 689.3},
{2.70, 690.1}};

(*------------------------------*)
(*  liq ksp bi cd g sp sill q H2O  *) 

ncku12 = {{2.10, 673.0},
{2.20, 679.7},
{2.30, 685.4},
{2.40, 690.7},
{2.50, 695.7},
{2.60, 700.6},
{2.70, 705.3},
{2.80, 709.9},
{2.90, 714.4},
{3.00, 718.9}};

(*------------------------------*)
(*  liq ksp pl cd g sp sill q H2O  *) 

ncku13 = {{2.30, 662.0},
{2.32, 684.7},
{2.34, 690.3},
{2.36, 695.5},
{2.38, 700.4},
{2.40, 705.1},
{2.42, 709.7},
{2.44, 714.1},
{2.46, 718.5}};

(*------------------------------*)
(*  liq ksp pl bi cd mu sill H2O  *) 

ncku14 = {{3.40, 647.8},
{3.50, 653.3},
{3.60, 657.8},
{3.70, 662.0},
{3.80, 665.9},
{3.90, 669.7},
{4.00, 673.4},
{4.10, 677.0},
{4.20, 680.5},
{4.30, 683.9},
{4.40, 687.3},
{4.50, 690.7},
{4.60, 694.0},
{4.70, 697.3},
{4.80, 700.5},
{4.90, 703.7}};


\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1500; hlow = 0; hhigh = 1;\n   xycols = \
{2,1};\n   \n \n \t\tas1 = makeline[ka, trp, ll];\n \t\tas2 = makeline[sk, \
trp, ur];\n \t\tas3 = makeline[as, trp, lr];\n  \tlu1 = makeline[u1, ur, i2]; \
    \n  \tlu2 = makeline[u2, i2, ksu2];   \n   lu3 = makeline[u3, i2, i1];    \
 \n   lu4 = makeline[u4, i1, ur];\t\t\t\t\t\n   lu5 = makeline[u5, i1, e5];\t\
\t\t\t\t\n   lu6 = makeline[u6, i1, kau6];\t\t\t\n   lu7 = makeline[u7, i1, \
i3];\t\t\t\t\t\n   lu8 = makeline[u8, i2, i3];\t\t\t\t\t\n   lu9 = \
makeline[u9, i2, ksu9];\t\t\t\n   lu10 = makeline[u10, ksu2, e10];\t\t\t\n   \
lu12 = makeline[u12, kau6, e12];\t\t\t\n   lu13 = makeline[u13, sau13, e13];\t\
\t\t\n   lu14 = makeline[u14, sau13, ksu9];\t\t\t\n   lu15 = makeline[u15, \
e15, i3];\t\t\t   \n   lu16 = makeline[u16, e16, sau16];\t\t\t  \n   lu17 = \
makeline[u17, ll, sau16];\t\t\t  \n   lu18 = makeline[u18, i3, e18];\t\t\t  \n\
   lu19 = makeline[u19, i3, e19];\n   lu20 = makeline[u20, i1, ll];\n   lu21 \
= makeline[u21, i2, ll];\n   lu22 = makeline[u22, i2, lr];\t\n   lu23 = \
makeline[u23, i3, ll];\t\n   lu24 = makeline[u24, i3, lr];\n   \n   lu25 = \
makeline[u25, i8, ur];\n   lu26 = makeline[u26, i8, ur];\n   lu27 = \
makeline[u27, i8, ll];\n   lu28 = makeline[u28, i8, i9];\n   lu29 = \
makeline[u29, i8, ll];\n   \n   lu30 = makeline[u30, i9, ll];\n   lu31 = \
makeline[u31, i9, ll];\n   lu32 = makeline[u32, i9, ll];\n   lu33 = \
makeline[u33, i9, ll];\n   \n   lu101 = makeline[u101, i4, ll];\n   lu102 = \
makeline[u102, i4, i103];\n   lu103 = makeline[u103, i4, i5];\n   lu104 = \
makeline[u104, i4, i102];\n   lu105 = makeline[u105, i4, ur];\n   lu106 = \
makeline[u106, i4, ksu106];\n   lu107 = makeline[u107, i4, i10];\n   \n   \
lu108 = makeline[u108, i5, lr];\n   lu109 = makeline[u109, i5, lr];\n   lu110 \
= makeline[u110, i5, ll];\n   lu111 = makeline[u111, i5, i101];\n   lu112 = \
makeline[u112, i5, ul];\n   lu113 = makeline[u113, i5, i10];\n  \n   lu114 = \
makeline[u114, i101, lr];\n   lu115 = makeline[u115, i101, ll];\n   lu116 = \
makeline[u116, i101, i105];\n   lu117 = makeline[u117, i101, i106];\n   lu118 \
= makeline[u118, i101, i104];\n   lu119 = makeline[u119, i101, i103];\n   \n\n\
   lu120 = makeline[u120, ll, i102];\n   lu121 = makeline[u121, ur, i102];\n  \
 lu122 = makeline[u122, ll, i102];\n   lu123 = makeline[u123, i103, i102];\n  \
 \n   lu124 = makeline[u124, i104, i105];\n   lu125 = makeline[u125, i104, \
ll];\n   lu125a = makeline[u125, i104, ur];\n   lu126 = makeline[u126, i104, \
i106];\n   lu127 = makeline[u127, i104, i10];\n   lu128 = makeline[u128, \
i104, i103];\n   \n   lu129 = makeline[u129, i105, lr];\n   lu130 = \
makeline[u130, i105, ll];\n   lu131 = makeline[u131, i105, i106];\n   lu132 = \
makeline[u132, i105, i107];\n   lu133 = makeline[u133, i105, i103];\n   \n   \
lu134 = makeline[u134, i106, ll];\n   lu135 = makeline[u135, i106, i108];\n   \
lu136 = makeline[u136, i106, ur];\n   lu137 = makeline[u137, i106, i103];\n   \
\n   lu138 = makeline[u138, i107, i108];\n   lu139 = makeline[u139, i107, \
ll];\n   lu140 = makeline[u140, i107, ul];\n   lu141 = makeline[u141, i107, \
ul];\n   lu142 = makeline[u142, i107, ur];\n   lu143 = makeline[u143, i107, \
ur];\n   \n   lu144 = makeline[u144, i108, ur];\n   lu145 = makeline[u145, \
i108, ur];\n   lu146 = makeline[u146, i108, ksu146];\n   lu147 = \
makeline[u147, i108, ksu147];\n   lu148 = makeline[u148, i108, ll];\n   \n   \
lu149 = makeline[u149, i10, ksu149];\n   lu150 = makeline[u150, i10, ur];\n   \
lu151 = makeline[u151, ksu151, ur];\n   \n   lu152 = makeline[u152, i103, \
ll];\n   \n   lu153 = makeline[u153, ksu146, ur];\n   lu154 = makeline[u154, \
ksu147, ur];\n   lu155 = makeline[u155, ksu149, ur];\n   lu156 = \
makeline[u156, ksu106, ur];\n   lu157 = makeline[u157, ksu151, ll];\n  \n   \n\
   lu201 = makeline[ncku1, cki4, ll];\n \t\tlu202 = makeline[ncku2, cki10, \
ll];\n \t\tlu203 = makeline[ncku3, cki5, ll];\n \t\tlu204 = makeline[ncku4, \
cki101, ncki1];\n \t\tlu205 = makeline[ncku5, cki105, ncki1];\n \t\tlu206 = \
makeline[ncku6, cki106, ncki1];\n \t\tlu207 = makeline[ncku7, cki104, ncki1];\
\n \t\tlu208 = makeline[ncku8, cki103, ncki1];\n \t\tlu209 = makeline[ncku9, \
cki108, ll];\n \t\tlu210 = makeline[ncku10, ncki1, ll];\n \t\tlu211 = \
makeline[ncku11, ncki1, ur];\n \t\tlu212 = makeline[ncku12, ncki1, ll];\n \t\t\
lu213 = makeline[ncku13, ncki1, ll];\n \t\tlu214 = makeline[ncku14, cki107, \
ll];\n   \n   \n   \n  \n   \t\t\t\t  \n   \n   \n   \n   \n   \n   \
Show[Graphics[\n          {GrayLevel[0],\n           AbsoluteThickness[0.3],\n\
           \n        \t\t\tdrawline[as1],\n           drawline[as2],\n        \
   drawline[as3],\n           drawline[lu1],\n           drawline[lu2],\n     \
      drawline[lu3],\n           drawline[lu4],    \n           \
drawline[lu5],\n           drawline[lu6],\n           drawline[lu7],\n        \
   drawline[lu8],\n         \t\tdrawline[lu9],\n          \tdrawline[lu10],\n \
         \tdrawline[lu12], \n           drawline[lu13], \n           \
drawline[lu14],\n           drawline[lu15],\n           drawline[lu16],\n     \
      drawline[lu17],\n           drawline[lu18],\n           \n           \
drawline[lu20],\n           drawline[lu21],\n           drawline[lu22],\n     \
      drawline[lu23],\n           drawline[lu24],\n           \n           \
drawline[lu25],\n           drawline[lu26],\n           drawline[lu27],\n     \
      drawline[lu28],\n           drawline[lu29],\n           \n           \
drawline[lu30],\n           drawline[lu31],\n           drawline[lu32],\n     \
      drawline[lu33],\n           ",
    FontWeight->"Plain"],
  StyleBox["\n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu101],\n           drawline[lu102],\n           \
drawline[lu103],\n           drawline[lu104],\n           drawline[lu105],\n  \
         drawline[lu106],\n           drawline[lu107],\n           \
drawline[lu108],\n           drawline[lu109],\n           drawline[lu110],\n  \
         drawline[lu111],\n           drawline[lu112],\n           \
drawline[lu113],\n           ",
    FontWeight->"Plain"],
  StyleBox["\n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[0.423529, 0.0941176, 0.690196]],
  StyleBox["drawline[lu114],\n           drawline[lu115],\n           \
drawline[lu116],\n           drawline[lu117],\n           drawline[lu118],\n  \
         drawline[lu119],",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n          ",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n           drawline[lu120],\n           drawline[lu121],\n      \
     drawline[lu122],\n           drawline[lu123],\n           ",
    FontWeight->"Plain"],
  StyleBox["\n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu124],\n           drawline[lu125],\n           \
drawline[lu125a],\n           drawline[lu126],\n           drawline[lu127],\n \
          drawline[lu128],\n          ",
    FontWeight->"Plain"],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->GrayLevel[1]],
  StyleBox["\n           drawline[lu129],\n           drawline[lu130],\n      \
     drawline[lu131],\n           drawline[lu132],\n           \
drawline[lu133],\n           \n           drawline[lu134],\n           \
drawline[lu135],\n           drawline[lu136],\n           drawline[lu137],\n  \
         \n           drawline[lu138],\n           drawline[lu139],\n         \
  drawline[lu140],\n           drawline[lu141],\n           drawline[lu142],\n\
           drawline[lu143],\n           ",
    FontWeight->"Plain"],
  StyleBox["\n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu144],\n           drawline[lu145],\n           \
drawline[lu146],\n           drawline[lu147],\n           drawline[lu148],\n  \
         drawline[lu149],\n           drawline[lu150],\n           \
drawline[lu151],\n           \n           drawline[lu152],\n           \
drawline[lu153],\n           drawline[lu154],\n           drawline[lu155],\n  \
         drawline[lu156],\n           drawline[lu157],\n           \n         \
  ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n          \tdrawline[lu201],\n          \tdrawline[lu202],\n    \
      \tdrawline[lu203],\n          \tdrawline[lu204],\n          \t\
drawline[lu205],\n          \tdrawline[lu206],\n          \tdrawline[lu207],\n\
          \tdrawline[lu208],\n          \tdrawline[lu209],\n          \t\
drawline[lu210],\n          \tdrawline[lu211],\n          \tdrawline[lu212],\n\
          \tdrawline[lu213],\n          \tdrawline[lu214],\n           \n     \
     \n           \n           \n           \n           outline}],\n         \
      \n         AspectRatio -> 1, Frame -> True,\n         PlotRange -> \
{{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 600; xhigh = 1000; ylow = 1; yhigh = 12;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.5 0.0025 -0.0909091 0.0909091 [
[(650)] .125 0 0 2 Msboxa
[(700)] .25 0 0 2 Msboxa
[(750)] .375 0 0 2 Msboxa
[(800)] .5 0 0 2 Msboxa
[(850)] .625 0 0 2 Msboxa
[(900)] .75 0 0 2 Msboxa
[(950)] .875 0 0 2 Msboxa
[(1000)] 1 0 0 2 Msboxa
[(2)] -0.0125 .09091 1 0 Msboxa
[(4)] -0.0125 .27273 1 0 Msboxa
[(6)] -0.0125 .45455 1 0 Msboxa
[(8)] -0.0125 .63636 1 0 Msboxa
[(10)] -0.0125 .81818 1 0 Msboxa
[(12)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.125 0 m
.125 .00625 L
s
P
[(650)] .125 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(700)] .25 0 0 2 Mshowa
p
.002 w
.375 0 m
.375 .00625 L
s
P
[(750)] .375 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(800)] .5 0 0 2 Mshowa
p
.002 w
.625 0 m
.625 .00625 L
s
P
[(850)] .625 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(900)] .75 0 0 2 Mshowa
p
.002 w
.875 0 m
.875 .00625 L
s
P
[(950)] .875 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1000)] 1 0 0 2 Mshowa
p
.001 w
.025 0 m
.025 .00375 L
s
P
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.075 0 m
.075 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.15 0 m
.15 .00375 L
s
P
p
.001 w
.175 0 m
.175 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.225 0 m
.225 .00375 L
s
P
p
.001 w
.275 0 m
.275 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.325 0 m
.325 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.425 0 m
.425 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.475 0 m
.475 .00375 L
s
P
p
.001 w
.525 0 m
.525 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.575 0 m
.575 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.65 0 m
.65 .00375 L
s
P
p
.001 w
.675 0 m
.675 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.725 0 m
.725 .00375 L
s
P
p
.001 w
.775 0 m
.775 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.825 0 m
.825 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.925 0 m
.925 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.975 0 m
.975 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .09091 m
.00625 .09091 L
s
P
[(2)] -0.0125 .09091 1 0 Mshowa
p
.002 w
0 .27273 m
.00625 .27273 L
s
P
[(4)] -0.0125 .27273 1 0 Mshowa
p
.002 w
0 .45455 m
.00625 .45455 L
s
P
[(6)] -0.0125 .45455 1 0 Mshowa
p
.002 w
0 .63636 m
.00625 .63636 L
s
P
[(8)] -0.0125 .63636 1 0 Mshowa
p
.002 w
0 .81818 m
.00625 .81818 L
s
P
[(10)] -0.0125 .81818 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(12)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .12727 m
.00375 .12727 L
s
P
p
.001 w
0 .16364 m
.00375 .16364 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23636 m
.00375 .23636 L
s
P
p
.001 w
0 .30909 m
.00375 .30909 L
s
P
p
.001 w
0 .34545 m
.00375 .34545 L
s
P
p
.001 w
0 .38182 m
.00375 .38182 L
s
P
p
.001 w
0 .41818 m
.00375 .41818 L
s
P
p
.001 w
0 .49091 m
.00375 .49091 L
s
P
p
.001 w
0 .52727 m
.00375 .52727 L
s
P
p
.001 w
0 .56364 m
.00375 .56364 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .67273 m
.00375 .67273 L
s
P
p
.001 w
0 .70909 m
.00375 .70909 L
s
P
p
.001 w
0 .74545 m
.00375 .74545 L
s
P
p
.001 w
0 .78182 m
.00375 .78182 L
s
P
p
.001 w
0 .85455 m
.00375 .85455 L
s
P
p
.001 w
0 .89091 m
.00375 .89091 L
s
P
p
.001 w
0 .92727 m
.00375 .92727 L
s
P
p
.001 w
0 .96364 m
.00375 .96364 L
s
P
p
.001 w
0 .05455 m
.00375 .05455 L
s
P
p
.001 w
0 .01818 m
.00375 .01818 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.125 .99375 m
.125 1 L
s
P
p
.002 w
.25 .99375 m
.25 1 L
s
P
p
.002 w
.375 .99375 m
.375 1 L
s
P
p
.002 w
.5 .99375 m
.5 1 L
s
P
p
.002 w
.625 .99375 m
.625 1 L
s
P
p
.002 w
.75 .99375 m
.75 1 L
s
P
p
.002 w
.875 .99375 m
.875 1 L
s
P
p
.001 w
.025 .99625 m
.025 1 L
s
P
p
.001 w
.05 .99625 m
.05 1 L
s
P
p
.001 w
.075 .99625 m
.075 1 L
s
P
p
.001 w
.1 .99625 m
.1 1 L
s
P
p
.001 w
.15 .99625 m
.15 1 L
s
P
p
.001 w
.175 .99625 m
.175 1 L
s
P
p
.001 w
.2 .99625 m
.2 1 L
s
P
p
.001 w
.225 .99625 m
.225 1 L
s
P
p
.001 w
.275 .99625 m
.275 1 L
s
P
p
.001 w
.3 .99625 m
.3 1 L
s
P
p
.001 w
.325 .99625 m
.325 1 L
s
P
p
.001 w
.35 .99625 m
.35 1 L
s
P
p
.001 w
.4 .99625 m
.4 1 L
s
P
p
.001 w
.425 .99625 m
.425 1 L
s
P
p
.001 w
.45 .99625 m
.45 1 L
s
P
p
.001 w
.475 .99625 m
.475 1 L
s
P
p
.001 w
.525 .99625 m
.525 1 L
s
P
p
.001 w
.55 .99625 m
.55 1 L
s
P
p
.001 w
.575 .99625 m
.575 1 L
s
P
p
.001 w
.6 .99625 m
.6 1 L
s
P
p
.001 w
.65 .99625 m
.65 1 L
s
P
p
.001 w
.675 .99625 m
.675 1 L
s
P
p
.001 w
.7 .99625 m
.7 1 L
s
P
p
.001 w
.725 .99625 m
.725 1 L
s
P
p
.001 w
.775 .99625 m
.775 1 L
s
P
p
.001 w
.8 .99625 m
.8 1 L
s
P
p
.001 w
.825 .99625 m
.825 1 L
s
P
p
.001 w
.85 .99625 m
.85 1 L
s
P
p
.001 w
.9 .99625 m
.9 1 L
s
P
p
.001 w
.925 .99625 m
.925 1 L
s
P
p
.001 w
.95 .99625 m
.95 1 L
s
P
p
.001 w
.975 .99625 m
.975 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .09091 m
1 .09091 L
s
P
p
.002 w
.99375 .27273 m
1 .27273 L
s
P
p
.002 w
.99375 .45455 m
1 .45455 L
s
P
p
.002 w
.99375 .63636 m
1 .63636 L
s
P
p
.002 w
.99375 .81818 m
1 .81818 L
s
P
p
.001 w
.99625 .12727 m
1 .12727 L
s
P
p
.001 w
.99625 .16364 m
1 .16364 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23636 m
1 .23636 L
s
P
p
.001 w
.99625 .30909 m
1 .30909 L
s
P
p
.001 w
.99625 .34545 m
1 .34545 L
s
P
p
.001 w
.99625 .38182 m
1 .38182 L
s
P
p
.001 w
.99625 .41818 m
1 .41818 L
s
P
p
.001 w
.99625 .49091 m
1 .49091 L
s
P
p
.001 w
.99625 .52727 m
1 .52727 L
s
P
p
.001 w
.99625 .56364 m
1 .56364 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .67273 m
1 .67273 L
s
P
p
.001 w
.99625 .70909 m
1 .70909 L
s
P
p
.001 w
.99625 .74545 m
1 .74545 L
s
P
p
.001 w
.99625 .78182 m
1 .78182 L
s
P
p
.001 w
.99625 .85455 m
1 .85455 L
s
P
p
.001 w
.99625 .89091 m
1 .89091 L
s
P
p
.001 w
.99625 .92727 m
1 .92727 L
s
P
p
.001 w
.99625 .96364 m
1 .96364 L
s
P
p
.001 w
.99625 .05455 m
1 .05455 L
s
P
p
.001 w
.99625 .01818 m
1 .01818 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.3 Mabswid
s
0 .44135 m
.02 .45698 L
.04 .47265 L
.06 .48834 L
.08 .50404 L
.1 .51976 L
.12 .5355 L
.14 .55125 L
.16 .56702 L
.18 .58281 L
.2 .59862 L
.22 .61443 L
.24 .63027 L
.26 .64613 L
.28 .66201 L
.3 .67791 L
.32 .69384 L
.34 .70979 L
.36 .72576 L
.38 .74178 L
.4 .75782 L
.42 .77389 L
.44 .78998 L
.46 .80609 L
.48 .8222 L
.5 .83829 L
.52 .85438 L
.54 .87049 L
.56 .88661 L
.58 .90274 L
.6 .91889 L
.62 .93506 L
.64 .95125 L
.66 .96747 L
.68 .98372 L
.7 1 L
.7 1 L
s
0 .12747 m
.02006 .11696 L
.04012 .10651 L
.06018 .09611 L
.08024 .08577 L
.1003 .07549 L
.12036 .06526 L
.14042 .05509 L
.16048 .04498 L
.18054 .03491 L
.2006 .0249 L
.22065 .01495 L
.24071 .00504 L
.25097 0 L
s
.10575 .96455 m
.11225 1 L
s
.1955 .59545 m
.1919 .61596 L
.18823 .63646 L
.18429 .65697 L
.18029 .67747 L
.17596 .69798 L
.17145 .71848 L
.16677 .73899 L
.16198 .75949 L
.15695 .78 L
.15188 .80051 L
.14674 .82101 L
.14115 .84152 L
.13572 .86202 L
.12994 .88253 L
.124 .90303 L
.11809 .92354 L
.11193 .94404 L
.10575 .96455 L
s
.095 1 m
.10575 .96455 L
s
s
s
s
s
0 .58658 m
.00462 .60021 L
.0112 .62045 L
.0176 .6407 L
.0238 .66094 L
.02981 .68118 L
.03583 .70142 L
.04165 .72166 L
.04745 .7419 L
.0531 .76214 L
.05867 .78238 L
.06416 .80262 L
.06949 .82286 L
.07483 .8431 L
.08017 .86334 L
.08552 .88358 L
.09068 .90382 L
.09579 .92406 L
.10098 .9443 L
.10575 .96455 L
s
0 .47545 m
.00406 .4902 L
.00947 .50997 L
.01439 .52973 L
.01951 .54949 L
.02439 .56926 L
.0293 .58902 L
.03407 .60879 L
.03869 .62855 L
.04314 .64832 L
.04748 .66808 L
.05183 .68785 L
.05617 .70761 L
.06052 .72737 L
.0646 .74714 L
.06863 .7669 L
.0725 .78667 L
.0765 .80643 L
.08029 .8262 L
.0841 .84596 L
.08792 .86572 L
.09153 .88549 L
.09527 .90525 L
.09885 .92502 L
.10238 .94478 L
.10575 .96455 L
s
.002 .25455 m
.01387 .2746 L
.02593 .29465 L
.03765 .31471 L
.04932 .33476 L
.0609 .35481 L
.07249 .37487 L
.08396 .39492 L
.09541 .41497 L
.10673 .43503 L
.11805 .45508 L
.12914 .47513 L
.14035 .49519 L
.15155 .51524 L
.16266 .53529 L
.17369 .55535 L
.18473 .5754 L
.1955 .59545 L
s
s
s
s
s
s
s
s
s
0 .90689 m
.03249 .92448 L
.06945 .94452 L
.10575 .96455 L
s
.19125 .27273 m
.19302 .29249 L
.19441 .31226 L
.1954 .33203 L
.19616 .35179 L
.19663 .37156 L
.19678 .39132 L
.19673 .41109 L
.19628 .43086 L
.19544 .45062 L
.19458 .47039 L
.19345 .49016 L
.19202 .50992 L
.19043 .52969 L
.18858 .54945 L
.18639 .56922 L
.18422 .58899 L
.18166 .60875 L
.17907 .62852 L
.17621 .64829 L
.17304 .66805 L
.16978 .68782 L
.16645 .70758 L
.16274 .72735 L
.15906 .74712 L
.15499 .76688 L
.15086 .78665 L
.14664 .80642 L
.1421 .82618 L
.13729 .84595 L
.13248 .86571 L
.12748 .88548 L
.12228 .90525 L
.1169 .92501 L
.11128 .94478 L
.10575 .96455 L
s
s
s
.27575 .71364 m
.27834 .73409 L
.28081 .75455 L
.28326 .775 L
.2855 .79545 L
.28753 .81591 L
.28956 .83636 L
.29143 .85682 L
.29306 .87727 L
.29464 .89773 L
.29613 .91818 L
.29739 .93864 L
.29851 .95909 L
.29961 .97955 L
.3005 1 L
s
.27575 .71364 m
.28757 .73068 L
.29903 .74773 L
.31052 .76477 L
.322 .78182 L
s
0 .17469 m
.00235 .17841 L
.01483 .19823 L
.02697 .21806 L
.03883 .23788 L
.05052 .2577 L
.06202 .27753 L
.0733 .29735 L
.0842 .31717 L
.0951 .33699 L
.10603 .35682 L
.11665 .37664 L
.1271 .39646 L
.1375 .41629 L
.14768 .43611 L
.15771 .45593 L
.16774 .47576 L
.17758 .49558 L
.18722 .5154 L
.19683 .53523 L
.20622 .55505 L
.21535 .57487 L
.22447 .5947 L
.2334 .61452 L
.24235 .63434 L
.2509 .65417 L
.25941 .67399 L
.26771 .69381 L
.27575 .71364 L
s
.18425 .58818 m
.19906 .60909 L
.21453 .63 L
.22986 .65091 L
.24508 .67182 L
.26057 .69273 L
.27575 .71364 L
s
0 .46095 m
.01421 .47314 L
.03725 .49318 L
.05988 .51322 L
.08224 .53326 L
.10441 .55331 L
.1264 .57335 L
.14818 .59339 L
.16978 .61343 L
.19139 .63347 L
.21282 .65351 L
.23405 .67355 L
.25514 .6936 L
.27575 .71364 L
s
0 .24958 m
.00027 .25004 L
.0121 .26993 L
.02372 .28982 L
.03533 .30971 L
.04681 .3296 L
.05808 .34949 L
.06922 .36938 L
.08039 .38927 L
.09154 .40916 L
.10249 .42905 L
.11324 .44895 L
.12397 .46884 L
.13456 .48873 L
.14506 .50862 L
.15551 .52851 L
.16579 .5484 L
.1758 .56829 L
.18425 .58818 L
s
0 .29781 m
.00758 .30971 L
.02041 .3296 L
.03325 .34949 L
.04586 .36938 L
.05835 .38927 L
.07105 .40916 L
.08374 .42905 L
.09644 .44895 L
.10897 .46884 L
.12142 .48873 L
.134 .50862 L
.14664 .52851 L
.15909 .5484 L
.17157 .56829 L
.18425 .58818 L
s
0 .31781 m
.00805 .3296 L
.02151 .34949 L
.0349 .36938 L
.04848 .38927 L
.06205 .40916 L
.07562 .42905 L
.08899 .44895 L
.10248 .46884 L
.11608 .48873 L
.12954 .50862 L
.14294 .52851 L
.15646 .5484 L
.16983 .56829 L
.18425 .58818 L
s
0 .42386 m
.0103 .43206 L
.03399 .45158 L
.05673 .47109 L
.07854 .49061 L
.09963 .51012 L
.1203 .52964 L
.14033 .54915 L
.16003 .56867 L
.18425 .58818 L
s
0 .31136 m
.01986 .32012 L
.03972 .32899 L
.05958 .33798 L
.07944 .34708 L
.09931 .35628 L
.11917 .3656 L
.13903 .37504 L
.15889 .38461 L
.17875 .3943 L
.19861 .40413 L
.21847 .41415 L
.23833 .42434 L
.25819 .43465 L
.27806 .44504 L
.29792 .45557 L
.31778 .46625 L
.33764 .47707 L
.3575 .48805 L
.37736 .49921 L
.39722 .5106 L
.41708 .52219 L
.43694 .53396 L
.45681 .54595 L
.47667 .55815 L
.49653 .57055 L
.51639 .58314 L
.53625 .59592 L
.55611 .60891 L
.57597 .62212 L
.59583 .63557 L
.61569 .64926 L
.63556 .66317 L
.65542 .67728 L
.67528 .69159 L
.69514 .70613 L
.715 .72091 L
s
.3165 .20273 m
.32557 .22266 L
.33525 .24259 L
.34552 .26252 L
.35635 .28245 L
.36783 .30238 L
.38011 .32231 L
.39314 .34224 L
.40673 .36217 L
.42088 .3821 L
.43581 .40203 L
.45122 .42196 L
.46712 .44189 L
.48353 .46182 L
.50031 .48175 L
.51745 .50168 L
.53477 .52161 L
.55229 .54154 L
.56999 .56147 L
.58789 .5814 L
.60601 .60133 L
.62413 .62126 L
.64214 .64119 L
.66035 .66112 L
.67855 .68105 L
.69674 .70098 L
.715 .72091 L
s
.3805 .05818 m
.39242 .07826 L
.4041 .09835 L
.41575 .11843 L
.42725 .13851 L
.43896 .1586 L
.45046 .17868 L
.46194 .19876 L
.47344 .21884 L
.4848 .23893 L
.49607 .25901 L
.50728 .27909 L
.51827 .29917 L
.52908 .31926 L
.5399 .33934 L
.55075 .35942 L
.56123 .3795 L
.57159 .39959 L
.58198 .41967 L
.59229 .43975 L
.60239 .45983 L
.61229 .47992 L
.622 .5 L
.63151 .52008 L
.64083 .54017 L
.64995 .56025 L
.65888 .58033 L
.66761 .60041 L
.67616 .6205 L
.68445 .64058 L
.69236 .66066 L
.70009 .68074 L
.70762 .70083 L
.715 .72091 L
s
.715 .72091 m
.73536 .71383 L
.75571 .70588 L
.77607 .69725 L
.79643 .68803 L
.81679 .67843 L
.83714 .66839 L
.8575 .65783 L
.87786 .64679 L
.89821 .63554 L
.91857 .62437 L
.93893 .61327 L
.95929 .60223 L
.97964 .59136 L
1 .58091 L
s
.715 .72091 m
.72776 .74068 L
.73969 .76045 L
.75065 .78023 L
.76025 .8 L
s
.715 .72091 m
.72088 .74084 L
.72648 .76078 L
.73196 .78071 L
.73738 .80065 L
.74264 .82058 L
.7479 .84052 L
.75296 .86045 L
.75781 .88039 L
.76264 .90032 L
.76736 .92026 L
.77186 .94019 L
.77623 .96013 L
.78062 .98006 L
.785 1 L
s
.715 .72091 m
.71516 .74023 L
.71213 .75955 L
.70568 .77886 L
.69559 .79818 L
.68163 .8175 L
.66356 .83682 L
.64118 .85614 L
.61425 .87545 L
s
.3805 .05818 m
.40183 .04234 L
.42317 .02836 L
.4445 .01664 L
.46583 .00663 L
.48225 0 L
s
.3805 .05818 m
.39744 .03891 L
.41438 .02361 L
.43131 .01078 L
.44825 0 L
s
.28425 0 m
.30092 .00852 L
.32082 .01953 L
.34071 .0315 L
.36061 .04434 L
.3805 .05818 L
s
.3805 .05818 m
.36611 .07803 L
.35342 .09788 L
.34189 .11773 L
.33143 .13758 L
.32171 .15742 L
.31225 .17727 L
s
.3805 .05818 m
.37175 .07273 L
s
.3805 .05818 m
.38793 .07812 L
.39501 .09805 L
.40185 .11798 L
.40852 .13792 L
.41515 .15785 L
.42169 .17778 L
.4281 .19772 L
.43445 .21765 L
.4408 .23758 L
.44716 .25752 L
.45349 .27745 L
.45976 .29738 L
.46598 .31732 L
.47215 .33725 L
.47828 .35718 L
.48435 .37712 L
.49038 .39705 L
.49636 .41698 L
.50228 .43692 L
.50819 .45685 L
.51414 .47678 L
.52004 .49672 L
.52581 .51665 L
.53149 .53659 L
.53714 .55652 L
.54274 .57645 L
.54825 .59639 L
.55366 .61632 L
.55897 .63625 L
.56419 .65619 L
.5693 .67612 L
.57434 .69605 L
.57927 .71599 L
.58405 .73592 L
.58867 .75585 L
.59319 .77579 L
.59764 .79572 L
.60196 .81565 L
.60603 .83559 L
.61007 .85552 L
.61425 .87545 L
s
.34125 .10909 m
.33254 .12614 L
.32494 .14318 L
.31825 .16023 L
.31225 .17727 L
s
.2675 .09091 m
.28071 .1125 L
.29232 .13409 L
.30271 .15568 L
.31225 .17727 L
s
.31225 .17727 m
.30775 .19091 L
s
.31225 .17727 m
.30625 .19818 L
s
.31225 .17727 m
.3125 .20091 L
s
.31225 .17727 m
.3165 .20273 L
s
0 .04725 m
.02 .05532 L
.04 .06352 L
.06 .07182 L
.08 .08022 L
.1 .08868 L
.12 .09714 L
.14 .10562 L
.16 .11413 L
.18 .12266 L
.2 .13122 L
.22 .13978 L
.24 .14834 L
.26 .15691 L
.28 .16549 L
.3 .17408 L
.32 .18268 L
.34 .19129 L
.36 .19992 L
.38 .20856 L
.4 .2172 L
.42 .22586 L
.44 .23453 L
.46 .24322 L
.48 .25191 L
.5 .26062 L
.52 .26934 L
.54 .27808 L
.56 .28684 L
.58 .29562 L
.6 .30441 L
.62 .31322 L
.64 .32204 L
.66 .33088 L
.68 .33973 L
.7 .34861 L
.72 .3575 L
.74 .36643 L
.76 .37539 L
.78 .38437 L
.8 .39338 L
.82 .40241 L
.84 .41147 L
.86 .42053 L
.88 .42963 L
.9 .43874 L
.92 .44789 L
.94 .45707 L
.96 .46628 L
.98 .47552 L
Mistroke
1 .48481 L
Mfstroke
s
.7655 .06818 m
.7876 .0878 L
.8086 .10742 L
.82829 .12705 L
.84704 .14667 L
.86489 .16629 L
.8817 .18591 L
.89779 .20553 L
.91314 .22515 L
.92771 .24477 L
.94187 .26439 L
.95553 .28402 L
.96869 .30364 L
.98157 .32326 L
.99427 .34288 L
1 .35183 L
s
.3165 .20273 m
.3366 .21249 L
.35671 .22226 L
.37681 .23205 L
.39691 .24182 L
.41701 .25158 L
.43712 .26131 L
.45722 .27102 L
.47732 .28072 L
.49743 .29039 L
.51753 .30001 L
.53763 .30959 L
.55774 .31912 L
.57784 .32858 L
.59794 .33798 L
.61804 .34729 L
.63815 .35653 L
.65825 .36568 L
.67835 .37474 L
.69846 .38369 L
.71856 .39253 L
.73866 .40125 L
.75876 .40984 L
.77887 .4183 L
.79897 .42661 L
.81907 .43477 L
.83918 .44277 L
.85928 .45062 L
.87938 .45829 L
.89949 .4658 L
.91959 .47316 L
.93969 .48038 L
.95979 .48746 L
.9799 .49442 L
1 .50126 L
s
.30775 .19091 m
.3125 .20091 L
s
0 .05319 m
.01953 .06166 L
.03906 .07037 L
.05859 .07936 L
.07813 .0885 L
.09766 .09767 L
.11719 .10687 L
.13672 .1161 L
.15625 .12532 L
.17578 .13459 L
.19531 .14394 L
.21484 .15334 L
.23438 .16278 L
.25391 .17227 L
.27344 .18179 L
.29297 .19133 L
.3125 .20091 L
s
.3125 .20091 m
.33272 .21085 L
.35294 .22082 L
.37316 .23082 L
.39338 .24086 L
.4136 .25092 L
.43382 .26101 L
.45404 .27112 L
.47426 .28125 L
.49449 .29141 L
.51471 .30164 L
.53493 .31191 L
.55515 .32219 L
.57537 .33245 L
.59559 .34275 L
.61581 .35312 L
.63603 .36352 L
.65625 .37391 L
.67647 .38429 L
.69669 .39467 L
.71691 .40506 L
.73713 .41547 L
.75735 .42592 L
.77757 .4364 L
.79779 .4469 L
.81801 .45741 L
.83824 .46791 L
.85846 .47842 L
.87868 .48892 L
.8989 .49943 L
.91912 .50992 L
.93934 .52043 L
.95956 .53098 L
.97978 .54155 L
s
1 .55212 m
.97978 .54155 L
s
s
.30625 .19818 m
.3125 .20071 L
s
.3125 .20091 m
.31753 .22075 L
.32286 .24059 L
.32855 .26043 L
.33452 .28027 L
.34078 .30011 L
.34763 .31995 L
.35483 .33979 L
.36222 .35963 L
.36997 .37947 L
.3781 .3993 L
.38664 .41914 L
.39538 .43898 L
.4042 .45882 L
.4134 .47866 L
.42278 .4985 L
.43237 .51834 L
.44196 .53818 L
.45169 .55802 L
.46165 .57786 L
.47162 .5977 L
.48146 .61754 L
.49151 .63738 L
.50155 .65722 L
.51179 .67706 L
.52188 .6969 L
.53205 .71674 L
.54221 .73658 L
.5523 .75642 L
.56257 .77626 L
.57283 .7961 L
.58309 .81594 L
.59333 .83578 L
.60375 .85561 L
.61425 .87545 L
s
.3125 .20101 m
.3165 .20273 L
s
.33425 .10909 m
.32588 .12955 L
.31879 .15 L
.31289 .17045 L
.30775 .19091 L
s
.184 .07273 m
.20463 .09148 L
.22525 .11051 L
.24588 .13025 L
.2665 .1501 L
.28713 .17035 L
.30775 .19091 L
s
.30775 .19091 m
.30625 .19818 L
s
.30775 .19091 m
.304 .21091 L
.30079 .23091 L
.29797 .25091 L
.29568 .27091 L
.29375 .29091 L
.29184 .31091 L
.29024 .33091 L
.28887 .35091 L
.28751 .37091 L
.28625 .39091 L
s
.30775 .19091 m
.3165 .20273 L
s
.27825 .18545 m
.30625 .19818 L
s
.30625 .19818 m
.30243 .21864 L
.29933 .23909 L
.29634 .25955 L
.29392 .28 L
.29182 .30045 L
.28985 .32091 L
.28807 .34136 L
.2865 .36182 L
s
.30625 .19818 m
.30625 .19909 L
s
.30625 .19818 m
.3165 .20273 L
s
.2865 .36182 m
.28625 .39091 L
s
0 .03828 m
.00086 .03909 L
.02086 .05864 L
.03993 .07818 L
.05838 .09773 L
.07629 .11727 L
.09365 .13682 L
.11044 .15636 L
.12686 .17591 L
.14291 .19545 L
.15859 .215 L
.1739 .23455 L
.18884 .25409 L
.20343 .27364 L
.21784 .29318 L
.23188 .31273 L
.2457 .33227 L
.25933 .35182 L
.27286 .37136 L
.28625 .39091 L
s
.28625 .39091 m
.286 .41818 L
s
.28625 .39091 m
.2855 .40455 L
s
.28625 .39091 m
.29283 .4125 L
.29969 .43409 L
.30608 .45568 L
.3125 .47727 L
s
.28625 .39091 m
.29425 .40909 L
.3025 .42727 L
.31075 .44545 L
.3185 .46364 L
s
.2865 .36182 m
.28673 .38222 L
.28676 .40263 L
.28677 .42303 L
.28662 .44343 L
.2865 .46384 L
.28643 .48424 L
.28625 .50465 L
.28624 .52505 L
.286 .54545 L
s
s
.2865 .36182 m
.29358 .38177 L
.30085 .40173 L
.30781 .42169 L
.31471 .44165 L
.32167 .4616 L
.32846 .48156 L
.33527 .50152 L
.34207 .52147 L
.34888 .54143 L
.3557 .56139 L
.36234 .58134 L
.36904 .6013 L
.37577 .62126 L
.3824 .64121 L
.38919 .66117 L
.39577 .68113 L
.40235 .70108 L
.40913 .72104 L
.41579 .741 L
.42239 .76095 L
.429 .78091 L
s
.2865 .36182 m
.29727 .38215 L
.30801 .40247 L
.31875 .4228 L
.32936 .44313 L
.33986 .46345 L
.35038 .48378 L
.36084 .50411 L
.37111 .52444 L
.3814 .54476 L
.3917 .56509 L
.40179 .58542 L
.41184 .60575 L
.42191 .62607 L
.43198 .6464 L
.44195 .66673 L
.45184 .68705 L
.46188 .70738 L
.47171 .72771 L
.48156 .74804 L
.49118 .76836 L
.50098 .78869 L
.51068 .80902 L
.52028 .82935 L
.52989 .84967 L
.5395 .87 L
s
.274 .34545 m
.2865 .36182 L
s
.61425 .87545 m
.61682 .89136 L
.61944 .90727 L
.62227 .92318 L
.625 .93909 L
s
.61425 .87545 m
.61929 .88841 L
.62429 .90136 L
.62922 .91432 L
.634 .92727 L
s
.489 .82909 m
.50865 .83701 L
.52831 .84421 L
.54796 .8511 L
.56762 .85858 L
.58727 .86611 L
.60692 .87335 L
.62658 .88014 L
.64623 .88688 L
.66588 .89395 L
.68554 .90112 L
.70519 .90818 L
.72485 .915 L
.7445 .92175 L
.76415 .92857 L
.78381 .93537 L
.80346 .94205 L
.82312 .94848 L
.84277 .95489 L
.86242 .96155 L
.88208 .96836 L
.90173 .97513 L
.92138 .98166 L
.94104 .98804 L
.96069 .99423 L
.97943 1 L
s
0 .05284 m
.01978 .06143 L
.03956 .07026 L
.05934 .07932 L
.07913 .08851 L
.09891 .09772 L
.11869 .10695 L
.13847 .1163 L
.15825 .12572 L
.17803 .13516 L
.19781 .14464 L
.21759 .1542 L
.23738 .16382 L
.25716 .17345 L
.27694 .18314 L
.29672 .19289 L
.3165 .20273 L
s
.429 .78091 m
.43436 .80083 L
.43968 .82074 L
.44495 .84066 L
.4502 .86058 L
.45544 .8805 L
.4607 .90041 L
.46603 .92033 L
.4714 .94025 L
.47674 .96017 L
.48199 .98008 L
.48725 1 L
s
.5395 .87 m
.55925 .92141 L
.579 .97295 L
.58925 1 L
s
.625 .93909 m
.63425 1 L
s
s
.125 .62727 m
.14522 .63904 L
.16544 .6508 L
.18567 .66262 L
.20589 .67414 L
.22611 .68519 L
.24633 .69697 L
.26656 .70817 L
.28678 .7191 L
.307 .73042 L
.32722 .74214 L
.34744 .75317 L
.36767 .76418 L
.38789 .77521 L
.40811 .78629 L
.42833 .79716 L
.44856 .80744 L
.46878 .81845 L
.489 .82909 L
s
1 0 0 r
.60375 .68182 m
.62365 .69264 L
.64355 .70372 L
.66345 .71522 L
.68335 .72689 L
.70325 .73909 L
s
.15 .64455 m
.1699 .65902 L
.1898 .67352 L
.2097 .68724 L
.2296 .70125 L
.2495 .71422 L
.2694 .72724 L
.2893 .74029 L
.3092 .75261 L
.3291 .76512 L
.349 .77754 L
.3689 .78918 L
.3888 .80076 L
.4087 .81233 L
.4286 .82391 L
.4485 .83549 L
.4684 .84707 L
.4883 .85865 L
.5082 .87028 L
.5281 .88083 L
.548 .89273 L
s
.35025 .03273 m
.377 .04091 L
s
.21725 .12091 m
.22545 .14034 L
.23226 .15977 L
.23824 .1792 L
.24316 .19864 L
.24773 .21807 L
.2517 .2375 L
.25516 .25693 L
.25825 .27636 L
s
.21725 .12091 m
.23544 .13322 L
.25362 .14649 L
.27181 .16013 L
.29 .17455 L
s
.21725 .12091 m
.23856 .1233 L
.25987 .12631 L
.28119 .12957 L
.3025 .13273 L
s
.21725 .12091 m
.22887 .11991 L
.2405 .11881 L
.25212 .11762 L
.26375 .11636 L
s
.21725 .12091 m
.24375 .10636 L
s
.19475 .26818 m
.21258 .28568 L
.22972 .30318 L
.24673 .32068 L
.2635 .33818 L
s
.199 .1 m
.21725 .12091 L
s
.21725 .12091 m
.22009 .12932 L
.22199 .13773 L
.22337 .14614 L
.22525 .15455 L
s
.1825 .1 m
.19119 .10437 L
.19988 .10948 L
.20856 .11507 L
.21725 .12091 L
s
.155 .11818 m
.17056 .11852 L
.18613 .11897 L
.20169 .11971 L
.21725 .12091 L
s
.1195 .21818 m
.13989 .23252 L
.16029 .25033 L
.18068 .26993 L
.20107 .29072 L
.22146 .31251 L
.24186 .33482 L
.26225 .35818 L
s
p
0 g
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{483, 483},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007S0001ha000`40O003h00Oogooi7oo003oOooT
Ool00?moonAoo`00ogooi7oo003oOooTOol00?moonAoo`00ogooi7oo0012Ool30003Ool30004Ool2
000ZOol00`00Oomoo`03Ool20004Ool2000[Ool00`00Oomoo`02Ool30004Ool2000YOol30004Ool2
0004Ool2000ZOol30003Ool30004Ool2000YOol20005Ool20004Ool2000ZOol20004Ool30004Ool2
000VOol30004Ool20004Ool20004Ool20004Ool0045oo`07001oogooOol007oo00000goo00@007oo
Ool0009oo`03001oogoo02Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00:Woo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`0UOol01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo000XOol01`00Oomoogoo001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`0XOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo02Uoo`04001oogoo0003Ool0
1000Oomoo`000Woo00<007ooOol097oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo0011Ool01@00Oomoogoo00001Goo00@007ooOol0009oo`03001oogoo02Qo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0:Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo02Eoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol002Qo
o`05001oogooOol00005Ool01000Oomoo`000Woo00<007ooOol0:Goo00@007ooOol0009oo`04001o
ogoo0002Ool00`00Oomoo`0ZOol00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol097oo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo0011Ool40006Ool0
1000Oomoo`000Woo00<007ooOol0:7oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`0YOol00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol09Woo0`000goo00@007ooOol0009o
o`04001oogoo000YOol30006Ool01000Oomoo`000Woo00<007ooOol09Woo10000Woo00@007ooOol0
009oo`04001oogoo000YOol40005Ool01000Oomoo`000Woo00<007ooOol097oo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo0011Ool00`00Oomoo`03Ool40003
Ool01000Oomoo`00:goo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0ZOol00`00Ool0
00030003Ool01000Oomoo`009goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
:7oo00H007ooOomoo`00Ool40003Ool01000Oomoo`009goo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`00:7oo00H007ooOomoo`00Ool40003Ool01000Oomoo`009Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo0012Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool01000Oomoo`009goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`00:7oo00L007ooOomoo`00Ool00006Ool01000Oomoo`009goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`00:7oo00L007ooOomoo`00Ool00006Ool01000Oomoo`009goo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`00:7oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`009Goo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo0013Ool2
0002Ool50003Ool2000XOol50003Ool20004Ool2000YOol500000goo000000030003Ool2000YOol3
0004Ool20004Ool2000ZOol30002Ool50003Ool2000YOol30004Ool20004Ool2000ZOol30002Ool5
0003Ool2000WOol00`00Oomoo`03Ool20004Ool20004Ool20004Ool00?moonAoo`00ogooi7oo003o
OooTOol00?moonAoo`00ogooi7oo003oOooTOol00?moonAoo`004Gooo`00aP003Goo000AOol00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`05Ool4000;
Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000Oomoo`002Goo0`002Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
2goo000AOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool20003Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01000Oomoo`002Woo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol017oo0P000goo00<0
07ooOol01Goo0P0000=oo`00Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol02goo000AOol00`00Oomoo`0fOol00`00Oomo
o`0^Ool20005Ool00`00Oomoo`0BOol2000ROol00`00Oomoo`0HOol2000;Ool2000>Ool00`00Oomo
o`0fOol00`00Oomoo`0eOol00`00Oomoo`0fOol00`00Oomoo`0eOol00`00Oomoo`0;Ool0015oo`03
001oogoo06Eoo`8001ioo`8003Yoo`03001oogoo00Qoo`<00?9oo`03001oogoo00]oo`004Goo00<0
07ooOol0I7oo00<007ooOol087oo0P00=Woo0P002Goo0P00mGoo00<007ooOol02goo000AOol00`00
Oomoo`1ROol2000UOol2000cOol00`00Oomoo`06Ool3003gOol00`00Oomoo`0;Ool0015oo`03001o
ogoo061oo`8002Uoo`03001oogoo02moo`03001oogoo00Eoo`800?Yoo`03001oogoo00]oo`004Goo
0`00GWoo0P00;7oo0P00;Woo00<007ooOol01Goo00<007ooOol0nGoo0P003Goo000AOol00`00Oomo
o`1KOol3000`Ool2000[Ool00`00Oomoo`04Ool2003mOol00`00Oomoo`0;Ool0015oo`03001oogoo
05Uoo`8003Eoo`8002Qoo`03001oogoo00Aoo`03001oogoo0?eoo`03001oogoo00]oo`004Goo00<0
07ooOol0Egoo0P00>Goo0P0097oo0P001Goo0P00ogoo0Goo00<007ooOol02goo000AOol00`00Oomo
o`1EOol2000mOol00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool00`00Oomoo`0;
Ool0015oo`03001oogoo05=oo`80041oo`8001moo`03001oogoo00=oo`800?moo`Aoo`03001oogoo
00]oo`004Goo00<007ooOol0DWoo00<007ooOol0@Woo0P006goo0P0017oo0P00ogoo1Woo00<007oo
Ool02goo000AOol00`00Oomoo`1@Ool20017Ool00`00Oomoo`03O00DOol00`00Oomoo`03Ool00`00
Oomoo`3oOol6Ool00`00Oomoo`0;Ool0015oo`03001oogoo04ioo`8004Yoo`8000=oo`Al00moo`03
001oogoo009oo`800?moo`Uoo`03001oogoo00]oo`004Goo00<007ooOol0C7oo0P00CWoo00<007oo
Ool017oo17`02Woo00@007ooOomoo`800?moo`]oo`03001oogoo00]oo`004Goo0`00BGoo0`00DGoo
0P0027oo0W`027oo00@007ooOol00?moo`eoo`03001oogoo00]oo`004Goo00@007ooOol004Ioo`80
05Ioo`03001oogoo00ioo`04001oo`00003oOol>Ool00`00Oomoo`0;Ool0015oo`05001oogooOol0
0013Ool2001IOol2000=Ool00`00Ool0003oOol@Ool00`00Oomoo`0;Ool0015oo`8000=oo`03001o
ogoo03ioo`8005eoo`03001oogoo00Uoo`<00?mooa5oo`03001oogoo00]oo`004Goo00@007oo0000
009oo`03001oogoo03]oo`80061oo`8000Qoo`800?mooa=oo`03001oogoo00]oo`004Goo00@007oo
Oomoo`@003]oo`03001oogoo069oo`03001oogoo00Aoo`800?mooaAoo`03001oogoo00]oo`004Goo
0P001Goo0P00>7oo0P00IWoo0P000goo0P00ogoo5Goo00<007ooOol02goo000AOol40005Ool2000d
Ool2001ZOol00`00Ool0003oOolFOol2000=Ool0015oo`04001oogooOol30003Ool3000`Ool2001]
Ool00`00Oomoo`3oOolFOol00`00Oomoo`0;Ool0015oo`03001oogoo00Aoo`800004Ool007ooOol3
000ZOol3001_Ool00`00Oomoo`3oOolFOol00`00Oomoo`0;Ool0015oo`03001oogoo00Ioo`<000Ao
o`8002Ioo`80075oo`03001oo`000?mooaMoo`03001oogoo00]oo`004Goo00<007ooOol027oo0P00
1Goo0`008Goo0P00LWoo0P0000=oo`000000ogoo5Woo00<007ooOol02goo000AOol00`00Oomoo`0:
Ool30005Ool3000LOol2001dOol01@00Oomoogoo0000ogoo5Woo00<007ooOol02goo000AOol00`00
Oomoo`0;Ool01000Ool000001Woo0`005goo0P00MGoo00<007ooOol00Woo0P00ZWoo0P00J7oo00<0
07ooOol02goo000AOol00`00Oomoo`0<Ool00`00Oomoo`020007Ool2000DOol00`00Oomoo`1dOol2
0004Ool00`00Ool0002[Ool00`00Oomoo`1UOol00`00Oomoo`0;Ool0015oo`03001oogoo00eoo`04
001oogooOol20007Ool2000@Ool2000ROol2001COol00`00Oomoo`04Ool2002/Ool00`00Oomoo`1T
Ool00`00Oomoo`0;Ool0015oo`03001oogoo00ioo`03001oogoo009oo`<000Ioo`<000]oo`8002Io
o`03001oogoo04moo`03001oogoo00Eoo`03001oo`000:aoo`03001oogoo06=oo`03001oogoo00]o
o`004Goo00<007ooOol03goo00<007ooOol017oo0P001goo0P001goo0P00:Goo00<007ooOol0CGoo
00<007ooOol01goo00<007oo0000[7oo00<007ooOol0HWoo00<007ooOol02goo000AOol00`00Oomo
o`0@Ool00`00Oomoo`05Ool20007Ool20003Ool2000/Ool00`00Oomoo`1<Ool00`00Oomoo`07Ool0
0`00Ool0002]Ool00`00Oomoo`1QOol00`00Oomoo`0;Ool0015oo`03001oogoo015oo`03001oogoo
00Ioo`8000Moo`<002moo`8004]oo`03001oogoo00Uoo`03001oo`000:eoo`03001oogoo061oo`03
001oogoo00]oo`001Woo1@001Woo00<007ooOol04Woo00<007ooOol01goo0`000goo0P0000Aoo`00
000002moo`03001oogoo04Moo`03001oogoo00Yoo`03001oo`000:ioo`03001oogoo05moo`03001o
ogoo00]oo`001goo00@007ooOol000Ioo`03001oogoo01=oo`03001oogoo00Qoo`@000Ioo`8002io
o`03001oogoo04Ioo`03001oogoo00Yoo`04001oogoo002^Ool00`00Oomoo`1NOol00`00Oomoo`0;
Ool000Qoo`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo00Moo`D000Moo`8002eoo`03001o
ogoo04Aoo`03001oogoo00aoo`04001oogoo002^Ool2001NOol00`00Oomoo`0;Ool000Uoo`03001o
ogoo00Eoo`@001Aoo`03001oogoo00=oo`<000Aoo`<000Moo`8002aoo`03001oogoo01Uoo`03001o
ogoo02Ioo`03001oogoo00eoo`04001oogoo002`Ool00`00Oomoo`1IOol3000=Ool000Ioo`05001o
ogooOol00006Ool00`00Oomoo`0FOol00`00Oomoo`020009Ool40006Ool3000ZOol00`00Oomoo`0H
Ool00`00Oomoo`0VOol00`00Oomoo`0=Ool01@00Oomoogoo0000/7oo00<007ooOol0FWoo00<007oo
Ool02goo0006Ool01@00Oomoogoo00001Woo00<007ooOol05goo0P003Woo0`001goo0P00:Goo00<0
07ooOol067oo00<007ooOol097oo00<007ooOol03goo00@007ooOol00;5oo`03001oogoo05Uoo`03
001oogoo00]oo`001goo0`001goo00<007ooOol05Goo0P0000=oo`00Ool03goo0`001goo0P00:7oo
00<007ooOol067oo00<007ooOol08Woo00<007ooOol047oo00D007ooOomoo`000;5oo`8005Uoo`03
001oogoo00]oo`004Goo00<007ooOol04goo0P000goo00<007ooOol047oo0`001goo0P006Goo0W`0
1Goo00=l07ooOol017oo00<007ooOol05goo00<007ooOol08Woo00<007ooOol047oo00D007ooOomo
o`000;=oo`03001oogoo05Ioo`03001oogoo00]oo`004Goo00<007ooOol04Woo00<007ooOol017oo
00<007ooOol04Goo10001Woo0`0067oo0W`00goo00=l07ooOol01Goo00<007ooOol05goo00<007oo
Ool087oo00<007ooOol04Woo00D007ooOomoo`000;=oo`03001oogoo05Eoo`03001oogoo00]oo`00
4Goo00<007ooOol047oo0P0027oo00<007ooOol04goo0`001goo0P0067oo0W`00Woo00=l07ooOol0
1Goo00<007ooOol05Woo00<007ooOol087oo00<007ooOol04Woo00D007ooOomoo`000;Aoo`03001o
ogoo05Aoo`03001oogoo00]oo`004Goo00<007ooOol03Woo0P002goo00<007ooOol057oo0`001goo
0`005goo0W`000=oog`0Ool01Woo00<007ooOol01Woo0W`03Woo00<007ooOol07Woo00<007ooOol0
4goo00<007ooOol00Woo00<007ooOol0/Woo00<007ooOol0Dgoo00<007ooOol02goo000AOol00`00
Oomoo`0<Ool2000>Ool00`00Oomoo`0EOol30008Ool3000FOol00g`0Ooml0007Ool00`00Oomoo`03
Ool2O00AOol00`00Oomoo`0FOol01`00Oomoogoo001oo`0001Moo`03001oogoo009oo`03001oogoo
0;9oo`03001oogoo059oo`03001oogoo00]oo`004Goo00<007ooOol02Woo0P004Goo00<007ooOol0
5Woo100027oo0`0057oo00=l07ooO0001goo00D007ooOomoog`001=oo`03001oogoo01Ioo`07001o
ogooOol007oo00005goo00<007ooOol00Woo00<007ooOol0/goo00<007ooOol0DGoo00<007ooOol0
2goo000AOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0HOol30009Ool3000BOol2O008
Ool00`00O01l000EOol00`00Oomoo`0DOol01`00Oomoogoo001oo`0001Qoo`03001oogoo00=oo`03
001oogoo0;=oo`03001oogoo051oo`03001oogoo00]oo`004Goo00<007ooOol01goo0P005Woo00<0
07ooOol06Goo0`002Woo0P004Goo0W`01Woo0W`000<007ooOol02Woo0g`01goo00<007ooOol057oo
00L007ooOomoo`00Ool0000IOol00`00Oomoo`02Ool00`00Oomoo`2dOol00`00Oomoo`1?Ool00`00
Oomoo`0;Ool0015oo`03001oogoo00Eoo`8001Uoo`03001oogoo01Yoo`<000=oo`al00ioo`03O01o
ogoo009oo`05O01oogooOol00006Ool5O00;Ool00`00Oomoo`0COol01P00Oomoo`00Ool001Yoo`03
001oogoo00=oo`03001oogoo0;Aoo`03001oogoo04ioo`03001oogoo00]oo`004Goo00<007ooOol0
0goo0P006goo00<007ooOol077oo0`002goo0P003W`000=oog`0Ool03G`047oo00<007ooOol04Woo
00L007ooOomoo`00Ool0000JOol00`00Oomoo`03Ool00`00Oomoo`2eOol00`00Oomoo`1=Ool00`00
Oomoo`0;Ool0015oo`03001oogoo00<001ioo`03001oogoo01eoo`8000aoo`8000aoo`Ql00=oo`03
001oogoo01=oo`03001oogoo015oo`06001oogoo001oo`0077oo00<007ooOol00goo00<007ooOol0
]Goo00<007ooOol0C7oo00<007ooOol02goo000AOol3000ROol00`00Oomoo`0MOol3000<Ool2000<
Ool017`0Ooml07`00Woo2W`047oo00<007ooOol047oo00H007ooOol007oo000LOol00`00Oomoo`03
Ool00`00Oomoo`2fOol00`00Oomoo`1;Ool00`00Oomoo`0;Ool0015oo`<002=oo`03001oogoo01io
o`<000aoo`<000Yoo`03O01oogoo009l00Eoo`03001oogoo009oo`Yl00Ioo`03001oogoo00moo`06
001oogoo001oo`007Goo00<007ooOol017oo00<007ooOol0]Woo00<007ooOol0BGoo0P003Goo000A
Ool00`00Oomoo`0TOol00`00Oomoo`0OOol3000=Ool20008Ool2O003Ool00g`0Oomoo`03Ool00`00
Oomoo`0;Ool7O0000`00Oomoo`0>Ool00`00Oomoo`02000OOol00`00Oomoo`04Ool00`00Oomoo`2e
Ool00`00Oomoo`1:Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Eoo`03001oogoo021oo`@000ao
o`8000Moo`03O01oogoo009oo`9l00Aoo`80019oo`El00aoo`05001oo`00Ool0000OOol00`00Oomo
o`04Ool00`00Oomoo`2fOol00`00Oomoo`19Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Ioo`03
001oogoo029oo`<000aoo`8000Eoo`03O01oogoo00Aoo`9l00Aoo`03001oogoo011oo`04001oogoo
Ool2O009Ool00`00Oomoo`02000POol00`00Oomoo`05Ool00`00Oomoo`2fOol00`00Oomoo`18Ool0
0`00Oomoo`0;Ool0015oo`03001oogoo02Moo`03001oogoo02=oo`<000aoo`<000=oo`03O01oogoo
00Eoo`03O01oogoo009oo`03001oogoo00moo`03001oogoo00aoo`05001oo`00Ool0000QOol00`00
Oomoo`04Ool00`00Oomoo`2gOol00`00Oomoo`17Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Qo
o`03001oogoo02Aoo`<000eoo`800003Ooml07oo00Moo`03O01oogoo009oo`03001oogoo00moo`03
001oogoo00]oo`04001oo`00000ROol00`00Oomoo`05Ool00`00Oomoo`2gOol00`00Oomoo`16Ool0
0`00Oomoo`0;Ool0015oo`03001oogoo02Qoo`03001oogoo02Ioo`@000aoo`03001l07`000Qoo`9l
00=oo`03001oogoo00ioo`03001oogoo00Yoo`05001oo`00Ool0000ROol00`00Oomoo`05Ool00`00
Oomoo`2hOol00`00Oomoo`15Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Uoo`03001oogoo02Qo
o`<000]oo`9l0003001oogoo00Moo`05O01oogooOol0000@Ool00`00Oomoo`09Ool01000Ool00000
97oo00<007ooOol01Goo00<007ooOol0^7oo00<007ooOol0A7oo00<007ooOol02goo000AOol00`00
Oomoo`0ZOol00`00Oomoo`0YOol30009Ool00g`0Ooml00030007Ool01G`0Oomoogoo00003goo00<0
07ooOol027oo00D007oo001oo`0002Aoo`03001oogoo00Ioo`03001oogoo0;Qoo`03001oogoo04=o
o`03001oogoo00]oo`004Goo00<007ooOol0:goo00<007ooOol0:Woo0`001goo00=l07ooO0000goo
0P001Woo0W`00Woo00<007ooOol03Goo00<007ooOol01goo00@007oo000002Eoo`03001oogoo00Io
o`03001oogoo0;Uoo`03001oogoo049oo`03001oogoo00]oo`004Goo00<007ooOol0;7oo00<007oo
Ool0:goo0`001Goo00=l07ooO0001Goo0P001Woo00Al07ooOol000ioo`03001oogoo00Moo`800003
Ool007oo02Eoo`03001oogoo00Ioo`03001oogoo0;Qoo`03001oogoo049oo`03001oogoo00]oo`00
4Goo00<007ooOol0;7oo00<007ooOol0;Goo0P0017oo00Al07ooOoml00Ioo`8000Eoo`04O01oogoo
000>Ool00`00Oomoo`05Ool01@00Ool007oo00009Woo00<007ooOol01Woo00<007ooOol0^Goo00<0
07ooOol0@Goo00<007ooOol02goo000AOol00`00Oomoo`0]Ool00`00Oomoo`0^Ool20003Ool00g`0
Ooml0008Ool30003Ool2O0000goo001oo`0<Ool00`00Oomoo`05Ool200000goo001oo`0VOol00`00
Oomoo`07Ool00`00Oomoo`2iOol00`00Oomoo`10Ool00`00Oomoo`0;Ool0015oo`03001oogoo02io
o`03001oogoo02moo`800004Ooml07ooO00;Ool20003Ool00g`0Ool0000=Ool00`00Oomoo`04Ool2
00000goo001oo`0WOol00`00Oomoo`07Ool00`00Oomoo`2iOol00`00Oomoo`0oOol00`00Oomoo`0;
Ool0015oo`03001oogoo02moo`03001oogoo031oo`<00003Ooml07oo00]oo`80009oo`03O01oo`00
00aoo`03001oogoo00=oo`04001oo`00000YOol00`00Oomoo`07Ool00`00Oomoo`2jOol00`00Oomo
o`0nOol00`00Oomoo`0;Ool0015oo`03001oogoo031oo`03001oogoo035oo`800003O01oogoo00ao
o`800004Ooml07`0000<Ool00`00Oomoo`02Ool200000goo001oo`0XOol00`00Oomoo`08Ool00`00
Oomoo`2jOol00`00Oomoo`0mOol00`00Oomoo`0;Ool0015oo`03001oogoo035oo`03001oogoo039o
o`03O000000000ioo`<00003O00007oo00Yoo`03001oogoo009oo`<002]oo`03001oogoo00Moo`03
001oogoo0;]oo`03001oogoo03aoo`03001oogoo00]oo`004Goo0`00<Woo00<007ooOol0<Woo00Al
07oo000000moo`03001l000000Yoo`03001oogoo009oo`03001oo`0002]oo`03001oogoo00Qoo`03
001oogoo0;]oo`03001oogoo03Yoo`8000eoo`004Goo00<007ooOol0<goo00<007ooOol0<Goo00Al
07ooOomoo`8000moo`03O00007oo00Uoo`04001oogooOol2000/Ool00`00Oomoo`08Ool00`00Oomo
o`2lOol00`00Oomoo`0jOol00`00Oomoo`0;Ool0015oo`03001oogoo03Aoo`03001oogoo031oo`03
O01oogoo00=oo`8000ioo`03O000000000Qoo`03001oogoo008002ioo`03001oogoo00Qoo`03001o
ogoo0;]oo`03001oogoo03Yoo`03001oogoo00]oo`004Goo00<007ooOol0=Goo00<007ooOol0<7oo
00=l07ooOol00goo0`003Goo00=l000000000P001Woo00@007oo000002ioo`03001oogoo00Uoo`03
001oogoo0;]oo`03001oogoo03Uoo`03001oogoo00]oo`004Goo00<007ooOol0=Woo00<007ooOol0
;goo00=l07ooOol01Goo0`0037oo00Al0000Oomoo`8000Aoo`03001oo`0002moo`03001oogoo00Uo
o`03001oogoo0;aoo`03001oogoo03Qoo`03001oogoo00]oo`004Goo00<007ooOol0=goo00<007oo
Ool0;Woo00=l07ooOol01goo0`002goo00=l0000Ool00Woo0`0000Aoo`000000031oo`03001oogoo
00Uoo`03001oogoo0;aoo`03001oogoo03Moo`03001oogoo00]oo`004Goo00<007ooOol0=goo00<0
07ooOol0;goo00=l07ooOol027oo0`002goo00<007ooOol00goo0`00<Goo00<007ooOol02Goo00<0
07ooOol0_Goo00<007ooOol0=Woo00<007ooOol02goo000AOol2000iOol00`00Oomoo`0^Ool00g`0
Oomoo`0;Ool2000:Ool00`00Oomoo`04Ool4000^Ool00`00Oomoo`0:Ool00`00Oomoo`2mOol00`00
Oomoo`0eOol00`00Oomoo`0;Ool0015oo`8003Yoo`03001oogoo02eoo`03O01oogoo00aoo`<000Uo
o`03001oogoo009oo`8000=oo`8002eoo`03001oogoo00Uoo`03001oogoo0;ioo`03001oogoo03Ao
o`03001oogoo00]oo`004Goo00<007oo0000>Woo00<007ooOol0;7oo00=l07ooOol03Woo0`0027oo
00@007ooOomoo`8000Eoo`8002]oo`03001oogoo00Yoo`03001oogoo0;ioo`03001oogoo03=oo`03
001oogoo00]oo`004Goo00@007ooOol003Yoo`03001oogoo02aoo`03O01oogoo00ioo`D000Ioo`03
001oogoo00<000Ioo`<002Qoo`03001oogoo00Yoo`03001oogoo0;moo`03001oogoo039oo`03001o
ogoo00]oo`004Goo00D007ooOomoo`0003Uoo`03001oogoo02aoo`03O01oogoo011oo`D000Eoo`D0
00Uoo`8002Moo`03001oogoo00Yoo`03001oogoo0;ioo`03001oogoo039oo`03001oogoo00]oo`00
4Goo00D007ooOomoo`0003Yoo`03001oogoo02]oo`03O01oogoo01=oo`@000Aoo`800003Ool007oo
00Yoo`8002Eoo`03001oogoo00]oo`03001oogoo0;ioo`03001oogoo035oo`03001oogoo00]oo`00
4Goo00<007ooOol00Woo00<007ooOol0>7oo00<007ooOol0:Woo00=l07ooOol05Woo0`000Woo0P00
00=oo`00Ool037oo0P008goo00<007ooOol02goo00<007ooOol0_goo00<007ooOol0<7oo00<007oo
Ool02goo000AOol00`00Oomoo`03Ool00`00Oomoo`0hOol00`00Oomoo`0YOol00g`0Oomoo`0HOol5
00000goo001oo`0>Ool3000QOol00`00Oomoo`0;Ool00`00Oomoo`2oOol00`00Oomoo`0_Ool00`00
Oomoo`0;Ool0015oo`03001oogoo00Aoo`03001oogoo03Moo`03001oogoo02Yoo`03O01oogoo01Uo
o`D0019oo`8001moo`03001oogoo00]oo`03001oogoo0<1oo`03001oogoo02ioo`03001oogoo00]o
o`004Goo0`0017oo00<007ooOol0>7oo00<007ooOol0:Goo00=l07ooOol06Woo1@004goo0P007Goo
00<007ooOol037oo00<007ooOol0_goo00<007ooOol0;Goo0P003Goo000AOol00`00Oomoo`05Ool0
0`00Oomoo`0hOol00`00Oomoo`0XOol00g`0Oomoo`0IOol2000017oo000000005Goo0P0077oo00<0
07ooOol02goo00<007ooOol0`7oo00<007ooOol0;Goo00<007ooOol02goo000AOol00`00Oomoo`05
Ool00`00Oomoo`0iOol00`00Oomoo`0WOol00g`0Oomoo`0IOol01000Oomoogoo10005Goo0`006Goo
00<007ooOol037oo00<007ooOol0`7oo00<007ooOol0;7oo00<007ooOol02goo000AOol00`00Oomo
o`06Ool00`00Oomoo`0iOol00`00Oomoo`0WOol00g`0Oomoo`0HOol01000Oomoogoo0P0000=oo`00
00000P005Goo0P005goo00<007ooOol037oo00<007ooOol0`Goo00<007ooOol0:goo00<007ooOol0
2goo000AOol00`00Oomoo`07Ool00`00Oomoo`0hOol00`00Oomoo`0WOol00g`0Oomoo`0HOol00`00
Oomoo`02Ool20002Ool4000EOol2000FOol00`00Oomoo`0<Ool00`00Oomoo`30Ool00`00Oomoo`0[
Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Moo`03001oogoo03Uoo`03001oogoo02Ioo`03O01o
ogoo01Qoo`03001oogoo009oo`8000Eoo`<001Eoo`8001Aoo`03001oogoo00eoo`03001oogoo0<1o
o`03001oogoo02Yoo`03001oogoo00]oo`004Goo00<007ooOol027oo00<007ooOol0>Goo00<007oo
Ool09Goo00=l07ooOol067oo00<007ooOol00Woo00<007oo00001Woo0`005Goo0`004Goo00<007oo
Ool03Goo00<007ooOol0`Goo00<007ooOol0:Goo00<007ooOol02goo000AOol00`00Oomoo`08Ool0
0`00Oomoo`0jOol00`00Oomoo`0UOol00g`0Oomoo`0FOol20004Ool00`00Ool00008Ool3000FOol2
000@Ool00`00Oomoo`0=Ool00`00Oomoo`31Ool00`00Oomoo`0XOol00`00Oomoo`0;Ool0015oo`03
001oogoo00Uoo`03001oogoo03Uoo`03001oogoo02Eoo`03O01oogoo01Ioo`03001oogoo00=oo`03
001oo`0000]oo`8001Ioo`8000ioo`03001oogoo00eoo`03001oogoo0<9oo`03001oogoo02Moo`03
001oogoo00]oo`004Goo00<007ooOol02Goo00<007ooOol09goo0W`04Goo00<007ooOol097oo00=l
07ooOol05Woo00<007ooOol017oo00<007oo00002goo10005Goo0P0037oo00<007ooOol03Woo00<0
07ooOol0`Goo00<007ooOol09goo00<007ooOol02goo000AOol00`00Oomoo`0:Ool00`00Oomoo`0X
Ool00g`0Oomoo`0?Ool00`00Oomoo`0SOol00g`0Oomoo`0FOol00`00Oomoo`04Ool00`00Ool0000=
Ool4000EOol3000:Ool00`00Oomoo`0=Ool00`00Oomoo`32Ool00`00Oomoo`0VOol00`00Oomoo`0;
Ool0015oo`03001oogoo00]oo`03001oogoo02Qoo`9l011oo`03001oogoo02=oo`03O01oogoo01Eo
o`03001oogoo00Aoo`04001oogoo000>Ool4000FOol20008Ool00`00Oomoo`0>Ool00`00Oomoo`32
Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool0015oo`03001oogoo00]oo`03001oogoo02Yoo`03O01o
ogoo00ioo`03001oogoo029oo`03O01oogoo01Eoo`03001oogoo00Aoo`04001oogoo000@Ool4000F
Ool20006Ool00`00Oomoo`0>Ool00`00Oomoo`33Ool00`00Oomoo`0TOol00`00Oomoo`0;Ool0015o
o`03001oogoo00aoo`03001oogoo02Yoo`9l00ioo`03001oogoo029oo`03O01oogoo01Aoo`8000Mo
o`04001oogoo000BOol2000GOol20005Ool00`00Oomoo`0>Ool00`00Oomoo`32Ool00`00Oomoo`0T
Ool00`00Oomoo`0;Ool0015oo`03001oogoo00eoo`03001oogoo02]oo`03O01oogoo00aoo`03001o
ogoo025oo`03O01oogoo01Aoo`03001oogoo00Ioo`04001oogoo000DOol2000GOol30002Ool00`00
Oomoo`0?Ool00`00Oomoo`32Ool00`00Oomoo`0SOol00`00Oomoo`0;Ool0015oo`03001oogoo00eo
o`03001oogoo02aoo`9l00eoo`03001oogoo021oo`03O01oogoo01Aoo`03001oogoo00Ioo`05001o
ogooOol0000EOol2000HOol3000AOol00`00Oomoo`33Ool00`00Oomoo`0ROol00`00Oomoo`0;Ool0
015oo`03001oogoo00ioo`03001oogoo02eoo`03O01oogoo00]oo`03001oogoo021oo`03O01oogoo
01=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo01Aoo`8001Qoo`80015oo`03001oogoo
0<=oo`03001oogoo025oo`03001oogoo00]oo`004Goo0`003goo00<007ooOol0;Goo00=l07ooOol0
2Woo00<007ooOol087oo00=l07ooOol04goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
5Woo0`005Woo0`003goo00<007ooOol0a7oo00<007ooOol07goo0P003Goo000AOol00`00Oomoo`0?
Ool00`00Oomoo`0^Ool00g`0Oomoo`0:Ool00`00Oomoo`0OOol00g`0Oomoo`0COol00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`0FOol4000DOol00`00Oomoo`03000=Ool00`00Oomoo`33Ool0
0`00Oomoo`0POol00`00Oomoo`0;Ool0015oo`03001oogoo011oo`03001oogoo02ioo`9l00]oo`03
001oogoo01ioo`03O01oogoo019oo`8000Uoo`03001oogoo009oo`03001oogoo01Qoo`@0019oo`03
001oogoo00=oo`8000]oo`03001oogoo0<Aoo`03001oogoo01moo`03001oogoo00]oo`004Goo00<0
07ooOol047oo00<007ooOol0<7oo00=l07ooOol02Goo00<007ooOol07Woo00=l07ooOol04Goo0P00
2Goo00<007ooOol00goo00<007ooOol06Goo10004Goo00<007ooOol017oo0P002Woo00<007ooOol0
a7oo00<007ooOol07Woo00<007ooOol02goo000AOol00`00Oomoo`0AOol00`00Oomoo`0`Ool00g`0
Oomoo`09Ool00`00Oomoo`0MOol00g`0Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`02Ool00`00
Oomoo`0KOol4000?Ool00`00Oomoo`06Ool20009Ool00`00Oomoo`34Ool00`00Oomoo`0MOol00`00
Oomoo`0;Ool0015oo`03001oogoo019oo`03001oogoo031oo`03O01oogoo00Qoo`03001oogoo01eo
o`03O01oogoo015oo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo01eoo`8000ioo`03001o
ogoo00Qoo`<000Ioo`03001oogoo0<Aoo`03001oogoo01eoo`03001oogoo00]oo`004Goo00<007oo
Ool04Woo00<007ooOol0<Goo00=l07ooOol027oo00<007ooOol077oo00=l07ooOol04Goo00<007oo
Ool02Goo00<007ooOol00goo00<007ooOol07goo0P0037oo00<007ooOol02goo0P001Goo00<007oo
Ool0a7oo00<007ooOol077oo00<007ooOol02goo000AOol00`00Oomoo`0COol00`00Oomoo`0aOol0
0g`0Oomoo`08Ool00`00Oomoo`0KOol00g`0Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`03Ool0
0`00Oomoo`0POol2000:Ool00`00Oomoo`0=Ool20004Ool00`00Oomoo`34Ool00`00Oomoo`0KOol0
0`00Oomoo`0;Ool0015oo`8001Aoo`03001oogoo039oo`03O01oogoo00Qoo`03001oogoo01]oo`03
O01oogoo011oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo029oo`8000Uoo`03001oogoo
00ioo`80009oo`03001oogoo0<Eoo`03001oogoo01Yoo`03001oogoo00]oo`004Goo0`0057oo00<0
07ooOol0<Woo00=l07ooOol01goo00<007ooOol06goo00=l07ooOol03goo0P0037oo00<007ooOol0
0goo00<007ooOol097oo0`001Woo00<007ooOol047oo1000aWoo00<007ooOol06Woo00<007ooOol0
2goo000AOol00`00Ool0000DOol00`00Oomoo`0cOol00g`0Oomoo`07Ool00`00Oomoo`0JOol00g`0
Oomoo`0?Ool2000=Ool00`00Oomoo`03Ool00`00Oomoo`0TOol40004Ool00`00Oomoo`0COol20036
Ool00`00Oomoo`0IOol00`00Oomoo`0;Ool0015oo`04001oo`00000DOol00`00Oomoo`0cOol00g`0
Oomoo`07Ool00`00Oomoo`0IOol00g`0Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0VOol40003Ool00`00Oomoo`0COol30035Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool0015o
o`03001oogoo008001=oo`03001oogoo03Aoo`03O01oogoo00Ioo`03001oogoo01Uoo`03O01oogoo
00moo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo02Moo`@00003Ool007oo01Eoo`04001o
o`000034Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool0015oo`05001oogooOol0000DOol00`00Oomo
o`0dOol00g`0Oomoo`06Ool00`00Oomoo`0HOol00g`0Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomo
o`04Ool00`00Oomoo`0ZOol4000EOol01000Oomoogoo0`00`Goo00<007ooOol05goo00<007ooOol0
2goo0008Ool30006Ool01000Oomoogoo0P0057oo00<007ooOol0=7oo00=l07ooOol017oo00=l07oo
00006Woo00=l07ooOol03Woo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0:goo100057oo
00<007ooOol00goo0P00`7oo00<007ooOol05Woo00<007ooOol02goo0009Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool2000COol00`00Oomoo`0eOol00g`0Oomoo`04Ool00g`0001oo`0IOol00g`0Oomo
o`0=Ool2000?Ool00`00Oomoo`04Ool00`00Oomoo`0/Ool00`00Ool00002000COol00`00Oomoo`04
Ool2002oOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Ioo`D000Ioo`@00003Ool0000001Aoo`03
001oogoo03Eoo`05O01oogooOol00002Ool00g`0001oo`0HOol00g`0Oomoo`0=Ool2000?Ool00`00
Oomoo`05Ool00`00Oomoo`0[Ool01000Oomoogoo0`004Goo00<007ooOol01Woo0P00_Goo00<007oo
Ool04goo0`003Goo0006Ool01000Oomoo`001goo00<007ooOol00goo0P004goo00<007ooOol0=Woo
00Al07ooOol000=oo`03O00007oo01Moo`03O01oogoo00eoo`8000moo`03001oogoo00Ioo`03001o
ogoo02]oo`03001oogoo009oo`<0011oo`03001oogoo00Moo`<00;]oo`03001oogoo01Aoo`03001o
ogoo00]oo`001goo00<007oo00001goo00<007ooOol00goo0P0057oo00<007ooOol0=Woo00=l07oo
000017oo00=l07ooOol05Woo00=l07ooOol03Goo0P003goo00<007ooOol01Woo00<007ooOol0:goo
00<007ooOol017oo0P003goo00<007ooOol02Woo0P00^Woo00<007ooOol04goo00<007ooOol02goo
0008Ool20007Ool00`00Oomoo`04Ool2000COol00`00Oomoo`0gOol00g`0001oo`04Ool00g`0Oomo
o`0UOol2000@Ool00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool3000>Ool00`00Oomo
o`0;Ool2002hOol00`00Oomoo`0COol00`00Oomoo`0;Ool000Uoo`03001oogoo00Eoo`03001oogoo
00Eoo`8001=oo`03001oogoo03Moo`03O01oogoo00Aoo`03O01oogoo02Aoo`03001oogoo00moo`03
001oogoo00Ioo`03001oogoo02]oo`03001oogoo00Ioo`<000aoo`03001oogoo00eoo`800;Moo`03
001oogoo019oo`03001oogoo00]oo`004Goo00<007ooOol01Goo0P004goo00<007ooOol0=goo00<0
07`0Ool01Goo00=l07ooOol08goo00<007ooOol03goo00<007ooOol01goo00<007ooOol0:Woo00<0
07ooOol027oo0`002goo00<007ooOol03Woo0`00]Goo00<007ooOol04Goo00<007ooOol02goo000A
Ool00`00Oomoo`06Ool2000COol00`00Oomoo`0fOol00`00Ooml0006Ool00g`0Oomoo`0ROol00`00
Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`0:Ool40008Ool00`00Oomoo`0A
Ool2002cOol00`00Oomoo`0AOol00`00Oomoo`0;Ool0015oo`03001oogoo00Moo`03001oogoo019o
o`03001oogoo03Eoo`04001oogooO006Ool00g`0Oomoo`0QOol00`00Oomoo`0@Ool00`00Oomoo`07
Ool00`00Oomoo`0ZOol00`00Oomoo`0;Ool01000Ool000001goo00<007ooOol04Woo0P00/Woo00<0
07ooOol047oo00<007ooOol02goo000AOol00`00Oomoo`07Ool2000COol00`00Oomoo`0eOol01@00
OomoogooO0001Woo00=l07ooOol087oo00<007ooOol047oo00<007ooOol027oo00<007ooOol0:Goo
00<007ooOol037oo0P0000=oo`0000001Woo00<007ooOol04goo0`00/7oo00<007ooOol03goo00<0
07ooOol02goo000AOol00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0dOol01@00Oomoogoo
O0001goo00=l07ooOol07Woo0P004goo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol03Woo
0P0000=oo`00000017oo00<007ooOol05Woo0P00[Woo00<007ooOol03goo00<007ooOol02goo000A
Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0dOol00`00Oomoo`02Ool00g`0Oomoo`04
Ool00`00O01oo`0NOol2000COol00`00Oomoo`08Ool00`00Oomoo`0YOol00`00Oomoo`0?Ool20000
0goo00000003Ool00`00Oomoo`0GOol3002/Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool0015oo`03
001oogoo00Uoo`03001oogoo019oo`03001oogoo03=oo`03001oogoo00=oo`03O01oogoo00Aoo`03
001l07oo01eoo`8001=oo`03001oogoo00Uoo`03001oogoo02Qoo`03001oogoo015oo`@0009oo`03
001oogoo01Yoo`800:]oo`03001oogoo00eoo`03001oogoo00]oo`004Goo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol0<goo00<007ooOol017oo00=l07ooOol017oo00<007`0Ool077oo0P00
57oo00<007ooOol027oo00<007ooOol0:7oo00<007ooOol057oo0`0000=oo`00Ool077oo0P00ZGoo
00<007ooOol03Goo00<007ooOol02goo000AOol00`00Oomoo`0:Ool2000COol00`00Oomoo`0bOol0
0`00Oomoo`05Ool00g`0Oomoo`03Ool00`00Ooml000LOol00`00Oomoo`0COol00`00Oomoo`09Ool0
0`00Oomoo`0XOol00`00Oomoo`0EOol3000OOol3002WOol00`00Oomoo`0<Ool00`00Oomoo`0;Ool0
015oo`8000aoo`03001oogoo015oo`03001oogoo03=oo`03001oogoo00Eoo`03O01oogoo00=oo`03
001oog`001]oo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo02Moo`03001oogoo01Moo`<0
021oo`800:Ioo`03001oogoo00]oo`03001oogoo00]oo`004Goo00<007oo000037oo00<007ooOol0
4Goo00<007ooOol0<Woo00<007ooOol01Woo00=l07ooOol00goo00<007ooO0006Woo00<007ooOol0
57oo00<007ooOol02Goo00<007ooOol09goo00<007ooOol067oo1@007goo0P00Y7oo00<007ooOol0
2goo00<007ooOol02goo000AOol01000Oomoo`002goo00<007ooOol04Woo00<007ooOol0<Goo00<0
07ooOol01goo00=l07ooOol00Woo00@007ooOoml01Uoo`03001oogoo01Aoo`03001oogoo00Yoo`03
001oogoo02Moo`03001oogoo01Qoo`04001oo`00Ool2000OOol2002SOol00`00Oomoo`0:Ool00`00
Oomoo`0;Ool0015oo`<00003Ool007oo00Yoo`03001oogoo015oo`03001oogoo035oo`03001oogoo
00Qoo`03O01oogoo009oo`04001oogooO00HOol00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomo
o`0WOol00`00Oomoo`0HOol00`00Oomoo`0200000goo0000000OOol3002QOol00`00Oomoo`08Ool2
000=Ool0015oo`80009oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo031oo`03001oogoo
00Uoo`03O01oogoo009oo`04001oogooO00FOol2000GOol00`00Oomoo`0:Ool00`00Oomoo`0VOol0
0`00Oomoo`0HOol00`00Oomoo`02Ool200000goo0000000POol2002OOol00`00Oomoo`09Ool00`00
Oomoo`0;Ool0015oo`06001oo`00001oo`002goo00<007ooOol04Goo00<007ooOol0<7oo00<007oo
Ool02Woo00El07ooOomoo`0000=oo`03O01oogoo01=oo`8001Moo`03001oogoo00]oo`03001oogoo
02Ioo`03001oogoo01Qoo`03001oogoo00=oo`800004Ool00000000OOol3002MOol00`00Oomoo`08
Ool00`00Oomoo`0;Ool0015oo`04001oogooOol3000:Ool00`00Oomoo`0BOol00`00Oomoo`0_Ool0
0`00Oomoo`0;Ool01G`0Oomoogoo00000goo00=l07ooOol04Woo0P005goo00<007ooOol02goo00<0
07ooOol09Woo00<007ooOol067oo00<007ooOol01Goo0P000Woo0P0087oo0`00Vgoo00<007ooOol0
1goo00<007ooOol02goo000AOol00`00Oomoo`03Ool30009Ool00`00Oomoo`0AOol00`00Oomoo`0_
Ool00`00Oomoo`0<Ool01G`0Oomoogoo00000goo00=l07ooOol04Goo0P0067oo00<007ooOol02goo
00<007ooOol09Goo00<007ooOol06Goo00<007ooOol01Woo00@007ooOomoo`80025oo`<009Qoo`03
001oogoo00Moo`03001oogoo00]oo`004Goo00<007ooOol017oo00@007oo000000Moo`8001=oo`03
001oogoo02ioo`03001oogoo00eoo`04O01oogoo0004Ool00g`0Oomoo`0@Ool2000HOol00`00Oomo
o`0;Ool00`00Oomoo`0VOol00`00Oomoo`0HOol00`00Oomoo`07Ool20003Ool3000QOol2002GOol0
0`00Oomoo`06Ool00`00Oomoo`0;Ool0015oo`8000Eoo`04001oogooOol20006Ool00`00Oomoo`0A
Ool00`00Oomoo`0_Ool00`00Oomoo`0=Ool017`0Oomoo`000goo00=l07ooOol047oo00<007ooOol0
5goo00<007ooOol037oo00<007ooOol09Goo00<007ooOol06Goo00<007ooOol027oo0P0017oo0P00
8Goo0P00UWoo00<007ooOol01Goo00<007ooOol02goo000AOol00`00Ool00005Ool00`00Oomoo`02
Ool30004Ool00`00Oomoo`0AOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool017`0Oomoo`000goo00=l
07ooOol03goo00<007ooOol067oo00<007ooOol02goo00<007ooOol09Goo00<007ooOol06Goo00<0
07ooOol02Woo0P0017oo0`0087oo0`00Tgoo00<007ooOol01Goo00<007ooOol02goo000AOol01000
Oomoo`0017oo00<007ooOol01Goo0P000Woo00<007ooOol04Woo00<007ooOol0;Goo00<007ooOol0
3goo00=l07oo000017oo00=l07ooOol03Woo00<007ooOol067oo00<007ooOol037oo00<007ooOol0
9Goo00<007ooOol06Goo00<007ooOol02goo0`0017oo0P008Goo0P00TWoo00<007ooOol017oo00<0
07ooOol02goo000AOol01@00Oomoogoo000017oo00<007ooOol01Woo0P0000=oo`00Ool04Woo00<0
07ooOol0;Goo00<007ooOol047oo00=l07oo000017oo00=l07ooOol03Goo00<007ooOol06Goo00<0
07ooOol037oo00<007ooOol097oo00<007ooOol06Woo00<007ooOol03Goo0P0017oo0P008Goo0P00
TGoo00<007ooOol00goo00<007ooOol02goo000AOol01@00Oomoogoo000017oo00<007ooOol027oo
0P0057oo00<007ooOol0;7oo00<007ooOol04Goo00=l07oo000017oo00=l07ooOol02goo0P006goo
00<007ooOol037oo00<007ooOol097oo00<007ooOol06Woo00<007ooOol03goo0P0017oo0P008Goo
0P00Sgoo00<007ooOol00goo00<007ooOol02goo000AOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool3000AOol00`00Oomoo`0/Ool00`00Oomoo`0BOol00g`0001oo`04Ool00g`0Oomo
o`0:Ool2000KOol00`00Oomoo`0=Ool00`00Oomoo`0TOol00`00Oomoo`0JOol00`00Oomoo`0@Ool2
0004Ool00`00Oomoo`0POol2002>Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool0015oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo0080011oo`03001oogoo02]oo`03001o
ogoo019oo`03O01oo`0000Eoo`03O01oogoo00Uoo`8001aoo`03001oogoo00eoo`03001oogoo02=o
o`03001oogoo01Yoo`03001oogoo019oo`8000=oo`80029oo`03001oogoo08aoo`05001oogooOol0
000=Ool0015oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Uoo`04001oogooOol2000>
Ool00`00Oomoo`0[Ool00`00Oomoo`0COol00g`0Ool00005Ool00g`0Oomoo`08Ool2000LOol00`00
Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomoo`0KOol00`00Oomoo`0COol20003Ool2000QOol2002<
Ool01@00Oomoogoo00003Goo000AOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
0`00Oomoo`02Ool2000=Ool00`00Oomoo`0ZOol00`00Oomoo`0DOol00g`0001oo`0?Ool2000MOol0
0`00Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomoo`0JOol00`00Oomoo`0EOol20003Ool2000QOol2
002;Ool01000Oomoo`003Goo000AOol00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`04Ool3000:Ool00`00Oomoo`0ZOol00`00Oomoo`0EOol00g`0001oo`0>Ool2000MOol0
0`00Oomoo`0>Ool00`00Oomoo`0ROol00`00Oomoo`0KOol00`00Oomoo`0FOol20003Ool3000POol2
002:Ool00`00Ool0000=Ool0015oo`<000Eoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo
00Ioo`8000Uoo`03001oogoo02Uoo`03001oogoo01Ioo`03O00007oo00Moo`03001oogoo00=oo`80
01ioo`03001oogoo00eoo`03001oogoo029oo`03001oogoo01]oo`03001oogoo01Qoo`8000Aoo`80
021oo`<008Moo`<000eoo`004Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol027oo0P00
2Goo0P0027oo00<007ooOol0:7oo00<007ooOol05goo00=l07ooOol01Woo00<007ooOol00goo0P00
7Woo00<007ooOol03Woo00<007ooOol08Woo00<007ooOol06goo00<007ooOol06Goo0P0017oo0P00
8Goo0P00QWoo0P003Goo000AOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool20006Ool00`00Oomoo`0XOol00`00Oomoo`0GOol00g`0001oo`07Ool00`00Oomoo`02
Ool2000NOol00`00Oomoo`0?Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0JOol00`00
Oomoo`03Ool2000QOol20024Ool2000=Ool0015oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Qoo`8000aoo`<000Aoo`03001oogoo02Moo`03001oogoo01Qoo`03O00007oo00Moo`04001o
ogooOol2000OOol00`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`0LOol00`00Oomoo`0KOol2
0005Ool3000POol20023Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Qoo`8000ioo`80009oo`03001oogoo02Moo`03001oogoo01Uoo`03O01oogoo00Moo`03
001oogoo008001moo`03001oogoo00moo`03001oogoo025oo`03001oogoo01aoo`03001oogoo01ao
o`8000Ioo`80021oo`<0081oo`03001oogoo00]oo`004Goo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol01goo0P0047oo0P0000=oo`00Ool09goo00<007ooOol06Woo00=l07ooOol01goo00@0
07oo000001moo`03001oogoo011oo`03001oogoo021oo`03001oogoo01aoo`03001oogoo01ioo`80
00Ioo`80025oo`8007ioo`03001oogoo00]oo`004Goo00<007ooOol02Goo00<007ooOol00Woo00<0
07ooOol027oo0P004Goo0P00:7oo00<007ooOol06goo00=l07ooOol01goo0`0087oo00<007ooOol0
3goo00<007ooOol087oo00<007ooOol07Goo00<007ooOol07goo0`001Goo0P008Goo0P00O7oo00<0
07ooOol02goo000AOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0A
Ool3000UOol00`00Oomoo`0LOol00`00Oomoo`07Ool2000POol00`00Oomoo`0@Ool00`00Oomoo`0O
Ool00`00Oomoo`0MOol00`00Oomoo`0ROol20005Ool3000POol2001jOol00`00Oomoo`0;Ool0015o
o`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Moo`80019oo`03001oogoo008002=oo`03
001oogoo01eoo`03001oogoo00Ioo`03001oogoo01moo`03001oogoo015oo`03001oogoo01moo`03
001oogoo01eoo`03001oogoo02=oo`8000Ioo`80021oo`<007Moo`03001oogoo00]oo`004Goo00<0
07ooOol02goo00<007ooOol00Woo00<007ooOol027oo0P004Woo00@007ooOomoo`80025oo`03001o
ogoo01eoo`03001oogoo00Ioo`80025oo`03001oogoo011oo`03001oogoo01moo`03001oogoo01eo
o`03001oogoo02Eoo`8000Ioo`80025oo`8007Eoo`03001oogoo00]oo`004Goo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol01goo0P004goo00<007ooOol00Woo0P007goo00<007ooOol07Woo
00<007ooOol01Goo0P008Goo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol07Woo00<007oo
Ool09Woo0P001Woo0P008Goo0P00Lgoo00<007ooOol02goo000AOol00`00Oomoo`0=Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool2000BOol00`00Oomoo`04Ool3000LOol00`00Oomoo`0OOol00`00Oomo
o`04Ool3000QOol00`00Oomoo`0AOol00`00Oomoo`0MOol00`00Oomoo`0OOol00`00Oomoo`0WOol0
0`00Oomoo`05Ool3000POol2001aOol00`00Oomoo`0;Ool0015oo`03001oogoo00eoo`03001oogoo
009oo`03001oogoo00Moo`8001=oo`03001oogoo00Ioo`8001Yoo`03001oogoo021oo`03001oogoo
00=oo`<0025oo`03001oogoo019oo`03001oogoo01aoo`03001oogoo01moo`03001oogoo02Qoo`80
00Qoo`80021oo`<006ioo`03001oogoo00]oo`004Goo00<007ooOol03Woo00<007ooOol00Woo00<0
07ooOol01goo0P004Woo00<007ooOol027oo0P0067oo00<007ooOol087oo00<007ooOol00goo00@0
07oo0000025oo`03001oogoo019oo`03001oogoo01aoo`03001oogoo01moo`03001oogoo02Uoo`80
00Qoo`80025oo`8006aoo`03001oogoo00]oo`004Goo00<007ooOol03goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol04Goo00<007ooOol02Goo0P005Woo00<007ooOol08Goo00<007ooOol0
0Woo00@007oo0000025oo`03001oogoo019oo`03001oogoo01aoo`03001oogoo01moo`03001oogoo
02]oo`8000Qoo`80025oo`8006Yoo`03001oogoo00]oo`004Goo00<007ooOol03goo00<007ooOol0
0Woo00<007ooOol01goo0P004Woo00<007ooOol02goo0P0057oo00<007ooOol08Woo00T007ooOomo
o`00Ool007oo00008Goo00<007ooOol04Woo00<007ooOol06goo00<007ooOol087oo00<007ooOol0
;7oo0P0027oo0`0087oo0P00J7oo00<007ooOol02goo000AOol00`00Oomoo`0@Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0R
Ool01@00Oomoogoo00000Woo0P008Goo00<007ooOol04goo00<007ooOol06goo00<007ooOol07goo
00<007ooOol0;Woo00<007ooOol027oo0P0087oo0`00IGoo00<007ooOol02goo000AOol3000AOol0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0=Ool2000AOol00`00Oomo
o`0SOol01000Oomoo`000Woo00<007oo00008Goo00<007ooOol04goo00<007ooOol06Woo00<007oo
Ool087oo00<007ooOol0;Woo0P002Woo0P008Goo0P00HWoo0P003Goo000AOol00`00Oomoo`0AOol0
0`00Oomoo`02Ool00`00Oomoo`07Ool2000BOol00`00Oomoo`0>Ool2000?Ool00`00Oomoo`0TOol0
0`00Ool00002Ool00`00Ool0000QOol00`00Oomoo`0COol00`00Oomoo`0JOol00`00Oomoo`0POol0
0`00Oomoo`0`Ool2000:Ool2000QOol2001QOol00`00Oomoo`0;Ool0015oo`03001oogoo019oo`03
001oogoo009oo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00moo`8000eoo`03001oogoo
02Aoo`03001oo`0000=oo`03001oo`00021oo`03001oogoo01Aoo`03001oogoo01Yoo`03001oogoo
021oo`03001oogoo035oo`8000Yoo`<0021oo`8005moo`03001oogoo00]oo`004Goo00<007ooOol0
4goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol047oo00<007ooOol04Goo0`002Woo00<0
07ooOol09Goo0P000goo00<007oo00008Goo00<007ooOol057oo00<007ooOol06Goo00<007ooOol0
87oo00<007ooOol0<goo0`002Woo0P0087oo0`00G7oo00<007ooOol02goo000AOol00`00Oomoo`0C
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`0COol20008Ool00`00
Oomoo`0VOol01@00Oomoogoo00000Woo00<007ooOol07Woo00<007ooOol057oo00<007ooOol06Goo
00<007ooOol08Goo00<007ooOol0=Goo0P002Woo0P008Goo0P00FWoo00<007ooOol02goo000AOol0
0`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`0EOol2
0006Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Ool0000POol00`00Oomoo`0EOol00`00Oomo
o`0IOol00`00Oomoo`0POol00`00Oomoo`0gOol2000:Ool2000QOol2001HOol00`00Oomoo`0;Ool0
015oo`03001oogoo01Eoo`05001oogooOol00009Ool00`00Oomoo`0AOol00`00Oomoo`0FOol20004
Ool00`00Oomoo`0VOol20003Ool00`00Ool0000QOol00`00Oomoo`0EOol00`00Oomoo`0HOol00`00
Oomoo`0QOol00`00Oomoo`0hOol2000:Ool3000POol2001FOol00`00Oomoo`0;Ool0015oo`03001o
ogoo01Eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo01Qoo`80009o
o`03001oogoo02Ioo`8000=oo`04001oogoo000POol00`00Oomoo`0EOol00`00Oomoo`0HOol00`00
Oomoo`0QOol00`00Oomoo`0jOol2000;Ool2000POol3001COol00`00Oomoo`0;Ool0015oo`03001o
ogoo01Ioo`03001oogoo009oo`03001oogoo00Ioo`80019oo`03001oogoo01Uoo`03001oo`0002Mo
o`<000Aoo`03001oo`00021oo`03001oogoo01Ioo`03001oogoo01Qoo`03001oogoo025oo`03001o
ogoo03]oo`03001oogoo00Yoo`80025oo`80055oo`03001oogoo00]oo`004Goo00<007ooOol05goo
00D007ooOomoo`0000Uoo`03001oogoo011oo`03001oogoo01Yoo`8002Moo`800003Ool007oo009o
o`04001oogoo000POol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0QOol00`00Oomoo`0l
Ool2000<Ool2000QOol2001?Ool00`00Oomoo`0;Ool0015oo`03001oogoo01Moo`03001oogoo009o
o`03001oogoo00Ioo`80019oo`03001oogoo01Yoo`<002Eoo`800003Ool007oo009oo`04001oogoo
000POol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0ROol00`00Oomoo`0mOol2000<Ool3
000POol2001=Ool00`00Oomoo`0;Ool0015oo`03001oogoo01Qoo`05001oogooOol00009Ool00`00
Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`02000TOol00`00Ool00004Ool01000Oomoo`0087oo
00<007ooOol05Woo00<007ooOol05goo00<007ooOol08Goo00<007ooOol0?goo0P003Goo0P0087oo
0`00BWoo00<007ooOol02goo000AOol00`00Oomoo`0IOol01@00Oomoogoo000027oo0P004Goo00<0
07ooOol06Woo00<007ooOol00Woo0`008Goo00@007ooOol000=oo`04001oogoo000POol00`00Oomo
o`0GOol00`00Oomoo`0FOol00`00Oomoo`0ROol00`00Oomoo`10Ool2000=Ool2000QOol20018Ool0
0`00Oomoo`0;Ool0015oo`03001oogoo01Uoo`05001oogooOol00009Ool00`00Oomoo`0@Ool00`00
Oomoo`0IOol00`00Oomoo`05Ool2000OOol01000Oomoo`000goo00D007ooOomoo`0001moo`03001o
ogoo01Qoo`03001oogoo01Eoo`03001oogoo029oo`03001oogoo049oo`8000eoo`80025oo`8004Io
o`03001oogoo00]oo`004Goo00<007ooOol06Woo00D007ooOomoo`0000Qoo`80015oo`03001oogoo
01Uoo`03001oogoo00Moo`8001eoo`03001oogoo008000=oo`05001oogooOol0000OOol00`00Oomo
o`0HOol00`00Oomoo`0EOol00`00Oomoo`0QOol00`00Oomoo`14Ool2000=Ool3000POol20014Ool0
0`00Oomoo`0;Ool0015oo`03001oogoo01]oo`05001oogooOol00008Ool00`00Oomoo`0@Ool00`00
Oomoo`0HOol00`00Oomoo`09Ool2000KOol00`00Oomoo`020003Ool01@00Oomoogoo00007goo00<0
07ooOol067oo00<007ooOol05Goo00<007ooOol08Woo00<007ooOol0AGoo0P003Woo0P0087oo0`00
@Goo00<007ooOol02goo000AOol3000KOol01@00Oomoogoo000027oo0P004Goo00<007ooOol067oo
00<007ooOol02goo0P006Goo00@007ooOomoo`80009oo`03001oogoo009oo`03001oogoo01eoo`03
001oogoo01Qoo`03001oogoo01Aoo`03001oogoo029oo`03001oogoo04Moo`8000ioo`80025oo`80
03ioo`8000eoo`004Goo00<007ooOol077oo00D007ooOomoo`0000Qoo`80015oo`03001oogoo01Mo
o`03001oogoo00eoo`03001oogoo01Ioo`04001oogooOol20003Ool01@00Oomoogoo00007goo00<0
07ooOol06Goo00<007ooOol04goo00<007ooOol08goo00<007ooOol0B7oo0`003Goo0`0087oo0P00
?Goo00<007ooOol02goo000AOol00`00Oomoo`0MOol01@00Oomoogoo00001goo0P004Goo00<007oo
Ool05goo00<007ooOol03Woo0P005Woo00L007ooOomoo`00Ool00002Ool00`00Oomoo`02Ool00`00
Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`1;Ool2000>
Ool2000POol2000kOol00`00Oomoo`0;Ool0015oo`8001ioo`05001oogooOol00008Ool2000AOol0
0`00Oomoo`0FOol00`00Oomoo`0@Ool2000DOol00`00Oomoo`02Ool20002Ool00`00Oomoo`02Ool0
0`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`0COol00`00Oomoo`0SOol00`00Oomoo`1<Ool2
000>Ool3000OOol3000hOol00`00Oomoo`0;Ool0015oo`04001oo`00000MOol01@00Oomoogoo0000
27oo00<007ooOol047oo00<007ooOol05Goo00<007ooOol04Woo0P004Woo00<007ooOol00Woo00<0
07oo00000Woo00<007ooOol00Woo00<007ooOol07Goo00<007ooOol06Goo00<007ooOol04Woo00<0
07ooOol08goo00<007ooOol0CWoo0P003goo0`007goo0P00=Woo00<007ooOol02goo000AOol01@00
Oomoogoo00007Goo00D007ooOomoo`0000Moo`80015oo`03001oogoo01Eoo`03001oogoo01Aoo`<0
00moo`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`03001oogoo01eoo`03001oogoo
01Yoo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo04moo`80011oo`<001ioo`8003Aoo`03
001oogoo00]oo`004Goo00<007ooOol00Woo0P006goo00D007ooOomoo`0000Qoo`03001oogoo011o
o`03001oogoo01Aoo`03001oogoo01Moo`8000eoo`03001oogoo00=oo`03001oo`00009oo`03001o
ogoo009oo`03001oogoo01aoo`03001oogoo01]oo`03001oogoo011oo`03001oogoo02Eoo`03001o
ogoo051oo`03001oogoo011oo`<001eoo`80039oo`03001oogoo00]oo`004Goo00<007ooOol017oo
00<007ooOol06Goo00D007ooOomoo`0000Moo`80015oo`03001oogoo01Aoo`03001oogoo01Uoo`80
00]oo`03001oogoo00=oo`03001oo`00009oo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo
01]oo`03001oogoo011oo`03001oogoo02Aoo`03001oogoo055oo`8001=oo`8001eoo`<002moo`03
001oogoo00]oo`004Goo00<007ooOol01Goo00<007ooOol06Goo00D007ooOomoo`0000Moo`03001o
ogoo011oo`03001oogoo01=oo`03001oogoo01]oo`8000Uoo`03001oogoo00=oo`06001oogoo001o
o`001Goo00<007ooOol077oo00<007ooOol06goo00<007ooOol047oo00<007ooOol09Goo00<007oo
Ool0DWoo0P004goo0P007Woo0P00;Goo00<007ooOol02goo000AOol00`00Oomoo`06Ool00`00Oomo
o`0HOol01@00Oomoogoo00001goo0P004Goo00<007ooOol04goo00<007ooOol07Goo0P001goo00<0
07ooOol00goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo01]oo`03
001oogoo00moo`03001oogoo02Eoo`03001oogoo05Aoo`8001=oo`<001eoo`8002]oo`03001oogoo
00]oo`004Goo0P0027oo0P006Goo00D007ooOomoo`0000Moo`03001oogoo011oo`03001oogoo019o
o`03001oogoo01moo`03001oogoo00Aoo`03001oogoo00Aoo`06001oogoo001oo`001Goo00<007oo
Ool077oo00<007ooOol077oo00<007ooOol03goo00<007ooOol09Goo00<007ooOol0EGoo0P0057oo
0P007Goo0P00:Goo00<007ooOol02goo000AOol00`00Ool00009Ool00`00Oomoo`0GOol01@00Oomo
ogoo00001Woo0P004Goo00<007ooOol04Woo00<007ooOol087oo0P0017oo00<007ooOol017oo00@0
07ooOol0009oo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo01aoo`03001oogoo00ioo`03
001oogoo02Eoo`03001oogoo05Moo`03001oogoo01=oo`8001eoo`<002Ioo`03001oogoo00]oo`00
4Goo00@007ooOol000Uoo`03001oogoo01Ioo`05001oogooOol00007Ool00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`0ROol20002Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0000Eoo`03
001oogoo01aoo`03001oogoo01aoo`03001oogoo00ioo`03001oogoo02Ioo`03001oogoo05Moo`80
01Eoo`8001ioo`8002Aoo`03001oogoo00]oo`004Goo00D007ooOomoo`0000Uoo`03001oogoo01Io
o`05001oogooOol00006Ool2000AOol00`00Oomoo`0AOol00`00Oomoo`0TOol30007Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol077oo00<007ooOol077oo00<007ooOol03Woo00<007oo
Ool09Goo00<007ooOol0FGoo0P005Goo0`007Goo0P008Woo00<007ooOol02goo0007Ool30007Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0FOol01@00Oomoogoo00001Woo0P0047oo00<0
07ooOol04Goo00<007ooOol09Woo0P001Woo00L007ooOomoo`00Ool00005Ool00`00Oomoo`0LOol0
0`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Oomoo`0VOol00`00Oomoo`1JOol2000FOol2000MOol2
000POol00`00Oomoo`0;Ool000Ioo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool2000FOol01@00Oomoogoo00001Woo0P004Goo00<007ooOol047oo00<007ooOol09Woo00<007oo
00001Goo00L007ooOomoo`00Ool00006Ool00`00Oomoo`0KOol00`00Oomoo`0NOol00`00Oomoo`0<
Ool00`00Oomoo`0WOol00`00Oomoo`1KOol2000FOol3000LOol2000NOol00`00Oomoo`0;Ool000Io
o`05001oogooOol00006Ool40003Ool00`00Oomoo`08Ool00`00Oomoo`0DOol01@00Oomoogoo0000
1Woo0P0047oo00<007ooOol047oo00<007ooOol09Woo00<007ooOol00P0017oo00@007ooOol0009o
o`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo01ioo`03001oogoo00aoo`03001oogoo02Io
o`03001oogoo05eoo`03001oogoo01Ioo`<001]oo`03001oogoo01Uoo`<000eoo`001Woo10001goo
00<007ooOol01Goo00<007ooOol027oo00<007ooOol057oo00@007ooOol000Ioo`03001oo`00011o
o`03001oogoo00moo`03001oogoo02Ioo`03001oogoo009oo`80009oo`07001oogooOol007oo0000
1Woo00<007ooOol06goo00<007ooOol07goo00<007ooOol02goo00<007ooOol09goo00<007ooOol0
GGoo0P006Goo0`006Goo0P006goo00<007ooOol02goo0006Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool20009Ool00`00Oomoo`0DOol01000Oomoo`001Woo0P0047oo00<007ooOol03goo00<007ooOol0
9Woo00<007ooOol017oo0`000goo00<007oo00001goo00<007ooOol06goo00<007ooOol07goo00<0
07ooOol02Woo00<007ooOol09goo00<007ooOol0Ggoo0P006Woo0P006Goo0P006Goo00<007ooOol0
2goo0007Ool00`00Oomoo`07Ool20009Ool00`00Oomoo`07Ool00`00Oomoo`0DOol01000Oomoo`00
1Woo0P0047oo00<007ooOol03Woo00<007ooOol09Woo00<007ooOol01Woo0P000Woo00@007ooOol0
00Ioo`03001oogoo01]oo`03001oogoo021oo`03001oogoo00Yoo`03001oogoo02Moo`03001oogoo
061oo`8001Yoo`8001Uoo`8001Moo`03001oogoo00]oo`0027oo0P001goo00<007oo00002Goo00<0
07ooOol01goo00<007ooOol04goo00@007ooOol000Ioo`80011oo`03001oogoo00eoo`03001oogoo
02Moo`03001oogoo00Moo`80009oo`03001oo`0000Moo`03001oogoo01]oo`03001oogoo021oo`03
001oogoo00Uoo`03001oogoo02Moo`03001oogoo069oo`<001Uoo`<001Qoo`<001Aoo`03001oogoo
00]oo`004Goo00@007ooOol000Uoo`8000Qoo`03001oogoo01=oo`04001oogoo0006Ool2000@Ool0
0`00Oomoo`0<Ool00`00Oomoo`0WOol00`00Oomoo`07Ool00`00Ool0000200000goo001oo`06Ool0
0`00Oomoo`0KOol00`00Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`0XOol00`00Oomoo`1TOol2
000JOol2000IOol2000BOol00`00Oomoo`0;Ool0015oo`05001oogooOol0000:Ool00`00Oomoo`06
Ool00`00Oomoo`0COol00`00Ool00006Ool00`00Ool0000@Ool00`00Oomoo`0;Ool00`00Oomoo`0W
Ool00`00Oomoo`07Ool01000Oomoogoo0P0000=oo`00Ool01Woo00<007ooOol06goo00<007ooOol0
87oo00<007ooOol02Goo00<007ooOol09goo00<007ooOol0IWoo0P006Woo0`0067oo0P0047oo00<0
07ooOol02goo000AOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0C
Ool00`00Ool00006Ool2000@Ool00`00Oomoo`0;Ool00`00Oomoo`0WOol00`00Oomoo`08Ool00`00
Oomoo`02Ool20007Ool00`00Oomoo`0KOol00`00Oomoo`0QOol00`00Oomoo`08Ool00`00Oomoo`0X
Ool00`00Oomoo`1WOol2000KOol3000GOol2000>Ool00`00Oomoo`0;Ool0015oo`03001oogoo00=o
o`03001oogoo00Qoo`03001oogoo00Ioo`8001=oo`03001oo`0000Ioo`03001oo`00011oo`03001o
ogoo00Yoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo00=oo`<000Ioo`03001oogoo01Yo
o`03001oogoo029oo`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo06Uoo`8001aoo`<001Io
o`<000]oo`03001oogoo00]oo`004Goo00<007ooOol017oo0P002Goo0P0027oo00<007ooOol04Goo
00<007oo00001Woo0P0047oo00<007ooOol02Woo00<007ooOol09goo00<007ooOol027oo00<007oo
Ool017oo00<007oo00001Goo00<007ooOol06goo00<007ooOol08Woo00<007ooOol01goo00<007oo
Ool09goo00<007ooOol0Jgoo00<007ooOol077oo0`005Woo0P002Goo00<007ooOol02goo000AOol0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Ool00005Ool0
0`00Ool0000@Ool00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`03Ool0
0`00Oomoo`020004Ool00`00Oomoo`0JOol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`0X
Ool00`00Oomoo`1[Ool2000OOol3000EOol20007Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo011oo`03001oo`0000Ioo`80011oo`03001o
ogoo00Uoo`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo009oo`80009o
o`03001oogoo01]oo`03001oogoo029oo`03001oogoo00Ioo`03001oogoo02Qoo`03001oogoo06eo
o`80021oo`<001Aoo`8000Eoo`03001oogoo00]oo`004Goo00<007ooOol027oo00<007ooOol027oo
0P001goo00<007ooOol047oo00<007oo00001Woo0P0047oo00<007ooOol027oo00<007ooOol09goo
00<007ooOol047oo00<007ooOol00goo0P0000=oo`00Ool06goo00<007ooOol08goo00<007ooOol0
1Goo00<007ooOol0:Goo00<007ooOol0KWoo0P008Goo0`004goo0`000Woo00<007ooOol02goo000A
Ool2000:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Ool00005Ool2000@
Ool00`00Oomoo`08Ool00`00Oomoo`0WOol00`00Oomoo`0@Ool00`00Oomoo`05Ool2000MOol00`00
Oomoo`0SOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`1`Ool2000ROol3000COol3000=
Ool0015oo`8000]oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00moo`03001oo`0000Io
o`80011oo`03001oogoo00Moo`03001oogoo02Moo`03001oogoo011oo`03001oogoo00Moo`03001o
ogoo01Yoo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo02Uoo`03001oogoo075oo`8002=o
o`<0019oo`03001oogoo00]oo`004Goo0P0037oo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool03goo00<007oo00001Goo00<007oo00003goo00<007ooOol01goo00<007ooOol09goo00<007oo
Ool04Goo00<007ooOol01Woo0`006goo00<007ooOol08goo00<007ooOol017oo00<007ooOol0:Goo
00<007ooOol0Lgoo0P0097oo0`003goo00<007ooOol02goo000AOol00`00Ool0000<Ool00`00Oomo
o`09Ool20006Ool00`00Oomoo`0?Ool00`00Ool00005Ool2000?Ool00`00Oomoo`07Ool00`00Oomo
o`0WOol00`00Oomoo`0AOol00`00Oomoo`07Ool01000Ool000006Goo00<007ooOol097oo00<007oo
Ool00goo00<007ooOol0:Woo00<007ooOol0M7oo0P009Goo0`0037oo00<007ooOol02goo000AOol3
000=Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Ool00005Ool00`00Ool0
000?Ool00`00Oomoo`06Ool00`00Oomoo`0WOol00`00Oomoo`0AOol00`00Oomoo`07Ool01000Oomo
ogoo0P005goo00<007ooOol09Goo00<007ooOol00Woo00<007ooOol0:goo00<007ooOol0MGoo0P00
9Woo0`0027oo0P003Goo000AOol00`00Ool0000>Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`0>
Ool00`00Ool00005Ool2000?Ool00`00Oomoo`06Ool00`00Oomoo`0WOol00`00Oomoo`0BOol00`00
Oomoo`07Ool00`00Oomoo`02Ool2000FOol00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`0Z
Ool00`00Oomoo`1gOol2000WOol20007Ool00`00Oomoo`0;Ool0015oo`03001oo`00011oo`03001o
ogoo00Uoo`8000Eoo`03001oogoo00ioo`03001oo`0000Aoo`03001oo`0000moo`03001oogoo00Eo
o`03001oogoo02Moo`03001oogoo019oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo01=o
o`03001oogoo02Ioo`05001oogooOol0000]Ool00`00Oomoo`1hOol00`00Oomoo`0VOol20005Ool0
0`00Oomoo`0;Ool0015oo`04001oogoo000@Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomo
o`0=Ool00`00Ool00005Ool2000?Ool00`00Oomoo`05Ool00`00Oomoo`0WOol00`00Oomoo`0BOol0
0`00Oomoo`07Ool00`00Oomoo`05Ool2000DOol00`00Oomoo`0VOol01000Oomoo`00;Goo00<007oo
Ool0NGoo0P00:7oo0`000Woo00<007ooOol02goo000AOol01000Oomoo`004Goo00<007ooOol02Woo
00<007ooOol00goo00<007ooOol03Goo00<007oo00001Goo0P003goo00<007ooOol017oo00<007oo
Ool09goo00<007ooOol04goo00<007ooOol01goo00<007ooOol01Woo0P004Woo00<007ooOol09goo
00<007oo0000;Woo00<007ooOol0NWoo0P00:Goo0`003Goo000AOol01000Oomoo`004Woo00<007oo
Ool02Woo00<007ooOol00goo00<007ooOol03Goo00<007oo000017oo0P003goo00<007ooOol00goo
00<007ooOol0:7oo00<007ooOol04goo00<007ooOol01goo00<007ooOol027oo0P004Goo00<007oo
Ool09goo00<007oo0000;Goo00<007ooOol0O7oo0P00:Goo00<007ooOol02goo000AOol01000Oomo
o`004goo00<007ooOol02Woo0P0017oo00<007ooOol037oo00<007oo00001Goo0P003goo00<007oo
Ool00Woo00<007ooOol0:7oo00<007ooOol04goo00<007ooOol027oo00<007ooOol02Goo0P003goo
00<007ooOol09goo00<007oo0000;Woo00<007ooOol0OGoo0`009Woo00<007ooOol02goo000AOol0
1000Oomoo`0057oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol037oo00<007oo000017oo
00<007oo00003goo00D007ooOomoo`0002Yoo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo
00]oo`03001oogoo00eoo`03001oogoo02Moo`8002ioo`03001oogoo081oo`8002Aoo`03001oogoo
00]oo`004Goo00D007ooOomoo`0001Aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00ao
o`03001oo`0000Aoo`8000moo`05001oogooOol0000ZOol00`00Oomoo`0DOol00`00Oomoo`08Ool0
0`00Oomoo`0;Ool2000>Ool00`00Oomoo`0WOol2000^Ool00`00Oomoo`21Ool2000ROol00`00Oomo
o`0;Ool0015oo`05001oogooOol0000EOol00`00Oomoo`0;Ool20003Ool2000<Ool00`00Ool00004
Ool00`00Ool0000?Ool01000Oomoo`00:Woo00<007ooOol057oo00<007ooOol027oo00<007ooOol0
3Goo0P0037oo00<007ooOol0:7oo00<007ooOol0;7oo00<007ooOol0Pgoo0P0087oo00<007ooOol0
2goo000AOol01@00Oomoogoo00005Woo0P003Goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
000017oo0P003goo00@007ooOol002Yoo`03001oogoo01Eoo`03001oogoo00Qoo`03001oogoo00io
o`8000]oo`03001oogoo02Moo`8002eoo`03001oogoo08Eoo`8001ioo`03001oogoo00]oo`004Goo
00<007ooOol00Woo00<007ooOol05Goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol02Woo
0P0017oo00<007oo00003goo00<007oo0000:Woo00<007ooOol05Goo00<007ooOol02Goo00<007oo
Ool03goo0P002Goo00<007ooOol0:7oo0P00;Goo00<007ooOol0QWoo00<007ooOol06goo00<007oo
Ool02goo000AOol00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Ool00004Ool2000?Ool00`00Ool0000ZOol00`00Oomoo`0EOol00`00Oomo
o`09Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`0WOol00`00Ool0000/Ool00`00Oomo
o`27Ool2000KOol00`00Oomoo`0;Ool0015oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo
00]oo`8000=oo`8000Yoo`03001oo`0000Aoo`8000moo`03001oogoo02Uoo`03001oogoo01Ioo`03
001oogoo00Uoo`03001oogoo015oo`8000Moo`03001oogoo02Moo`04001oogoo000/Ool00`00Oomo
o`28Ool2000IOol00`00Oomoo`0;Ool0015oo`03001oogoo00=oo`03001oogoo01Moo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00Qoo`8000Aoo`8000moo`03001oogoo02Uoo`03001oogoo
01Ioo`03001oogoo00Uoo`03001oogoo01=oo`8000Ioo`03001oogoo02Moo`04001oogoo000[Ool0
0`00Oomoo`2:Ool2000GOol00`00Oomoo`0;Ool0015oo`03001oogoo00=oo`03001oogoo01Qoo`03
001oogoo00aoo`03001oogoo009oo`03001oogoo00Moo`03001oo`0000Aoo`8000ioo`8002Yoo`03
001oogoo01Ioo`03001oogoo00Yoo`03001oogoo01Aoo`8000Aoo`03001oogoo02Moo`04001oogoo
000/Ool00`00Oomoo`2;Ool2000EOol00`00Oomoo`0;Ool0015oo`<000=oo`03001oogoo01Uoo`03
001oogoo00aoo`8000=oo`03001oogoo00Moo`8000Aoo`03001oo`0000eoo`8002Yoo`03001oogoo
01Moo`03001oogoo00Uoo`03001oogoo01Ioo`8000=oo`03001oogoo02Ioo`05001oogooOol0000[
Ool00`00Oomoo`2=Ool00`00Oomoo`0AOol2000=Ool0015oo`03001oogoo00Aoo`03001oogoo01Uo
o`03001oogoo00eoo`05001oogooOol00009Ool20004Ool2000=Ool2000ZOol00`00Oomoo`0GOol0
0`00Oomoo`0:Ool00`00Oomoo`0GOol01000Oomoo`00:Goo00D007ooOomoo`0002]oo`03001oogoo
08eoo`80019oo`03001oogoo00]oo`004Goo00<007ooOol017oo00<007ooOol06Woo00<007ooOol0
3Goo00D007ooOomoo`0000Qoo`8000Aoo`03001oo`0000aoo`03001oo`0002Uoo`03001oogoo01Mo
o`03001oogoo00Yoo`03001oogoo01Qoo`<002Uoo`03001oogoo009oo`03001oogoo02Qoo`03001o
ogoo08moo`80011oo`03001oogoo00]oo`004Goo00<007ooOol017oo00<007ooOol06goo0P003Woo
00D007ooOomoo`0000Qoo`8000Aoo`8000aoo`03001oo`0002Uoo`03001oogoo01Qoo`03001oogoo
00Yoo`03001oogoo01Uoo`8002Qoo`03001oogoo00=oo`03001oogoo02Moo`03001oogoo095oo`80
00ioo`03001oogoo00]oo`004Goo00<007ooOol01Goo00<007ooOol077oo00<007ooOol037oo0P00
0Woo00<007ooOol01Woo0P000goo00<007oo00002goo00@007ooOol002Qoo`03001oogoo01Qoo`03
001oogoo00]oo`03001oogoo01Uoo`8002Qoo`03001oogoo00=oo`03001oogoo02Moo`03001oogoo
099oo`8000aoo`03001oogoo00]oo`004Goo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol0
3Goo00@007ooOol000Moo`8000Aoo`8000]oo`04001oogoo000XOol00`00Oomoo`0HOol00`00Oomo
o`0;Ool00`00Oomoo`0JOol3000VOol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`2DOol0
0`00Oomoo`09Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Eoo`03001oogoo01ioo`03001oogoo
00eoo`04001oogoo0007Ool20003Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`0UOol0
0`00Oomoo`0IOol00`00Oomoo`0;Ool00`00Oomoo`0IOol01000Oomoo`009Goo00<007ooOol01Goo
00<007ooOol09Woo00<007ooOol0U7oo0P002Goo00<007ooOol02goo000AOol00`00Oomoo`05Ool0
0`00Oomoo`0OOol00`00Oomoo`0=Ool200000goo001oo`06Ool20002Ool00`00Ool00009Ool00`00
Oomoo`02Ool00`00Oomoo`0UOol00`00Oomoo`0IOol00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00
Oomoo`02000SOol00`00Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`2FOol20007Ool00`00Oomo
o`0;Ool0015oo`03001oogoo00Eoo`03001oogoo021oo`03001oogoo00ioo`03001oo`0000Ioo`80
00=oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02Aoo`03001oogoo01Uoo`03001oogoo
00aoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo025oo`03001oogoo00Eoo`03001oogoo
02Ioo`03001oogoo09Moo`8000Eoo`03001oogoo00]oo`004Goo00<007ooOol01Woo00<007ooOol0
87oo00<007ooOol03Woo00<007oo00001Woo0P000Woo00@007ooOol000Moo`03001oogoo00=oo`03
001oogoo02Aoo`03001oogoo01Yoo`03001oogoo00]oo`03001oogoo01Yoo`03001oogoo009oo`80
025oo`03001oogoo00Ioo`03001oogoo02Eoo`03001oogoo09Uoo`8000=oo`03001oogoo00]oo`00
4Goo00<007ooOol01Woo00<007ooOol08Goo00<007ooOol03Woo00<007oo00001Woo0P000Woo00<0
07oo00001goo00<007ooOol00goo00<007ooOol0@Goo00<007ooOol037oo00<007ooOol06Goo00<0
07ooOol017oo0P007goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol0VWoo00@007ooOol0
00eoo`004Goo00<007ooOol01Woo00<007ooOol08Woo00<007ooOol03Woo0`001Goo0P000Woo00@0
07ooOol000Ioo`03001oogoo00Aoo`03001oogoo041oo`03001oogoo00aoo`03001oogoo01Uoo`03
001oogoo00Ioo`8001eoo`03001oogoo00Qoo`03001oogoo02Aoo`03001oogoo09]oo`<000eoo`00
4Goo00<007ooOol01Woo00<007ooOol08goo0P0047oo0P001Goo0P000Woo00<007oo00001Woo00<0
07ooOol017oo00<007ooOol0@Goo00<007ooOol037oo00<007ooOol06Goo00<007ooOol01goo00<0
07ooOol06Woo00<007ooOol02Goo00<007ooOol08goo00<007ooOol0WGoo00<007ooOol02goo000A
Ool00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`0>Ool20005Ool200001Goo001oogoo0000
1Goo00<007ooOol01Goo00<007ooOol0@7oo00<007ooOol037oo00<007ooOol06Goo00<007ooOol0
27oo0P006goo00<007ooOol02Goo00<007ooOol08goo00<007ooOol0W7oo00<007ooOol02goo000A
Ool00`00Oomoo`07Ool00`00Oomoo`0UOol00`00Oomoo`0?Ool00`00Oomoo`02Ool20002Ool00`00
Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`10Ool00`00Oomoo`0<Ool00`00Oomoo`0JOol00`00
Oomoo`09Ool2000IOol00`00Oomoo`0:Ool00`00Oomoo`0ROol00`00Oomoo`2LOol00`00Oomoo`0;
Ool0015oo`03001oogoo00Moo`03001oogoo02Ioo`03001oogoo00moo`03001oogoo009oo`80009o
o`03001oo`0000=oo`03001oogoo00Moo`03001oogoo041oo`03001oogoo00aoo`03001oogoo01Uo
o`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo029oo`03001oogoo09]o
o`03001oogoo00]oo`004Goo00<007ooOol01goo00<007ooOol09goo00<007ooOol03goo0P000goo
0P0000Aoo`00Ool000=oo`03001oogoo00Moo`03001oogoo041oo`03001oogoo00aoo`03001oogoo
01Yoo`03001oogoo00]oo`8001Moo`03001oogoo00]oo`03001oogoo025oo`03001oogoo09]oo`03
001oogoo00]oo`004Goo0`001goo00<007ooOol0:7oo00<007ooOol03goo0P000Woo0P000Woo00<0
07oo00000Woo00<007ooOol027oo00<007ooOol0?goo00<007ooOol03Goo00<007ooOol06Goo00<0
07ooOol03Goo00<007ooOol057oo00<007ooOol02goo00<007ooOol08Woo00<007ooOol0VGoo0P00
3Goo000AOol00`00Oomoo`08Ool00`00Oomoo`0XOol00`00Oomoo`0?Ool300001Goo000007oo0000
0Woo00<007oo00002goo00<007ooOol0?goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol0
3Goo0P0057oo00<007ooOol037oo00<007ooOol08Goo00<007ooOol0VWoo00<007ooOol02goo000A
Ool00`00Oomoo`08Ool00`00Oomoo`0YOol00`00Oomoo`0?Ool300002Goo000007oo001oo`00Ool0
000;Ool00`00Oomoo`0oOol00`00Oomoo`0=Ool00`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomo
o`0BOol00`00Oomoo`0<Ool00`00Oomoo`0QOol00`00Oomoo`2IOol00`00Oomoo`0;Ool0015oo`03
001oogoo00Qoo`03001oogoo02Yoo`03001oogoo011oo`@00004Ool007ooOol2000<Ool00`00Oomo
o`0nOol00`00Oomoo`0=Ool00`00Oomoo`0JOol00`00Oomoo`0?Ool2000BOol00`00Oomoo`0=Ool0
0`00Oomoo`0POol00`00Oomoo`2IOol00`00Oomoo`0;Ool0015oo`03001oogoo00Qoo`03001oogoo
02]oo`80015oo`@00003Ool007oo008000aoo`03001oogoo03moo`03001oogoo00eoo`03001oogoo
01Yoo`03001oogoo011oo`03001oogoo00moo`03001oogoo00ioo`03001oogoo01moo`03001oogoo
09Uoo`03001oogoo00]oo`004Goo00<007ooOol02Goo00<007ooOol0;7oo00<007ooOol03goo00<0
07oo00000P000Woo00<007ooOol02goo00<007ooOol0?Woo00<007ooOol03Goo00<007ooOol06Woo
00<007ooOol04Goo0P0047oo00<007ooOol03Woo00<007ooOol07goo00<007ooOol0V7oo00<007oo
Ool02goo000AOol00`00Oomoo`09Ool00`00Oomoo`0]Ool00`00Oomoo`0?Ool3000017oo001oo`00
3Goo00<007ooOol0?Woo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol04Woo00<007ooOol0
3Goo00<007ooOol03goo00<007ooOol07Woo00<007ooOol0V7oo00<007ooOol02goo000AOol00`00
Oomoo`09Ool00`00Oomoo`0^Ool00`00Oomoo`0@Ool400000goo001oo`0<Ool00`00Oomoo`0nOol0
0`00Oomoo`0=Ool00`00Oomoo`0JOol00`00Oomoo`0COol2000=Ool00`00Oomoo`0@Ool00`00Oomo
o`0NOol00`00Oomoo`2GOol00`00Oomoo`0;Ool0015oo`03001oogoo00Uoo`03001oogoo02moo`03
001oogoo011oo`<00003Ool007oo00aoo`03001oogoo03ioo`03001oogoo00ioo`03001oogoo01Yo
o`03001oogoo01Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo01eoo`03001oogoo09Io
o`8000eoo`004Goo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol047oo0`0000=oo`00Ool0
37oo00<007ooOol0?Goo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol05Goo0P002goo00<0
07ooOol047oo00<007ooOol07Woo00<007ooOol0Tgoo0P0000=oo`00Ool037oo000AOol00`00Oomo
o`0:Ool00`00Oomoo`0`Ool00`00Oomoo`0@Ool01@00Ool007oo000037oo00<007ooOol0?Woo00<0
07ooOol03Woo00<007ooOol06Woo00<007ooOol05Woo0P002Goo00<007ooOol04Goo00<007ooOol0
7Goo00<007ooOol0T7oo0`000goo00<007ooOol02goo000AOol00`00Oomoo`0:Ool00`00Oomoo`0a
Ool00`00Oomoo`0?Ool200000goo0000000<Ool00`00Oomoo`0nOol00`00Oomoo`0>Ool00`00Oomo
o`0JOol00`00Oomoo`0HOol20007Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`2=Ool2
0006Ool00`00Oomoo`0;Ool0015oo`8000]oo`03001oogoo039oo`03001oogoo00ioo`80009oo`80
00aoo`03001oogoo03eoo`03001oogoo00moo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo
00Aoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo08]oo`8000Qoo`03001oogoo00]oo`00
4Goo0P0037oo00<007ooOol0<Woo0P003Woo00<007oo00000Woo00<007ooOol02Woo00<007ooOol0
?Woo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol06Woo0P0017oo00<007ooOol057oo00<0
07ooOol06goo00<007ooOol0RGoo0P002Woo00<007ooOol02goo000AOol2000<Ool00`00Oomoo`0d
Ool00`00Oomoo`0;Ool01000Oomoo`000Woo00<007ooOol02Woo00<007ooOol0?Goo00<007ooOol0
3goo00<007ooOol06Goo00<007ooOol077oo0P000goo00<007ooOol057oo00<007ooOol06goo00<0
07ooOol0QWoo0P0037oo00<007ooOol02goo000AOol00`00Ool0000;Ool00`00Oomoo`0eOol00`00
Oomoo`0:Ool01000Oomoo`000Woo0P002goo00<007ooOol0?Goo00<007ooOol03goo00<007ooOol0
6Woo00<007ooOol07Goo00@007ooOol001Moo`03001oogoo01Yoo`03001oogoo08Eoo`03001oogoo
00aoo`03001oogoo00]oo`004Goo0`0037oo00<007ooOol0=Goo00<007ooOol027oo00<007ooOol0
0Woo00@007oo001oo`8000Yoo`03001oogoo03eoo`03001oogoo00ioo`03001oogoo01Yoo`03001o
ogoo01ioo`<001Qoo`03001oogoo01Yoo`03001oogoo089oo`8000ioo`8000eoo`004Goo00<007oo
000037oo00<007ooOol0=Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol0?Goo00<007ooOol03goo00<007ooOol06Woo00<007ooOol07goo0P0067oo
00<007ooOol06Goo00<007ooOol0P7oo0P004Goo00<007ooOol02goo000AOol01000Oomoo`002goo
00<007ooOol0=goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol0?7oo00<007ooOol03goo00<007ooOol06Woo00<007ooOol087oo0P005goo00<007oo
Ool06Woo00<007ooOol0OGoo0P004goo00<007ooOol02goo000AOol01000Oomoo`0037oo00<007oo
Ool0=goo00<007ooOol01Goo00<007ooOol00goo0P001Goo0P001goo00<007ooOol0?Goo00<007oo
Ool03goo00<007ooOol06Woo00<007ooOol07goo00<007oo00005goo00<007ooOol06Goo00<007oo
Ool0Ngoo0P005Goo00<007ooOol02goo000AOol01000Oomoo`0037oo00<007ooOol0>7oo00<007oo
Ool017oo00<007ooOol00goo00<007oo00001Woo00<007ooOol017oo00<007ooOol0?Goo00<007oo
Ool03goo00<007ooOol06goo00<007ooOol07goo00@007oo000001Ioo`03001oogoo01Qoo`03001o
ogoo07Yoo`03001oogoo01Eoo`03001oogoo00]oo`004Goo00D007ooOomoo`0000]oo`03001oogoo
03Uoo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo
03aoo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo01moo`05001oogooOol0000FOol00`00
Oomoo`0HOol00`00Oomoo`1gOol2000HOol00`00Oomoo`0;Ool0015oo`05001oogooOol0000;Ool0
0`00Oomoo`0jOol20003Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00<007ooOol00goo00<0
07ooOol0?Goo00<007ooOol03goo00<007ooOol06goo00<007ooOol07Woo00<007ooOol00Woo0P00
5Goo00<007ooOol05goo00<007ooOol0MGoo0P006Woo00<007ooOol02goo000AOol01@00Oomoogoo
000037oo00<007ooOol0>goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Eoo`8000Ao
o`03001oogoo03aoo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo01moo`03001oogoo00=o
o`03001oogoo01=oo`03001oogoo01Moo`03001oogoo079oo`8001aoo`03001oogoo00]oo`004Goo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0?7oo00<007oo000017oo00<007ooOol00Woo
00<007ooOol01goo00D007ooOomoo`0003ioo`03001oogoo015oo`03001oogoo01Yoo`03001oogoo
01ioo`03001oogoo00Aoo`8001Aoo`03001oogoo01Ioo`03001oogoo071oo`8001ioo`03001oogoo
00]oo`004Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0?Goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol01goo00D007ooOomoo`0003ioo`03001oogoo011oo`03001oogoo01Yo
o`03001oogoo01ioo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo01Eoo`03001oogoo06mo
o`03001oogoo01ioo`03001oogoo00]oo`004Goo00<007ooOol00Woo00<007ooOol02Goo00<007oo
Ool0?Goo0P000goo00<007ooOol01Goo00<007ooOol01goo0P0000=oo`00Ool0?Goo00<007ooOol0
4Goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol01goo0P004goo00<007ooOol05Goo00<0
07ooOol0K7oo0P008Goo00<007ooOol02goo000AOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0mOol00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool0000mOol00`00
Oomoo`0AOol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00
Oomoo`0DOol00`00Oomoo`1ZOol2000SOol00`00Oomoo`0;Ool0015oo`03001oogoo00=oo`03001o
ogoo00Uoo`03001oogoo03aoo`06001oogoo001oo`0027oo00<007ooOol02Goo0P00?Woo00<007oo
Ool04Goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol02Goo0P004Woo00<007ooOol057oo
00<007ooOol0Igoo0P009Goo00<007ooOol02goo000AOol00`00Oomoo`03Ool00`00Oomoo`09Ool0
0`00Oomoo`0TOol2000FOol01000Oomoogoo0P002Goo00<007ooOol02Goo00<007ooOol0?7oo00<0
07ooOol04Goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol02goo00<007ooOol047oo00<0
07ooOol04goo00<007ooOol0IGoo0P009goo00<007ooOol02goo0007Ool30007Ool00`00Oomoo`03
Ool00`00Oomoo`09Ool00`00Oomoo`0VOol2000DOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool2000lOol00`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomoo`0<
Ool2000AOol00`00Oomoo`0COol00`00Oomoo`1ROol2000YOol00`00Oomoo`0;Ool000Ioo`05001o
ogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0XOol2000BOol01`00Oomo
ogoo001oo`0000Uoo`03001oogoo00Uoo`03001oo`0003aoo`03001oogoo015oo`03001oogoo01Yo
o`03001oogoo01aoo`03001oogoo00ioo`03001oogoo00moo`03001oogoo019oo`03001oogoo061o
o`8002]oo`03001oogoo00]oo`001Woo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo02Uoo`03001oogoo00moo`05001oogooOol00002Ool00`00Oomoo`07Ool00`00
Oomoo`09Ool00`00Ool0000kOol00`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0MOol00`00
Oomoo`0>Ool2000@Ool00`00Oomoo`0AOol00`00Oomoo`1NOol2000]Ool00`00Oomoo`0;Ool000Mo
o`<000Moo`@000=oo`03001oogoo00Uoo`03001oogoo02Yoo`8000moo`05001oogooOol00003Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`02000iOol00`00Oomoo`0COol00`00Oomoo`0I
Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`1K
Ool2000]Ool3000=Ool000Ioo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`08Ool0
0`00Oomoo`0/Ool2000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool01@00Oomoogoo0000>Goo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol077oo00<0
07ooOol04Goo00<007ooOol03Woo00<007ooOol047oo00<007ooOol0FGoo0P00<Goo00<007ooOol0
2goo0006Ool01@00Oomoogoo00001Woo00<007ooOol01Goo00<007ooOol027oo00<007ooOol0;Woo
0P002Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol0=Woo00<007ooOol04goo00<007ooOol06Goo00<007ooOol06goo00<007oo
Ool04Woo0P003goo00<007ooOol047oo00<007ooOol0Egoo00<007ooOol0<Goo00<007ooOol02goo
0007Ool30007Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0^Ool2O0020008Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`0eOol00`00Oomoo`0COol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0COol00`00
Oomoo`0<Ool00`00Oomoo`0@Ool00`00Oomoo`1EOol2000dOol00`00Oomoo`0;Ool0015oo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo02moo`03O01oo`0000Moo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00=oo`8003Ioo`03001oogoo01=o
o`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo011o
o`03001oogoo059oo`8003Ioo`03001oogoo00]oo`004Goo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol0<7oo00Al07oo000000Eoo`05001oogooOol00009Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`0cOol00`00Oomoo`0COol00`00Oomoo`0JOol00`00Oomo
o`0JOol00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`1@Ool2000hOol0
0`00Oomoo`0;Ool0015oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo035oo`9l0003Ool0
000000=oo`05001oogooOol0000:Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`0bOol00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0FOol2
000=Ool00`00Oomoo`0>Ool00`00Oomoo`1>Ool2000jOol00`00Oomoo`0;Ool0015oo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo03=oo`04O01oogoo0002Ool01@00Oomoogoo00002goo00<0
07ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo0P00<goo00<007ooOol04goo00<007ooOol0
6Woo00<007ooOol06Goo00<007ooOol067oo00<007ooOol02goo00<007ooOol03Woo00<007ooOol0
C7oo00<007ooOol0>Woo00<007ooOol02goo000AOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`0cOol00g`0Oomoo`020004Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`0JOol0
0`00Oomoo`0HOol2000<Ool00`00Oomoo`0=Ool00`00Oomoo`1:Ool2000mOol00`00Oomoo`0;Ool0
015oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo03Aoo`03O01oogoo008000=oo`03001o
ogoo00]oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo02moo`03001o
ogoo01Aoo`03001oogoo01Yoo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo00Yoo`03001o
ogoo00aoo`03001oogoo04Qoo`8003moo`03001oogoo00]oo`004Goo00<007ooOol027oo00<007oo
Ool01goo00<007ooOol0=Goo0W`000H007oo000007oo000>Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Oomoo`0_Ool00`00Oomoo`0COol00`00Oomoo`0JOol00`00Oomoo`0I
Ool00`00Oomoo`0KOol2000;Ool00`00Oomoo`0<Ool00`00Oomoo`15Ool20011Ool00`00Oomoo`0;
Ool0015oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo03Moo`04O01oogooOol2000?Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000_Ool00`00Oomoo`0DOol00`00Oomo
o`0JOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomo
o`13Ool20013Ool00`00Oomoo`0;Ool0015oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
03Moo`04001l07`0Ool3000?Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`0/Ool00`00Oomoo`0DOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0MOol20009
Ool00`00Oomoo`0;Ool00`00Oomoo`12Ool00`00Oomoo`13Ool00`00Oomoo`0;Ool0015oo`03001o
ogoo00Uoo`03001oogoo00Moo`03001oogoo03Eoo`06001oogooOoml00000Woo0P003Woo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol02goo00<007ooOol0;7oo00<007ooOol057oo00<007oo
Ool06Woo00<007ooOol067oo00<007ooOol07goo00<007ooOol01goo00<007ooOol02goo00<007oo
Ool0?goo0P00AWoo00<007ooOol02goo000AOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomo
o`0eOol00`00Oomoo`02Ool2O003Ool2000=Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool2000/Ool00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0OOol2
0008Ool00`00Oomoo`0:Ool00`00Oomoo`0mOol20018Ool00`00Oomoo`0;Ool0015oo`03001oogoo
00Uoo`03001oogoo00Moo`03001oogoo03Eoo`03001oogoo009oo`03001oog`000Aoo`03001oogoo
00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo02Uoo`03001oogoo
01Eoo`03001oogoo01Yoo`03001oogoo01Qoo`03001oogoo025oo`03001oogoo00Ioo`03001oogoo
00Yoo`03001oogoo03Yoo`8004Yoo`03001oogoo00]oo`004Goo0`002Woo00<007ooOol01Woo00<0
07ooOol0=Goo00<007ooOol00Woo00<007ooOol00W`00goo0P0037oo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol0:Goo00<007ooOol057oo00<007ooOol06goo00<007oo
Ool05goo00<007ooOol08Woo0P001goo00<007ooOol02Goo00<007ooOol0>7oo0P00Bgoo0P003Goo
000AOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0dOol01@00Oomoogoo00001Goo00=l
07ooOol00Woo0P002goo0P000goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0:7oo00<0
07ooOol05Goo00<007ooOol06Woo00<007ooOol067oo00<007ooOol08goo00<007ooOol01Goo00<0
07ooOol027oo00<007ooOol0=goo00<007ooOol0C7oo00<007ooOol02goo000AOol00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`0dOol01@00Oomoogoo00001Woo00=l07ooOol00goo0P002goo
00D007ooOomoo`0000Eoo`03001oogoo00moo`8002Qoo`03001oogoo01Eoo`03001oogoo01]oo`03
001oogoo01Moo`03001oogoo02Aoo`8000Ioo`03001oogoo00Qoo`03001oogoo03Aoo`8004moo`03
001oogoo00]oo`004Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0<goo00<007ooOol0
0Woo00<007ooOol01Goo0W`01Goo0P002Woo00D007ooOomoo`0000Eoo`03001oogoo011oo`03001o
ogoo02Ioo`03001oogoo01Eoo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo02Ioo`03001o
ogoo00Aoo`03001oogoo00Moo`03001oogoo039oo`80055oo`03001oogoo00]oo`004Goo00<007oo
Ool02goo00<007ooOol01Woo00<007ooOol0<goo00<007ooOol00Woo00<007ooOol01goo00=l07oo
Ool017oo00<007ooOol027oo00D007ooOomoo`0000Aoo`03001oogoo015oo`03001oogoo02Eoo`03
001oogoo01Eoo`03001oogoo01]oo`03001oogoo01Ioo`03001oogoo00aoo`9l01Uoo`03001oogoo
00Aoo`03001oogoo00Moo`03001oogoo02ioo`<005=oo`03001oogoo00]oo`004Goo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol0<goo00D007ooOomoo`0000]oo`03O01oogoo00Aoo`8000Uo
o`05001oogooOol00003Ool00`00Oomoo`0BOol00`00Oomoo`0TOol00`00Oomoo`0FOol00`00Oomo
o`0JOol00`00Oomoo`0GOol00`00Oomoo`0=Ool2O00HOol20004Ool00`00Oomoo`07Ool00`00Oomo
o`0/Ool2001FOol00`00Oomoo`0;Ool0015oo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
039oo`05001oogooOol0000<Ool00g`0Oomoo`05Ool20008Ool01000Oomoo`0017oo00<007ooOol0
4Woo00<007ooOol097oo00<007ooOol05Goo00<007ooOol06goo00<007ooOol05Woo00<007ooOol0
3goo0W`067oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0:7oo0`00F7oo00<007ooOol0
2goo000AOol00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0bOol01@00Oomoogoo00003Goo
0W`01goo0P001goo00@007ooOol000=oo`03001oogoo01=oo`03001oogoo02=oo`03001oogoo01Io
o`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo015oo`03O01oogoo01Ioo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo02Ioo`8005]oo`03001oogoo00]oo`004Goo00<007ooOol037oo
00<007ooOol01Woo00<007ooOol0<Woo00D007ooOomoo`0000moo`03O01oogoo00Ioo`8000Ioo`04
001oogoo0002Ool00`00Oomoo`0DOol00`00Oomoo`0ROol00`00Oomoo`0FOol00`00Oomoo`0JOol0
0`00Oomoo`0FOol00`00Oomoo`0BOol2O00GOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`0TOol2001MOol00`00Oomoo`0;Ool0015oo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo
039oo`05001oogooOol0000@Ool2O008Ool20005Ool01000Oomoo`000Woo00<007ooOol057oo00<0
07ooOol08Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol057oo0W`0
5Woo0P000goo00<007ooOol01Goo00<007ooOol087oo0`00Ggoo00<007ooOol02goo000AOol00`00
Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool01@00Oomoogoo00004goo00=l07ooOol01goo
0P0017oo00<007oo00000Woo00<007ooOol05Goo0P008Woo00<007ooOol05Woo00<007ooOol06Woo
00<007ooOol05Woo00<007ooOol05Goo0W`05Woo00D007ooOomoo`0000Ioo`03001oogoo01ioo`80
069oo`03001oogoo00]oo`004Goo00<007ooOol037oo00<007ooOol01goo00<007ooOol0<7oo00D0
07ooOomoo`0001Aoo`9l00Uoo`8000=oo`05001oo`00Ool0000IOol00`00Oomoo`0OOol00`00Oomo
o`0GOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0GOol2O00EOol20002Ool00`00Oomo
o`03Ool00`00Oomoo`0LOol2001TOol00`00Oomoo`0;Ool0015oo`03001oogoo00eoo`03001oogoo
00Ioo`03001oogoo031oo`05001oogooOol0000FOol00g`0Oomoo`08Ool20002Ool01@00Ool007oo
00006Goo00<007ooOol07goo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007oo
Ool06Goo00=l07ooOol057oo00@007ooOol000Eoo`03001oogoo01Uoo`8006Ioo`03001oogoo00]o
o`004Goo00<007ooOol03Goo00<007ooOol01Woo00<007ooOol0<7oo00D007ooOomoo`0001Moo`9l
00Yoo`800005Ool00000Ool0000JOol2000OOol00`00Oomoo`0FOol00`00Oomoo`0KOol00`00Oomo
o`0DOol00`00Oomoo`0JOol2O00EOol200000goo001oo`03Ool00`00Oomoo`0FOol3001XOol00`00
Oomoo`0;Ool0015oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo031oo`05001oogooOol0
000IOol00g`0Oomoo`09Ool01P00Ool00000Ool001]oo`03001oogoo01aoo`03001oogoo01Moo`03
001oogoo01Yoo`03001oogoo01Eoo`03001oogoo01]oo`9l01Eoo`03001oo`0000=oo`03001oogoo
01Aoo`8006]oo`03001oogoo00]oo`004Goo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol0
;Woo00D007ooOomoo`0001]oo`9l00Yoo`D001aoo`03001oogoo01aoo`03001oogoo01Ioo`03001o
ogoo01]oo`03001oogoo01Aoo`03001oogoo01eoo`9l01Aoo`<000=oo`03001oogoo015oo`8006eo
o`03001oogoo00]oo`004Goo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol0;Woo00D007oo
Oomoo`0001eoo`03O01oogoo00Uoo`<001eoo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo
01]oo`03001oogoo01=oo`03001oogoo01moo`9l01Aoo`80009oo`03001oogoo00moo`8006moo`03
001oogoo00]oo`004Goo0`003Woo00<007ooOol01Woo00<007ooOol0;Woo00D007ooOomoo`0001io
o`9l00]oo`8001eoo`8001]oo`03001oogoo01Moo`03001oogoo01]oo`03001oogoo01=oo`03001o
ogoo025oo`03O01oogoo019oo`80009oo`03001oogoo00]oo`<0071oo`8000eoo`004Goo00<007oo
Ool03goo00<007ooOol01Goo00<007ooOol0;Woo00D007ooOomoo`00021oo`03O01oogoo00Uoo`<0
01eoo`03001oogoo01Uoo`03001oogoo01Moo`03001oogoo01]oo`03001oogoo019oo`03001oogoo
029oo`9l01=oo`800003Ool007oo00Yoo`8007Aoo`03001oogoo00]oo`004Goo00<007ooOol03goo
00<007ooOol01Woo00<007ooOol0;Goo00D007ooOomoo`00025oo`9l00Yoo`03001oo`0001eoo`03
001oogoo01Qoo`03001oogoo01Moo`03001oogoo01]oo`03001oogoo01=oo`03001oogoo02=oo`9l
01=oo`8000Uoo`8007Ioo`03001oogoo00]oo`004Goo00<007ooOol03goo00<007ooOol01Woo00<0
07ooOol0;Goo00@007ooOol002Aoo`03O01oogoo00Moo`03001oogoo008001aoo`8001Qoo`03001o
ogoo01Qoo`03001oogoo01]oo`03001oogoo019oo`03001oogoo02Eoo`03O01oogoo015oo`8000Eo
o`<007Qoo`03001oogoo00]oo`004Goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol0;7oo
00D007ooOomoo`0002Eoo`9l00Moo`8000=oo`8001aoo`03001oogoo01Ioo`03001oogoo01Qoo`03
001oogoo01Yoo`03001oogoo019oo`03001oogoo02Ioo`9l019oo`03001oogoo00<007]oo`03001o
ogoo00]oo`004Goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol0;7oo00D007ooOomoo`00
02Moo`03O01oogoo00Aoo`03001oo`0000Aoo`8001]oo`03001oogoo01Eoo`03001oogoo01Qoo`03
001oogoo01]oo`03001oogoo015oo`03001oogoo02Qoo`03O01oogoo011oo`8007ioo`03001oogoo
00]oo`004Goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol0;7oo00D007ooOomoo`0002Qo
o`9l00Aoo`04001oogoo0005Ool2000JOol00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`0J
Ool00`00Oomoo`0BOol00`00Oomoo`0XOol2O00@Ool00`00Oomoo`1mOol00`00Oomoo`0;Ool0015o
o`03001oogoo015oo`03001oogoo00Eoo`03001oogoo02]oo`04001oogoo000[Ool00g`0Oomoo`02
Ool00`00Ool00007Ool00`00Oomoo`0HOol2000EOol00`00Oomoo`0HOol00`00Oomoo`0KOol00`00
Oomoo`0AOol00`00Oomoo`0ZOol00g`0Oomoo`0=Ool2001nOol00`00Oomoo`0;Ool0015oo`03001o
ogoo015oo`03001oogoo00Eoo`03001oogoo02]oo`04001oogoo000/Ool2O002Ool01000Oomoo`00
1goo0P006Woo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol04Goo00<0
07ooOol0:goo0W`03Goo0P00OWoo00<007ooOol02goo000AOol00`00Oomoo`0AOol00`00Oomoo`05
Ool00`00Oomoo`0[Ool01000Oomoo`00;Woo00=l07oo00000goo00<007ooOol01Woo0P006Goo00<0
07ooOol04Goo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol0;Goo0W`0
2goo0`00OGoo00<007ooOol02goo000AOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0[
Ool01000Oomoo`00;goo0W`00goo00<007ooOol027oo00<007ooOol05goo0P004Woo00<007ooOol0
6Goo00<007ooOol06Woo00<007ooOol047oo00<007ooOol0;goo0W`02Goo0P0000=oo`00Ool0Ngoo
00<007ooOol02goo000AOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0ZOol01@00Oomo
ogoo0000<7oo00<007`0Ool00Woo00<007ooOol027oo0P006Goo00<007ooOol03goo00<007ooOol0
6Goo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol0<7oo00=l07ooOol01Woo0P0000=oo`00
Ool0Ngoo00<007ooOol02goo000AOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0ZOol0
1000Oomoo`00<Goo00@007ooO01l009oo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo00io
o`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo011oo`03001oogoo035oo`9l00Ioo`80009o
o`03001oogoo07Uoo`03001oogoo00]oo`004Goo00<007ooOol04goo00<007ooOol017oo00<007oo
Ool0:Goo00@007ooOol0035oo`07001oogooOoml07oo000037oo0P0067oo00<007ooOol03Woo00<0
07ooOol06Goo00<007ooOol06Woo00<007ooOol047oo00<007ooOol0<goo00=l07ooOol00goo00D0
07oo001oo`0007]oo`03001oogoo00]oo`004Goo00<007ooOol04goo00<007ooOol017oo00<007oo
Ool0:Goo00@007ooOol0035oo`03001oogoo009oo`9l0003001oogoo00]oo`03001oogoo01Ioo`80
00ioo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo00moo`03001oogoo03Uoo`03001oo`00
009oo`03001oogoo07Qoo`03001oogoo00]oo`004Goo00<007ooOol04goo00<007ooOol017oo00<0
07ooOol0:Goo00<007oo0000<Woo00<007ooOol017oo0W`03Goo0P0067oo00<007ooOol02goo00<0
07ooOol06Woo00<007ooOol06Woo00<007ooOol047oo00<007ooOol0>7oo00<007oo00000Woo00<0
07ooOol0N7oo00<007ooOol02goo000AOol3000COol00`00Oomoo`04Ool00`00Oomoo`0XOol01000
Oomoo`00<goo00<007ooOol017oo00<007`0O0003Goo0P005goo00<007ooOol02goo00<007ooOol0
6Goo00<007ooOol06goo00<007ooOol03goo00<007ooOol0>7oo00@007ooOol0009oo`03001oogoo
07Ioo`8000eoo`004Goo00<007ooOol057oo00<007ooOol00goo00<007ooOol0:7oo00@007ooOol0
03=oo`03001oogoo00Eoo`03001oog`000ioo`8001Ioo`03001oogoo00Yoo`03001oogoo01Yoo`03
001oogoo01]oo`03001oogoo00ioo`03001oogoo03Moo`05001oogooOol00003Ool00`00Oomoo`1f
Ool00`00Oomoo`0;Ool0015oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo02Qoo`03001o
o`0003Aoo`03001oogoo00Eoo`03001oogoo009l00ioo`03001oogoo01Aoo`03001oogoo00Uoo`03
001oogoo01Yoo`03001oogoo01]oo`03001oogoo00ioo`03001oogoo03Moo`05001oogooOol00003
Ool00`00Oomoo`1fOol00`00Oomoo`0;Ool0015oo`03001oogoo01Aoo`03001oogoo00=oo`03001o
ogoo02Qoo`03001oo`0003Aoo`03001oogoo00Ioo`04001oogooOol2O00=Ool2000EOol00`00Oomo
o`09Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0=Ool00`00Oomoo`0gOol00`00Oomo
o`02Ool01@00Oomoogoo0000Mgoo00<007ooOol02goo000AOol00`00Oomoo`0DOol00`00Oomoo`04
Ool00`00Oomoo`0VOol01000Oomoo`00=7oo00<007ooOol01goo00<007ooOol00Woo00=l07ooOol0
37oo0P0057oo00<007ooOol027oo00<007ooOol06Woo00<007ooOol06goo00<007ooOol03Woo00<0
07ooOol0=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0M7oo00<007ooOol02goo000A
Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Ool0000eOol00`00Oomoo`08
Ool00`00Oomoo`02Ool2O00>Ool2000COol00`00Oomoo`07Ool00`00Oomoo`0KOol00`00Oomoo`0K
Ool00`00Oomoo`0=Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1d
Ool00`00Oomoo`0;Ool0015oo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo02Ioo`03001o
o`0003Eoo`03001oogoo00Qoo`03001oogoo00Aoo`03O01oogoo00eoo`<0015oo`8000Qoo`03001o
ogoo01Yoo`03001oogoo01]oo`03001oogoo00eoo`03001oogoo03Eoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo07=oo`03001oogoo00]oo`004Goo00<007ooOol05Goo00<007ooOol00goo
00<007ooOol09Woo00<007oo0000=Goo00<007ooOol02Goo00<007ooOol017oo0W`047oo0P004Goo
00<007ooOol01Goo00<007ooOol06Woo00<007ooOol077oo00<007ooOol037oo00<007ooOol0=Goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol0LWoo00<007ooOol02goo000AOol00`00Oomo
o`0EOol00`00Oomoo`03Ool00`00Oomoo`0VOol00`00Ool0000eOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00g`0Oomoo`0?Ool2000@Ool00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`0KOol0
0`00Oomoo`0=Ool00`00Oomoo`0cOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`1bOol0
0`00Oomoo`0;Ool0015oo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo02Aoo`03001oo`00
03Moo`03001oogoo00Yoo`03001oogoo00Eoo`9l015oo`8000moo`8000Eoo`03001oogoo01Yoo`03
001oogoo01aoo`03001oogoo00aoo`03001oogoo03=oo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo075oo`03001oogoo00]oo`004Goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol0
97oo00<007oo0000=goo00<007ooOol02Woo00<007ooOol01goo00=l07ooOol047oo0P003goo00<0
07ooOol00Woo00<007ooOol06goo00<007ooOol077oo00<007ooOol02goo00<007ooOol0<goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol0LGoo00<007ooOol02goo000AOol00`00Oomoo`0F
Ool00`00Oomoo`03Ool00`00Oomoo`0TOol00`00Ool0000gOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool2O00BOol2000>Ool01@00Oomoogoo00007Goo00<007ooOol077oo00<007ooOol02goo00<007oo
Ool0<Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol0L7oo00<007ooOol02goo000AOol0
0`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`0TOol00`00Ool0000gOol00`00Oomoo`0<Ool0
0`00Oomoo`08Ool00g`0Oomoo`0AOol2000=Ool01@00Oomoogoo00007Goo00<007ooOol077oo00<0
07ooOol02Woo00<007ooOol0<Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0Kgoo00<0
07ooOol02goo000AOol00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0ROol01000Oomoo`00
=goo00<007ooOol03Goo00<007ooOol027oo0W`04goo0P0037oo0P0000=oo`00Ool077oo00<007oo
Ool077oo00<007ooOol02goo00<007ooOol0<Goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool0Kgoo00<007ooOol02goo000AOol00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0ROol0
0`00Ool0000hOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00g`0Oomoo`0BOol2000<Ool2000NOol0
0`00Oomoo`0LOol00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`1^Ool00`00Oomoo`0;Ool0015oo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo
029oo`03001oo`0003Qoo`03001oogoo00ioo`03001oogoo00Yoo`9l01Aoo`8000]oo`8001eoo`03
001oogoo01aoo`03001oogoo00Yoo`03001oogoo031oo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo06ioo`03001oogoo00]oo`004Goo0`0067oo00<007ooOol00Woo00<007ooOol08Woo00<0
07oo0000>7oo00<007ooOol03goo00<007ooOol02goo0W`057oo00<007ooOol02Goo0P007Goo00<0
07ooOol077oo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol0K7oo0P003Goo000AOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`0ROol00`00
Ool0000hOol00`00Oomoo`0OOol2O00COol20009Ool00`00Ool0000LOol00`00Oomoo`0LOol00`00
Oomoo`0:Ool00`00Oomoo`0^Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`1]Ool00`00
Oomoo`0;Ool0015oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo021oo`04001oogoo000h
Ool00`00Oomoo`0QOol00g`0Oomoo`0BOol20008Ool00`00Ool0000LOol00`00Oomoo`0LOol00`00
Oomoo`09Ool00`00Oomoo`0^Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`1/Ool00`00
Oomoo`0;Ool0015oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo021oo`03001oo`0003Yo
o`03001oogoo025oo`9l01Aoo`8000Ioo`04001oogoo000KOol00`00Oomoo`0LOol00`00Oomoo`09
Ool00`00Oomoo`0]Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`1/Ool00`00Oomoo`0;
Ool0015oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo021oo`03001oo`0003Yoo`03001o
ogoo02=oo`9l01Aoo`8000Aoo`04001oogooOol2000JOol00`00Oomoo`0KOol00`00Oomoo`09Ool0
0`00Oomoo`0]Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`1[Ool00`00Oomoo`0;Ool0
015oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo021oo`03001oo`0003Yoo`03001oogoo
02Eoo`9l01Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo01aoo`03
001oogoo00Qoo`03001oogoo02eoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo06]oo`03
001oogoo00]oo`004Goo00<007ooOol06Goo00<007ooOol00goo00<007ooOol07Woo00@007ooOol0
03Yoo`03001oogoo02Moo`9l01=oo`80009oo`03001oogoo00=oo`03001oogoo01Moo`03001oogoo
01]oo`03001oogoo00Uoo`03001oogoo02]oo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo
06]oo`03001oogoo00]oo`004Goo00<007ooOol06Goo00<007ooOol00goo00<007ooOol07Woo00@0
07ooOol003Yoo`03001oogoo02Uoo`03O01oogoo019oo`<000Ioo`8001Moo`03001oogoo01aoo`03
001oogoo00Qoo`03001oogoo02]oo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo06Yoo`03
001oogoo00]oo`004Goo00<007ooOol06Goo00<007ooOol00goo00<007ooOol07Woo00<007oo0000
>goo00<007ooOol0:Woo0W`057oo0P001goo00<007ooOol05Goo00<007ooOol06goo00<007ooOol0
27oo00<007ooOol0:Woo00<007ooOol047oo00<007ooOol01Woo00<007ooOol0JWoo00<007ooOol0
2goo000AOol00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Ool0000kOol00`00
Oomoo`0/Ool2O00COol30006Ool00`00Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`07Ool00`00
Oomoo`0ZOol00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`1YOol00`00Oomoo`0;Ool0015o
o`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01ioo`03001oo`0003]oo`03001oogoo02io
o`9l015oo`04001oogoo0006Ool00`00Oomoo`0COol00`00Oomoo`0LOol00`00Oomoo`08Ool00`00
Oomoo`0XOol00`00Oomoo`0AOol00`00Oomoo`1cOol00`00Oomoo`0;Ool0015oo`03001oogoo01Yo
o`03001oogoo00=oo`03001oogoo01aoo`04001oogoo000kOol00`00Oomoo`0`Ool2O00?Ool01000
Oomoogoo0P001Goo0P0057oo00<007ooOol077oo00<007ooOol01goo00<007ooOol09goo00<007oo
Ool04Woo00<007ooOol0Lgoo00<007ooOol02goo000AOol00`00Oomoo`0KOol00`00Oomoo`02Ool0
0`00Oomoo`0LOol00`00Ool0000mOol00`00Oomoo`0aOol00g`0Oomoo`0=Ool00`00Oomoo`02Ool2
0005Ool00`00Oomoo`0AOol00`00Oomoo`0MOol00`00Oomoo`06Ool00`00Oomoo`0VOol00`00Oomo
o`0DOol00`00Oomoo`1bOol00`00Oomoo`0;Ool0015oo`03001oogoo01]oo`03001oogoo009oo`03
001oogoo01aoo`03001oo`0003eoo`03001oogoo039oo`9l00eoo`03001oogoo00Aoo`8000Aoo`03
001oogoo015oo`03001oogoo01aoo`03001oogoo00Ioo`03001oogoo02Eoo`03001oogoo01Eoo`03
001oogoo079oo`03001oogoo00]oo`0000Aoo`00000000Aoo`8000Moo`03001oogoo01]oo`03001o
ogoo009oo`03001oogoo01aoo`03001oo`0003eoo`03001oogoo03Aoo`9l00]oo`03001oogoo00Io
o`8000=oo`03001oogoo011oo`03001oogoo01eoo`03001oogoo00Eoo`03001oogoo02Eoo`03001o
ogoo01Eoo`03001oogoo079oo`03001oogoo00]oo`000Woo00<007ooOol00Woo00@007ooOol000Io
o`03001oogoo01aoo`05001oogooOol0000MOol01000Oomoo`00?Goo00<007ooOol0=Woo00=l07oo
Ool027oo00<007ooOol027oo00D007ooOomoo`00019oo`03001oogoo01aoo`03001oogoo00Ioo`03
001oogoo02=oo`03001oogoo01Ioo`03001oogoo079oo`03001oogoo00]oo`000Woo00<007ooOol0
0Woo00@007ooOol000Ioo`03001oogoo01aoo`05001oogooOol0000MOol01000Oomoo`00?Goo00<0
07ooOol0=goo0W`027oo00<007ooOol02Goo0P000Woo00<007ooOol03goo00<007ooOol07Goo00<0
07ooOol01Goo00<007ooOol08Woo00<007ooOol05goo00<007ooOol0LWoo00<007ooOol02goo0002
Ool00`00Oomoo`02Ool01000Oomoo`001Woo10006goo00<007ooOol00Woo00<007ooOol06Woo00<0
07oo0000?Woo00<007ooOol0>Goo00=l07ooOol01Woo00<007ooOol02Woo0P0000=oo`00Ool047oo
00<007ooOol077oo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol06Goo00<007ooOol0Kgoo
0`003Goo0002Ool00`00Oomoo`02Ool01000Oomoo`001Woo00<007ooOol07Goo00D007ooOomoo`00
01aoo`03001oo`0003ioo`03001oogoo03Yoo`9l00Ioo`03001oogoo00aoo`<0015oo`03001oogoo
01aoo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo01Yoo`03001oogoo075oo`03001oogoo
00]oo`0000=oo`00000017oo00@007ooOol000Ioo`03001oogoo01eoo`05001oogooOol0000LOol0
0`00Ool0000nOol00`00Oomoo`0lOol00g`0Oomoo`03Ool00`00Oomoo`0>Ool3000?Ool00`00Oomo
o`0LOol00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0KOol00`00Oomoo`1aOol00`00Oomo
o`0;Ool0009oo`03001oogoo00=oo`8000Moo`03001oogoo01eoo`05001oogooOol0000KOol00`00
Ool0000oOol00`00Oomoo`0mOol2O003Ool00`00Oomoo`0@Ool2000?Ool00`00Oomoo`0LOol00`00
Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`0LOol00`00Oomoo`1aOol00`00Oomoo`0;Ool0015o
o`03001oogoo01eoo`05001oogooOol0000KOol00`00Ool00010Ool00`00Oomoo`0nOol2O002Ool0
0`00Oomoo`0@Ool2000>Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomo
o`0NOol00`00Oomoo`1`Ool00`00Oomoo`0;Ool0015oo`03001oogoo01ioo`04001oogoo000KOol0
0`00Ool00010Ool00`00Oomoo`10Ool2O0000`00Oomoo`0BOol3000<Ool00`00Oomoo`0LOol00`00
Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`0OOol00`00Oomoo`1`Ool00`00Oomoo`0;Ool0015o
o`03001oogoo01ioo`04001oogoo000KOol20011Ool00`00Oomoo`12Ool00g`0Oomoo`0DOol40009
Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0POol00`00Oomoo`1`
Ool00`00Oomoo`0;Ool0015oo`03001oogoo01ioo`05001oogooOol0000IOol00`00Ool00011Ool0
0`00Oomoo`12Ool00`00O01l000EOol00`00Oomoo`030007Ool00`00Oomoo`0LOol00`00Oomoo`03
Ool00`00Oomoo`0HOol00`00Oomoo`0QOol00`00Oomoo`1`Ool00`00Oomoo`0;Ool0015oo`03001o
ogoo01ioo`05001oogooOol0000IOol00`00Ool00011Ool00`00Oomoo`12Ool00`00Oomoo`02O00D
Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`0MOol00`00Oomoo`02Ool00`00Oomoo`0FOol2000T
Ool00`00Oomoo`1`Ool00`00Oomoo`0;Ool0015oo`03001oogoo01ioo`05001oogooOol0000IOol2
0012Ool00`00Oomoo`13Ool01000Oomoogoo0W`04goo0P0017oo0P0017oo00<007ooOol077oo00<0
07ooOol00Woo00<007ooOol05Goo00<007ooOol09Goo00<007ooOol0Kgoo00<007ooOol02goo000A
Ool00`00Oomoo`0OOol01000Oomoo`006Goo0P00@Woo00<007ooOol0@goo00<007ooOol00goo0W`0
4goo00<007ooOol00goo0`0000=oo`00Ool07Woo00D007ooOomoo`0001Ioo`03001oogoo02Ioo`03
001oogoo06moo`03001oogoo00]oo`004Goo00<007ooOol07goo00D007ooOomoo`0001Moo`03001o
o`00049oo`03001oogoo04=oo`03001oogoo00Eoo`03O01oogoo015oo`03001oogoo00Eoo`8001mo
o`03001oogoo009oo`03001oogoo019oo`03001oogoo02Moo`03001oogoo06moo`03001oogoo00]o
o`004Goo00<007ooOol07goo00D007ooOomoo`0001Moo`03001oo`00049oo`03001oogoo04Aoo`03
001oogoo00Eoo`9l019oo`8000Moo`<001eoo`05001oogooOol0000COol00`00Oomoo`0YOol00`00
Oomoo`1^Ool00`00Oomoo`0;Ool0015oo`03001oogoo01moo`05001oogooOol0000GOol20014Ool0
0`00Oomoo`13Ool00`00Oomoo`07Ool2O00BOol00`00Oomoo`04Ool00`00Oomoo`03000JOol01@00
Oomoogoo00004Woo00<007ooOol0:Woo00<007ooOol0KWoo00<007ooOol02goo000AOol00`00Oomo
o`0POol01000Oomoo`005goo0P00A7oo00<007ooOol0@goo00<007ooOol02Goo0W`04Goo00<007oo
Ool017oo00<007ooOol00Woo0`005goo00D007ooOomoo`00015oo`03001oogoo02]oo`03001oogoo
06ioo`03001oogoo00]oo`004Goo00<007ooOol087oo00D007ooOomoo`0001Eoo`03001oo`0004Ao
o`03001oogoo04Aoo`03001oogoo00Yoo`9l011oo`03001oogoo00=oo`03001oogoo00Eoo`<001Eo
o`04001oogoo000@Ool00`00Oomoo`0]Ool00`00Oomoo`1]Ool00`00Oomoo`0;Ool0015oo`<0021o
o`05001oogooOol0000EOol00`00Ool00014Ool00`00Oomoo`14Ool00`00Oomoo`0<Ool00g`0Oomo
o`0>Ool20004Ool00`00Oomoo`07Ool3000BOol01@00Oomoogoo00003Woo00<007ooOol0;Woo00<0
07ooOol0K7oo0P003Goo000AOol00`00Oomoo`0POol01@00Oomoogoo00005Goo00<007oo0000A7oo
00<007ooOol0A7oo00<007ooOol03Goo0W`047oo00D007ooOomoo`0000aoo`<0011oo`04001oogoo
000<Ool2000aOol00`00Oomoo`1]Ool00`00Oomoo`0;Ool0015oo`03001oogoo021oo`05001oogoo
Ool0000EOol20015Ool00`00Oomoo`15Ool00`00Oomoo`0>Ool2O00?Ool01@00Oomoogoo00003Woo
0P003Woo00@007ooOol000]oo`03001oogoo039oo`03001oogoo06aoo`03001oogoo00]oo`004Goo
00<007ooOol08Goo00@007ooOol001Eoo`8004Eoo`03001oogoo04Eoo`03001oogoo011oo`9l00io
o`04001oogoo000@Ool2000=Ool00`00Ool0000:Ool00`00Oomoo`0cOol00`00Oomoo`1/Ool00`00
Oomoo`0;Ool0015oo`03001oogoo025oo`05001oogooOol0000COol00`00Ool00015Ool00`00Oomo
o`15Ool00`00Oomoo`0BOol2O00=Ool00`00Ool0000BOol3000:Ool01000Oomoo`001goo0P00=Woo
00<007ooOol0K7oo00<007ooOol02goo000AOol00`00Oomoo`0QOol01@00Oomoogoo00004goo00<0
07oo0000AGoo00<007ooOol0AGoo00<007ooOol057oo00=l07ooOol02goo00<007oo000057oo0P00
2Goo00<007oo00001Woo00<007ooOol0=Woo00<007ooOol0K7oo00<007ooOol02goo000AOol00`00
Oomoo`0QOol01@00Oomoogoo00004goo0P00AWoo00<007ooOol0AWoo00<007ooOol057oo0W`037oo
0P005Woo0`001goo0P001Goo00<007ooOol0>7oo00<007ooOol0Jgoo00<007ooOol02goo000AOol0
0`00Oomoo`0ROol01000Oomoo`004goo0P00Agoo00<007ooOol0AGoo00<007ooOol05Woo0W`02goo
0P0067oo0`0017oo0P000goo0P00>goo00<007ooOol0Jgoo00<007ooOol02goo000AOol00`00Oomo
o`0ROol01@00Oomoogoo00004Goo00<007oo0000Agoo00<007ooOol0AGoo00<007ooOol067oo0W`0
2Woo0P006Woo0`000Woo00@007ooOol003eoo`03001oogoo06]oo`03001oogoo00]oo`004Goo00<0
07ooOol08Woo00D007ooOomoo`00015oo`8004Qoo`03001oogoo04Eoo`03001oogoo01Yoo`9l00Uo
o`8001aoo`D003ioo`03001oogoo06]oo`03001oogoo00]oo`004Goo00<007ooOol08goo00@007oo
Ool0015oo`8004Qoo`03001oogoo04Eoo`03001oogoo01aoo`03O01oogoo00Ioo`03001oo`0001io
o`<003eoo`03001oogoo06]oo`03001oogoo00]oo`004Goo00<007ooOol08goo00@007ooOol0015o
o`8004Qoo`03001oogoo04Ioo`03001oogoo01aoo`9l00Ioo`03001oogoo008001aoo`03001oogoo
00<003]oo`03001oogoo06Yoo`03001oogoo00]oo`004Goo00<007ooOol08goo00@007ooOol0015o
o`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo01ioo`9l00Eoo`05001oogooOol0000KOol2
0004Ool2000iOol00`00Oomoo`1ZOol00`00Oomoo`0;Ool0015oo`03001oogoo02Aoo`04001oogoo
000?Ool20019Ool00`00Oomoo`16Ool00`00Oomoo`0POol00g`0Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol20006Ool3000fOol00`00Oomoo`1ZOol00`00Oomoo`0;Ool0015oo`03001oogoo
02Aoo`04001oogoo000?Ool20019Ool00`00Oomoo`17Ool00`00Oomoo`0POol2O002Ool00`00Oomo
o`03Ool00`00Oomoo`0HOol00`00Oomoo`07Ool3000cOol00`00Oomoo`1ZOol00`00Oomoo`0;Ool0
015oo`03001oogoo02Aoo`04001oogoo000?Ool00`00Oomoo`18Ool00`00Oomoo`17Ool00`00Oomo
o`0ROol017`0Oomoo`001Goo0P0067oo0P002goo0`00<Goo00<007ooOol0JGoo00<007ooOol02goo
000AOol00`00Oomoo`0TOol01000Oomoo`003Woo0P00BWoo00<007ooOol0Agoo00<007ooOol08goo
0W`000<007ooOol01Goo00<007ooOol05Goo0P003Woo0`00;Woo00<007ooOol0JGoo00<007ooOol0
2goo000AOol3000UOol00`00Ool0000>Ool2001:Ool00`00Oomoo`18Ool00`00Oomoo`0TOol00g`0
001oo`06Ool2000EOol2000AOol3000[Ool00`00Oomoo`1XOol2000=Ool0015oo`03001oogoo02Eo
o`03001oo`0000ioo`03001oogoo04Uoo`03001oogoo04Qoo`03001oogoo02Eoo`03O01oogoo00Mo
o`03001oogoo019oo`03001oo`0001=oo`<002Qoo`03001oogoo06Uoo`03001oogoo00]oo`004Goo
00<007ooOol09Goo00@007ooOol000aoo`8004]oo`03001oogoo04Qoo`03001oogoo02Eoo`03001o
ogoo00Qoo`03001oogoo015oo`03001oo`0001Ioo`<002Eoo`03001oogoo06Uoo`03001oogoo00]o
o`004Goo00<007ooOol09Goo00@007ooOol000aoo`8004]oo`03001oogoo04Uoo`03001oogoo02Eo
o`03001oogoo00Qoo`80015oo`04001oogoo000HOol3000SOol00`00Oomoo`1XOol00`00Oomoo`0;
Ool0015oo`03001oogoo02Eoo`04001oogoo000<Ool00`00Oomoo`1:Ool00`00Oomoo`19Ool00`00
Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Ool0000KOol2000QOol00`00Oomoo`1X
Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Ioo`03001oo`0000]oo`8004aoo`03001oogoo04Uo
o`03001oogoo02Eoo`03001oogoo00]oo`8000moo`04001oogoo000LOol2000OOol00`00Oomoo`1X
Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Ioo`03001oo`0000]oo`8004aoo`03001oogoo04Uo
o`03001oogoo02Ioo`03001oogoo00aoo`03001oogoo00aoo`04001oogoo000NOol3000LOol00`00
Oomoo`1XOol00`00Oomoo`0;Ool0015oo`8002Moo`03001oo`0000]oo`8004aoo`03001oogoo04Yo
o`03001oogoo02Eoo`03001oogoo00eoo`03001oogoo00]oo`05001oogooOol0000POol2000KOol0
0`00Oomoo`1WOol00`00Oomoo`0;Ool0015oo`04001oo`00000UOol00`00Ool0000;Ool00`00Oomo
o`1<Ool00`00Oomoo`19Ool00`00Oomoo`0VOol00`00Oomoo`0=Ool2000;Ool01@00Oomoogoo0000
8Woo0`0067oo00<007ooOol0Igoo00<007ooOol02goo000AOol01000Oomoogoo0P0097oo00<007oo
00002Goo0P00CWoo00<007ooOol0BGoo00<007ooOol09Woo00<007ooOol03goo00<007ooOol027oo
00D007ooOomoo`0002Eoo`<001Eoo`03001oogoo06Moo`03001oogoo00]oo`004Goo00<007ooOol0
0goo0P008Woo00<007oo00002Goo0P00CWoo00<007ooOol0BGoo00<007ooOol09Woo00<007ooOol0
47oo00<007ooOol027oo00D007ooOomoo`0002Moo`<0019oo`03001oogoo06Moo`03001oogoo00]o
o`004Goo00<007ooOol01Goo00<007ooOol07goo00<007oo00002Goo0P00CWoo00<007ooOol0BGoo
00<007ooOol09goo00<007ooOol047oo00<007ooOol01goo00D007ooOomoo`0002Yoo`<000moo`03
001oogoo06Moo`03001oogoo00]oo`004Goo00<007ooOol01Woo0P007goo00<007oo00002Goo0P00
CWoo00<007ooOol0BWoo00<007ooOol09Woo00<007ooOol04Goo0P001goo00<007ooOol00Woo00<0
07ooOol0:Woo0`003Goo00<007ooOol0IWoo00<007ooOol02goo000AOol00`00Oomoo`08Ool2000M
Ool00`00Ool00009Ool00`00Oomoo`1=Ool00`00Oomoo`1:Ool00`00Oomoo`0VOol00`00Oomoo`0C
Ool00`00Oomoo`05Ool01@00Oomoogoo0000;goo0`002Woo00<007ooOol0IWoo00<007ooOol02goo
000AOol00`00Oomoo`0:Ool2000LOol00`00Ool00007Ool2001?Ool00`00Oomoo`1:Ool00`00Oomo
o`0WOol00`00Oomoo`0COol00`00Oomoo`04Ool01@00Oomoogoo0000<Woo0`001goo00<007ooOol0
IWoo00<007ooOol02goo000AOol00`00Oomoo`0<Ool2000JOol00`00Ool00007Ool2001?Ool00`00
Oomoo`1:Ool00`00Oomoo`0WOol00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`0bOol30004Ool00`00Oomoo`1VOol00`00Oomoo`0;Ool0015oo`<000ioo`8001Qoo`03001o
o`0000Moo`8004moo`03001oogoo04]oo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo03Eoo`<0009oo`03001oogoo06Aoo`8000eoo`004Goo00<007oo
Ool047oo0P005goo0P001Woo0P00DGoo00<007ooOol0BWoo00<007ooOol09goo00<007ooOol05Goo
00D007ooOomoo`0003moo`<006Moo`03001oogoo00]oo`004Goo00<007ooOol04Woo0P005Goo0P00
1Woo0P00DGoo00<007ooOol0BWoo00<007ooOol09goo00<007ooOol05Woo00@007ooOol0045oo`@0
06Aoo`03001oogoo00]oo`004Goo00<007ooOol057oo0P004goo0P001Woo0P00DGoo00<007ooOol0
BWoo00<007ooOol0:7oo00<007ooOol05Woo00@007ooOol0041oo`04001oogooOol3001QOol00`00
Oomoo`0;Ool0015oo`03001oogoo01Ioo`03001oogoo015oo`8000Aoo`80059oo`03001oogoo04Yo
o`03001oogoo02Qoo`03001oogoo01Moo`<0041oo`03001oogoo00Aoo`<005ioo`03001oogoo00]o
o`004Goo00<007ooOol05goo0P004Goo0P0017oo0P00DWoo00<007ooOol0Bgoo00<007ooOol0:7oo
00<007ooOol067oo00<007ooOol0?goo00<007ooOol01Woo0`00Fgoo00<007ooOol02goo000AOol0
0`00Oomoo`0IOol2000?Ool20004Ool2001BOol00`00Oomoo`1;Ool00`00Oomoo`0XOol00`00Oomo
o`0HOol20010Ool00`00Oomoo`09Ool3001HOol00`00Oomoo`0;Ool0015oo`03001oogoo01]oo`80
00ioo`04001oogooOol2001COol00`00Oomoo`1;Ool00`00Oomoo`0XOol00`00Oomoo`0HOol01000
Ool00000?Woo00<007ooOol037oo0P00EWoo00<007ooOol02goo000AOol00`00Oomoo`0MOol2000<
Ool01000Oomoogoo0P00Dgoo00<007ooOol0C7oo00<007ooOol0:7oo00<007ooOol05goo00D007oo
Oomoo`0003eoo`03001oogoo00ioo`<005=oo`03001oogoo00]oo`004Goo00<007ooOol07goo0P00
2Woo00@007ooOomoo`8005=oo`03001oogoo04aoo`03001oogoo02Qoo`03001oogoo01Moo`03001o
ogoo009oo`03001oogoo03]oo`03001oogoo011oo`<0051oo`03001oogoo00]oo`004Goo00<007oo
Ool08Goo00<007ooOol01goo00D007ooOomoo`0005Aoo`03001oogoo04aoo`03001oogoo02Uoo`03
001oogoo01Moo`03001oogoo009oo`03001oogoo03Yoo`03001oogoo01=oo`<004eoo`03001oogoo
00]oo`004Goo00<007ooOol08Woo0P0027oo00@007oo000005Aoo`03001oogoo04eoo`03001oogoo
02Qoo`03001oogoo01Moo`03001oogoo00=oo`8003Yoo`03001oogoo01Ioo`<004Yoo`03001oogoo
00]oo`004Goo00<007ooOol097oo0P001Woo00@007oo000005Aoo`03001oogoo04eoo`03001oogoo
02Qoo`03001oogoo01Moo`03001oogoo00Eoo`03001oogoo03Moo`03001oogoo01Uoo`<004Moo`03
001oogoo00]oo`004Goo00<007ooOol09Woo0P0017oo00<007oo0000EGoo00<007ooOol0CGoo00<0
07ooOol0:Goo00<007ooOol05Woo00<007ooOol01Woo00<007ooOol0=Woo00<007ooOol077oo0`00
A7oo00<007ooOol02goo000AOol00`00Oomoo`0XOol20002Ool00`00Ool0001EOol00`00Oomoo`1>
Ool00`00Oomoo`0XOol00`00Oomoo`0FOol00`00Oomoo`07Ool2000gOol00`00Oomoo`0NOol30011
Ool00`00Oomoo`0;Ool0015oo`03001oogoo02Yoo`05001oo`00Ool0001EOol00`00Oomoo`1>Ool0
0`00Oomoo`0XOol00`00Oomoo`0FOol00`00Oomoo`09Ool00`00Oomoo`0dOol00`00Oomoo`0QOol3
000nOol00`00Oomoo`0;Ool0015oo`03001oogoo02]oo`<005Ioo`03001oogoo04ioo`03001oogoo
02Uoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo03=oo`03001oogoo02Aoo`<003]oo`03
001oogoo00]oo`004Goo0`00;Goo00<007ooOol0E7oo00<007ooOol0CWoo00<007ooOol0:Goo00<0
07ooOol05Woo00<007ooOol02Woo00<007ooOol0<Woo00<007ooOol09goo0`00=goo0P003Goo000A
Ool00`00Oomoo`0]Ool00`00Oomoo`1DOol00`00Oomoo`1?Ool00`00Oomoo`0YOol00`00Oomoo`0E
Ool00`00Oomoo`0;Ool2000cOol00`00Oomoo`0YOol3000eOol00`00Oomoo`0;Ool0015oo`03001o
ogoo02eoo`03001oogoo05Aoo`03001oogoo04moo`03001oogoo02Uoo`03001oogoo01Eoo`03001o
ogoo00eoo`03001oogoo031oo`03001oogoo02aoo`<0039oo`03001oogoo00]oo`004Goo00<007oo
Ool0;7oo0P00Egoo00<007ooOol0CWoo00<007ooOol0:Goo00<007ooOol05Goo00<007ooOol03Woo
00<007ooOol0;goo00<007ooOol0;goo0`00;goo00<007ooOol02goo000AOol00`00Oomoo`0/Ool0
0`00Ool0001FOol00`00Oomoo`1>Ool00`00Oomoo`0ZOol00`00Oomoo`0DOol00`00Oomoo`0?Ool0
0`00Oomoo`0^Ool00`00Oomoo`0bOol3000/Ool00`00Oomoo`0;Ool0015oo`03001oogoo02aoo`03
001oo`0005Ioo`03001oogoo04ioo`03001oogoo02Yoo`03001oogoo01Aoo`03001oogoo011oo`03
001oogoo02eoo`03001oogoo03Eoo`<002Uoo`03001oogoo00]oo`004Goo00<007ooOol0:goo00@0
07ooOol005Ioo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo01=oo`03001oogoo015oo`03
001oogoo02eoo`03001oogoo03Moo`<002Ioo`03001oogoo00]oo`004Goo00<007ooOol0:goo00@0
07ooOol005Ioo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo01Aoo`03001oogoo015oo`03
001oogoo02aoo`03001oogoo03Yoo`<002=oo`03001oogoo00]oo`004Goo00<007ooOol0:goo00@0
07ooOol005Ioo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo01Aoo`03001oogoo019oo`03
001oogoo02]oo`03001oogoo03eoo`<0021oo`03001oogoo00]oo`004Goo00<007ooOol0:Woo00<0
07ooOol00Woo00<007ooOol0Dgoo00<007ooOol0D7oo00<007ooOol0:Woo00<007ooOol04goo00<0
07ooOol04goo0P00:goo00<007ooOol0@7oo0`007Goo00<007ooOol02goo000AOol00`00Oomoo`0Z
Ool00`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`1@Ool00`00Oomoo`0ZOol00`00Oomoo`0C
Ool00`00Oomoo`0EOol00`00Oomoo`0YOol00`00Oomoo`12Ool3000JOol00`00Oomoo`0;Ool0015o
o`03001oogoo02Yoo`03001oogoo009oo`03001oogoo05=oo`03001oogoo051oo`03001oogoo02]o
o`03001oogoo019oo`03001oogoo01Ioo`03001oogoo02Qoo`03001oogoo04Eoo`<001Moo`03001o
ogoo00]oo`004Goo00<007ooOol0:Goo00<007ooOol00goo00<007ooOol0Dgoo00<007ooOol0DGoo
00<007ooOol0:Woo00<007ooOol04Woo00<007ooOol05goo0P00:7oo00<007ooOol0B7oo0`0057oo
00<007ooOol02goo000AOol00`00Oomoo`0YOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`0eOol00`00Oomoo`0DOol00`00Oomoo`0OOol00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomo
o`0UOol00`00Oomoo`0>Ool01000Oomoo`006goo00<007ooOol05Woo00<007ooOol037oo00<007oo
Ool09goo00<007ooOol08Goo0`004Goo00<007ooOol02goo000017oo000000000Woo1@001Woo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo0P001Goo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol027oo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oo`0000Yoo`03001oogoo00Qoo`03001oogoo00Uoo`04001oogoo0007Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool0009oo`03001o
ogoo009oo`04001oogoo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`08Ool01@00
Oomoogoo00001Woo00<007ooOol027oo00<007ooOol027oo0P002Woo00<007ooOol027oo00<007oo
Ool02Goo00D007ooOomoo`0000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Eoo`@000Yoo`03001oogoo
00]oo`000Woo00<007ooOol00goo00<007ooOol01Wooo`00aP003Goo0002Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOooHOol0009oo`05001oogooOol00003Ool00`00Oomoo`3oOooGOol00003Ool00000
00=oo`05001oogooOol0003oOooIOol0009oo`03001oogoo009oo`<00?moomYoo`00ogooi7oo003o
OooTOol00?moonAoo`00ogooi7oo003oOooTOol00001\
\>"],
  ImageRangeCache->{{{0, 482}, {482, 0}} -> {584.387, 0.505631, 0.884288, \
0.0243179}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PT pseudosection - NCKFMASH", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}, {10, 790}, {12, 880}, {14, 968}, 
  {16, 1054}, {18, 1139}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH points data ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*------------------------------*)
(*  pl bi g mu H2O (liq ky)  *) 

i1={7.83, 661.2}//Reverse;
(*------------------------------*)
(*  pl bi mu sill H2O (liq g)  *) 

i2={6.24, 666.5}//Reverse;

i3={663.059, 7.217};

(*------------------------------*)
(*  liq pl bi g mu (ky H2O)  *) 

i4={7.84, 661.6}//Reverse;

i5={663.4, 7.22};


(*------------------------------*)
(*  liq pl bi mu sill (g H2O)  *) 

i6={6.24, 667.2}//Reverse;

i7={689.85, 7.80};

(*------------------------------*)
(*  liq pl bi g mu (ksp sill)  *) 

i8={8.30, 741.8}//Reverse;

(*------------------------------*)
(*  liq pl bi mu sill (ksp g)  *) 

i9={6.67, 715.6}//Reverse;

i10={759.5, 9.33};

(*------------------------------*)
(*  liq ksp bi g mu (pl ky)  *) 

i11={9.86, 766.8}//Reverse;

i12={760.2, 9.34};

i13={784.3, 9.87};

(*------------------------------*)
(*  liq ksp bi g sill (pl mu)  *) 

i14={7.53, 734.0}//Reverse;

(*------------------------------*)
(*  liq ksp g mu (bi ky)  *) 

i15={11.09, 794.3}//Reverse;

(*------------------------------*)
(*  liq ksp g ky (bi mu)  *) 

i16={11.08, 803.8}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi sill (g mu)  *) 

i17={6.54, 716.2}//Reverse;

(*------------------------------*)
(*  liq ksp bi g sill (pl cd)  *) 

i18={5.44, 751.0}//Reverse;
(*------------------------------*)
(*  liq ksp pl bi sill (cd g)  *) 

i19={4.64, 726.7}//Reverse;

(*------------------------------*)
(*  liq ksp cd g (bi sill)  *) 

i20={6.17, 781.2}//Reverse;

(*------------------------------*)
(*  liq ksp bi cd g (pl sill)  *) 

i21={4.91, 736.8}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi cd (g sill)  *) 

i22={4.23, 718.0}//Reverse;

(*------------------------------*)
(*  liq ksp g sill (bi cd)  *) 

i23={7.02, 810.5}//Reverse;

i24={803.7, 10.30};

(*------------------------------*)
(*  liq ksp cd g (bi opx)  *) 

i25={4.67, 802.0}//Reverse;

(*------------------------------*)
(*  liq ksp bi cd g (pl opx)  *) 

i26={2.77, 760.3}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi cd (g opx)  *) 

i27={2.23, 746.6}//Reverse;

(*------------------------------*)
(*  liq ksp cd g opx (pl bi)  *) 

i28={2.77, 764.5}//Reverse;

(*------------------------------*)
(*  liq ksp pl cd opx (bi g)  *) 

i29={2.54, 759.9}//Reverse;

(*------------------------------*)
(*  liq cd g (ksp opx)  *) 

i30={4.92, 865.6}//Reverse;

(*------------------------------*)
(*  liq cd opx (ksp g)  *) 

i31={3.29, 836.4}//Reverse;

(*------------------------------*)
(*  liq ksp cd opx (pl g)  *) 

i32={2.74, 793.4}//Reverse;

(*------------------------------*)
(*  liq cd g (ksp sill)  *) 

i33={6.35, 887.5}//Reverse;

(*------------------------------*)
(*  liq g sill (ksp cd)  *) 

i34={6.74, 888.4}//Reverse;

i35={964.7, 6.98};

(*------------------------------*)
(*  liq cd (opx H2O)  *) 

i36={0.56, 890.4}//Reverse;

(*------------------------------*)
(*  liq cd opx (ksp H2O)  *) 

i37={0.74, 776.8}//Reverse;

(*------------------------------*)
(*  liq ksp cd opx (pl H2O)  *) 

i38={0.78, 771.4}//Reverse;

(*------------------------------*)
(*  liq ksp pl cd opx (bi H2O)  *) 

i39={1.16, 741.5}//Reverse;

(*------------------------------*)
(*  ksp pl cd opx H2O (liq bi)  *) 

i40={1.08, 728.4}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi cd (opx H2O)  *) 

i41={1.15, 731.8}//Reverse;

(*------------------------------*)
(*  ksp pl bi cd H2O (liq opx)  *) 

i42={1.09, 721.9}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi cd (sill H2O)  *) 

i43={3.14, 666.9}//Reverse;

(*------------------------------*)
(*  ksp pl bi cd H2O (liq sill)  *) 

i44={3.08, 662.4}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi sill (cd H2O)  *) 

i45={3.26, 660.9}//Reverse;

(*------------------------------*)
(*  ksp pl bi sill H2O (liq cd)  *) 

i46={3.22, 657.9}//Reverse;

(*------------------------------*)
(*  ksp pl bi sill H2O (liq mu)  *) 

i47={3.50, 655.1}//Reverse;

(*------------------------------*)
(*  liq ksp pl bi sill (mu H2O)  *) 

i48={3.56, 657.9}//Reverse;

(*------------------------------*)
(*  liq pl bi mu sill (ksp H2O)  *) 

i49={3.47, 653.9}//Reverse;

(*------------------------------*)
(*  pl bi mu sill H2O (liq ksp)  *) 

i50={3.46, 653.3}//Reverse;

(*------------------------------*)
(*  ksp pl bi cd H2O (mu sill)  *) 

i51={2.20, 617.0}//Reverse;

(*------------------------------*)
(*  ksp pl bi sill H2O (cd mu)  *) 

i52={2.70, 631.4}//Reverse;

(*------------------------------*)
(*  pl bi mu sill H2O (ksp cd)  *) 

i53={2.71, 631.0}//Reverse;





\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
crossover[u71, u72]
crossover[sk, u48]
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
crossover[u71, u72]\
\>", "\<\
crossover[u71, u72]\
\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
crossover[{{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, \
{4.6, 541.5}, 
 
   {6.1, 611.4}, {7.6, 680.7000000000001}, {9.1, 749.3}, {10, 790}, 
 
   {12, 880}, {14, 968}, {16, 1054}, {18, 1139}}, u48]\
\>", \
"\<\
crossover[{{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, 
 
   {6.1, 611.4}, {7.6, 680.7}, {9.1, 749.3}, {10, 790}, {12, 880}, 
 
   {14, 968}, {16, 1054}, {18, 1139}}, u48]\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{964.7, 6.98}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{964.7, 6.980000000000001}\
\>", "\<\
{964.7, \
6.98}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{803.7, 10.30}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{803.7, 10.3}\
\>", "\<\
{803.7, 10.3}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH  data (lines 1-40)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(*------------------------------*)
(*  pl bi g mu H2O (liq)  *) 

u1={{6.00, 666.6},
{6.25, 666.1},
{6.50, 665.4},
{6.75, 664.7},
{7.00, 664.0},
{7.25, 663.2},
{7.50, 662.4},
{7.75, 661.5},
{8.00, 660.6},
{8.25, 659.7},
{8.50, 658.7},
{8.75, 657.7},
{9.00, 656.7},
{9.25, 655.7},
{9.50, 654.7},
{9.75, 653.6},
{10.00, 652.5},
{10.25, 651.4},
{10.50, 650.3},
{10.75, 649.2},
{11.00, 648.0},
{11.25, 646.8},
{11.50, 645.6},
{11.75, 644.4},
{12.00, 643.1},
{12.25, 641.8},
{12.50, 640.5},
{12.75, 639.1},
{13.00, 637.7},
{13.25, 636.2},
{13.50, 634.6},
{13.75, 632.9},
{14.00, 631.2}};

(*------------------------------*)
(*  pl bi mu sill H2O (liq)  *) 

u2={{3.00, 650.4},
{3.25, 651.9},
{3.50, 653.5},
{3.75, 655.0},
{4.00, 656.4},
{4.25, 657.8},
{4.50, 659.1},
{4.75, 660.4},
{5.00, 661.6},
{5.25, 662.7},
{5.50, 663.7},
{5.75, 664.7},
{6.00, 665.6},
{6.25, 666.5},
{6.50, 667.3},
{6.75, 668.0},
{7.00, 668.7},
{7.25, 669.4},
{7.50, 669.9},
{7.75, 670.4},
{8.00, 670.9}};

(*------------------------------*)
(*  pl bi g mu H2O (ky)  *) 

u3={{8.08, 600.0},
{8.02, 610.0},
{7.97, 620.0},
{7.93, 630.0},
{7.89, 640.0},
{7.86, 650.0},
{7.83, 660.0},
{7.81, 670.0},
{7.80, 680.0},
{7.78, 690.0},
{7.77, 700.0}};

(*------------------------------*)
(*  pl bi mu sill H2O (g)  *) 

u4={{5.58, 600.0},
{5.68, 610.0},
{5.78, 620.0},
{5.88, 630.0},
{5.98, 640.0},
{6.08, 650.0},
{6.18, 660.0},
{6.28, 670.0},
{6.37, 680.0},
{6.47, 690.0},
{6.56, 700.0}};

(*------------------------------*)
(*  pl bi g mu sill H2O (liq)  *) 

u5={{6.40, 665.7},
{6.60, 664.9},
{6.80, 664.2},
{7.00, 663.6},
{7.20, 663.1},
{7.40, 662.6}};

(*------------------------------*)
(*  pl bi g mu ky H2O (liq)  *) 

u6={{6.00, 666.7},
{6.20, 666.0},
{6.40, 665.4},
{6.60, 664.8},
{6.80, 664.2},
{7.00, 663.6},
{7.20, 663.1},
{7.40, 662.5},
{7.60, 661.9},
{7.80, 661.3}};

(*------------------------------*)
(*  liq pl bi g mu (H2O)  *) 

u7={{6.00, 667.2},
{6.20, 666.7},
{6.40, 666.2},
{6.60, 665.7},
{6.80, 665.1},
{7.00, 664.5},
{7.20, 663.8},
{7.40, 663.1},
{7.60, 662.4},
{7.80, 661.7},
{8.00, 661.0},
{8.20, 660.2},
{8.40, 659.4},
{8.60, 658.6},
{8.80, 657.8},
{9.00, 657.0},
{9.20, 656.1},
{9.40, 655.3},
{9.60, 654.4},
{9.80, 653.5},
{10.00, 652.7},
{10.20, 651.8},
{10.40, 650.9},
{10.60, 649.9},
{10.80, 649.0},
{11.00, 648.1},
{11.20, 647.1},
{11.40, 646.2},
{11.60, 645.2},
{11.80, 644.2},
{12.00, 643.2},
{12.20, 642.1},
{12.40, 641.1},
{12.60, 640.0},
{12.80, 638.8},
{13.00, 637.7},
{13.20, 636.5},
{13.40, 635.2},
{13.60, 634.0},
{13.80, 632.6},
{14.00, 631.2}};

(*------------------------------*)
(*  liq pl bi g mu ky (H2O)  *) 

u8={{6.00, 667.4},
{6.20, 666.7},
{6.40, 666.0},
{6.60, 665.4},
{6.80, 664.7},
{7.00, 664.1},
{7.20, 663.5},
{7.40, 662.9},
{7.60, 662.3},
{7.80, 661.7}};

(*------------------------------*)
(*  liq pl bi g mu sill (H2O)  *) 

u9={{6.40, 666.4},
{6.60, 665.5},
{6.80, 664.7},
{7.00, 664.1},
{7.20, 663.5},
{7.40, 663.0}};

(*------------------------------*)
(*  liq pl bi mu sill (H2O)  *) 

u10={{3.00, 650.8},
{3.20, 652.1},
{3.40, 653.4},
{3.60, 654.6},
{3.80, 655.8},
{4.00, 657.0},
{4.20, 658.1},
{4.40, 659.2},
{4.60, 660.3},
{4.80, 661.3},
{5.00, 662.2},
{5.20, 663.1},
{5.40, 664.0},
{5.60, 664.9},
{5.80, 665.6},
{6.00, 666.4},
{6.20, 667.1},
{6.40, 667.8},
{6.60, 668.4},
{6.80, 669.0},
{7.00, 669.6}};

u11={{7.83, 661.2},
{7.835,661.4},
{7.84, 661.6}};
     
u12={{6.24, 666.5},
{6.24, 666.9},
{6.24, 667.2}};

(*------------------------------*)
(*  liq pl bi g mu (ksp)  *) 

u13={{7.00, 734.4},
{7.25, 735.8},
{7.50, 737.1},
{7.75, 738.6},
{8.00, 740.0},
{8.25, 741.5},
{8.50, 743.0},
{8.75, 744.6},
{9.00, 746.3},
{9.25, 747.9},
{9.50, 749.6},
{9.75, 751.4},
{10.00, 753.2},
{10.25, 755.0},
{10.50, 756.9},
{10.75, 758.8},
{11.00, 760.7},
{11.25, 762.7},
{11.50, 764.7},
{11.75, 766.7},
{12.00, 768.8},
{12.25, 770.9},
{12.50, 773.0},
{12.75, 775.2},
{13.00, 777.3},
{13.25, 779.5},
{13.50, 781.8},
{13.75, 784.0},
{14.00, 786.3}};

(*------------------------------*)
(*  liq pl bi g mu (ky)  *) 

u14={{7.86, 650.0},
{7.84, 660.0},
{7.82, 670.0},
{7.81, 680.0},
{7.80, 690.0},
{7.80, 700.0},
{7.81, 710.0},
{7.82, 720.0},
{7.85, 730.0},
{7.91, 740.0},
{8.10, 750.0}};

(*------------------------------*)
(*  liq pl bi g mu (sill)  *) 

u15={{7.47, 650.0},
{7.55, 660.0},
{7.64, 670.0},
{7.72, 680.0},
{7.80, 690.0},
{7.89, 700.0},
{7.97, 710.0},
{8.07, 720.0},
{8.16, 730.0},
{8.28, 740.0},
{8.45, 750.0}};

(*------------------------------*)
(*  liq pl bi g mu sill (ksp)  *) 

u16={{6.80, 717.6},
{7.00, 720.7},
{7.20, 723.9},
{7.40, 727.1},
{7.60, 730.3},
{7.80, 733.6},
{8.00, 736.9},
{8.20, 740.1}};

(*------------------------------*)
(*  liq pl bi mu sill (g)  *) 

u17={{6.07, 650.0},
{6.17, 660.0},
{6.26, 670.0},
{6.36, 680.0},
{6.45, 690.0},
{6.54, 700.0},
{6.62, 710.0},
{6.70, 720.0},
{6.76, 730.0}};

(*------------------------------*)
(*  liq ksp bi g mu (pl)  *) 

u18={{7.00, 757.7},
{7.25, 758.2},
{7.50, 758.7},
{7.75, 759.3},
{8.00, 759.9},
{8.25, 760.6},
{8.50, 761.3},
{8.75, 762.2},
{9.00, 763.1},
{9.25, 764.1},
{9.50, 765.2},
{9.75, 766.3},
{10.00, 767.5},
{10.25, 768.8},
{10.50, 770.2},
{10.75, 771.6},
{11.00, 773.1},
{11.25, 774.6},
{11.50, 776.2},
{11.75, 777.9},
{12.00, 779.6},
{12.25, 781.3},
{12.50, 783.1},
{12.75, 784.9},
{13.00, 786.8},
{13.25, 788.7},
{13.50, 790.6},
{13.75, 792.6},
{14.00, 794.7}};


(*------------------------------*)
(*  liq ksp bi g mu (ky)  *) 

u19={{9.00, 752.4},
{9.25, 755.4},
{9.50, 759.5},
{9.75, 764.5},
{10.00, 769.9},
{10.25, 775.6},
{10.50, 781.3},
{10.75, 786.9},
{11.00, 792.4}};

(*------------------------------*)
(*  liq ksp pl bi g mu (sill)  *) 

u20={{8.40, 743.5},
{8.60, 747.0},
{8.80, 750.5},
{9.00, 753.9},
{9.20, 757.4},
{9.40, 760.8},
{9.60, 764.2}};

(*------------------------------*)
(*  liq ksp pl bi g mu (ky)  *) 

u21={{8.00, 740.8},
{8.20, 743.7},
{8.40, 746.6},
{8.60, 749.4},
{8.80, 752.2},
{9.00, 755.0},
{9.20, 757.8},
{9.40, 760.5},
{9.60, 763.3},
{9.80, 766.0}};

(*------------------------------*)
(*  liq ksp bi g mu sill (pl)  *) 

u22={{7.75, 736.7},
{8.00, 740.1},
{8.25, 743.6},
{8.50, 747.3},
{8.75, 751.0},
{9.00, 754.9},
{9.25, 758.8},
{9.50, 762.7}};

(*------------------------------*)
(*  liq ksp bi g mu ky (pl)  *) 

u23={{8.00, 744.1},
{8.20, 746.4},
{8.40, 748.7},
{8.60, 751.0},
{8.80, 753.5},
{9.00, 755.9},
{9.20, 758.4},
{9.40, 760.9},
{9.60, 763.5},
{9.80, 766.1}};

(*------------------------------*)
(*  liq ksp bi g ky (mu)  *) 

u24={{9.00, 769.6},
{9.25, 773.8},
{9.50, 778.1},
{9.75, 782.3},
{10.00, 786.4},
{10.25, 790.5},
{10.50, 794.5},
{10.75, 798.6},
{11.00, 802.6}};

(*------------------------------*)
(*  liq ksp bi g sill (mu)  *) 

u25={{6.00, 700.4},
{6.25, 704.7},
{6.50, 709.8},
{6.75, 715.5},
{7.00, 721.3},
{7.25, 727.2},
{7.50, 733.2},
{7.75, 739.0},
{8.00, 744.7},
{8.25, 750.3},
{8.50, 755.8},
{8.75, 761.2},
{9.00, 766.5},
{9.25, 771.7},
{9.50, 776.8},
{9.75, 781.8},
{10.00, 786.8}};

(*------------------------------*)
(*  liq ksp g mu (bi)  *) 

u26={{10.00, 789.1},
{10.25, 790.3},
{10.50, 791.5},
{10.75, 792.7},
{11.00, 793.9},
{11.25, 795.1},
{11.50, 796.3},
{11.75, 797.6},
{12.00, 798.9},
{12.25, 800.2},
{12.50, 801.4},
{12.75, 802.8},
{13.00, 804.1},
{13.25, 805.4},
{13.50, 806.8},
{13.75, 808.1},
{14.00, 809.5}};

(*------------------------------*)
(*  liq ksp g mu (ky)  *) 

u27={{11.00, 793.1},
{11.25, 796.5},
{11.50, 800.0},
{11.75, 803.4},
{12.00, 806.8},
{12.25, 810.3},
{12.50, 813.7},
{12.75, 817.1},
{13.00, 820.5},
{13.25, 823.9},
{13.50, 827.3},
{13.75, 830.6},
{14.00, 834.0}};

(*------------------------------*)
(*  liq ksp g ky (mu)  *) 

u28={{11.00, 802.7},
{11.25, 806.2},
{11.50, 809.6},
{11.75, 813.1},
{12.00, 816.5},
{12.25, 819.9},
{12.50, 823.3},
{12.75, 826.7},
{13.00, 830.0},
{13.25, 833.4},
{13.50, 836.8},
{13.75, 840.1},
{14.00, 843.4}};

u29={{11.09, 794.3},
{11.085, 799.05},
{11.08, 803.8}};

(*------------------------------*)
(*  liq ksp pl bi g sill (mu)  *) 

u30={{6.75, 720.1},
{7.00, 724.6},
{7.25, 729.0},
{7.50, 733.4}};

(*------------------------------*)
(*  liq ksp bi g sill (pl)  *) 

u31={{4.00, 757.1},
{4.25, 756.4},
{4.50, 755.6},
{4.75, 754.6},
{5.00, 753.4},
{5.25, 752.1},
{5.50, 750.6},
{5.75, 749.0},
{6.00, 747.2},
{6.25, 745.3},
{6.50, 743.3},
{6.75, 741.1},
{7.00, 738.8},
{7.25, 736.6},
{7.50, 734.3},
{7.75, 731.9},
{8.00, 729.5}};

(*------------------------------*)
(*  liq ksp bi g sill (cd)  *) 

u32={{4.50, 712.9},
{4.75, 722.2},
{5.00, 732.8},
{5.25, 743.2},
{5.50, 753.3},
{5.75, 763.1},
{6.00, 772.6},
{6.25, 782.0},
{6.50, 791.3},
{6.75, 800.5},
{7.00, 809.7}};

(*------------------------------*)
(*  liq pl bi mu sill (ksp)  *) 

u33={{3.00, 644.4},
{3.25, 649.4},
{3.50, 654.4},
{3.75, 659.3},
{4.00, 664.3},
{4.25, 669.2},
{4.50, 674.1},
{4.75, 678.9},
{5.00, 683.8},
{5.25, 688.6},
{5.50, 693.4},
{5.75, 698.2},
{6.00, 703.0},
{6.25, 707.7},
{6.50, 712.5},
{6.75, 717.2},
{7.00, 721.9}};

(*------------------------------*)
(*  liq ksp pl bi sill (mu)  *) 

u34={{3.00, 646.6},
{3.25, 651.7},
{3.50, 656.7},
{3.75, 661.7},
{4.00, 666.7},
{4.25, 671.7},
{4.50, 676.7},
{4.75, 681.6},
{5.00, 686.5},
{5.25, 691.4},
{5.50, 696.2},
{5.75, 701.1},
{6.00, 705.9},
{6.25, 710.7},
{6.50, 715.4},
{6.75, 720.2},
{7.00, 724.9}};

(*------------------------------*)
(*  liq ksp pl bi sill (g)  *) 

u35={{3.00, 728.3},
{3.25, 728.5},
{3.50, 728.6},
{3.75, 728.4},
{4.00, 728.2},
{4.25, 727.7},
{4.50, 727.1},
{4.75, 726.3},
{5.00, 725.4},
{5.25, 724.3},
{5.50, 723.0},
{5.75, 721.6},
{6.00, 719.9},
{6.25, 718.2},
{6.50, 716.4},
{6.75, 714.5},
{7.00, 712.5}};

(*------------------------------*)
(*  liq ksp pl bi g sill (cd)  *) 

u37={{4.80, 731.3},
{5.00, 737.3},
{5.20, 743.4},
{5.40, 749.7}};

(*------------------------------*)
(*  liq ksp pl bi sill (cd)  *) 

u38={{3.00, 648.7},
{3.20, 658.2},
{3.40, 667.7},
{3.60, 677.2},
{3.80, 686.7},
{4.00, 696.2},
{4.20, 705.7},
{4.40, 715.1},
{4.60, 724.6},
{4.80, 734.0},
{5.00, 743.4}};

(*------------------------------*)
(*  liq ksp cd g sill (bi)  *) 

u39={{6.25, 784.0},
{6.50, 792.5},
{6.75, 801.1},
{7.00, 809.8}};

(*------------------------------*)
(*  liq ksp bi cd g (sill)  *) 

u40={{4.00, 700.9},
{4.20, 709.3},
{4.40, 717.4},
{4.60, 725.2},
{4.80, 732.8},
{5.00, 740.1},
{5.20, 747.2},
{5.40, 754.3},
{5.60, 761.3},
{5.80, 768.3},
{6.00, 775.3}};



\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH  data (lines 41-80)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi cd g (sill)  *) 

u41={{4.40, 722.6},
{4.60, 728.1},
{4.80, 733.7}};

(*------------------------------*)
(*  liq ksp pl bi cd (sill)  *) 

u42={{2.00, 612.5},
{2.25, 624.3},
{2.50, 636.2},
{2.75, 648.1},
{3.00, 660.0},
{3.25, 671.9},
{3.50, 683.7},
{3.75, 695.5},
{4.00, 707.3},
{4.25, 719.1},
{4.50, 730.8},
{4.75, 742.5},
{5.00, 754.2}};

(*------------------------------*)
(*  liq ksp cd g (bi)  *) 

u45={{2.25, 807.3},
{2.50, 809.0},
{2.75, 810.2},
{3.00, 810.9},
{3.25, 811.0},
{3.50, 810.5},
{3.75, 809.6},
{4.00, 808.1},
{4.25, 806.2},
{4.50, 803.9},
{4.75, 801.2},
{5.00, 798.2},
{5.25, 794.9},
{5.50, 791.4},
{5.75, 787.7},
{6.00, 783.9},
{6.25, 779.9},
{6.50, 776.0}};

(*------------------------------*)
(*  liq ksp cd g (sill)  *) 

u46={{6.11, 750.0},
{6.13, 760.0},
{6.15, 770.0},
{6.17, 780.0},
{6.18, 790.0},
{6.20, 800.0},
{6.21, 810.0},
{6.23, 820.0},
{6.24, 830.0},
{6.26, 840.0},
{6.27, 850.0},
{6.29, 860.0},
{6.31, 870.0},
{6.33, 880.0}};

(*------------------------------*)
(*  liq ksp g sill (bi)  *) 

u47={{7.00, 810.5},
{7.25, 810.4},
{7.50, 810.3},
{7.75, 810.0},
{8.00, 809.7},
{8.25, 809.3},
{8.50, 808.9},
{8.75, 808.4},
{9.00, 807.7},
{9.25, 807.1},
{9.50, 806.3},
{9.75, 805.5},
{10.00, 804.7},
{10.25, 803.9},
{10.50, 803.1},
{10.75, 802.2},
{11.00, 801.3},
{11.25, 800.4},
{11.50, 799.4},
{11.75, 798.4},
{12.00, 797.3}};

(*------------------------------*)
(*  liq ksp g ky (bi)  *) 

u48={{10.00, 803.7},
{10.20, 803.7},
{10.40, 803.8},
{10.60, 803.8},
{10.80, 803.8},
{11.00, 803.8},
{11.20, 803.8},
{11.40, 803.8},
{11.60, 803.7},
{11.80, 803.7},
{12.00, 803.6}};

(*------------------------------*)
(*  liq ksp g sill (cd)  *) 

u49={{7.05, 800.0},
{7.02, 810.0},
{6.99, 820.0},
{6.96, 830.0},
{6.92, 840.0},
{6.89, 850.0},
{6.85, 860.0},
{6.81, 870.0},
{6.77, 880.0}};

(*------------------------------*)
(*  liq ksp bi cd g (pl)  *) 

u50={{1.00, 776.9},
{1.25, 774.5},
{1.50, 772.3},
{1.75, 770.1},
{2.00, 767.9},
{2.25, 765.5},
{2.50, 763.0},
{2.75, 760.5},
{3.00, 757.8},
{3.25, 755.1},
{3.50, 752.4},
{3.75, 749.6},
{4.00, 746.8},
{4.25, 744.0},
{4.50, 741.3},
{4.75, 738.5},
{5.00, 735.8},
{5.25, 733.2},
{5.50, 730.6},
{5.75, 728.2},
{6.00, 725.7}};

(*------------------------------*)
(*  liq ksp pl bi cd (g)  *) 

u51={{1.00, 769.8},
{1.25, 763.6},
{1.50, 758.8},
{1.75, 754.5},
{2.00, 750.3},
{2.25, 746.3},
{2.50, 742.3},
{2.75, 738.4},
{3.00, 734.6},
{3.25, 730.9},
{3.50, 727.4},
{3.75, 724.0},
{4.00, 720.8},
{4.25, 717.8},
{4.50, 714.9},
{4.75, 712.1},
{5.00, 709.5}};

(*------------------------------*)
(*  liq ksp bi cd g (opx)  *) 

u52={{2.00, 743.3},
{2.20, 747.6},
{2.40, 751.9},
{2.60, 756.4},
{2.80, 760.9},
{3.00, 765.4},
{3.20, 769.9},
{3.40, 774.4},
{3.60, 778.9},
{3.80, 783.3},
{4.00, 787.7},
{4.20, 792.0},
{4.40, 796.3},
{4.60, 800.5}};

(*------------------------------*)
(*  liq ksp pl bi cd g (opx)  *) 

u53={{2.30, 748.4},
{2.40, 751.0},
{2.50, 753.6},
{2.60, 756.1},
{2.70, 758.5}};

(*------------------------------*)
(*  liq ksp cd g opx (bi)  *) 

u54={{2.20, 753.8},
{2.40, 757.6},
{2.60, 761.3},
{2.80, 765.1},
{3.00, 769.0},
{3.20, 772.9},
{3.40, 776.9},
{3.60, 780.9},
{3.80, 784.8},
{4.00, 788.8},
{4.20, 792.7},
{4.40, 796.7},
{4.60, 800.6}};

(*------------------------------*)
(*  liq ksp pl cd g opx (bi)  *) 

u55={{2.60, 761.2},
{2.70, 763.2}};

(*------------------------------*)
(*  liq ksp cd g (opx)  *) 

u56={{4.67, 800.0},
{4.70, 810.0},
{4.73, 820.0},
{4.76, 830.0},
{4.80, 840.0},
{4.84, 850.0},
{4.89, 860.0}};

(*------------------------------*)
(*  liq cd g opx (ksp)  *) 

u59={{3.40, 838.6},
{3.60, 842.5},
{3.80, 846.3},
{4.00, 850.0},
{4.20, 853.6},
{4.40, 857.0},
{4.60, 860.4},
{4.80, 863.7}};

(*------------------------------*)
(*  liq ksp cd opx (g)  *) 

u60={{1.30, 700.0},
{1.48, 710.0},
{1.65, 720.0},
{1.82, 730.0},
{1.98, 740.0},
{2.13, 750.0},
{2.28, 760.0},
{2.42, 770.0},
{2.56, 780.0},
{2.70, 790.0},
{2.83, 800.0},
{2.96, 810.0},
{3.09, 820.0},
{3.21, 830.0}};

(*------------------------------*)
(*  liq ksp cd g opx (pl)  *) 

u61={{2.74, 700.0},
{2.75, 710.0},
{2.76, 720.0},
{2.76, 730.0},
{2.77, 740.0},
{2.77, 750.0},
{2.77, 760.0},
{2.77, 770.0},
{2.76, 780.0},
{2.75, 790.0}};

(*------------------------------*)
(*  liq ksp pl cd opx (g)  *) 

u62={{0.40, 427.6},
{0.60, 451.8},
{0.80, 477.2},
{1.00, 503.8},
{1.20, 531.9},
{1.40, 561.5},
{1.60, 592.9},
{1.80, 626.8},
{2.00, 662.6},
{2.20, 699.1},
{2.40, 735.5},
{2.60, 770.4}};

(*------------------------------*)
(*  liq ksp pl cd opx (bi)  *) 

u63={{0.60, 733.1},
{0.80, 736.1},
{1.00, 739.1},
{1.20, 742.0},
{1.40, 744.9},
{1.60, 747.7},
{1.80, 750.4},
{2.00, 753.0},
{2.20, 755.6},
{2.40, 758.2},
{2.60, 760.7},
{2.80, 763.2},
{3.00, 765.6}};

(*------------------------------*)
(*  liq ksp cd opx (pl)  *) 

u64={{0.60, 769.0},
{0.80, 771.6},
{1.00, 774.2},
{1.20, 776.7},
{1.40, 779.1},
{1.60, 781.4},
{1.80, 783.7},
{2.00, 785.9},
{2.20, 788.0},
{2.40, 790.0},
{2.60, 792.0},
{2.80, 793.9},
{3.00, 795.7}};

(*------------------------------*)
(*  liq cd opx (ksp)  *) 

u65={{0.60, 773.3},
{0.80, 778.5},
{1.00, 783.6},
{1.20, 788.6},
{1.40, 793.5},
{1.60, 798.4},
{1.80, 803.1},
{2.00, 807.8},
{2.20, 812.5},
{2.40, 817.0},
{2.60, 821.5},
{2.80, 825.9},
{3.00, 830.2},
{3.20, 834.5},
{3.40, 838.6},
{3.60, 842.8},
{3.80, 846.8},
{4.00, 850.8}};

(*------------------------------*)
(*  liq cd opx (g)  *) 

u66={{3.47, 850.0},
{3.60, 860.0},
{3.73, 870.0},
{3.87, 880.0},
{4.01, 890.0},
{4.15, 900.0},
{4.29, 910.0},
{4.44, 920.0},
{4.59, 930.0},
{4.75, 940.0},
{4.91, 950.0},
{5.08, 960.0},
{5.25, 970.0},
{5.44, 980.0},
{5.62, 990.0},
{5.81, 1000.0},
{6.01, 1010.0},
{6.22, 1020.0}};

(*------------------------------*)
(*  liq cd g (ksp)  *) 

u67={{4.00, 848.9},
{4.20, 852.7},
{4.40, 856.4},
{4.60, 860.0},
{4.80, 863.6},
{5.00, 867.0},
{5.20, 870.3},
{5.40, 873.5},
{5.60, 876.7},
{5.80, 879.7},
{6.00, 882.6},
{6.20, 885.5},
{6.40, 888.2}};

(*------------------------------*)
(*  liq cd g sill (ksp)  *) 

u68={{6.40, 887.7},
{6.50, 888.0},
{6.60, 888.2},
{6.70, 888.3}};

(*------------------------------*)
(*  liq g sill (ksp)  *) 

u69={{6.00, 875.1},
{6.25, 879.6},
{6.50, 884.1},
{6.75, 888.5},
{7.00, 892.9},
{7.25, 897.2},
{7.50, 901.5},
{7.75, 905.7},
{8.00, 909.8},
{8.25, 913.9},
{8.50, 918.0},
{8.75, 922.0},
{9.00, 926.0},
{9.25, 930.0},
{9.50, 933.9},
{9.75, 937.7},
{10.00, 941.5},
{10.25, 945.3},
{10.50, 949.0},
{10.75, 952.8},
{11.00, 956.4},
{11.25, 960.1},
{11.50, 963.7},
{11.75, 967.2},
{12.00, 970.8},
{12.25, 974.3},
{12.50, 977.7},
{12.75, 981.2},
{13.00, 984.6}};

(*------------------------------*)
(*  liq g sill (cd)  *) 

u70={{6.63, 850.0},
{6.69, 870.0},
{6.75, 890.0},
{6.80, 910.0},
{6.87, 930.0},
{6.93, 950.0}};

(*------------------------------*)
(*  liq g (sill)  *) 

u71={{6.42, 950.0},
{6.80, 960.0},
{7.19, 970.0},
{7.58, 980.0},
{7.97, 990.0},
{8.38, 1000.0},
{8.78, 1010.0},
{9.20, 1020.0}};

(*------------------------------*)
(*  liq g (cd)  *) 

u72={{7.14, 950.0},
{7.03, 960.0},
{6.93, 970.0},
{6.85, 980.0},
{6.79, 990.0},
{6.75, 1000.0},
{6.73, 1010.0},
{6.72, 1020.0}};

(*------------------------------*)
(*  liq cd g (opx)  *) 

u73={{4.52, 800.0},
{4.58, 810.0},
{4.63, 820.0},
{4.69, 830.0},
{4.75, 840.0},
{4.81, 850.0},
{4.88, 860.0},
{4.95, 870.0},
{5.02, 880.0},
{5.10, 890.0},
{5.18, 900.0},
{5.27, 910.0},
{5.36, 920.0},
{5.46, 930.0},
{5.56, 940.0},
{5.68, 950.0},
{5.81, 960.0},
{5.94, 970.0},
{6.09, 980.0},
{6.25, 990.0},
{6.43, 1000.0},
{6.61, 1010.0}};

(*------------------------------*)
(*  liq cd g (sill)  *) 

u74={{5.76, 800.0},
{5.82, 810.0},
{5.88, 820.0},
{5.95, 830.0},
{6.02, 840.0},
{6.09, 850.0},
{6.15, 860.0},
{6.22, 870.0},
{6.30, 880.0},
{6.37, 890.0},
{6.44, 900.0},
{6.52, 910.0},
{6.60, 920.0},
{6.68, 930.0},
{6.76, 940.0},
{6.85, 950.0},
{6.94, 960.0}};

(*------------------------------*)
(*  liq cd opx (H2O)  *) 

u75={{0.75, 750.0},
{0.74, 760.0},
{0.74, 770.0},
{0.73, 780.0},
{0.72, 790.0},
{0.71, 800.0},
{0.70, 810.0},
{0.69, 820.0},
{0.67, 830.0},
{0.66, 840.0},
{0.64, 850.0},
{0.62, 860.0},
{0.60, 870.0},
{0.58, 880.0},
{0.56, 890.0}};

(*------------------------------*)
(*  liq cd (opx)  *) 

u76={{1.45, 910.0},
{2.28, 930.0},
{2.66, 940.0},
{3.02, 950.0},
{3.35, 960.0},
{3.66, 970.0},
{3.94, 980.0},
{4.20, 990.0},
{4.43, 1000.0},
{4.63, 1010.0},
{4.81, 1020.0}};

(*------------------------------*)
(*  liq cd H2O (opx)  *) 

u77={{0.41, 900.0},
{0.28, 910.0},
{0.18, 920.0},
{0.10, 930.0},
{0.06, 940.0},
{0.01, 960.0}};

(*------------------------------*)
(*  liq cd (H2O)  *) 

u78={{0.57, 880.0},
{0.56, 890.0},
{0.55, 900.0},
{0.54, 910.0},
{0.52, 920.0},
{0.51, 930.0},
{0.50, 940.0},
{0.48, 950.0},
{0.47, 960.0},
{0.45, 970.0},
{0.43, 980.0},
{0.42, 990.0},
{0.40, 1000.0},
{0.38, 1010.0},
{0.36, 1020.0}};

(*------------------------------*)
(*  liq cd opx H2O (ksp)  *) 

u79={{0.01, 905.7},
{0.06, 881.8},
{0.11, 867.0},
{0.16, 855.2},
{0.21, 845.0},
{0.26, 835.9},
{0.31, 827.7},
{0.36, 820.0},
{0.41, 813.0},
{0.46, 806.4},
{0.51, 800.2},
{0.56, 794.5},
{0.61, 789.0},
{0.66, 783.9},
{0.71, 779.1}};

(*------------------------------*)
(*  ksp cd opx H2O (liq)  *) 

u80={{0.03, 878.8},
{0.05, 867.7},
{0.08, 859.0},
{0.10, 851.5},
{0.12, 844.8},
{0.15, 838.6},
{0.18, 833.0},
{0.20, 827.6},
{0.23, 822.6},
{0.25, 817.7},
{0.28, 813.1},
{0.30, 808.7},
{0.33, 804.5},
{0.35, 800.4},
{0.38, 796.4},
{0.40, 792.6},
{0.43, 788.9},
{0.45, 785.3},
{0.48, 781.8},
{0.50, 778.4},
{0.53, 775.1},
{0.55, 771.9},
{0.57, 768.8},
{0.60, 765.8},
{0.62, 762.8},
{0.65, 760.0},
{0.67, 757.2},
{0.70, 754.5},
{0.72, 751.9},
{0.75, 749.4},
{0.77, 746.9},
{0.80, 744.5},
{0.82, 742.2},
{0.85, 739.9},
{0.87, 737.8},
{0.90, 735.6},
{0.92, 733.6},
{0.95, 731.6},
{0.97, 729.7},
{1.00, 727.8},
{1.02, 726.0},
{1.05, 724.2},
{1.07, 722.5},
{1.10, 720.9},
{1.12, 719.3},
{1.15, 717.7},
{1.17, 716.2},
{1.20, 714.7},
{1.22, 713.3},
{1.25, 711.9},
{1.27, 710.6},
{1.30, 709.3},
{1.32, 708.0},
{1.35, 706.8},
{1.37, 705.6},
{1.40, 704.5},
{1.42, 703.3},
{1.45, 702.2},
{1.47, 701.2},
{1.50, 700.1},
{1.52, 699.1},
{1.55, 698.1},
{1.57, 697.1},
{1.60, 696.2},
{1.62, 695.3},
{1.65, 694.4},
{1.67, 693.5},
{1.70, 692.6},
{1.72, 691.8},
{1.75, 691.0},
{1.77, 690.2},
{1.80, 689.4},
{1.82, 688.6},
{1.85, 687.9},
{1.87, 687.1},
{1.90, 686.4},
{1.92, 685.7},
{1.95, 685.0},
{1.97, 684.3},
{2.00, 683.6}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["NCKFMASH  data (lines 81-> )", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\

(*------------------------------*)
(*  liq ksp cd opx (H2O)  *) 

u81={{1.00, 750.0},
{0.95, 755.0},
{0.89, 760.0},
{0.84, 765.0},
{0.80, 770.0},
{0.75, 775.0}};

(*------------------------------*)
(*  liq ksp cd opx H2O (pl)  *) 

u82={{0.01, 899.5},
{0.04, 885.9},
{0.06, 876.6},
{0.09, 869.1},
{0.11, 862.5},
{0.14, 856.5},
{0.16, 851.1},
{0.19, 846.0},
{0.21, 841.3},
{0.24, 836.8},
{0.26, 832.5},
{0.29, 828.5},
{0.31, 824.6},
{0.34, 820.8},
{0.36, 817.2},
{0.39, 813.8},
{0.41, 810.4},
{0.44, 807.2},
{0.46, 804.1},
{0.49, 801.1},
{0.50, 799.3},
{0.52, 796.4},
{0.55, 793.6},
{0.57, 790.9},
{0.60, 788.3},
{0.62, 785.8},
{0.65, 783.3},
{0.67, 780.9},
{0.70, 778.6},
{0.72, 776.4},
{0.75, 774.2},
{0.77, 772.1}};

(*------------------------------*)
(*  liq ksp pl cd opx (H2O)  *) 

u83={{0.80, 769.8},
{0.85, 765.1},
{0.90, 760.7},
{0.95, 756.6},
{1.00, 752.7},
{1.05, 749.0},
{1.10, 745.6},
{1.15, 742.3},
{1.20, 739.2},
{1.25, 736.3},
{1.30, 733.6},
{1.35, 731.0},
{1.40, 728.6},
{1.45, 726.2},
{1.50, 724.0}};

(*------------------------------*)
(*  ksp pl cd opx H2O (liq)  *) 

u84={{1.22, 720.0},
{1.13, 725.0},
{1.05, 730.0},
{0.98, 735.0},
{0.91, 740.0},
{0.85, 745.0},
{0.80, 750.0},
{0.74, 755.0},
{0.70, 760.0},
{0.65, 765.0},
{0.60, 770.0},
{0.56, 775.0},
{0.52, 780.0},
{0.48, 785.0},
{0.45, 790.0},
{0.41, 795.0},
{0.38, 800.0},
{0.35, 805.0},
{0.32, 810.0},
{0.29, 815.0},
{0.26, 820.0},
{0.23, 825.0},
{0.21, 830.0},
{0.18, 835.0},
{0.16, 840.0},
{0.14, 845.0},
{0.12, 850.0},
{0.10, 855.0},
{0.08, 860.0},
{0.06, 865.0},
{0.03, 870.0},
{0.01, 875.0}};

(*------------------------------*)
(*  liq ksp pl bi cd (opx)  *) 

u85={{0.60, 723.6},
{0.80, 726.7},
{1.00, 729.6},
{1.20, 732.6},
{1.40, 735.4},
{1.60, 738.2},
{1.80, 740.9},
{2.00, 743.5},
{2.20, 746.1},
{2.40, 748.7},
{2.60, 751.2},
{2.80, 753.6},
{3.00, 756.0}};

(*------------------------------*)
(*  liq ksp pl bi cd opx (H2O)  *) 

u86={{1.15, 731.9},
{1.16, 735.8}};

(*------------------------------*)
(*  liq ksp pl bi cd H2O (opx)  *) 

u87={{1.13, 728.9},
{1.14, 731.2}};

(*------------------------------*)
(*  ksp pl cd opx H2O (bi)  *) 

u88={{0.01, 434.7},
{0.11, 567.4},
{0.21, 611.6},
{0.31, 639.3},
{0.41, 659.5},
{0.51, 675.2},
{0.61, 688.1},
{0.71, 698.9},
{0.81, 708.3},
{0.91, 716.5},
{1.01, 723.9},
{1.11, 730.6},
{1.20, 736.2}};

(*------------------------------*)
(*  liq ksp pl cd opx H2O (bi)  *) 

u89={{1.09, 730.9},
{1.10, 732.4},
{1.11, 734.0},
{1.12, 735.4},
{1.13, 736.9},
{1.14, 738.3},
{1.15, 739.7},
{1.16, 741.0}};

(*------------------------------*)
(*  ksp pl bi cd H2O (opx)  *) 

u91={{0.01, 432.7},
{0.11, 562.3},
{0.21, 605.8},
{0.31, 633.2},
{0.41, 653.0},
{0.51, 668.6},
{0.61, 681.2},
{0.71, 691.9},
{0.81, 701.2},
{0.91, 709.3},
{1.01, 716.6},
{1.11, 723.2},
{1.20, 728.7}};

(*------------------------------*)
(*  liq ksp pl bi cd (H2O)  *) 

u92={{1.00, 741.9},
{1.20, 728.7},
{1.40, 717.8},
{1.60, 708.6},
{1.80, 700.9},
{2.00, 694.2},
{2.20, 688.2},
{2.40, 682.9},
{2.60, 678.0},
{2.80, 673.6},
{3.00, 669.6},
{3.20, 665.8},
{3.40, 662.3},
{3.60, 659.0},
{3.80, 656.0},
{4.00, 653.2}};

(*------------------------------*)
(*  ksp pl bi cd H2O (liq)  *) 

u93={{1.00, 727.3},
{1.20, 715.8},
{1.40, 706.2},
{1.60, 698.1},
{1.80, 691.3},
{2.00, 685.4},
{2.20, 680.1},
{2.40, 675.4},
{2.60, 671.1},
{2.80, 667.2},
{3.00, 663.6},
{3.20, 660.3},
{3.40, 657.2},
{3.60, 654.3},
{3.80, 651.6},
{4.00, 649.1}};

(*------------------------------*)
(*  ksp pl bi cd H2O (sill)  *) 

u94={{1.00, 552.9},
{1.20, 563.9},
{1.40, 574.7},
{1.60, 585.4},
{1.80, 596.0},
{2.00, 606.5},
{2.20, 616.9},
{2.40, 627.3},
{2.60, 637.7},
{2.80, 648.1},
{3.00, 658.5},
{3.20, 668.7},
{3.40, 678.9},
{3.60, 689.1},
{3.80, 699.2},
{4.00, 709.3}};

(*------------------------------*)
(*  ksp pl bi sill H2O (cd)  *) 

u95={{1.00, 542.7},
{1.20, 553.6},
{1.40, 564.2},
{1.60, 574.7},
{1.80, 585.2},
{2.00, 595.5},
{2.20, 605.8},
{2.40, 616.1},
{2.60, 626.4},
{2.80, 636.6},
{3.00, 646.8},
{3.20, 657.1},
{3.40, 667.3},
{3.60, 677.4},
{3.80, 687.5},
{4.00, 697.6}};

(*------------------------------*)
(*  liq ksp pl bi sill (H2O)  *) 

u100={{2.00, 680.3},
{2.20, 676.1},
{2.40, 672.4},
{2.60, 669.2},
{2.80, 666.3},
{3.00, 663.8},
{3.20, 661.5},
{3.40, 659.4},
{3.60, 657.5},
{3.80, 655.9}};
(*------------------------------*)
(*  ksp pl bi sill H2O (liq)  *) 

u101={{2.00, 676.6},
{2.20, 672.4},
{2.40, 668.8},
{2.60, 665.6},
{2.80, 662.9},
{3.00, 660.4},
{3.20, 658.1},
{3.40, 656.0},
{3.60, 654.3},
{3.80, 652.7}};

(*------------------------------*)
(*  ksp pl bi sill H2O (mu)  *) 

u102={{1.00, 572.6},
{1.20, 580.9},
{1.40, 588.5},
{1.60, 595.7},
{1.80, 602.6},
{2.00, 609.3},
{2.20, 615.8},
{2.40, 622.2},
{2.60, 628.4},
{2.80, 634.5},
{3.00, 640.5},
{3.20, 646.4},
{3.40, 652.2},
{3.60, 658.0},
{3.80, 663.7},
{4.00, 669.4}};

(*------------------------------*)
(*  pl bi mu sill H2O (ksp)  *) 

u103={{1.00, 572.2},
{1.20, 580.5},
{1.40, 588.1},
{1.60, 595.2},
{1.80, 602.1},
{2.00, 608.7},
{2.20, 615.2},
{2.40, 621.5},
{2.60, 627.7},
{2.80, 633.8},
{3.00, 639.8},
{3.20, 645.6},
{3.40, 651.4},
{3.60, 657.2},
{3.80, 662.9},
{4.00, 668.5}};

(*------------------------------*)
(*  pl bi mu sill H2O (cd)  *) 

u108={{1.00, 413.9},
{1.20, 439.8},
{1.40, 465.7},
{1.60, 491.3},
{1.80, 516.6},
{2.00, 541.8},
{2.20, 566.8},
{2.40, 591.8},
{2.60, 617.1},
{2.80, 643.5}};

(*------------------------------*)
(*  ksp pl bi cd sill H2O (mu)  *) 

u109={{2.30, 619.9},
{2.35, 621.4},
{2.40, 622.9},
{2.45, 624.3},
{2.50, 625.8},
{2.55, 627.2},
{2.60, 628.6},
{2.65, 630.0}};







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["draw function", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{2,1};\n   \n \n \t\tas1 = makeline[ka, trp, ll];\n \t\tas2 = makeline[sk, \
trp, i7];\n \t\tas3 = makeline[as, trp, lr];\n \t\tas21 = makeline[sk, i10, \
ur];\n \t\t\n \t\tlu1 = makeline[u1, ul, i1];\n \t\tlu2 = makeline[u2, i2, \
i50];\n \t\tlu3 = makeline[u3, ul, i1];\n \t\tlu4 = makeline[u4, i2, ll];\n \t\
\tlu5 = makeline[u5, i1, i3];\n \t\tlu6 = makeline[u6, i2, i3];\n \t\tlu7 = \
makeline[u7, ul, i4];\n \t\tlu8 = makeline[u8, i4, i5];\n \t\tlu9 = \
makeline[u9, i5, i6];\n \t\tlu10 = makeline[u10, i49, i6];\n \t\tlu11 = \
makeline[u11, i1, i4];\n \t\tlu12 = makeline[u12, i2, i6];\n \t\tlu13 = \
makeline[u13, i8, ur];\n \t\tlu14 = makeline[u14, i4, i7];\n \t\tlu15 = \
makeline[u15, i7, i8];\n \t\tlu16 = makeline[u16, i9, i8];\n \t\tlu17 = \
makeline[u17, i6, i9];\n \t\tlu18 = makeline[u18, i11, ur];\n \t\tlu19 = \
makeline[u19, i11, i15];\n \t\tlu20 = makeline[u20, i8, i10];\n \t\tlu21 = \
makeline[u21, i10, i11];\n \t\tlu22 = makeline[u22, i14, i12];\n \t\tlu23 = \
makeline[u23, i12, i11];\n \t\tlu24 = makeline[u24, i13, i16];\n \t\tlu25 = \
makeline[u25, i13, i14];\n \t\tlu26 = makeline[u26, i15, ur];\n \t\tlu27 = \
makeline[u27, i15, ur];\n \t\tlu28 = makeline[u28, i16, ur];\n \t\tlu29 = \
makeline[u29, i16, i15];\n \t\tlu30 = makeline[u30, i14, i17];\n \t\tlu31 = \
makeline[u31, i14, i18];\n \t\tlu32 = makeline[u32, i18, i23];\n \t\tlu33 = \
makeline[u33, i49, i9];\n \t\tlu34 = makeline[u34, i48, i17];\n \t\tlu35 = \
makeline[u35, i19, i17];\n \t\tlu36 = connect[i9, i17];\n \t\tlu37 = \
makeline[u37, i18, i19];\n \t\tlu38 = makeline[u38, i45, i19];\n \t\tlu39 = \
makeline[u39, i20, i23];\n \t\tlu40 = makeline[u40, i20, i21];\n \t\tlu41 = \
makeline[u41, i21, i22];\n \t\tlu42 = makeline[u42, i43, i22];\n \t\tlu43 = \
connect[i18, i21];\n \t\tlu44 = connect[i19, i22];\n \t\tlu45 = makeline[u45, \
i25, i20];\n \t\tlu46 = makeline[u46, i33, i20];\n \t\tlu47 = makeline[u47, \
i24, i23];\n \t\tlu48 = makeline[u48, i16, i24];\n \t\tlu49 = makeline[u49, \
i23, i34];\n \t\tlu50 = makeline[u50, i21, i26];\n \t\tlu51 = makeline[u51, \
i22, i27];\n \t\tlu52 = makeline[u52, i25, i26];\n \t\tlu53 = makeline[u53, \
i26, i27];\n \t\tlu54 = makeline[u54, i25, i28];\n \t\tlu55 = makeline[u55, \
i28, i29];\n \t\tlu56 = makeline[u56, i25, i30];\n \t\tlu57 = connect[i26, \
i28];\n \t\tlu58 = connect[i27, i29];\n \t\tlu59 = makeline[u59, i30, i31];\n \
\t\tlu60 = makeline[u60, i31, i32];\n \t\tlu61 = makeline[u61, i28, i32];\n \t\
\tlu62 = makeline[u62, i29, i32];\n \t\tlu63 = makeline[u63, i29, i39];\n \t\t\
lu64 = makeline[u64, i32, i38];\n \t\tlu65 = makeline[u65, i31, i37];\n \t\t\
lu66 = makeline[u66, i31, ur];\n \t\tlu67 = makeline[u67, i33, i30];\n \t\t\
lu68 = makeline[u68, i33, i34];\n \t\tlu69 = makeline[u69, ur, i34];\n \t\t\
lu70 = makeline[u70, i35, i34];\n \t\tlu71 = makeline[u71, ur, i35];\n \t\t\
lu72 = makeline[u72, lr, i35];\n \t\tlu73 = makeline[u73, ur, i30];\n \t\t\
lu74 = makeline[u74, i35, i33];\n \t\tlu75 = makeline[u75, i37, i36];\n \t\t\
lu76 = makeline[u76, ur, i36];\n \t\tlu77 = makeline[u77, lr, i36];\n \t\t\
lu78 = makeline[u78, lr, i36];\n \t\tlu79 = makeline[u79, lr, i37];\n \t\t\
lu80 = makeline[u80, lr, ul];\n \t\tlu81 = makeline[u81, i37, i38];\n \t\t\
lu82 = makeline[u82, lr, i38];\n \t\tlu83 = makeline[u83, i39, i38];\n \t\t\
lu84 = makeline[u84, i40, lr];\n \t\tlu85 = makeline[u85, i27, i41];\n \t\t\
lu86 = makeline[u86, i39, i41];\n \t\tlu87 = makeline[u87, i41, i42];\n \t\t\
lu88 = makeline[u88, i40, ll];\n \t\tlu89 = makeline[u89, i39, i40];\n \t\t\
lu90 = connect[i40, i42];\n \t\tlu91 = makeline[u91, i42, ll];\n \t\tlu92 = \
makeline[u92, i41, i43];\n \t\tlu93 = makeline[u93, i42, i44];\n \t\tlu94 = \
makeline[u94, i44, i51];\n \t\tlu95 = makeline[u95, i46,i52];\n \t\tlu96 = \
connect[i43, i44];\n \t\tlu97 = connect[i43, i45];\n \t\tlu98 = connect[i45, \
i46];\n \t\tlu99 = connect[i44, i46];\n \t\tlu100 = makeline[u100, i45, i48];\
\n \t\tlu101 = makeline[u101, i46, i47];\n \t\tlu102 = makeline[u102, i47, \
i52];\n \t\tlu103 = makeline[u103, i50, i53];\n \t\tlu104 = connect[i47, \
i48];\n \t\tlu105 = connect[i49, i48];\n \t\tlu106 = connect[i49, i50];\n \t\t\
lu107 = connect[i47, i50];\n \t\tlu108 = makeline[u108, ll, i53];\n \t\tlu109 \
= makeline[u109, i51, i52];\n \t\tlu110 = connect[i52, i53];\n  \t \n   \
Show[Graphics[\n   \t\t\t\t\t\t\t{GrayLevel[0.85],\n          \
area[{lu1,lu11,lu7}],\n          area[{lu13,lu20,lu21,lu18}],\n          \
area[{lu19,lu29,lu24,lu25,lu22,lu23}],\n          area[{lu52,lu54,lu57}],\n   \
       area[{lu61,lu55,lu62}],\n          area[{lu3,lu5,lu6,lu4}],\n          \
area[{lu14,lu15,lu16,lu17,lu9,lu8}],\n          area[{lu82,lu83,lu89,lu84}], \
\n          area[{lu58,lu63,lu86,lu85}],\n          \
area[{lu41,lu50,lu53,lu51}],\n          area[{lu91,lu90,lu88}],\n          \
area[{lu92,lu87,lu93,lu96}],\n          area[{lu32,lu39,lu40,lu43}],\n        \
  area[{lu30,lu31,lu37,lu35}],\n          area[{lu94,lu99,lu95}],\n          \
area[{lu38,lu44,lu42,lu97}],\n          area[{lu98,lu100,lu104,lu101}],\n     \
     area[{lu33,lu36,lu34,lu105}],\n         \n              \n          \n   \
       GrayLevel[0.7],\n          area[{lu1,lu3}],\n          \
area[{lu7,lu14,lu15,lu13}],\n          area[{lu18,lu19,lu26}],\n          \
area[{lu27,lu29,lu28}],\n          area[{lu25,lu24,lu48,lu47,lu32,lu31}],\n   \
       area[{lu49,lu68,lu46,lu39}],\n          \
area[{lu54,lu56,lu59,lu60,lu61}], \n          area[{lu40,lu45,lu52,lu50}],\n  \
        area[{lu84,lu88}],\n          area[{lu62,lu64,lu83,lu63}],\n          \
area[{lu51,lu85,lu92,lu42}],\n          area[{lu91,lu93,lu94}],\n          \
area[{lu34,lu35,lu38,lu100}],\n          area[{lu95,lu102,lu101}],\n          \
area[{lu4,lu2,lu103,lu108}],\n          area[{lu33,lu10,lu17}],\n          \n \
          \n          GrayLevel[0.55],\n          area[{lu26,lu27}],\n        \
  area[{lu28,lu48,lu47,lu49,lu69}],\n          area[{lu70,lu68,lu74}],\n      \
    area[{lu66,lu59,lu73}],\n          area[{lu56,lu45,lu46,lu67}], \n        \
  area[{lu60,lu65,lu81,lu64}],\n          area[{lu79,lu75,lu77}],\n          \
\n          \n          GrayLevel[0.4], \n          area[{lu69,lu70,lu71}],\n \
         area[{lu73,lu67,lu74,lu72}],\n          area[{lu66,lu65,lu75,lu76}],\
\n          area[{lu77,lu78}],\n          \n          GrayLevel[0.25],\n      \
    area[{lu71,lu72}],\n          area[{lu76,lu78}],\n   \n          \
GrayLevel[0],\n           AbsoluteThickness[0.3],\n         \n           \
drawline[as1],\n           drawline[as2],\n           drawline[as21],\n       \
   \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu1],\n          \tdrawline[lu2],\n          \t\
drawline[lu3],\n          \tdrawline[lu4],\n          \tdrawline[lu5],\n      \
    \tdrawline[lu6],\n          \t\n          \tdrawline[lu7],\n          \t\
drawline[lu8],\n          \tdrawline[lu9],\n          \tdrawline[lu10],\n     \
     \tdrawline[lu11],\n          \tdrawline[lu12],\n          \t\
drawline[lu13],\n          \tdrawline[lu14],\n          \tdrawline[lu15],\n   \
       \tdrawline[lu16],\n          \tdrawline[lu17],\n          \t\
drawline[lu18],\n          \t\n          \tdrawline[lu19],\n          \t\
drawline[lu20],\n          \tdrawline[lu21],\n          \tdrawline[lu22],\n   \
       \tdrawline[lu23],\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu24],\n          \tdrawline[lu25],\n          \t\
drawline[lu26],\n          \tdrawline[lu27],\n          \tdrawline[lu28],\n   \
       \tdrawline[lu29],\n          \tdrawline[lu30],\n          \t\
drawline[lu31],\n          \t\n          \tdrawline[lu32],\n          \t\
drawline[lu33],\n          \t\n          \tdrawline[lu34],\n          \t\
drawline[lu35],\n          \tdrawline[lu36],\n          \tdrawline[lu37],\n   \
       \tdrawline[lu38],\n          \tdrawline[lu39],\n          \t\
drawline[lu40],\n          \tdrawline[lu41],\n          \tdrawline[lu42],\n   \
       \tdrawline[lu43],\n          \tdrawline[lu44],\n          \t\
drawline[lu45],\n          \tdrawline[lu46],\n          \t\n          \t\
drawline[lu47],\n          \tdrawline[lu48],\n          \tdrawline[lu49],\n   \
       \tdrawline[lu50],\n          \tdrawline[lu51],\n          \t\
drawline[lu52],\n          \tdrawline[lu53],\n          \tdrawline[lu54],\n   \
       \tdrawline[lu55],\n          \tdrawline[lu56],\n          \t\n         \
 \tdrawline[lu57],\n          \tdrawline[lu58],\n          \tdrawline[lu59],\n\
          \tdrawline[lu60],\n          \tdrawline[lu61],\n          \t\
drawline[lu62],\n          \tdrawline[lu63],\n          \tdrawline[lu64],\n   \
       \tdrawline[lu65],\n          \tdrawline[lu66],\n          \t\
drawline[lu67],\n          \tdrawline[lu68],\n          \tdrawline[lu69],\n   \
       \tdrawline[lu70],\n          \tdrawline[lu71],\n          \t\
drawline[lu72],\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu73],\n          \tdrawline[lu74],\n          \t\
drawline[lu75],\n          \tdrawline[lu76],\n          \tdrawline[lu77],\n   \
       \tdrawline[lu78],\n          \tdrawline[lu79],\n          \t\n         \
 \tdrawline[lu81],\n          \tdrawline[lu82],\n          \tdrawline[lu83],\n\
          \tdrawline[lu84],\n          \tdrawline[lu85],\n          \t\
drawline[lu86],\n          \tdrawline[lu87],\n          \tdrawline[lu88],\n   \
       \tdrawline[lu89],\n          \tdrawline[lu90],\n          \t\
drawline[lu91],\n          \tdrawline[lu92],\n          \tdrawline[lu93],\n   \
       \tdrawline[lu94],\n          \tdrawline[lu95],\n          \t\
drawline[lu96],\n          \tdrawline[lu97],\n          \tdrawline[lu98],\n   \
       \tdrawline[lu99],\n          \tdrawline[lu100],\n          \t\
drawline[lu101],\n          \tdrawline[lu102],\n          \tdrawline[lu103],\n\
          \tdrawline[lu104],\n          \tdrawline[lu105],\n          \t\
drawline[lu106],\n          \tdrawline[lu107],\n          \tdrawline[lu108],\n\
          \tdrawline[lu109],\n          \tdrawline[lu110],\n           \n     \
      \n           outline}],\n               \n         AspectRatio -> 1, \
Frame -> True,\n         PlotRange -> {{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 630; xhigh = 930; ylow = 0.01; yhigh = 12;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.1 0.00333333 -0.000834028 0.0834028 [
[(650)] .06667 0 0 2 Msboxa
[(700)] .23333 0 0 2 Msboxa
[(750)] .4 0 0 2 Msboxa
[(800)] .56667 0 0 2 Msboxa
[(850)] .73333 0 0 2 Msboxa
[(900)] .9 0 0 2 Msboxa
[(2)] -0.0125 .16597 1 0 Msboxa
[(4)] -0.0125 .33278 1 0 Msboxa
[(6)] -0.0125 .49958 1 0 Msboxa
[(8)] -0.0125 .66639 1 0 Msboxa
[(10)] -0.0125 .83319 1 0 Msboxa
[(12)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06667 0 m
.06667 .00625 L
s
P
[(650)] .06667 0 0 2 Mshowa
p
.002 w
.23333 0 m
.23333 .00625 L
s
P
[(700)] .23333 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(750)] .4 0 0 2 Mshowa
p
.002 w
.56667 0 m
.56667 .00625 L
s
P
[(800)] .56667 0 0 2 Mshowa
p
.002 w
.73333 0 m
.73333 .00625 L
s
P
[(850)] .73333 0 0 2 Mshowa
p
.002 w
.9 0 m
.9 .00625 L
s
P
[(900)] .9 0 0 2 Mshowa
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.33333 0 m
.33333 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.66667 0 m
.66667 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .16597 m
.00625 .16597 L
s
P
[(2)] -0.0125 .16597 1 0 Mshowa
p
.002 w
0 .33278 m
.00625 .33278 L
s
P
[(4)] -0.0125 .33278 1 0 Mshowa
p
.002 w
0 .49958 m
.00625 .49958 L
s
P
[(6)] -0.0125 .49958 1 0 Mshowa
p
.002 w
0 .66639 m
.00625 .66639 L
s
P
[(8)] -0.0125 .66639 1 0 Mshowa
p
.002 w
0 .83319 m
.00625 .83319 L
s
P
[(10)] -0.0125 .83319 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(12)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .03253 m
.00375 .03253 L
s
P
p
.001 w
0 .06589 m
.00375 .06589 L
s
P
p
.001 w
0 .09925 m
.00375 .09925 L
s
P
p
.001 w
0 .13261 m
.00375 .13261 L
s
P
p
.001 w
0 .19933 m
.00375 .19933 L
s
P
p
.001 w
0 .23269 m
.00375 .23269 L
s
P
p
.001 w
0 .26606 m
.00375 .26606 L
s
P
p
.001 w
0 .29942 m
.00375 .29942 L
s
P
p
.001 w
0 .36614 m
.00375 .36614 L
s
P
p
.001 w
0 .3995 m
.00375 .3995 L
s
P
p
.001 w
0 .43286 m
.00375 .43286 L
s
P
p
.001 w
0 .46622 m
.00375 .46622 L
s
P
p
.001 w
0 .53294 m
.00375 .53294 L
s
P
p
.001 w
0 .56631 m
.00375 .56631 L
s
P
p
.001 w
0 .59967 m
.00375 .59967 L
s
P
p
.001 w
0 .63303 m
.00375 .63303 L
s
P
p
.001 w
0 .69975 m
.00375 .69975 L
s
P
p
.001 w
0 .73311 m
.00375 .73311 L
s
P
p
.001 w
0 .76647 m
.00375 .76647 L
s
P
p
.001 w
0 .79983 m
.00375 .79983 L
s
P
p
.001 w
0 .86656 m
.00375 .86656 L
s
P
p
.001 w
0 .89992 m
.00375 .89992 L
s
P
p
.001 w
0 .93328 m
.00375 .93328 L
s
P
p
.001 w
0 .96664 m
.00375 .96664 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.06667 .99375 m
.06667 1 L
s
P
p
.002 w
.23333 .99375 m
.23333 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.56667 .99375 m
.56667 1 L
s
P
p
.002 w
.73333 .99375 m
.73333 1 L
s
P
p
.002 w
.9 .99375 m
.9 1 L
s
P
p
.001 w
.1 .99625 m
.1 1 L
s
P
p
.001 w
.13333 .99625 m
.13333 1 L
s
P
p
.001 w
.16667 .99625 m
.16667 1 L
s
P
p
.001 w
.2 .99625 m
.2 1 L
s
P
p
.001 w
.26667 .99625 m
.26667 1 L
s
P
p
.001 w
.3 .99625 m
.3 1 L
s
P
p
.001 w
.33333 .99625 m
.33333 1 L
s
P
p
.001 w
.36667 .99625 m
.36667 1 L
s
P
p
.001 w
.43333 .99625 m
.43333 1 L
s
P
p
.001 w
.46667 .99625 m
.46667 1 L
s
P
p
.001 w
.5 .99625 m
.5 1 L
s
P
p
.001 w
.53333 .99625 m
.53333 1 L
s
P
p
.001 w
.6 .99625 m
.6 1 L
s
P
p
.001 w
.63333 .99625 m
.63333 1 L
s
P
p
.001 w
.66667 .99625 m
.66667 1 L
s
P
p
.001 w
.7 .99625 m
.7 1 L
s
P
p
.001 w
.76667 .99625 m
.76667 1 L
s
P
p
.001 w
.8 .99625 m
.8 1 L
s
P
p
.001 w
.83333 .99625 m
.83333 1 L
s
P
p
.001 w
.86667 .99625 m
.86667 1 L
s
P
p
.001 w
.03333 .99625 m
.03333 1 L
s
P
p
.001 w
.93333 .99625 m
.93333 1 L
s
P
p
.001 w
.96667 .99625 m
.96667 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .16597 m
1 .16597 L
s
P
p
.002 w
.99375 .33278 m
1 .33278 L
s
P
p
.002 w
.99375 .49958 m
1 .49958 L
s
P
p
.002 w
.99375 .66639 m
1 .66639 L
s
P
p
.002 w
.99375 .83319 m
1 .83319 L
s
P
p
.001 w
.99625 .03253 m
1 .03253 L
s
P
p
.001 w
.99625 .06589 m
1 .06589 L
s
P
p
.001 w
.99625 .09925 m
1 .09925 L
s
P
p
.001 w
.99625 .13261 m
1 .13261 L
s
P
p
.001 w
.99625 .19933 m
1 .19933 L
s
P
p
.001 w
.99625 .23269 m
1 .23269 L
s
P
p
.001 w
.99625 .26606 m
1 .26606 L
s
P
p
.001 w
.99625 .29942 m
1 .29942 L
s
P
p
.001 w
.99625 .36614 m
1 .36614 L
s
P
p
.001 w
.99625 .3995 m
1 .3995 L
s
P
p
.001 w
.99625 .43286 m
1 .43286 L
s
P
p
.001 w
.99625 .46622 m
1 .46622 L
s
P
p
.001 w
.99625 .53294 m
1 .53294 L
s
P
p
.001 w
.99625 .56631 m
1 .56631 L
s
P
p
.001 w
.99625 .59967 m
1 .59967 L
s
P
p
.001 w
.99625 .63303 m
1 .63303 L
s
P
p
.001 w
.99625 .69975 m
1 .69975 L
s
P
p
.001 w
.99625 .73311 m
1 .73311 L
s
P
p
.001 w
.99625 .76647 m
1 .76647 L
s
P
p
.001 w
.99625 .79983 m
1 .79983 L
s
P
p
.001 w
.99625 .86656 m
1 .86656 L
s
P
p
.001 w
.99625 .89992 m
1 .89992 L
s
P
p
.001 w
.99625 .93328 m
1 .93328 L
s
P
p
.001 w
.99625 .96664 m
1 .96664 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
.04367 1 m
.04792 .97954 L
.05185 .95908 L
.05577 .93863 L
.0597 .91817 L
.06363 .89771 L
.06726 .87725 L
.07085 .85679 L
.07445 .83633 L
.07805 .81588 L
.08166 .79542 L
.08499 .77496 L
.08825 .7545 L
.09152 .73404 L
.09479 .71358 L
.09808 .69313 L
.10111 .67267 L
.104 .65221 L
.104 .65221 L
.10533 .65304 L
.10533 .65304 L
.10222 .67345 L
.09894 .69386 L
.09568 .71427 L
.09242 .73468 L
.08905 .75509 L
.08556 .7755 L
.08205 .79591 L
.07837 .81632 L
.07505 .83673 L
.07138 .85714 L
.06747 .87755 L
.06368 .89795 L
.05998 .91836 L
.05601 .93877 L
.05218 .95918 L
.04808 .97959 L
.044 1 L
F
.46267 1 m
.45576 .97943 L
.44918 .95885 L
.4426 .93828 L
.43602 .91771 L
.42975 .89714 L
.42351 .87656 L
.41725 .85599 L
.4113 .83542 L
.40539 .81485 L
.39945 .79427 L
.39381 .7737 L
.38853 .75313 L
.38298 .73255 L
.37764 .71198 L
.37267 .69141 L
.37267 .69141 L
.3875 .71289 L
.40252 .73436 L
.41728 .75584 L
.43167 .77731 L
.43167 .77731 L
.43782 .78837 L
.4441 .79942 L
.45024 .81047 L
.456 .82152 L
.456 .82152 L
.46 .84135 L
.46424 .86118 L
.46869 .88101 L
.4732 .90084 L
.47797 .92067 L
.48276 .94051 L
.48788 .96034 L
.49328 .98017 L
.49867 1 L
F
.456 .82152 m
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
.54767 .9241 L
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
.57933 .92327 L
.56676 .90309 L
.55358 .8829 L
.54055 .86272 L
.52745 .84254 L
.51433 .82235 L
.51433 .82235 L
.49834 .80284 L
.48271 .78332 L
.46668 .7638 L
.45037 .74429 L
.43376 .72477 L
.41686 .70525 L
.39967 .68574 L
.38218 .66622 L
.3644 .64671 L
.34667 .62719 L
.34667 .62719 L
.35594 .64606 L
.36619 .66493 L
.3767 .6838 L
.38777 .70267 L
.39891 .72154 L
.41044 .74041 L
.42224 .75928 L
.434 .77815 L
.434 .77815 L
.43951 .78899 L
.445 .79983 L
.45049 .81068 L
.456 .82152 L
F
.43433 .23019 m
.45189 .25 L
.46971 .26981 L
.48754 .28962 L
.50515 .30942 L
.52257 .32923 L
.53964 .34904 L
.55665 .36885 L
.57333 .38866 L
.57333 .38866 L
.55783 .36885 L
.54201 .34904 L
.52651 .32923 L
.5108 .30942 L
.49519 .28962 L
.47932 .26981 L
.46382 .25 L
.44833 .23019 L
.44833 .23019 L
.43433 .23019 L
F
.54467 .22769 m
.5254 .22889 L
.50613 .2293 L
.48687 .22976 L
.4676 .23018 L
.44833 .23019 L
.44833 .23019 L
.433 .21101 L
.433 .21101 L
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
F
0 .66055 m
.0208 .65842 L
.0416 .65654 L
.0624 .65501 L
.0832 .65356 L
.104 .65221 L
.104 .65221 L
.10593 .63943 L
.10754 .62665 L
.10892 .61387 L
.1102 .60108 L
.1102 .60108 L
.11226 .58071 L
.11471 .56034 L
.11696 .53997 L
.12167 .5196 L
.12167 .5196 L
.10139 .5149 L
.08111 .50992 L
.06083 .5048 L
.04056 .49972 L
.02028 .49465 L
0 .48957 L
F
.10533 .65304 m
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
.1995 .64971 L
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
.37267 .69141 L
.35988 .67199 L
.34723 .65257 L
.33441 .63315 L
.32199 .61373 L
.30956 .5943 L
.29729 .57488 L
.28533 .55546 L
.28533 .55546 L
.26517 .55098 L
.245 .54694 L
.22483 .54275 L
.20467 .53818 L
.1845 .53364 L
.16433 .52907 L
.14417 .52439 L
.124 .5196 L
.124 .5196 L
.12002 .54003 L
.11654 .56047 L
.11391 .5809 L
.11133 .60133 L
.11133 .60133 L
.1099 .61426 L
.10837 .62719 L
.10682 .64012 L
.10533 .65304 L
F
.89833 0 m
.878 .00137 L
.85767 .0023 L
.83733 .00323 L
.817 .00465 L
.79667 .0067 L
.77633 .00822 L
.756 .01072 L
.73567 .0127 L
.71533 .0155 L
.695 .01824 L
.67467 .02091 L
.65433 .02428 L
.634 .0278 L
.61367 .03148 L
.59333 .03525 L
.573 .03943 L
.55267 .04306 L
.53233 .04785 L
.512 .05309 L
.49167 .05837 L
.47133 .06422 L
.47133 .06422 L
.4514 .06976 L
.43147 .07548 L
.41153 .08174 L
.3916 .08858 L
.37167 .09591 L
.37167 .09591 L
.36075 .0942 L
.34983 .09231 L
.33892 .09057 L
.328 .08924 L
.328 .08924 L
.34836 .08151 L
.36872 .0744 L
.38908 .06861 L
.40944 .06299 L
.42981 .05824 L
.45017 .05333 L
.47053 .04839 L
.49089 .04436 L
.51125 .04023 L
.53161 .03697 L
.55197 .03304 L
.57233 .03001 L
.59269 .02695 L
.61306 .02389 L
.63342 .02084 L
.65378 .01796 L
.67414 .01556 L
.6945 .01302 L
.71486 .01102 L
.73522 .00899 L
.75558 .00695 L
.77594 .00496 L
.79631 .00221 L
.81667 0 L
F
.38867 .18515 m
.433 .21101 L
.433 .21101 L
.42348 .19183 L
.41347 .17264 L
.40352 .15346 L
.39325 .13428 L
.38254 .1151 L
.37167 .09591 L
.37167 .09591 L
.36358 .09608 L
.3555 .096 L
.34742 .09567 L
.33933 .09508 L
.33933 .09508 L
.34972 .11309 L
.35984 .13111 L
.36958 .14912 L
.37897 .16714 L
.38867 .18515 L
F
.29333 .35196 m
.309 .36644 L
.32467 .38071 L
.34033 .39475 L
.356 .40867 L
.356 .40867 L
.36454 .38884 L
.37337 .36901 L
.38197 .34918 L
.39087 .32935 L
.39975 .30952 L
.40861 .28969 L
.41716 .26985 L
.42572 .25002 L
.43433 .23019 L
.43433 .23019 L
.42292 .21863 L
.4115 .20719 L
.40008 .19623 L
.38867 .18515 L
.38867 .18515 L
.37539 .20601 L
.36236 .22686 L
.34967 .24771 L
.3373 .26856 L
.32558 .28941 L
.31422 .31026 L
.3035 .33111 L
.29333 .35196 L
F
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
.30633 .09008 L
.328 .08924 L
.328 .08924 L
.3075 .08143 L
.287 .07463 L
.2665 .06832 L
.246 .06258 L
.2255 .05735 L
.205 .05253 L
.1845 .04813 L
.164 .04412 L
.1435 .04045 L
.123 .03706 L
.1025 .03396 L
.082 .03111 L
.0615 .02851 L
.041 .02612 L
.0205 .02391 L
0 .02186 L
F
.123 .26105 m
.14267 .23594 L
.16233 .21352 L
.182 .19381 L
.20167 .17602 L
.22133 .16027 L
.241 .14606 L
.26067 .13341 L
.28033 .12228 L
.3 .1123 L
.31967 .10323 L
.33933 .09508 L
.33933 .09508 L
.33108 .09365 L
.32283 .09233 L
.31458 .09114 L
.30633 .09008 L
.30633 .09008 L
.2865 .09901 L
.26667 .10896 L
.24683 .12007 L
.227 .13261 L
.20717 .14706 L
.18733 .16359 L
.1675 .18215 L
.14767 .20345 L
.12783 .22759 L
.108 .25605 L
.108 .25605 L
.123 .26105 L
F
.40333 .45288 m
.42317 .46544 L
.443 .4783 L
.46283 .49131 L
.48267 .50444 L
.5025 .51765 L
.52233 .53094 L
.54217 .54434 L
.562 .55783 L
.58183 .5713 L
.60167 .58465 L
.60167 .58465 L
.58213 .57065 L
.5626 .55653 L
.54307 .54231 L
.52353 .52788 L
.504 .51376 L
.504 .51376 L
.48286 .49852 L
.46171 .48341 L
.44057 .4683 L
.41943 .45317 L
.39829 .43822 L
.37714 .42327 L
.356 .40867 L
.356 .40867 L
.40333 .45288 L
F
.28733 .54462 m
.30261 .56526 L
.31739 .5859 L
.33191 .60655 L
.34667 .62719 L
.34667 .62719 L
.35388 .60782 L
.36074 .58845 L
.36778 .56909 L
.37476 .54972 L
.38122 .53035 L
.38725 .51098 L
.39301 .49161 L
.39842 .47225 L
.40333 .45288 L
.40333 .45288 L
.38308 .43696 L
.36283 .42045 L
.34258 .40366 L
.32233 .38616 L
.32233 .38616 L
.31961 .40596 L
.31639 .42577 L
.31262 .44558 L
.30839 .46539 L
.30364 .4852 L
.2982 .505 L
.29284 .52481 L
.28733 .54462 L
F
0 .20367 m
.0216 .21406 L
.0432 .22445 L
.0648 .2348 L
.0864 .24513 L
.108 .25605 L
.108 .25605 L
.093 .26772 L
.093 .26772 L
.07092 .2568 L
.04883 .24583 L
.02675 .235 L
.00467 .22435 L
F
.103 .27106 m
.12294 .28136 L
.14288 .29177 L
.16282 .30231 L
.18276 .31281 L
.2027 .32331 L
.22264 .33381 L
.24258 .34431 L
.26252 .35489 L
.28245 .3655 L
.30239 .37577 L
.32233 .38616 L
.32233 .38616 L
.29333 .35196 L
.29333 .35196 L
.27441 .34178 L
.25548 .33161 L
.23656 .32157 L
.21763 .31155 L
.1987 .30152 L
.17978 .29149 L
.16085 .28154 L
.14193 .27145 L
.123 .26105 L
.123 .26105 L
.103 .27106 L
F
.093 .26772 m
.103 .27106 L
.103 .27106 L
.093 .29608 L
.093 .29608 L
.08367 .29108 L
.08367 .29108 L
.093 .26772 L
F
.07967 .28857 m
.09549 .3091 L
.11182 .32963 L
.12796 .35016 L
.14405 .37069 L
.15984 .39122 L
.17587 .41175 L
.1917 .43228 L
.20744 .45281 L
.2232 .47334 L
.23897 .49387 L
.25446 .5144 L
.27018 .53493 L
.28533 .55546 L
.28533 .55546 L
.28733 .54462 L
.28733 .54462 L
.27164 .52391 L
.25578 .5032 L
.23989 .48249 L
.22371 .46177 L
.20777 .44106 L
.19161 .42035 L
.17538 .39964 L
.15917 .37893 L
.14268 .35822 L
.12611 .3375 L
.10956 .31679 L
.093 .29608 L
.093 .29608 L
.07967 .28857 L
F
.7 g
.04367 1 m
.04792 .97954 L
.05185 .95908 L
.05577 .93863 L
.0597 .91817 L
.06363 .89771 L
.06726 .87725 L
.07085 .85679 L
.07445 .83633 L
.07805 .81588 L
.08166 .79542 L
.08499 .77496 L
.08825 .7545 L
.09152 .73404 L
.09479 .71358 L
.09808 .69313 L
.10111 .67267 L
.104 .65221 L
.104 .65221 L
.0832 .65356 L
.0624 .65501 L
.0416 .65654 L
.0208 .65842 L
0 .66055 L
0 1 L
F
.044 1 m
.04808 .97959 L
.05218 .95918 L
.05601 .93877 L
.05998 .91836 L
.06368 .89795 L
.06747 .87755 L
.07138 .85714 L
.07505 .83673 L
.07837 .81632 L
.08205 .79591 L
.08556 .7755 L
.08905 .75509 L
.09242 .73468 L
.09568 .71427 L
.09894 .69386 L
.10222 .67345 L
.10533 .65304 L
.10533 .65304 L
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
.1995 .64971 L
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
.37267 .69141 L
.37764 .71198 L
.38298 .73255 L
.38853 .75313 L
.39381 .7737 L
.39945 .79427 L
.40539 .81485 L
.4113 .83542 L
.41725 .85599 L
.42351 .87656 L
.42975 .89714 L
.43602 .91771 L
.4426 .93828 L
.44918 .95885 L
.45576 .97943 L
.46267 1 L
F
.49867 1 m
.49328 .98017 L
.48788 .96034 L
.48276 .94051 L
.47797 .92067 L
.4732 .90084 L
.46869 .88101 L
.46424 .86118 L
.46 .84135 L
.456 .82152 L
.456 .82152 L
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
.54767 .9241 L
.55142 .94308 L
.5551 .96205 L
.55906 .98103 L
.563 1 L
F
.58933 1 m
.58548 .99294 L
.56657 .95813 L
.54767 .9241 L
.54767 .9241 L
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
.57933 .92327 L
.59819 .95742 L
.61705 .99147 L
.62167 1 L
F
.34667 .62719 m
.3644 .64671 L
.38218 .66622 L
.39967 .68574 L
.41686 .70525 L
.43376 .72477 L
.45037 .74429 L
.46668 .7638 L
.48271 .78332 L
.49834 .80284 L
.51433 .82235 L
.51433 .82235 L
.52745 .84254 L
.54055 .86272 L
.55358 .8829 L
.56676 .90309 L
.57933 .92327 L
.57933 .92327 L
.57933 .90701 L
.57933 .89074 L
.5794 .87448 L
.579 .85822 L
.579 .85822 L
.5816 .83868 L
.58414 .81913 L
.58663 .79959 L
.58917 .78005 L
.59133 .76051 L
.59334 .74097 L
.59533 .72143 L
.59675 .70189 L
.59799 .68235 L
.59919 .66281 L
.60012 .64327 L
.60102 .62373 L
.60133 .60419 L
.60167 .58465 L
.60167 .58465 L
.58183 .5713 L
.562 .55783 L
.54217 .54434 L
.52233 .53094 L
.5025 .51765 L
.48267 .50444 L
.46283 .49131 L
.443 .4783 L
.42317 .46544 L
.40333 .45288 L
.40333 .45288 L
.39842 .47225 L
.39301 .49161 L
.38725 .51098 L
.38122 .53035 L
.37476 .54972 L
.36778 .56909 L
.36074 .58845 L
.35388 .60782 L
.34667 .62719 L
F
.60167 .58465 m
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
.86133 .5613 L
.86089 .55317 L
.86033 .54504 L
.85953 .53691 L
.85833 .52877 L
.85833 .52877 L
.83865 .52742 L
.81896 .52634 L
.79928 .5254 L
.77959 .52442 L
.75991 .5234 L
.74022 .52241 L
.72054 .52177 L
.70085 .52129 L
.68117 .52032 L
.66148 .51946 L
.6418 .51899 L
.62211 .51821 L
.60243 .51721 L
.58274 .51667 L
.56306 .51609 L
.54337 .51509 L
.52369 .5143 L
.504 .51376 L
.504 .51376 L
.52353 .52788 L
.54307 .54231 L
.5626 .55653 L
.58213 .57065 L
.60167 .58465 L
F
.44833 .23019 m
.46382 .25 L
.47932 .26981 L
.49519 .28962 L
.5108 .30942 L
.52651 .32923 L
.54201 .34904 L
.55783 .36885 L
.57333 .38866 L
.57333 .38866 L
.59261 .39053 L
.61188 .3921 L
.63115 .39351 L
.65042 .39489 L
.6697 .39644 L
.68897 .39835 L
.70824 .40029 L
.72752 .40222 L
.74679 .40445 L
.76606 .40693 L
.78533 .40951 L
.78533 .40951 L
.77285 .39009 L
.75976 .37067 L
.74657 .35125 L
.73264 .33182 L
.71822 .3124 L
.70336 .29298 L
.688 .27356 L
.688 .27356 L
.66752 .26715 L
.64705 .26101 L
.62657 .25472 L
.6061 .24805 L
.58562 .2414 L
.56514 .23466 L
.54467 .22769 L
.54467 .22769 L
.5254 .22889 L
.50613 .2293 L
.48687 .22976 L
.4676 .23018 L
.44833 .23019 L
F
.356 .40867 m
.37714 .42327 L
.39829 .43822 L
.41943 .45317 L
.44057 .4683 L
.46171 .48341 L
.48286 .49852 L
.504 .51376 L
.504 .51376 L
.51711 .49291 L
.52967 .47206 L
.54181 .45121 L
.55328 .43036 L
.56387 .40951 L
.57333 .38866 L
.57333 .38866 L
.55665 .36885 L
.53964 .34904 L
.52257 .32923 L
.50515 .30942 L
.48754 .28962 L
.46971 .26981 L
.45189 .25 L
.43433 .23019 L
.43433 .23019 L
.42572 .25002 L
.41716 .26985 L
.40861 .28969 L
.39975 .30952 L
.39087 .32935 L
.38197 .34918 L
.37337 .36901 L
.36454 .38884 L
.356 .40867 L
F
.81667 0 m
.79631 .00221 L
.77594 .00496 L
.75558 .00695 L
.73522 .00899 L
.71486 .01102 L
.6945 .01302 L
.67414 .01556 L
.65378 .01796 L
.63342 .02084 L
.61306 .02389 L
.59269 .02695 L
.57233 .03001 L
.55197 .03304 L
.53161 .03697 L
.51125 .04023 L
.49089 .04436 L
.47053 .04839 L
.45017 .05333 L
.42981 .05824 L
.40944 .06299 L
.38908 .06861 L
.36872 .0744 L
.34836 .08151 L
.328 .08924 L
.328 .08924 L
.3075 .08143 L
.287 .07463 L
.2665 .06832 L
.246 .06258 L
.2255 .05735 L
.205 .05253 L
.1845 .04813 L
.164 .04412 L
.1435 .04045 L
.123 .03706 L
.1025 .03396 L
.082 .03111 L
.0615 .02851 L
.041 .02612 L
.0205 .02391 L
0 .02186 L
0 0 L
F
.433 .21101 m
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
.54467 .22769 L
.5365 .20726 L
.52835 .18682 L
.51985 .16639 L
.51082 .14595 L
.50143 .12552 L
.49184 .10509 L
.48172 .08465 L
.47133 .06422 L
.47133 .06422 L
.4514 .06976 L
.43147 .07548 L
.41153 .08174 L
.3916 .08858 L
.37167 .09591 L
.37167 .09591 L
.38254 .1151 L
.39325 .13428 L
.40352 .15346 L
.41347 .17264 L
.42348 .19183 L
.433 .21101 L
F
.29333 .35196 m
.3035 .33111 L
.31422 .31026 L
.32558 .28941 L
.3373 .26856 L
.34967 .24771 L
.36236 .22686 L
.37539 .20601 L
.38867 .18515 L
.38867 .18515 L
.37897 .16714 L
.36958 .14912 L
.35984 .13111 L
.34972 .11309 L
.33933 .09508 L
.33933 .09508 L
.31967 .10323 L
.3 .1123 L
.28033 .12228 L
.26067 .13341 L
.241 .14606 L
.22133 .16027 L
.20167 .17602 L
.182 .19381 L
.16233 .21352 L
.14267 .23594 L
.123 .26105 L
.123 .26105 L
.14193 .27145 L
.16085 .28154 L
.17978 .29149 L
.1987 .30152 L
.21763 .31155 L
.23656 .32157 L
.25548 .33161 L
.27441 .34178 L
.29333 .35196 L
F
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
.30633 .09008 L
.2865 .09901 L
.26667 .10896 L
.24683 .12007 L
.227 .13261 L
.20717 .14706 L
.18733 .16359 L
.1675 .18215 L
.14767 .20345 L
.12783 .22759 L
.108 .25605 L
.108 .25605 L
.0864 .24513 L
.0648 .2348 L
.0432 .22445 L
.0216 .21406 L
0 .20367 L
F
.093 .29608 m
.10956 .31679 L
.12611 .3375 L
.14268 .35822 L
.15917 .37893 L
.17538 .39964 L
.19161 .42035 L
.20777 .44106 L
.22371 .46177 L
.23989 .48249 L
.25578 .5032 L
.27164 .52391 L
.28733 .54462 L
.28733 .54462 L
.29284 .52481 L
.2982 .505 L
.30364 .4852 L
.30839 .46539 L
.31262 .44558 L
.31639 .42577 L
.31961 .40596 L
.32233 .38616 L
.32233 .38616 L
.30239 .37577 L
.28245 .3655 L
.26252 .35489 L
.24258 .34431 L
.22264 .33381 L
.2027 .32331 L
.18276 .31281 L
.16282 .30231 L
.14288 .29177 L
.12294 .28136 L
.103 .27106 L
.103 .27106 L
.093 .29608 L
F
.093 .26772 m
.07092 .2568 L
.04883 .24583 L
.02675 .235 L
.00467 .22435 L
.00467 .22435 L
.02442 .24048 L
.04417 .25711 L
.06392 .27402 L
.08367 .29108 L
.08367 .29108 L
.093 .26772 L
F
0 .48957 m
.02028 .49465 L
.04056 .49972 L
.06083 .5048 L
.08111 .50992 L
.10139 .5149 L
.12167 .5196 L
.12167 .5196 L
.11877 .50028 L
.11599 .48096 L
.11294 .46163 L
.10986 .44231 L
.10657 .42299 L
.10297 .40367 L
.09907 .38435 L
.09506 .36503 L
.09091 .3457 L
.08658 .32638 L
.08224 .30706 L
.07767 .28774 L
.07767 .28774 L
.05908 .27199 L
.0405 .25611 L
.02192 .24032 L
.00333 .22519 L
.00333 .22519 L
0 .22455 L
F
.28533 .55546 m
.27018 .53493 L
.25446 .5144 L
.23897 .49387 L
.2232 .47334 L
.20744 .45281 L
.1917 .43228 L
.17587 .41175 L
.15984 .39122 L
.14405 .37069 L
.12796 .35016 L
.11182 .32963 L
.09549 .3091 L
.07967 .28857 L
.07967 .28857 L
.08398 .30783 L
.08865 .32708 L
.09299 .34633 L
.09721 .36558 L
.10142 .38483 L
.10518 .40409 L
.10862 .42334 L
.11208 .44259 L
.11558 .46184 L
.11842 .4811 L
.12144 .50035 L
.124 .5196 L
.124 .5196 L
.14417 .52439 L
.16433 .52907 L
.1845 .53364 L
.20467 .53818 L
.22483 .54275 L
.245 .54694 L
.26517 .55098 L
.28533 .55546 L
F
.55 g
.563 1 m
.55906 .98103 L
.5551 .96205 L
.55142 .94308 L
.54767 .9241 L
.54767 .9241 L
.56657 .95813 L
.58548 .99294 L
.58933 1 L
F
.62167 1 m
.61705 .99147 L
.59819 .95742 L
.57933 .92327 L
.57933 .92327 L
.57933 .90701 L
.57933 .89074 L
.5794 .87448 L
.579 .85822 L
.579 .85822 L
.5816 .83868 L
.58414 .81913 L
.58663 .79959 L
.58917 .78005 L
.59133 .76051 L
.59334 .74097 L
.59533 .72143 L
.59675 .70189 L
.59799 .68235 L
.59919 .66281 L
.60012 .64327 L
.60102 .62373 L
.60133 .60419 L
.60167 .58465 L
.60167 .58465 L
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
.86133 .5613 L
.87514 .58124 L
.88884 .60118 L
.90256 .62112 L
.91602 .64106 L
.92915 .66101 L
.94221 .68095 L
.9553 .70089 L
.96816 .72083 L
.9809 .74077 L
.99367 .76071 L
1 .77064 L
1 1 L
F
1 .57214 m
.98019 .57041 L
.96038 .56865 L
.94057 .56692 L
.92076 .56537 L
.90095 .56396 L
.88114 .56262 L
.86133 .5613 L
.86133 .5613 L
.86089 .55317 L
.86033 .54504 L
.85953 .53691 L
.85833 .52877 L
.85833 .52877 L
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
F
1 .38198 m
.9805 .37462 L
.961 .36732 L
.9415 .35998 L
.922 .35294 L
.9025 .34615 L
.883 .33933 L
.8635 .3325 L
.844 .32567 L
.8245 .31881 L
.805 .31198 L
.7855 .30549 L
.766 .2992 L
.7465 .29287 L
.727 .2865 L
.7075 .28008 L
.688 .27356 L
.688 .27356 L
.70336 .29298 L
.71822 .3124 L
.73264 .33182 L
.74657 .35125 L
.75976 .37067 L
.77285 .39009 L
.78533 .40951 L
.78533 .40951 L
.80485 .41284 L
.82436 .41623 L
.84388 .41991 L
.86339 .42385 L
.88291 .42772 L
.90242 .43172 L
.92194 .43609 L
.94145 .4405 L
.96097 .44489 L
.98048 .44961 L
1 .45455 L
F
.78533 .40951 m
.76606 .40693 L
.74679 .40445 L
.72752 .40222 L
.70824 .40029 L
.68897 .39835 L
.6697 .39644 L
.65042 .39489 L
.63115 .39351 L
.61188 .3921 L
.59261 .39053 L
.57333 .38866 L
.57333 .38866 L
.56387 .40951 L
.55328 .43036 L
.54181 .45121 L
.52967 .47206 L
.51711 .49291 L
.504 .51376 L
.504 .51376 L
.52369 .5143 L
.54337 .51509 L
.56306 .51609 L
.58274 .51667 L
.60243 .51721 L
.62211 .51821 L
.6418 .51899 L
.66148 .51946 L
.68117 .52032 L
.70085 .52129 L
.72054 .52177 L
.74022 .52241 L
.75991 .5234 L
.77959 .52442 L
.79928 .5254 L
.81896 .52634 L
.83865 .52742 L
.85833 .52877 L
.85833 .52877 L
.84746 .5089 L
.8359 .48902 L
.82412 .46914 L
.81149 .44926 L
.7987 .42939 L
.78533 .40951 L
F
.54467 .22769 m
.56514 .23466 L
.58562 .2414 L
.6061 .24805 L
.62657 .25472 L
.64705 .26101 L
.66752 .26715 L
.688 .27356 L
.688 .27356 L
.67155 .25423 L
.6549 .23489 L
.63793 .21556 L
.62056 .19622 L
.60296 .17689 L
.58476 .15756 L
.56664 .13822 L
.54791 .11889 L
.52897 .09955 L
.50955 .08022 L
.48933 .06088 L
.48933 .06088 L
.47133 .06422 L
.47133 .06422 L
.48172 .08465 L
.49184 .10509 L
.50143 .12552 L
.51082 .14595 L
.51985 .16639 L
.52835 .18682 L
.5365 .20726 L
.54467 .22769 L
F
.919 0 m
.89854 .00076 L
.87808 .00174 L
.85762 .00293 L
.83716 .00433 L
.8167 .00594 L
.79624 .00775 L
.77578 .00976 L
.75532 .01198 L
.73486 .01438 L
.7144 .01698 L
.69394 .01976 L
.67348 .02277 L
.65302 .02596 L
.63256 .02932 L
.6121 .03297 L
.59163 .03682 L
.57117 .0409 L
.55071 .04534 L
.53025 .04998 L
.50979 .05505 L
.48933 .06088 L
.48933 .06088 L
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
.868 .04587 L
.88686 .03826 L
.90571 .03134 L
.92457 .02514 L
.94343 .01977 L
.96229 .01516 L
.98114 .01098 L
1 .00751 L
1 0 L
F
.4 g
1 .77064 m
.99367 .76071 L
.9809 .74077 L
.96816 .72083 L
.9553 .70089 L
.94221 .68095 L
.92915 .66101 L
.91602 .64106 L
.90256 .62112 L
.88884 .60118 L
.87514 .58124 L
.86133 .5613 L
.86133 .5613 L
.88114 .56262 L
.90095 .56396 L
.92076 .56537 L
.94057 .56692 L
.96038 .56865 L
.98019 .57041 L
1 .57214 L
F
1 .45455 m
.98048 .44961 L
.96097 .44489 L
.94145 .4405 L
.92194 .43609 L
.90242 .43172 L
.88291 .42772 L
.86339 .42385 L
.84388 .41991 L
.82436 .41623 L
.80485 .41284 L
.78533 .40951 L
.78533 .40951 L
.7987 .42939 L
.81149 .44926 L
.82412 .46914 L
.8359 .48902 L
.84746 .5089 L
.85833 .52877 L
.85833 .52877 L
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
F
1 .38198 m
.9805 .37462 L
.961 .36732 L
.9415 .35998 L
.922 .35294 L
.9025 .34615 L
.883 .33933 L
.8635 .3325 L
.844 .32567 L
.8245 .31881 L
.805 .31198 L
.7855 .30549 L
.766 .2992 L
.7465 .29287 L
.727 .2865 L
.7075 .28008 L
.688 .27356 L
.688 .27356 L
.67155 .25423 L
.6549 .23489 L
.63793 .21556 L
.62056 .19622 L
.60296 .17689 L
.58476 .15756 L
.56664 .13822 L
.54791 .11889 L
.52897 .09955 L
.50955 .08022 L
.48933 .06088 L
.48933 .06088 L
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
.868 .04587 L
.88494 .06556 L
.90212 .08526 L
.91961 .10495 L
.9375 .12464 L
.95586 .14433 L
.97477 .16403 L
.99431 .18372 L
1 .18932 L
F
1 .00751 m
.98114 .01098 L
.96229 .01516 L
.94343 .01977 L
.92457 .02514 L
.90571 .03134 L
.88686 .03826 L
.868 .04587 L
.868 .04587 L
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
F
.25 g
p
P
1 .18932 m
.99431 .18372 L
.97477 .16403 L
.95586 .14433 L
.9375 .12464 L
.91961 .10495 L
.90212 .08526 L
.88494 .06556 L
.868 .04587 L
.868 .04587 L
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
F
0 g
.3 Mabswid
s
0 .54133 m
.0199 .55208 L
.05601 .5716 L
.09203 .59113 L
.12796 .61066 L
.16379 .63018 L
.1995 .64971 L
s
.43167 .77731 m
.45196 .78862 L
.47226 .79984 L
.49256 .81098 L
.51286 .82206 L
.53315 .8331 L
.55345 .84429 L
.57375 .85549 L
.59405 .8667 L
.61435 .87793 L
.63464 .88917 L
.65494 .90043 L
.67524 .9117 L
.69554 .92298 L
.71583 .93428 L
.73613 .94559 L
.75643 .95692 L
.77673 .96827 L
.79702 .97963 L
.81732 .99101 L
.83333 1 L
s
.104 .65221 m
.10111 .67267 L
.09808 .69313 L
.09479 .71358 L
.09152 .73404 L
.08825 .7545 L
.08499 .77496 L
.08166 .79542 L
.07805 .81588 L
.07445 .83633 L
.07085 .85679 L
.06726 .87725 L
.06363 .89771 L
.0597 .91817 L
.05577 .93863 L
.05185 .95908 L
.04792 .97954 L
s
.04367 1 m
.04792 .97954 L
s
s
.07767 .28774 m
.08224 .30706 L
.08658 .32638 L
.09091 .3457 L
.09506 .36503 L
.09907 .38435 L
.10297 .40367 L
.10657 .42299 L
.10986 .44231 L
.11294 .46163 L
.11599 .48096 L
.11877 .50028 L
.12167 .5196 L
s
0 .66055 m
.0208 .65842 L
.0416 .65654 L
.0624 .65501 L
.0832 .65356 L
.104 .65221 L
s
0 .48957 m
.02028 .49465 L
.04056 .49972 L
.06083 .5048 L
.08111 .50992 L
.10139 .5149 L
.12167 .5196 L
s
.1102 .60108 m
.10892 .61387 L
.10754 .62665 L
.10593 .63943 L
.104 .65221 L
s
.12167 .5196 m
.11696 .53997 L
.11471 .56034 L
.11226 .58071 L
.1102 .60108 L
s
.10533 .65304 m
.10222 .67345 L
.09894 .69386 L
.09568 .71427 L
.09242 .73468 L
.08905 .75509 L
.08556 .7755 L
.08205 .79591 L
.07837 .81632 L
.07505 .83673 L
.07138 .85714 L
.06747 .87755 L
.06368 .89795 L
.05998 .91836 L
.05601 .93877 L
.05218 .95918 L
.04808 .97959 L
.044 1 L
s
.11133 .60133 m
.1099 .61426 L
.10837 .62719 L
.10682 .64012 L
.10533 .65304 L
s
.124 .5196 m
.12002 .54003 L
.11654 .56047 L
.11391 .5809 L
.11133 .60133 L
s
.07967 .28857 m
.08398 .30783 L
.08865 .32708 L
.09299 .34633 L
.09721 .36558 L
.10142 .38483 L
.10518 .40409 L
.10862 .42334 L
.11208 .44259 L
.11558 .46184 L
.11842 .4811 L
.12144 .50035 L
.124 .5196 L
s
.104 .65221 m
.10533 .65304 L
s
.12167 .5196 m
.124 .5196 L
s
.37267 .69141 m
.37764 .71198 L
.38298 .73255 L
.38853 .75313 L
.39381 .7737 L
.39945 .79427 L
.40539 .81485 L
.4113 .83542 L
.41725 .85599 L
.42351 .87656 L
.42975 .89714 L
.43602 .91771 L
.4426 .93828 L
.44918 .95885 L
.45576 .97943 L
.46267 1 L
s
.10533 .65304 m
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
s
.1995 .64971 m
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
s
.28533 .55546 m
.29729 .57488 L
.30956 .5943 L
.32199 .61373 L
.33441 .63315 L
.34723 .65257 L
.35988 .67199 L
.37267 .69141 L
s
.124 .5196 m
.14417 .52439 L
.16433 .52907 L
.1845 .53364 L
.20467 .53818 L
.22483 .54275 L
.245 .54694 L
.26517 .55098 L
.28533 .55546 L
s
.456 .82152 m
.46 .84135 L
.46424 .86118 L
.46869 .88101 L
.4732 .90084 L
.47797 .92067 L
.48276 .94051 L
.48788 .96034 L
.49328 .98017 L
.49867 1 L
s
.456 .82152 m
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
s
.37267 .69141 m
.3875 .71289 L
.40252 .73436 L
.41728 .75584 L
.43167 .77731 L
s
.43167 .77731 m
.43782 .78837 L
.4441 .79942 L
.45024 .81047 L
.456 .82152 L
s
.34667 .62719 m
.35594 .64606 L
.36619 .66493 L
.3767 .6838 L
.38777 .70267 L
.39891 .72154 L
.41044 .74041 L
.42224 .75928 L
.434 .77815 L
s
.434 .77815 m
.43951 .78899 L
.445 .79983 L
.45049 .81068 L
.456 .82152 L
s
.51433 .82235 m
.52745 .84254 L
.54055 .86272 L
.55358 .8829 L
.56676 .90309 L
.57933 .92327 L
s
.34667 .62719 m
.3644 .64671 L
.38218 .66622 L
.39967 .68574 L
.41686 .70525 L
.43376 .72477 L
.45037 .74429 L
.46668 .7638 L
.48271 .78332 L
.49834 .80284 L
.51433 .82235 L
s
.54767 .9241 m
.55142 .94308 L
.5551 .96205 L
.55906 .98103 L
.563 1 L
s
.54767 .9241 m
.56657 .95813 L
.58548 .99294 L
.58933 1 L
s
.57933 .92327 m
.59819 .95742 L
.61705 .99147 L
.62167 1 L
s
.54767 .9241 m
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
s
.28733 .54462 m
.30261 .56526 L
.31739 .5859 L
.33191 .60655 L
.34667 .62719 L
s
.40333 .45288 m
.39842 .47225 L
.39301 .49161 L
.38725 .51098 L
.38122 .53035 L
.37476 .54972 L
.36778 .56909 L
.36074 .58845 L
.35388 .60782 L
.34667 .62719 L
s
.40333 .45288 m
.42317 .46544 L
.443 .4783 L
.46283 .49131 L
.48267 .50444 L
.5025 .51765 L
.52233 .53094 L
.54217 .54434 L
.562 .55783 L
.58183 .5713 L
.60167 .58465 L
s
.07967 .28857 m
.09549 .3091 L
.11182 .32963 L
.12796 .35016 L
.14405 .37069 L
.15984 .39122 L
.17587 .41175 L
.1917 .43228 L
.20744 .45281 L
.2232 .47334 L
.23897 .49387 L
.25446 .5144 L
.27018 .53493 L
.28533 .55546 L
s
.093 .29608 m
.10956 .31679 L
.12611 .3375 L
.14268 .35822 L
.15917 .37893 L
.17538 .39964 L
.19161 .42035 L
.20777 .44106 L
.22371 .46177 L
.23989 .48249 L
.25578 .5032 L
.27164 .52391 L
.28733 .54462 L
s
.32233 .38616 m
.31961 .40596 L
.31639 .42577 L
.31262 .44558 L
.30839 .46539 L
.30364 .4852 L
.2982 .505 L
.29284 .52481 L
.28733 .54462 L
s
.28533 .55546 m
.28733 .54462 L
s
.32233 .38616 m
.34258 .40366 L
.36283 .42045 L
.38308 .43696 L
.40333 .45288 L
s
.103 .27106 m
.12294 .28136 L
.14288 .29177 L
.16282 .30231 L
.18276 .31281 L
.2027 .32331 L
.22264 .33381 L
.24258 .34431 L
.26252 .35489 L
.28245 .3655 L
.30239 .37577 L
.32233 .38616 L
s
.504 .51376 m
.52353 .52788 L
.54307 .54231 L
.5626 .55653 L
.58213 .57065 L
.60167 .58465 L
s
.356 .40867 m
.37714 .42327 L
.39829 .43822 L
.41943 .45317 L
.44057 .4683 L
.46171 .48341 L
.48286 .49852 L
.504 .51376 L
s
.29333 .35196 m
.309 .36644 L
.32467 .38071 L
.34033 .39475 L
.356 .40867 L
s
.123 .26105 m
.14193 .27145 L
.16085 .28154 L
.17978 .29149 L
.1987 .30152 L
.21763 .31155 L
.23656 .32157 L
.25548 .33161 L
.27441 .34178 L
.29333 .35196 L
s
.40333 .45288 m
.356 .40867 L
s
.32233 .38616 m
.29333 .35196 L
s
.57333 .38866 m
.56387 .40951 L
.55328 .43036 L
.54181 .45121 L
.52967 .47206 L
.51711 .49291 L
.504 .51376 L
s
.504 .51376 m
.52369 .5143 L
.54337 .51509 L
.56306 .51609 L
.58274 .51667 L
.60243 .51721 L
.62211 .51821 L
.6418 .51899 L
.66148 .51946 L
.68117 .52032 L
.70085 .52129 L
.72054 .52177 L
.74022 .52241 L
.75991 .5234 L
.77959 .52442 L
.79928 .5254 L
.81896 .52634 L
.83865 .52742 L
.85833 .52877 L
s
.60167 .58465 m
.60133 .60419 L
.60102 .62373 L
.60012 .64327 L
.59919 .66281 L
.59799 .68235 L
.59675 .70189 L
.59533 .72143 L
.59334 .74097 L
.59133 .76051 L
.58917 .78005 L
.58663 .79959 L
.58414 .81913 L
.5816 .83868 L
.579 .85822 L
s
.579 .85822 m
.5794 .87448 L
.57933 .89074 L
.57933 .90701 L
.57933 .92327 L
s
.60167 .58465 m
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
s
.43433 .23019 m
.42572 .25002 L
.41716 .26985 L
.40861 .28969 L
.39975 .30952 L
.39087 .32935 L
.38197 .34918 L
.37337 .36901 L
.36454 .38884 L
.356 .40867 L
s
.38867 .18515 m
.37539 .20601 L
.36236 .22686 L
.34967 .24771 L
.3373 .26856 L
.32558 .28941 L
.31422 .31026 L
.3035 .33111 L
.29333 .35196 L
s
.43433 .23019 m
.45189 .25 L
.46971 .26981 L
.48754 .28962 L
.50515 .30942 L
.52257 .32923 L
.53964 .34904 L
.55665 .36885 L
.57333 .38866 L
s
.38867 .18515 m
.40008 .19623 L
.4115 .20719 L
.42292 .21863 L
.43433 .23019 L
s
.44833 .23019 m
.46382 .25 L
.47932 .26981 L
.49519 .28962 L
.5108 .30942 L
.52651 .32923 L
.54201 .34904 L
.55783 .36885 L
.57333 .38866 L
s
.433 .21101 m
.44833 .23019 L
s
.57333 .38866 m
.59261 .39053 L
.61188 .3921 L
.63115 .39351 L
.65042 .39489 L
.6697 .39644 L
.68897 .39835 L
.70824 .40029 L
.72752 .40222 L
.74679 .40445 L
.76606 .40693 L
.78533 .40951 L
s
.43433 .23019 m
.44833 .23019 L
s
.38867 .18515 m
.433 .21101 L
s
.688 .27356 m
.70336 .29298 L
.71822 .3124 L
.73264 .33182 L
.74657 .35125 L
.75976 .37067 L
.77285 .39009 L
.78533 .40951 L
s
.54467 .22769 m
.56514 .23466 L
.58562 .2414 L
.6061 .24805 L
.62657 .25472 L
.64705 .26101 L
.66752 .26715 L
.688 .27356 L
s
.44833 .23019 m
.4676 .23018 L
.48687 .22976 L
.50613 .2293 L
.5254 .22889 L
.54467 .22769 L
s
.433 .21101 m
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
s
.37167 .09591 m
.38254 .1151 L
.39325 .13428 L
.40352 .15346 L
.41347 .17264 L
.42348 .19183 L
.433 .21101 L
s
.47133 .06422 m
.48172 .08465 L
.49184 .10509 L
.50143 .12552 L
.51082 .14595 L
.51985 .16639 L
.52835 .18682 L
.5365 .20726 L
.54467 .22769 L
s
.48933 .06088 m
.50955 .08022 L
.52897 .09955 L
.54791 .11889 L
.56664 .13822 L
.58476 .15756 L
.60296 .17689 L
.62056 .19622 L
.63793 .21556 L
.6549 .23489 L
.67155 .25423 L
.688 .27356 L
s
.688 .27356 m
.7075 .28008 L
.727 .2865 L
.7465 .29287 L
.766 .2992 L
.7855 .30549 L
.805 .31198 L
.8245 .31881 L
.844 .32567 L
.8635 .3325 L
.883 .33933 L
.9025 .34615 L
.922 .35294 L
.9415 .35998 L
.961 .36732 L
.9805 .37462 L
s
1 .38198 m
.9805 .37462 L
s
s
.78533 .40951 m
.7987 .42939 L
.81149 .44926 L
.82412 .46914 L
.8359 .48902 L
.84746 .5089 L
.85833 .52877 L
s
.85833 .52877 m
.85953 .53691 L
.86033 .54504 L
.86089 .55317 L
.86133 .5613 L
s
.86133 .5613 m
.87514 .58124 L
.88884 .60118 L
.90256 .62112 L
.91602 .64106 L
.92915 .66101 L
.94221 .68095 L
.9553 .70089 L
.96816 .72083 L
.9809 .74077 L
.99367 .76071 L
1 .77064 L
s
.86133 .5613 m
.88114 .56262 L
.90095 .56396 L
.92076 .56537 L
.94057 .56692 L
.96038 .56865 L
.98019 .57041 L
s
1 .57214 m
.98019 .57041 L
s
s
s
s
.78533 .40951 m
.80485 .41284 L
.82436 .41623 L
.84388 .41991 L
.86339 .42385 L
.88291 .42772 L
.90242 .43172 L
.92194 .43609 L
.94145 .4405 L
.96097 .44489 L
.98048 .44961 L
s
1 .45455 m
.98048 .44961 L
s
s
.85833 .52877 m
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
s
.48933 .06088 m
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
s
.868 .04587 m
.88494 .06556 L
.90212 .08526 L
.91961 .10495 L
.9375 .12464 L
.95586 .14433 L
.97477 .16403 L
.99431 .18372 L
1 .18932 L
s
.868 .04587 m
.88686 .03826 L
.90571 .03134 L
.92457 .02514 L
.94343 .01977 L
.96229 .01516 L
.98114 .01098 L
1 .00751 L
s
.868 .04587 m
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
s
.48933 .06088 m
.50979 .05505 L
.53025 .04998 L
.55071 .04534 L
.57117 .0409 L
.59163 .03682 L
.6121 .03297 L
.63256 .02932 L
.65302 .02596 L
.67348 .02277 L
.69394 .01976 L
.7144 .01698 L
.73486 .01438 L
.75532 .01198 L
.77578 .00976 L
.79624 .00775 L
.8167 .00594 L
.83716 .00433 L
.85762 .00293 L
.87808 .00174 L
.89854 .00076 L
.919 0 L
s
.47133 .06422 m
.48933 .06088 L
s
.47133 .06422 m
.49167 .05837 L
.512 .05309 L
.53233 .04785 L
.55267 .04306 L
.573 .03943 L
.59333 .03525 L
.61367 .03148 L
.634 .0278 L
.65433 .02428 L
.67467 .02091 L
.695 .01824 L
.71533 .0155 L
.73567 .0127 L
.756 .01072 L
.77633 .00822 L
.79667 .0067 L
.817 .00465 L
.83733 .00323 L
.85767 .0023 L
.878 .00137 L
.89833 0 L
s
.37167 .09591 m
.3916 .08858 L
.41153 .08174 L
.43147 .07548 L
.4514 .06976 L
.47133 .06422 L
s
.328 .08924 m
.34836 .08151 L
.36872 .0744 L
.38908 .06861 L
.40944 .06299 L
.42981 .05824 L
.45017 .05333 L
.47053 .04839 L
.49089 .04436 L
.51125 .04023 L
.53161 .03697 L
.55197 .03304 L
.57233 .03001 L
.59269 .02695 L
.61306 .02389 L
.63342 .02084 L
.65378 .01796 L
.67414 .01556 L
.6945 .01302 L
.71486 .01102 L
.73522 .00899 L
.75558 .00695 L
.77594 .00496 L
.79631 .00221 L
.81667 0 L
s
.33933 .09508 m
.34972 .11309 L
.35984 .13111 L
.36958 .14912 L
.37897 .16714 L
.38867 .18515 L
s
.33933 .09508 m
.34742 .09567 L
.3555 .096 L
.36358 .09608 L
.37167 .09591 L
s
.30633 .09008 m
.31458 .09114 L
.32283 .09233 L
.33108 .09365 L
.33933 .09508 L
s
0 .02186 m
.0205 .02391 L
.041 .02612 L
.0615 .02851 L
.082 .03111 L
.1025 .03396 L
.123 .03706 L
.1435 .04045 L
.164 .04412 L
.1845 .04813 L
.205 .05253 L
.2255 .05735 L
.246 .06258 L
.2665 .06832 L
.287 .07463 L
.3075 .08143 L
.328 .08924 L
s
.328 .08924 m
.33892 .09057 L
.34983 .09231 L
.36075 .0942 L
.37167 .09591 L
s
.328 .08924 m
.30633 .09008 L
s
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
s
.123 .26105 m
.14267 .23594 L
.16233 .21352 L
.182 .19381 L
.20167 .17602 L
.22133 .16027 L
.241 .14606 L
.26067 .13341 L
.28033 .12228 L
.3 .1123 L
.31967 .10323 L
.33933 .09508 L
s
.108 .25605 m
.12783 .22759 L
.14767 .20345 L
.1675 .18215 L
.18733 .16359 L
.20717 .14706 L
.227 .13261 L
.24683 .12007 L
.26667 .10896 L
.2865 .09901 L
.30633 .09008 L
s
0 .20367 m
.0216 .21406 L
.0432 .22445 L
.0648 .2348 L
.0864 .24513 L
.108 .25605 L
s
.00467 .22435 m
.02675 .235 L
.04883 .24583 L
.07092 .2568 L
.093 .26772 L
s
.123 .26105 m
.108 .25605 L
s
.123 .26105 m
.103 .27106 L
s
.103 .27106 m
.093 .26772 L
s
.108 .25605 m
.093 .26772 L
s
.103 .27106 m
.093 .29608 L
s
.093 .26772 m
.08367 .29108 L
s
.00467 .22435 m
.02442 .24048 L
.04417 .25711 L
.06392 .27402 L
.08367 .29108 L
s
.00333 .22519 m
.02192 .24032 L
.0405 .25611 L
.05908 .27199 L
.07767 .28774 L
s
.08367 .29108 m
.093 .29608 L
s
.07967 .28857 m
.093 .29608 L
s
.07967 .28857 m
.07767 .28774 L
s
.08367 .29108 m
.07767 .28774 L
s
0 .22455 m
.00333 .22519 L
s
0 .22018 m
.00467 .22435 L
s
.00467 .22435 m
.00333 .22519 L
s
p
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{483, 483},
  ImageMargins->{{33, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007S0001ha000`40O003h00Oogooi7oo003oOooT
Ool00?moonAoo`00ogooi7oo000ZOol30003Ool30004Ool2000nOol00`00Oomoo`03Ool20004Ool2
000oOol00`00Oomoo`02Ool30004Ool2000nOol30004Ool20004Ool2000mOol30003Ool30004Ool2
000nOol20005Ool20004Ool2000[Ool002Uoo`07001oogooOol007oo00000goo00@007ooOol0009o
o`03001oogoo03]oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00?Woo00D007ooOomo
o`0000=oo`04001oogoo0002Ool00`00Oomoo`0jOol01@00Oomoogoo00000Woo00@007ooOol0009o
o`04001oogoo000kOol01`00Oomoogoo001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`0mOol0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo02Qoo`00:Goo00D007ooOomoo`0000Eo
o`04001oogoo0002Ool00`00Oomoo`0lOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo03eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`0jOol01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo000kOol01@00Oomoogoo00001Goo00@007ooOol0009oo`03001o
ogoo03ioo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol0:7oo000YOol40006Ool01000
Oomoo`000Woo00<007ooOol0?7oo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0m
Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0>goo0`000goo00@007ooOol0009oo`04
001oogoo000lOol30006Ool01000Oomoo`000Woo00<007ooOol0>goo10000Woo00@007ooOol0009o
o`04001oogoo000ZOol002Uoo`03001oogoo00=oo`@000=oo`04001oogoo000oOol01000Oomoo`00
0Woo00@007ooOol0009oo`03001oogoo03ioo`03001oo`0000<000=oo`04001oogoo000lOol01@00
Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo000kOol01P00Oomoogoo001oo`@000=oo`04
001oogoo000lOol01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo000ZOol002Yoo`03
001oogoo009oo`03001oogoo00Aoo`04001oogoo000kOol01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo000lOol01`00Oomoogoo001oo`0000Ioo`04001oogoo000lOol01@00Oomoogoo
00000Woo00@007ooOol0009oo`04001oogoo000kOol01`00Oomoogoo001oo`0000Ioo`04001oogoo
000lOol01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo000ZOol002]oo`80009oo`D0
00=oo`8003aoo`D000=oo`8000Aoo`8003eoo`D00003Ool0000000<000=oo`8003ioo`<000Aoo`80
00Aoo`8003eoo`<0009oo`D000=oo`8003ioo`<000Aoo`8000Aoo`8002]oo`00ogooi7oo003oOooT
Ool00?moonAoo`00ogooi7oo003oOooTOol00?moonAoo`004gooo`00cP000goo000COol00`00F]IJ
eP3oF]IXF]H9000:Kg/L000cAS400`00Oomoo`01Ool001=oo`03001JeU[F0?mJeUmJePT000Y_Na80
04I6<@03001oogoo005oo`004goo00<005[FF]H0oe[FEE[F2P002Fmk4`00CDHa0`000goo000COol0
0`00F]IJeP3oF]I<F]H9000:Kg/B001BAS450002<H`00`00Oomoo`01Ool001=oo`03001JeU[F0?mJ
eT=JePT000Y_N`/005i6<@@000LaS003001oogoo005oo`004goo00<005[FF]H0oe[F>E[F2P002Fmk
4000GdHa10002c6<00<007ooOol00Goo000COol00`00F]IJeP3oF]H`F]H9000:Kg/B001RAS44000?
<H`00`00Oomoo`01Ool001=oo`03001JeU[F0?mJeRUJePL000a_Na0006I6<@D001<aS003001oogoo
005oo`004goo00<005[FF]H0oe[F95[F1@003Vmk2`00KDHa0`00636<00<007ooOol00Goo000COol6
003oF]HJF]H7000<Kg/9001cAS43000K<H`00`00Oomoo`01Ool001=ooa000?mJePMJePT000a_N`T0
07M6<@<001haS003001oogoo005oo`004goo00<005[FF]H00e[F4`00mU[F1`0046mk2@00N4Ha1000
8C6<00<007ooOol00Goo000COol00`00F]IJeP0=F]HB003XF]H5000@Kg/9001kAS44000U<H`00`00
Oomoo`01Ool001=oo`03001JeU[F01IJePL0009_N`L00=YJePL000i_N`T007m6<@<002TaS003001o
ogoo005oo`004goo00<005[FF]H07E[F1@0016mk1@00cU[F1`0046mk2@00PTHa0P00;36<00<007oo
Ool00Goo000COol00`00F]IJeP0RF]H70002Kg/70032F]H5000CKg/90023AS43000^<H`00`00Oomo
o`01Ool001=oo`03001JeU[F02UJePL0009_N`L00;MJeP@001=_N`T008I6<@80034aS003001oogoo
005oo`004goo00<005[FF]H0<5[F1@0016mk1@00[E[F1@004fmk2000RDHa0P00<c6<00<007ooOol0
0Goo000COol00`00F]IJeP0eF]H70002Kg/7002OF]H7000CKg/8002;AS43000X<H`>0003Ool001=o
o`03001JeU[F03aJePH000=_N`L0095JePL001E_N`T008a6<@<0014aS1X000dLi`03001oogoo005o
o`004goo00<005[FF]H0@U[F1@001Fmk1@00Qe[F1@005fmk2@00RdHa6P009acW00<007ooOol00Goo
000COol00`00F]IJeP17F]H50005Kg/4001oF]H4000HKg/8001eAS4K0004<H`00`007>LLi`0j7>L0
0`00Oomoo`01Ool001=oo`03001JeU[F04aJePD000A_N`D007MJeP<001M_N`P006M6<A<0020aS003
000LiacW03TLi`03001oogoo005oo`004goo00<005[FF]H0DE[F10001Fmk1@00Ke[F0`005Vmk2000
FDHa4P00=36<00<001cW7>L0>1cW00<007ooOol00Goo000COol00`00F]IJeP1EF]H30007Kg/5001V
F]H4000FKg/60013AS4K0017<H`00`007>LLi`0g7>L00`00Oomoo`01Ool001=oo`03001JeU[F05QJ
eP<000U_N`@005eJePD001M_N`D002]6<A`006<aS003000LiacW03HLi`03001oogoo005oo`004goo
00<005[FF]H0Fe[F0`002Vmk0`00EU[F10006Fmk<`00P36<00<001cW7>L0=AcW00<007ooOol00Goo
000COol00`00F]IJeP1NF]H50008Kg/3001>F]H5000JKg/8002_<H`00`007>LLi`0d7>L00`00Oomo
o`01Ool001=oo`03001JeU[F06=JeP@000M_N`@004IJeP@001a_N`@000A6<@03000aS36<0;0aS003
000LiacW03<Li`03001oogoo005oo`004goo00<005[FF]H0Ie[F0`0026mk1@00?U[F0`0076mk1000
2DHa00<0036<<H`0/36<00<001cW7>L0<QcW00<007ooOol00Goo000COol00`00F]IJeP1ZF]H3000:
Kg/4000gF]H3000JKg/50002F]H00`00AS56<@09AS400`00<H`aS02_<H`00`007>LLi`0b7>L00`00
Oomoo`01Ool001=oo`03001JeU[F06eJeP@000Y_N`<0031JeP@001Y_N`<000QJeP030016<DHa00U6
<@03000aS36<0:laS003000LiacW034Li`03001oogoo005oo`004goo00<005[FF]H0LE[F0`002Vmk
0`00:5[F1@006fmk0`002e[F00<004HaAS402THa00<0036<<H`0[c6<00<001cW7>L0<1cW00<007oo
Ool00Goo000COol00`00F]IJeP1dF]H3000:Kg/3000QF]H4000MKg/3000?F]H00`00AS56<@0:AS40
0`00<H`aS02_<H`00`007>LLi`0_7>L00`00Oomoo`01Ool001=oo`03001JeU[F07MJeP<000Y_N`<0
01]JeP<001e_N`@001=JeP030016<DHa00Y6<@03000aS36<0:laS003000LiacW02hLi`03001oogoo
005oo`004goo00<005[FF]H0NU[F0`002Vmk0`005E[F0`007Fmk0`005e[F00<004HaAS402dHa00<0
036<<H`0[c6<00<001cW7>L0;AcW00<007ooOol00Goo000COol00`00F]IJeP1mF]H3000:Kg/3000?
F]H3000MKg/3000KF]H00`00AS56<@0;AS400`00<H`aS02_<H`00`007>LLi`0/7>L00`00Oomoo`01
Ool001=oo`03001JeU[F081JeP@000U_N`8000]JeP8001e_N`<001iJeP030016<DHa00]6<@03000a
S36<0;0aS003000LiacW02/Li`03001oogoo005oo`004goo00<005[FF]H0Q5[F0`0026mk0`001E[F
0`0076mk0`008U[F00<004HaAS402dHa00<0036<<H`0/36<00<001cW7>L0:QcW00<007ooOol00Goo
000COol00`00F]IJeP27F]H30008Kg/200000e[F0000000LKg/3000UF]H00`00AS56<@0<AS400`00
<H`aS02_<H`00`007>LLi`0Z7>L00`00Oomoo`01Ool001=oo`03001JeU[F08UJePl001Q_N`<002UJ
eP030016<DHa00a6<@03000aS36<0:laS003000LiacW02TLi`03001oogoo005oo`004goo00<005[F
F]H0Qe[F0P0016mk20000goo2P002fmk0`00;5[F00<004HaAS403DHa00<0036<<H`0[c6<00<001cW
7>L0:1cW00<007ooOol00Goo000COol00`00F]IJeP25F]H2000>Kg/3000:Ool50003Kg/3000`F]H0
0`00AS56<@0=AS400`00<H`aS02_<H`00`007>LLi`0W7>L00`00Oomoo`01Ool001=oo`03001JeU[F
08AJeP03001_Nfmk015_Na8003=JeP030016<DHa00i6<@03000aS36<0:laS003000LiacW02HLi`03
001oogoo005oo`004goo00<005[FF]H0PU[F0P004Fmk0`0000=JeP00Kg/03Fmk00<005[FF]H0<U[F
00<004HaAS403dHa00<0036<<H`0[c6<00<001cW7>L09AcW00<007ooOol00Goo000COol00`00F]IJ
eP20F]H2000@Kg/30005F]H00`00Kg]_N`0<Kg/00`00F]IJeP0bF]H00`00AS56<@0?AS400`00<H`a
S02_<H`00`007>LLi`0T7>L00`00Oomoo`01Ool001=oo`03001JeU[F07iJeP8000m_N`<000UJeP03
001_Nfmk00]_N`03001JeU[F039JeP030016<DHa0116<@03000aS36<0:laS003000LiacW02<Li`03
001oogoo005oo`004goo00<005[FF]H0Ne[F0`003fmk0P0035[F00<006mkKg/036mk00<005[FF]H0
<U[F00<004HaAS4044Ha00<0036<<H`0[c6<00<001cW7>L08QcW00<007ooOol00Goo000COol00`00
F]IJeP1iF]H2000@Kg/2000?F]H00`00Kg]_N`0<Kg/00`00F]IJeP0aF]H00`00AS56<@0AAS400`00
<H`aS02^<H`00`007>LLi`0R7>L00`00Oomoo`01Ool001=oo`03001JeU[F07MJeP80015_N`03001J
eU[F00mJeP03001_Nfmk00a_N`03001JeU[F039JeP030016<DHa0156<@03000aS36<0:haS003000L
iacW024Li`03001oogoo005oo`004goo00<005[FF]H0ME[F0P004Fmk0P004e[F00<006mkKg/036mk
00<005[FF]H0<E[F00<004HaAS404THa00<0036<<H`0[S6<00<001cW7>L081cW00<007ooOol00Goo
000COol00`00F]IJeP1cF]H2000AKg/2000FF]H00`00Kg]_N`0;Kg/00`00F]IJeP0bF]H00`00AS56
<@0BAS400`00<H`aS02^<H`00`007>LLi`0O7>L00`00Oomoo`01Ool001=oo`03001JeU[F079JeP03
001_Nfmk00m_N`8001QJeP03001_Nfmk00a_N`03001JeU[F035JeP030016<DHa01=6<@03000aS36<
0:haS003000LiacW01hLi`03001oogoo005oo`004goo00<005[FF]H0L5[F0P003fmk0`006e[F00<0
06mkKg/02fmk00<005[FF]H0<U[F00<004HaAS404dHa00<0036<<H`0[S6<00<001cW7>L07AcW00<0
07ooOol00Goo000COol00`00F]IJeP1^F]H2000?Kg/2000OF]H00`00Kg]_N`0;Kg/00`00F]IJeP0a
F]H00`00AS56<@0DAS400`00<H`aS02^<H`00`007>LLi`0L7>L00`00Oomoo`01Ool001=oo`03001J
eU[F06eJeP03001_Nfmk00e_N`80025JeP03001_Nfmk00]_N`03001JeU[F039JeP030016<DHa01A6
<@03000aS36<0:haS003000LiacW01/Li`03001oogoo005oo`004goo00<005[FF]H0Je[F0P003Vmk
0P0095[F00<006mkKg/02fmk00<005[FF]H0<E[F00<004HaAS405DHa00<0036<<H`0[S6<00<001cW
7>L06QcW00<007ooOol00Goo000COol00`00F]IJeP1ZF]H00`00Kg]_N`0<Kg/2000VF]H00`00Kg]_
N`0<Kg/00`00F]IJeP0aF]H00`00AS56<@0EAS400`00<H`aS02^<H`00`007>LLi`0I7>L00`00Oomo
o`01Ool001=oo`03001JeU[F06QJeP8000i_N`03001JeU[F02MJeP03001_Nfmk00]_N`03001JeU[F
035JeP030016<DHa01I6<@03000aS36<0:haS003000LiacW01PLi`03001oogoo005oo`004goo00<0
05[FF]H0Ie[F00<006mkKg/036mk0P00:e[F00<006mkKg/02fmk00<005[FF]H0<E[F00<004HaAS40
5THa00<0036<<H`0[S6<00<001cW7>L05acW00<007ooOol00Goo000COol00`00F]IJeP1UF]H2000=
Kg/2000]F]H00`00Kg]_N`0;Kg/00`00F]IJeP0aF]H00`00AS56<@0GAS400`00<H`aS02^<H`00`00
7>LLi`0F7>L00`00Oomoo`01Ool001=oo`03001JeU[F06AJeP03001_Nfmk00a_N`03001JeU[F02iJ
eP03001_Nfmk00]_N`03001JeU[F035JeP030016<DHa01M6<@03000aS36<0:haS003000LiacW01DL
i`03001oogoo005oo`004goo00<005[FF]H0HU[F0P003Fmk0P00<E[F00<006mkKg/02fmk00<005[F
F]H0<E[F00<004HaAS4064Ha00<0036<<H`0[S6<00<001cW7>L051cW00<007ooOol00Goo000COol0
0`00F]IJeP1QF]H00`00Kg]_N`0<Kg/00`00F]IJeP0bF]H00`00Kg]_N`0;Kg/00`00F]IJeP0`F]H0
0`00AS56<@0IAS400`00<H`aS02^<H`00`007>LLi`0C7>L00`00Oomoo`01Ool001=oo`03001JeU[F
061JeP03001_Nfmk00]_N`8003EJeP03001_Nfmk00]_N`03001JeU[F035JeP030016<DHa01U6<@03
000aS36<0:haS003000LiacW018Li`03001oogoo005oo`004goo00<005[FF]H0GU[F0P003Fmk00<0
05[FF]H0=E[F00<006mkKg/036mk00<005[FF]H0<5[F00<004HaAS406THa00<0036<<H`0[S6<00<0
01cW7>L04AcW00<007ooOol00Goo000COol00`00F]IJeP1MF]H00`00Kg]_N`0;Kg/2000iF]H00`00
Kg]_N`0<Kg/00`00F]IJeP0`F]H00`00AS56<@0JAS400`00<H`aS02^<H`00`007>LLi`0@7>L00`00
Oomoo`01Ool001=oo`03001JeU[F05]JeP8000e_N`03001JeU[F03UJeP03001_Nfmk00a_N`03001J
eU[F031JeP030016<DHa01]6<@03000aS36<0:haS003000LiacW00lLi`03001oogoo005oo`004goo
00<005[FF]H0FU[F00<006mkKg/036mk00<005[FF]H0>e[F00<006mkKg/036mk00<005[FF]H0<5[F
00<004HaAS406dHa00<0036<<H`0[S6<00<001cW7>L03QcW00<007ooOol00Goo000COol00`00F]IJ
eP1IF]H00`00Kg]_N`0;Kg/2000nF]H00`00Kg]_N`0<Kg/00`00F]IJeP0`F]H00`00AS56<@0LAS40
0`00<H`aS02^<H`00`007>LLi`0=7>L00`00Oomoo`01Ool001=oo`03001JeU[F05MJeP8000e_N`03
001JeU[F03mJeP03001_Nfmk00a_N`03001JeU[F02mJeP030016<DHa01e6<@03000aS36<0:haS003
000LiacW00`Li`03001oogoo005oo`004goo00<005[FF]H0EU[F00<006mkKg/036mk00<005[FF]H0
@5[F00<006mkKg/036mk00<005[FF]H0<5[F00<004HaAS407DHa00<0036<<H`0[S6<00<001cW7>L0
2acW00<007ooOol00Goo000COol00`00F]IJeP1EF]H00`00Kg]_N`0<Kg/00`00F]IJeP12F]H00`00
Kg]_N`0<Kg/00`00F]IJeP0_F]H00`00AS56<@0NAS400`00<H`aS02^<H`00`007>LLi`0:7>L00`00
Oomoo`01Ool000Moo`D000Moo`03001JeU[F05AJeP03001_Nfmk00]_N`8004EJeP03001_Nfmk00a_
N`03001JeU[F031JeP030016<DHa01i6<@03000aS36<0:haS003000LiacW00TLi`03001oogoo005o
o`0027oo00@007ooOol000Moo`03001JeU[F05=JeP03001_Nfmk00]_N`03001JeU[F04IJeP03001_
Nfmk00a_N`03001JeU[F02mJeP030016<DHa01m6<@03000aS36<0:haS003000LiacW00PLi`03001o
ogoo005oo`002Goo00<007ooOol01goo00<005[FF]H0DU[F00<006mkKg/02fmk00<005[FF]H0Ae[F
00<006mkKg/036mk00<005[FF]H0;e[F00<004HaAS4084Ha00<0036<<H`0[C6<00<001cW7>L021cW
00<007ooOol00Goo000:Ool00`00Oomoo`06Ool00`00F]IJeP1AF]H00`00Kg]_N`0:Kg/2001;F]H0
0`00Kg]_N`0<Kg/00`00F]IJeP0_F]H00`00AS56<@0PAS400`00<H`aS02]<H`00`007>LLi`077>L0
0`00Oomoo`01Ool000Moo`05001oogooOol00007Ool00`00F]IJeP1@F]H00`00Kg]_N`0:Kg/00`00
F]IJeP1;F]H00`00Kg]_N`0<Kg/00`00F]IJeP0_F]H00`00AS56<@0QAS400`00<H`aS02]<H`00`00
7>LLi`067>L00`00Oomoo`01Ool000Moo`05001oogooOol00007Ool00`00F]IJeP1?F]H00`00Kg]_
N`0:Kg/00`00F]IJeP1=F]H00`00Kg]_N`0<Kg/00`00F]IJeP0_F]H00`00AS56<@0QAS400`00<H`a
S02]<H`00`007>LLi`057>L00`00Oomoo`01Ool000Qoo`<000Qoo`03001JeU[F04iJeP03001_Nfmk
00Y_N`03001JeU[F04mJeP03001_Nfmk00]_N`03001JeU[F02mJeP030016<DHa0296<@03000aS36<
0:daS003000LiacW00@Li`03001oogoo005oo`004goo00<005[FF]H0CE[F00<006mkKg/02Fmk0P00
DU[F00<006mkKg/036mk00<005[FF]H0;e[F00<004HaAS408THa00<0036<<H`0[C6<00<001cW7>L0
0acW00<007ooOol00Goo000COol00`00F]IJeP1<F]H00`00Kg]_N`09Kg/00`00F]IJeP1CF]H00`00
Kg]_N`0;Kg/00`00F]IJeP0_F]H00`00AS56<@0RAS400`00<H`aS02^<H`00`007>LLi`027>L00`00
Oomoo`01Ool001=oo`03001JeU[F04]JeP03001_Nfmk00U_N`03001JeU[F05AJeP03001_Nfmk00a_
N`03001JeU[F02iJeP030016<DHa02=6<@03000aS36<0:haS005000LiacW7>L00003Ool001=oo`03
001JeU[F04YJeP03001_Nfmk00U_N`03001JeU[F05IJeP03001_Nfmk00a_N`03001JeU[F02iJeP03
0016<DHa02=6<@03000aS36<0:haS004000LiacW0003Ool001=oo`03001JeU[F04YJeP03001_Nfmk
00Q_N`03001JeU[F05QJeP8000a_N`03001JeU[F02iJeP030016<DHa02A6<@03000aS36<0:haS003
000Li`0000=oo`004goo00<005[FF]H0BE[F00<006mkKg/026mk00<005[FF]H0FE[F10002fmk00<0
05[FF]H0;U[F00<004HaAS4094Ha00<0036<<H`0[S6<0P000goo000COol00`00F]IJeP18F]H00`00
Kg]_N`08Kg/00`00F]IJeP1IF]H01P00Kg]_N`00Ool000Y_N`03001JeU[F02iJeP030016<DHa02E6
<@03000aS36<0:haS003001oogoo005oo`004goo00<005[FF]H0Ae[F00<006mkKg/026mk00<005[F
F]H0FE[F00<006mkKg/00Vmk00@007oo000000U_N`03001JeU[F02iJeP030016<DHa02E6<@03000a
S36<0:daS003001oogoo005oo`004goo00<005[FF]H0AU[F00<006mkKg/026mk00<005[FF]H0FU[F
00<006mkKg/00fmk00<007ooOol00P001fmk00<005[FF]H0;U[F00<004HaAS409THa00<0036<<H`0
[36<00<007ooOol00Goo000COol00`00F]IJeP15F]H00`00Kg]_N`08Kg/00`00F]IJeP1JF]H00`00
Kg]_N`05Kg/01@00Oomoogoo00001fmk00<005[FF]H0;U[F00<004HaAS409THa00<0036<<H`0Zc6<
00<007ooOol00Goo000COol00`00F]IJeP14F]H00`00Kg]_N`08Kg/00`00F]IJeP1KF]H00`00Kg]_
N`06Kg/01000Oomoogoo0P001Fmk00<005[FF]H0;U[F00<004HaAS409THa00<0036<<H`0Zc6<00<0
07ooOol00Goo000COol00`00F]IJeP13F]H00`00Kg]_N`08Kg/00`00F]IJeP1KF]H00`00Kg]_N`08
Kg/00`00Oomoo`02Ool20004Kg/00`00F]IJeP0]F]H00`00AS56<@0WAS400`00<H`aS02Z<H`00`00
Oomoo`01Ool001=oo`03001JeU[F049JeP03001_Nfmk00Q_N`03001JeU[F05]JeP03001_Nfmk00Y_
N`03001oogoo00=oo`05001_NfmkKg/0000`F]H00`00AS56<@0WAS400`00<H`aS02Y<H`00`00Oomo
o`01Ool001=oo`80049JeP03001_Nfmk00Q_N`03001JeU[F05aJeP03001_Nfmk00]_N`03001oogoo
00=oo`800003Kg/005[F02mJeP030016<DHa02Q6<@03000aS36<0:PaS003001oogoo005oo`004goo
00<006mk00000P00?e[F00<006mkKg/01fmk00<005[FF]H0G5[F00<006mkKg/03Fmk00<007ooOol0
17oo0`00<5[F00<004HaAS40:4Ha00<0036<<H`0Yc6<00<007ooOol00Goo000COol00`00Kg]_N`02
Kg/2000lF]H00`00Kg]_N`07Kg/00`00F]IJeP1MF]H00`00Kg]_N`0>Kg/00`00Oomoo`05Ool00`00
F]IJeP0^F]H00`00AS56<@0YAS400`00<H`aS02V<H`00`00Oomoo`01Ool001=oo`03001_Nfmk00A_
N`<003QJeP03001_Nfmk00M_N`03001JeU[F05eJeP03001_Nfmk011_N`03001oogoo00Eoo`H002]J
eP030016<DHa02U6<@03000aS36<0:DaS003001oogoo005oo`004goo00<006mkKg/01fmk0P00=E[F
00<006mkKg/01fmk00<005[FF]H0GE[F00<006mkKg/04Vmk00<007ooOol017oo00<006mkKg/00fmk
1P009E[F00<004HaAS40:THa00<0036<<H`0Y36<00<007ooOol00Goo000COol00`00Kg]_N`09Kg/2
000bF]H00`00Kg]_N`08Kg/00`00F]IJeP1MF]H00`00Kg]_N`0CKg/00`00Oomoo`04Ool00`00Kg]_
N`08Kg/4000QF]H00`00AS56<@0[AS400`00<H`aS02S<H`00`00Oomoo`01Ool001=oo`03001_Nfmk
00]_N`8002mJeP03001_Nfmk00Q_N`03001JeU[F05eJeP03001_Nfmk01E_N`03001oogoo00Aoo`03
001_Nfmk00]_N`L001]JeP030016<DHa02Y6<@03000aS36<0:<aS003001oogoo005oo`004goo00<0
06mkKg/03Fmk0P00;E[F00<006mkKg/01fmk00<005[FF]H0GE[F00<006mkKg/05fmk00<007ooOol0
17oo00<006mkKg/04Fmk2@004U[F00<004HaAS40:dHa00<0036<<H`0XS6<00<007ooOol00Goo000C
Ool2000@Kg/2000ZF]H00`00Kg]_N`07Kg/00`00F]IJeP1NF]H00`00Kg]_N`0HKg/00`00Oomoo`04
Ool00`00Kg]_N`0IKg/8000;F]H00`00AS56<@0[AS400`00<H`aS02Q<H`00`00Oomoo`01Ool001=o
o`@0011_N`8002MJeP03001_Nfmk00M_N`03001JeU[F05iJeP03001_Nfmk01Y_N`03001oogoo00=o
o`03001_Nfmk025_N`H000EJeP030016<DHa02a6<@03000aS36<0:0aS003001oogoo005oo`004goo
00<005[F00000`0046mk0P0095[F00<006mkKg/01fmk00<005[FF]H0GU[F00<006mkKg/076mk00<0
07ooOol00goo00<006mkKg/09Vmk1P00;dHa00<0036<<H`0Wc6<00<007ooOol00Goo000COol01000
F]IJeU[F100046mk0P008E[F00<006mkKg/026mk00<005[FF]H0GU[F00<006mkKg/07Fmk00<007oo
Ool00goo00<006mkKg/05Fmk6@00;4Ha00<0036<<H`0Wc6<00<007ooOol00Goo000COol00`00F]IJ
eP02F]H200000e[F0000000@Kg/2000OF]H00`00Kg]_N`07Kg/00`00F]IJeP1NF]H00`00Kg]_N`0O
Kg/M000IF]H3000ZAS400`00<H`aS02N<H`00`00Oomoo`01Ool001=oo`03001JeU[F00=JeP80009J
eP80011_N`8001aJeP03001_Nfmk00M_N`03001JeU[F05iJeP03001_Nfmk021_N`03001_Nfmk00=_
N`03001JeU[F031JeP<002Q6<@03000aS36<09daS003001oogoo005oo`004goo00<005[FF]H015[F
0P000e[F0P0046mk0P006E[F00<006mkKg/01fmk00<005[FF]H0Ge[F00<006mkKg/07fmk00<005[F
00001Fmk00<005[FF]H0<U[F0`009THa00<0036<<H`0W36<00<007ooOol00Goo000COol00`00F]IJ
eP05F]H20004F]H2000@Kg/2000GF]H00`00Kg]_N`06Kg/00`00F]IJeP1OF]H00`00Kg]_N`0PKg/0
1000F]IJeP001Fmk00<005[FF]H0=5[F0`008dHa00<0036<<H`0W36<00<007ooOol00Goo000COol0
0`00F]IJeP06F]H20005F]H3000?Kg/2000DF]H00`00Kg]_N`07Kg/00`00F]IJeP1OF]H00`00Kg]_
N`0OKg/00`00F]IJeP02F]H00`00Kg]_N`03Kg/00`00F]IJeP0fF]H3000QAS400`00<H`aS02K<H`0
0`00Oomoo`01Ool001=oo`03001JeU[F00MJeP<000IJeP8000m_N`80015JeP03001_Nfmk00M_N`03
001JeU[F05mJeP03001_Nfmk021_N`03001JeU[F00=JeP03001_Nfmk00=_N`03001JeU[F03QJeP@0
01i6<@03000aS36<09XaS003001oogoo005oo`004goo00<005[FF]H02E[F0P001e[F0P003fmk0P00
3U[F00<006mkKg/01fmk00<005[FF]H0Ge[F00<006mkKg/08Fmk00<005[FF]H015[F00<006mkKg/0
0fmk00<005[FF]H0>e[F0`0074Ha00<0036<<H`0VC6<00<007ooOol00Goo000COol00`00F]IJeP0:
F]H20008F]H2000?Kg/2000<F]H00`00Kg]_N`06Kg/00`00F]IJeP1PF]H00`00Kg]_N`0PKg/00`00
F]IJeP06F]H00`00Kg]_N`03Kg/00`00F]IJeP0mF]H3000JAS400`00<H`aS02H<H`00`00Oomoo`01
Ool001=oo`03001JeU[F00]JeP<000QJeP8000m_N`8000UJeP03001_Nfmk00I_N`03001JeU[F061J
eP03001_Nfmk025_N`03001JeU[F00MJeP03001_Nfmk00=_N`03001JeU[F03mJeP<001Q6<@03000a
S36<09LaS003001oogoo005oo`004goo00<005[FF]H03E[F0P002E[F0P003fmk0P001U[F00<006mk
Kg/01Vmk00<005[FF]H0HE[F00<006mkKg/086mk00<005[FF]H02E[F00<006mkKg/00fmk00<005[F
F]H0@E[F0`005THa00<0036<<H`0US6<00<007ooOol00Goo000COol00`00F]IJeP0>F]H2000:F]H2
000?Kg/20004F]H00`00Kg]_N`06Kg/00`00F]IJeP1PF]H00`00Kg]_N`0QKg/00`00F]IJeP09F]H0
0`00Kg]_N`03Kg/00`00F]IJeP14F]H3000DAS400`00<H`aS02E<H`00`00Oomoo`01Ool001=oo`03
001JeU[F00mJeP8000]JeP8000m_N`800003F]H006mk00M_N`03001JeU[F061JeP03001_Nfmk025_
N`03001JeU[F00]JeP03001_Nfmk00=_N`03001JeU[F04IJeP<00196<@03000aS36<09@aS003001o
ogoo005oo`004goo00<005[FF]H045[F0`002e[F0P003Vmk10001Vmk00<005[FF]H0HE[F00<006mk
Kg/08Fmk00<005[FF]H035[F00<006mkKg/00fmk00<005[FF]H0B5[F0`003dHa00<0036<<H`0U36<
00<007ooOol00Goo000COol00`00F]IJeP0BF]H2000<F]H2000;Kg/00`00Oomoo`02Ool30002Kg/0
0`00F]IJeP1QF]H00`00Kg]_N`0QKg/00`00F]IJeP0>F]H00`00Kg]_N`03Kg/00`00F]IJeP1:F]H3
000=AS400`00<H`aS02C<H`00`00Oomoo`01Ool001=oo`03001JeU[F01=JeP8000eJeP8000M_N`80
00Qoo`<006=JeP03001_Nfmk025_N`03001JeU[F00mJeP03001_Nfmk00=_N`03001JeU[F04aJeP@0
00Y6<@03000aS36<098aS003001oogoo005oo`004goo00<005[FF]H055[F0P003U[F0P0016mk00<0
07ooOol01Woo0P000fmk00<005[FF]H0Ge[F00<006mkKg/08Vmk00<005[FF]H045[F00<006mkKg/0
0Vmk00<005[FF]H0D5[F0`0024Ha00<0036<<H`0TC6<00<007ooOol00Goo000COol00`00F]IJeP0E
F]H3000>F]H200000fmk001oo`06Ool20006Kg/2001NF]H00`00Kg]_N`0RKg/00`00F]IJeP0BF]H0
0`00Kg]_N`02Kg/00`00F]IJeP1BF]H30006AS400`00<H`aS02@<H`00`00Oomoo`01Ool001=oo`03
001JeU[F01IJeP03001oo`0000mJeP8000Ioo`03001_Nfmk00Q_N`8005aJeP03001_Nfmk029_N`03
001JeU[F01=JeP03001_Nfmk009_N`03001JeU[F05AJeP<000A6<@03000aS36<08laS003001oogoo
005oo`004goo00<005[FF]H05e[F00<007oo00003U[F00<006mk00000P0000=oo`0000003Fmk00<0
05[FF]H0F5[F00<006mkKg/08Vmk00<005[FF]H05E[F00<006mkKg/00Vmk00<005[FF]H0EU[F0`00
0THa00<0036<<H`0SS6<00<007ooOol00Goo000COol00`00F]IJeP0HF]H3000<F]H00`00Kg]_N`03
Kg/2000?Kg/2001HF]H00`00Kg]_N`0RKg/00`00F]IJeP0EF]H00`00Kg]_N`02Kg/00`00F]IJeP1I
F]H4002?<H`00`00Oomoo`01Ool001=oo`03001JeU[F01YJeP<000YJeP03001_Nfmk00=_N`04001J
eP00000?Kg/2001EF]H00`00Kg]_N`0RKg/00`00F]IJeP0GF]H00`00Kg]_N`02Kg/00`00F]IJeP1K
F]H4002<<H`00`00Oomoo`01Ool001=oo`03001JeU[F01]JeP03001oo`0000UJeP03001_Nfmk009_
N`03001JeU[F009JeP<000i_N`8005=JeP03001_Nfmk029_N`03001JeU[F01QJeP03001_Nfmk009_
N`03001JeU[F05]JeP030016<DHa00<008TaS003001oogoo005oo`004goo00<005[FF]H075[F0`00
1e[F00<006mkKg/00fmk00<005[FF]H01E[F0P003Vmk00<005[FF]H0Ce[F00<006mkKg/08Vmk00<0
05[FF]H06U[F00<006mkKg/00Vmk00<005[FF]H0Fe[F00<004HaAS400THa0`00QS6<00<007ooOol0
0Goo000COol00`00F]IJeP0NF]H20006F]H00`00Kg]_N`02Kg/00`00F]IJeP08F]H2000=Kg/2001>
F]H00`00Kg]_N`0SKg/00`00F]IJeP0KF]H00`00Kg]_N`02Kg/00`00F]IJeP1KF]H00`00AS56<@04
AS430023<H`00`00Oomoo`01Ool001=oo`03001JeU[F01mJeP8000EJeP03001_Nfmk009_N`03001J
eU[F00YJeP8000e_N`8004aJeP03001_Nfmk02=_N`03001JeU[F01aJeP05001_NfmkKg/0001NF]H0
0`00AS56<@06AS430020<H`00`00Oomoo`01Ool001=oo`03001JeU[F021JeP8000=JeP03001_Nfmk
009_N`03001JeU[F00eJeP8000e_N`8004UJeP03001_Nfmk02=_N`03001JeU[F01iJeP05001_Nfmk
Kg/0001NF]H00`00AS56<@08AS43001m<H`00`00Oomoo`01Ool001=oo`03001JeU[F025JeP80009J
eP03001_Nfmk009_N`03001JeU[F00mJeP03001_Nfmk00a_N`<004IJeP03001_Nfmk02=_N`03001J
eU[F01mJeP05001_NfmkKg/0001MF]H00`00AS56<@0;AS43001j<H`00`00Oomoo`01Ool001=oo`03
001JeU[F025JeP<00003F]H006mk00=_N`03001JeU[F011JeP8000m_N`8004=JeP03001_Nfmk02=_
N`03001JeU[F025JeP05001_NfmkKg/0001MF]H00`00AS56<@0=AS43001g<H`00`00Oomoo`01Ool0
01=oo`03001JeU[F025JeP800003Kg/0000000=_N`03001JeU[F01=JeP8000m_N`80045JeP03001_
Nfmk02=_N`03001JeU[F029JeP04001_Nfmk001NF]H00`00AS56<@0?AS43001d<H`00`00Oomoo`01
Ool001=oo`03001JeU[F029JeP80009_N`800003Kg/005[F01IJeP8000m_N`8003iJeP03001_Nfmk
02=_N`03001JeU[F02AJeP04001_Nfmk001NF]H00`00AS56<@0AAS43001a<H`00`00Oomoo`01Ool0
01=oo`03001JeU[F029JeP<000=_N`03001JeU[F01QJeP8000m_N`8003aJeP03001_Nfmk02=_N`03
001JeU[F02EJeP04001_Nfmk001MF]H00`00AS56<@0DAS43001^<H`00`00Oomoo`01Ool001=oo`03
001JeU[F029JeP800005F]H006mkKg/0000LF]H00`00Kg]_N`0>Kg/00`00F]IJeP0hF]H00`00Kg]_
N`0SKg/00`00F]IJeP0WF]H01000Kg]_N`00GE[F00<004HaAS405THa0`00Jc6<00<007ooOol00Goo
000COol00`00F]IJeP0RF]H20002F]H01000Kg]_N`0075[F0P003fmk0P00>5[F00<006mkKg/08fmk
00<005[FF]H0:5[F00@006mkKg/005eJeP030016<DHa01Q6<@8006TaS003001oogoo005oo`004goo
00<005[FF]H08U[F0P000U[F00D006mkKg]_N`0001eJeP8000m_N`8003EJeP03001_Nfmk02A_N`03
001JeU[F02UJeP03001_N`0005iJeP030016<DHa01U6<@<006HaS003001oogoo005oo`004goo00<0
05[FF]H08e[F00D005[FF]IJeP0000=_N`03001JeU[F01aJeP8000m_N`8003=JeP03001_Nfmk02=_
N`03001JeU[F02]JeP03001_N`0005iJeP030016<DHa01]6<@<006<aS003001oogoo005oo`004goo
00<005[FF]H08e[F0P000e[F00D006mkKg]_N`0001mJeP8000m_N`80031JeP03001_Nfmk02A_N`03
001JeU[F02aJeP03001_N`0005eJeP030016<DHa01i6<@<0060aS003001oogoo005oo`004goo00<0
05[FF]H08e[F0P0015[F00@006mkKg/0025JeP03001_Nfmk00i_N`8002iJeP03001_Nfmk02=_N`03
001JeU[F02iJeP03001_N`0005eJeP030016<DHa0216<@<005daS003001oogoo005oo`004goo00<0
05[FF]H08e[F0P0015[F00D006mkKg]_N`00025JeP80011_N`8002]JeP03001_Nfmk02A_N`03001J
eU[F02iJeP03001_N`0005iJeP030016<DHa0296<@<005XaS003001oogoo005oo`004goo00<005[F
F]H095[F00<005[FF]H00e[F00D006mkKg]_N`00029JeP80011_N`8002UJeP03001_Nfmk02=_N`03
001JeU[F031JeP03001_N`0005iJeP030016<DHa02A6<@<005LaS003001oogoo005oo`004goo00<0
05[FF]H095[F0P001E[F00D006mkKg]_N`0002=JeP80011_N`8002IJeP03001_Nfmk02A_N`03001J
eU[F035JeP03001_N`0005eJeP030016<DHa02M6<@<005@aS003001oogoo005oo`004goo00<005[F
F]H095[F0P001U[F00D006mkKg]_N`0002AJeP80011_N`03001JeU[F02=JeP03001_Nfmk02=_N`03
001JeU[F03=JeP03001_N`0005eJeP030016<DHa02U6<@<0054aS003001oogoo005oo`004goo00<0
05[FF]H095[F0P001e[F00@006mkKg/002IJeP03001_Nfmk00i_N`80029JeP03001_Nfmk02A_N`03
001JeU[F03AJeP03001_N`0005eJeP030016<DHa02]6<@<004haS003001oogoo005oo`004goo00<0
05[FF]H095[F0P001e[F00D006mkKg]_N`0002IJeP80011_N`8001mJeP03001_Nfmk02E_N`03001J
eU[F03EJeP8005eJeP030016<DHa02i6<@<004/aS003001oogoo005oo`004goo00<005[FF]H09E[F
0P001e[F00D006mkKg]_N`0002MJeP80011_N`8001eJeP03001_Nfmk02A_N`03001JeU[F03MJeP80
05eJeP030016<DHa0316<@<004PaS003001oogoo005oo`004goo00<005[FF]H09E[F0P0025[F00D0
06mkKg]_N`0002QJeP80011_N`8001YJeP03001_Nfmk02E_N`03001JeU[F03QJeP8005eJeP030016
<DHa0396<@<004DaS003001oogoo005oo`002Goo0`001goo00<005[FF]H09E[F0P002E[F00D006mk
Kg]_N`0002UJeP80011_N`03001JeU[F01MJeP03001_Nfmk02A_N`03001JeU[F03YJeP8005aJeP03
0016<DHa03E6<@<0048aS003001oogoo005oo`002Woo00<007ooOol01Woo00<005[FF]H09E[F0P00
2U[F00@006mkKg/002]JeP8000m_N`8001IJeP03001_Nfmk02E_N`03001JeU[F03YJeP8005eJeP03
0016<DHa03M6<@<003laS003001oogoo005oo`001goo1@001goo00<005[FF]H09U[F0P002E[F00D0
06mkKg]_N`0002aJeP8000m_N`8001AJeP03001_Nfmk02A_N`03001JeU[F03aJeP8005eJeP030016
<DHa03U6<@<003`aS003001oogoo005oo`001goo00@007ooOol000Qoo`03001JeU[F02IJeP8000YJ
eP05001_NfmkKg/0000]F]H2000?Kg/2000AF]H00`00Kg]_N`0UKg/00`00F]IJeP0mF]H2001LF]H0
0`00AS56<@0lAS43000i<H`00`00Oomoo`01Ool000Qoo`03001oo`0000Qoo`03001JeU[F02IJeP80
00]JeP05001_NfmkKg/0000^F]H2000?Kg/2000?F]H00`00Kg]_N`0UKg/00`00F]IJeP0mF]H2001M
F]H00`00AS56<@0nAS43000f<H`00`00Oomoo`01Ool000Uoo`8000Qoo`03001JeU[F02IJeP8000aJ
eP04001_Nfmk000`F]H3000>Kg/2000<F]H00`00Kg]_N`0UKg/00`00F]IJeP0oF]H2001MF]H00`00
AS56<@10AS43000c<H`00`00Oomoo`01Ool000Yoo`03001oogoo00Ioo`03001JeU[F02IJeP8000eJ
eP04001_Nfmk000bF]H2000>Kg/2000:F]H00`00Kg]_N`0UKg/00`00F]IJeP10F]H2001MF]H00`00
AS56<@12AS43000`<H`00`00Oomoo`01Ool001=oo`03001JeU[F02MJeP8000aJeP05001_NfmkKg/0
000cF]H2000>Kg/20007F]H00`00Kg]_N`0UKg/00`00F]IJeP12F]H2001MF]H00`00AS56<@14AS43
000]<H`00`00Oomoo`01Ool001=oo`03001JeU[F02MJeP8000eJeP05001_NfmkKg/0000dF]H2000>
Kg/20005F]H00`00Kg]_N`0UKg/00`00F]IJeP12F]H2001MF]H00`00AS56<@17AS43000Z<H`00`00
Oomoo`01Ool001=oo`03001JeU[F02MJeP8000iJeP05001_NfmkKg/0000eF]H2000>Kg/01@00F]IJ
eU[F0000:6mk00<005[FF]H0@e[F0P00GE[F00<004HaAS40BDHa0`009c6<00<007ooOol00Goo000C
Ool00`00F]IJeP0WF]H2000?F]H01000Kg]_N`00=e[F00<006mkKg/036mk0P0000=JeP00Kg/09Vmk
00<005[FF]H0AE[F0P00GE[F00<004HaAS40BdHa0`00936<00<007ooOol00Goo000COol00`00F]IJ
eP0XF]H2000>F]H01@00Kg]_Nfmk0000=e[F0P003Vmk00<006mkKg/09Vmk00<005[FF]H0AE[F0P00
GU[F00<004HaAS40CDHa0P008S6<00<007ooOol00Goo000COol00`00F]IJeP0XF]H2000?F]H01@00
Kg]_Nfmk0000>5[F0P0036mk0P009Vmk00<005[FF]H0Ae[F0P00GE[F00<004HaAS40CdHa0P00836<
00<007ooOol00Goo000COol00`00F]IJeP0XF]H2000@F]H01@00Kg]_Nfmk0000>E[F0P002fmk0P00
9Fmk00<005[FF]H0B5[F0P00GE[F00<004HaAS40D4Ha0`007C6<00<007ooOol00Goo000COol00`00
F]IJeP0XF]H2000@F]H00`00Kg]_N`02Kg/00`00F]IJeP0hF]H2000:Kg/2000SKg/00`00F]IJeP1:
F]H2001MF]H00`00AS56<@1BAS42000K<H`00`00Oomoo`01Ool001=oo`03001JeU[F02QJeP80015J
eP05001_NfmkKg/0000lF]H00`00Kg]_N`08Kg/2000RKg/00`00F]IJeP1;F]H2001LF]H00`00AS56
<@1DAS43000H<H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP80015JeP05001_NfmkKg/0000l
F]H20009Kg/2000QKg/00`00F]IJeP1<F]H2001LF]H00`00AS56<@1FAS43000E<H`00`00Oomoo`01
Ool001=oo`03001JeU[F02UJeP80019JeP05001_NfmkKg/0000mF]H20007Kg/00`00Ool0000OKg/0
0`00F]IJeP1>F]H2001LF]H00`00AS56<@1HAS43000B<H`00`00Oomoo`01Ool001=oo`03001JeU[F
02UJeP80019JeP03001_Nfmk009_N`03001JeU[F03aJeP8000I_N`04001oo`00000MKg/00`00F]IJ
eP1?F]H2001KF]H00`00AS56<@1KAS43000?<H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP80
01=JeP03001_Nfmk009_N`03001JeU[F03eJeP8000E_N`04001oogoo000KKg/00`00F]IJeP1AF]H2
001KF]H00`00AS56<@1MAS43000<<H`00`00Oomoo`01Ool001=oo`03001JeU[F02YJeP8001=JeP05
001_NfmkKg/00011F]H00`00Kg]_N`03Kg/01000Oomoo`006Vmk00<005[FF]H0DE[F0P00G5[F00<0
04HaAS40GdHa0`002C6<00<007ooOol00Goo000COol00`00F]IJeP0ZF]H2000CF]H00`00Kg]_N`02
Kg/00`00F]IJeP0oF]H20004Kg/01000Oomoo`0066mk00<005[FF]H0De[F0P00Fe[F00<004HaAS40
HTHa0P001c6<00<007ooOol00Goo000COol00`00F]IJeP0ZF]H2000DF]H00`00Kg]_N`02Kg/00`00
F]IJeP10F]H20003Kg/01000Oomoo`005fmk00<005[FF]H0E5[F0P00Fe[F00<004HaAS40HdHa0P00
1C6<00<007ooOol00Goo000COol00`00F]IJeP0ZF]H2000EF]H00`00Kg]_N`02Kg/00`00F]IJeP11
F]H200000fmk001oo`02Ool00`00Kg]_N`0CKg/00`00F]IJeP1FF]H2001KF]H00`00AS56<@1TAS43
0002<H`00`00Oomoo`01Ool001=oo`03001JeU[F02YJeP8001IJeP05001_NfmkKg/00015F]H30003
Ool2000CKg/00`00F]IJeP1GF]H2001KF]H00`00AS56<@1VAS430003Ool001=oo`03001JeU[F02]J
eP8001IJeP05001_NfmkKg/00016F]H20004Ool00`00Kg]_N`0@Kg/00`00F]IJeP1HF]H00`00F]IJ
eP1IF]H00`00AS56<@1XAS400`00Oomoo`01Ool001=oo`03001JeU[F02]JeP8001MJeP05001_Nfmk
Kg/00016F]H20004Ool00`00Kg]_N`0>Kg/00`00F]IJeP1JF]H00`00F]IJeP1IF]H00`00AS56<@1W
AS400`00Oomoo`01Ool001=oo`03001JeU[F02]JeP8001QJeP05001_NfmkKg/00017F]H20003Ool0
0`00Kg]_N`0=Kg/00`00F]IJeP1KF]H00`00F]IJeP1IF]H00`00AS56<@1VAS400`00Oomoo`01Ool0
01=oo`03001JeU[F02]JeP8001UJeP05001_NfmkKg/00016F]H00`00Kg/00003Ool00`00Kg]_N`0;
Kg/00`00F]IJeP1MF]H6001FF]H00`00AS56<@1UAS400`00Oomoo`01Ool001=oo`03001JeU[F02aJ
eP8001UJeP04001_Nfmk0016F]H01000Kg]_N`000goo00<006mkKg/02Vmk00<005[FF]H0GE[F00<0
04HaAS400dHa4@00AE[F00<004HaAS40IDHa00<007ooOol00Goo000COol00`00F]IJeP0/F]H2000I
F]H01@00Kg]_Nfmk0000AE[F00D006mkKg]_N`0000=oo`03001_Nfmk00Q_N`03001JeU[F05eJeP03
0016<DHa01E6<@T003eJeP030016<DHa06A6<@03001oogoo005oo`004goo00<005[FF]H0;5[F0P00
6U[F00D006mkKg]_N`0004AJeP03001_Nfmk009_N`80009oo`8000Q_N`03001JeU[F05eJeP030016
<DHa01i6<A8002]JeP030016<DHa06A6<@03001oogoo005oo`004goo00<005[FF]H0;5[F0P006e[F
00D006mkKg]_N`00049JeP03001_Nfmk00E_N`05001oogooOol00006Kg/00`00F]IJeP1MF]H00`00
AS56<@0aAS49000SF]H00`00AS56<@1SAS400`00Oomoo`01Ool001=oo`03001JeU[F02aJeP8001aJ
eP05001_NfmkKg/00011F]H00`00Kg]_N`06Kg/01@00Oomoogoo00001Fmk00<005[FF]H0GE[F00<0
04HaAS40>THa2@006e[F00<004HaAS40HTHa00<007ooOol00Goo000COol00`00F]IJeP0]F]H2000L
F]H01000Kg]_N`00@E[F00<006mkKg/01fmk00D007ooOomoo`0000A_N`03001JeU[F05eJeP030016
<DHa04=6<@T0019JeP030016<DHa0696<@03001oogoo005oo`004goo00<005[FF]H0;E[F0P0075[F
00D006mkKg]_N`00041JeP03001_Nfmk00Q_N`80009oo`04001_Nfmk001OF]H00`00AS56<@1=AS49
000:F]H00`00AS56<@1QAS400`00Oomoo`01Ool001=oo`03001JeU[F02eJeP8001eJeP05001_Nfmk
Kg/0000oF]H00`00Kg]_N`0:Kg/01P00Oomoo`00Kg/005mJeP030016<DHa05I6<@P0009JeP030016
<DHa0656<@03001oogoo005oo`004goo00<005[FF]H0;E[F0P007U[F00D006mkKg]_N`0003iJeP03
001_Nfmk00]_N`03001oogoo008005iJeP030016<DHa05m6<@H00616<@03001oogoo005oo`004goo
00<005[FF]H0;E[F0P007e[F00D006mkKg]_N`0003eJeP03001_Nfmk00a_N`80009oo`03001JeU[F
05]JeP030016<DHa0696<@03000aS36<00D005]6<@03001oogoo005oo`004goo00<005[FF]H0;E[F
0P007e[F00D006mkKg]_N`0003eJeP03001_Nfmk00i_N`03001oogoo008005YJeP030016<DHa06A6
<@03000aS36<00@aS0L005A6<@03001oogoo005oo`004goo00<005[FF]H0;U[F0P007e[F00D006mk
Kg]_N`0003aJeP03001_Nfmk00m_N`03001oogoo008005UJeP030016<DHa06E6<@03000aS36<00Xa
S0H004i6<@03001oogoo005oo`004goo00<005[FF]H0;U[F0P0085[F00D006mkKg]_N`0003YJeP03
001_Nfmk015_N`03001oogoo008005MJeP030016<DHa06I6<@03000aS36<010aS0D004U6<@03001o
ogoo005oo`004goo00<005[FF]H0;U[F0P0085[F00<006mkKg/00Vmk00<005[FF]H0=e[F00<006mk
Kg/04Vmk0P0000Aoo`00000005EJeP030016<DHa06M6<@03000aS36<01@aS0@004E6<@03001oogoo
005oo`004goo00<005[FF]H0;U[F0P008E[F00D006mkKg]_N`0003UJeP03001_Nfmk01A_N`05001o
o`00Kg/0001CF]H00`00AS56<@1YAS400`00<H`aS00G<H`50010AS400`00Oomoo`01Ool001=oo`03
001JeU[F02iJeP80029JeP05001_NfmkKg/0000hF]H00`00Kg]_N`0EKg/01000Ool006mk0P00DE[F
00<004HaAS40JTHa00<0036<<H`06c6<1000?4Ha00<007ooOol00Goo000COol00`00F]IJeP0^F]H2
000SF]H01@00Kg]_Nfmk0000=e[F00<006mkKg/05Vmk00<007oo00000Vmk00<005[FF]H0CE[F00<0
04HaAS40JdHa00<0036<<H`07c6<1@00=dHa00<007ooOol00Goo000COol00`00F]IJeP0^F]H2000S
F]H00`00Kg]_N`02Kg/00`00F]IJeP0dF]H00`00Kg]_N`0GKg/00`00Ool00002Kg/00`00F]IJeP1<
F]H00`00AS56<@1/AS400`00<H`aS00S<H`4000cAS400`00Oomoo`01Ool001=oo`03001JeU[F02mJ
eP8002=JeP03001_Nfmk009_N`03001JeU[F03=JeP03001_Nfmk01Q_N`05001oo`00001_N`02001;
F]H00`00AS56<@1^AS400`00<H`aS00V<H`5000^AS400`00Oomoo`01Ool001=oo`03001JeU[F02mJ
eP8002AJeP05001_NfmkKg/0000dF]H00`00Kg]_N`0JKg/01000Oomoo`000Vmk00<005[FF]H0B5[F
00<004HaAS40KTHa00<0036<<H`0:c6<1000:THa00<007ooOol00Goo000COol00`00F]IJeP0_F]H2
000TF]H00`00Kg]_N`02Kg/00`00F]IJeP0aF]H00`00Kg]_N`0KKg/01000Oomoo`000Vmk00<005[F
F]H0AU[F00<004HaAS40L4Ha00<0036<<H`0;S6<1@009DHa00<007ooOol00Goo000COol00`00F]IJ
eP0_F]H2000UF]H00`00Kg]_N`02Kg/00`00F]IJeP0`F]H00`00Kg]_N`0LKg/200001Goo001_Nfmk
0000AU[F00<004HaAS40LDHa00<0036<<H`0<c6<10008DHa00<007ooOol00Goo000COol00`00F]IJ
eP0`F]H00`00F]IJeP0TF]H00`00Kg]_N`02Kg/00`00F]IJeP0_F]H00`00Kg]_N`0NKg/00`00Ool0
0002Kg/20014F]H00`00AS56<@1bAS400`00<H`aS00f<H`5000LAS400`00Oomoo`01Ool001=oo`03
001JeU[F031JeP8002IJeP03001_Nfmk009_N`03001JeU[F02iJeP03001_Nfmk01m_N`<000=_N`80
045JeP030016<DHa07A6<@03000aS36<03XaS0@001Q6<@03001oogoo005oo`004goo00<005[FF]H0
<5[F0P009e[F00D006mkKg]_N`0002mJeP03001_Nfmk029_N`8000A_N`03001JeU[F03iJeP030016
<DHa07A6<@03000aS36<03haS0D001=6<@03001oogoo005oo`004goo00<005[FF]H0<5[F0P00:5[F
00D006mkKg]_N`0002iJeP03001_Nfmk02=_N`8000A_N`8003eJeP030016<DHa07I6<@03000aS36<
048aS0@000m6<@03001oogoo005oo`004goo00<005[FF]H0<5[F0P00:E[F00D006mkKg]_N`0002eJ
eP03001_Nfmk02A_N`8000E_N`8003YJeP030016<DHa07M6<@03000aS36<04HaS0D000Y6<@03001o
ogoo005oo`004goo00<005[FF]H0<5[F0P00:U[F00D006mkKg]_N`0002aJeP03001_Nfmk02I_N`03
001_Nfmk00A_N`03001JeU[F03MJeP030016<DHa07Q6<@03000aS36<04XaS0@000I6<@03001oogoo
005oo`004goo00<005[FF]H0<E[F00<005[FF]H0:E[F00D006mkKg]_N`0002YJeP03001_Nfmk02Q_
N`8000E_N`8003IJeP030016<DHa07U6<@03000aS36<04haS0D00003AS4007oo009oo`004goo00<0
05[FF]H0<E[F0P00:U[F00D006mkKg]_N`0002YJeP03001_Nfmk02Q_N`03001JeP0000I_N`03001J
eU[F03=JeP030016<DHa07Y6<@03000aS36<058aS08000=oo`004goo00<005[FF]H0<E[F0P00:e[F
00D006mkKg]_N`0002UJeP03001_Nfmk02M_N`04001JeU[FF]H20005Kg/2000bF]H00`00AS56<@1l
AS400`00<H`aS01B<H`00`00Oomoo`01Ool001=oo`03001JeU[F035JeP8002aJeP05001_NfmkKg/0
000XF]H00`00Kg]_N`0WKg/00`00F]IJeP03F]H00`00Kg]_N`04Kg/00`00F]IJeP0_F]H00`00AS56
<@1lAS400`00<H`aS01B<H`00`00Oomoo`01Ool001=oo`03001JeU[F035JeP8002aJeP03001_Nfmk
009_N`03001JeU[F02EJeP03001_Nfmk02M_N`03001JeU[F00AJeP8000E_N`03001JeU[F02eJeP03
0016<DHa07i6<@03000aS36<054aS003001oogoo005oo`004goo00<005[FF]H0<E[F0P00;E[F00D0
06mkKg]_N`0002IJeP03001_Nfmk02M_N`03001JeU[F00MJeP03001_Nfmk00=_N`8002aJeP030016
<DHa0816<@03000aS36<050aS003001oogoo005oo`004goo00<005[FF]H0<E[F0P00;U[F00D006mk
Kg]_N`0002EJeP03001_Nfmk02M_N`03001JeU[F00QJeP8000E_N`03001JeU[F02UJeP030016<DHa
0816<@03000aS36<050aS003001oogoo005oo`004goo00<005[FF]H0<U[F0P00;U[F00D006mkKg]_
N`0002AJeP03001_Nfmk02M_N`03001JeU[F00YJeP03001_Nfmk00=_N`8002QJeP030016<DHa0896
<@03000aS36<04laS003001oogoo005oo`004goo00<005[FF]H0<U[F0P00;U[F00D006mkKg]_N`00
02AJeP03001_Nfmk02I_N`03001JeU[F00aJeP8000E_N`03001JeU[F02EJeP030016<DHa08=6<@03
000aS36<04haS003001oogoo005oo`004goo00<005[FF]H0<U[F0P00;e[F00D006mkKg]_N`00029J
eP03001_Nfmk02M_N`03001JeU[F00iJeP03001_Nfmk00=_N`8002AJeP030016<DHa08A6<@03000a
S36<04haS003001oogoo005oo`004goo00<005[FF]H0<U[F0P00<5[F00D006mkKg]_N`00025JeP03
001_Nfmk02M_N`03001JeU[F00mJeP8000E_N`03001JeU[F025JeP030016<DHa08E6<@03000aS36<
04daS003001oogoo005oo`004goo00<005[FF]H0<U[F0P00<5[F00<006mkKg/00Vmk00<005[FF]H0
7U[F00<006mkKg/09fmk00<005[FF]H04E[F00<006mkKg/00fmk00<005[FF]H07e[F00<004HaAS40
QdHa00<0036<<H`0C36<00<007ooOol00Goo000COol00`00F]IJeP0cF]H2000`F]H01@00Kg]_Nfmk
000085[F00<006mkKg/09Vmk00<005[FF]H04e[F0P0016mk0P007U[F00<004HaAS40R4Ha00<0036<
<H`0C36<00<007ooOol00Goo000COol00`00F]IJeP0cF]H2000aF]H01@00Kg]_Nfmk00007e[F00<0
06mkKg/09Vmk00<005[FF]H05E[F00<006mkKg/00fmk00<005[FF]H06e[F00<004HaAS40RDHa00<0
036<<H`0Bc6<00<007ooOol00Goo000COol00`00F]IJeP0cF]H2000bF]H01@00Kg]_Nfmk00007E[F
00<006mkKg/09fmk00<005[FF]H05U[F0P0016mk0P006U[F00<004HaAS40RdHa00<0036<<H`0BS6<
00<007ooOol00Goo000COol00`00F]IJeP0cF]H2000cF]H01000Kg]_N`007E[F00<006mkKg/09fmk
00<005[FF]H065[F00<006mkKg/00fmk00<005[FF]H05e[F00<004HaAS40RdHa00<0036<<H`0BS6<
00<007ooOol00Goo000COol00`00F]IJeP0cF]H2000cF]H01@00Kg]_Nfmk000075[F00<006mkKg/0
9fmk00<005[FF]H06E[F0P0016mk00<005[FF]H05E[F00<004HaAS40SDHa00<0036<<H`0BC6<00<0
07ooOol00Goo000COol3000cF]H2000dF]H01@00Kg]_Nfmk00006U[F00<006mkKg/09fmk00<005[F
F]H075[F00<006mkKg/00Vmk0P0055[F00<004HaAS40SdHa00<0036<<H`0B36<00<007ooOol00Goo
000COol00`00Kg]_N`03000aF]H2000dF]H01@00Kg]_Nfmk00006E[F00<006mkKg/09fmk00<005[F
F]H07E[F0P0016mk00<005[FF]H04E[F00<004HaAS40SdHa00<0036<<H`0B36<00<007ooOol00Goo
0008Ool30008Ool00`00Kg]_N`03Kg/3000^F]H2000eF]H01@00Kg]_Nfmk000065[F00<006mkKg/0
9fmk00<005[FF]H07e[F00<006mkKg/00Vmk00<005[FF]H03e[F00<004HaAS40TDHa00<0036<<H`0
Ac6<00<007ooOol00Goo0007Ool01@00Oomoogoo00001goo00<006mkKg/01Vmk1000:U[F0P00=E[F
00<006mkKg/00Vmk00<005[FF]H055[F00<006mkKg/09fmk00<005[FF]H08E[F0P000fmk00<005[F
F]H03U[F00<004HaAS40TDHa00<0036<<H`0Ac6<00<007ooOol00Goo0007Ool01@00Oomoogoo0000
1goo00<006mkKg/02Vmk1@009E[F0P00=U[F00<006mkKg/00Vmk00<005[FF]H04e[F00<006mkKg/0
9fmk00<005[FF]H08e[F00@006mkKg]_N`8000eJeP030016<DHa09=6<@03000aS36<04HaS003001o
ogoo005oo`001goo100027oo00<006mkKg/03fmk10008E[F0P00=e[F00<006mkKg/00Vmk00<005[F
F]H04U[F00<006mkKg/09fmk00<005[FF]H095[F0P000fmk00<005[FF]H02E[F00<004HaAS40UDHa
00<0036<<H`0AC6<00<007ooOol00Goo0007Ool00`00Oomoo`09Ool00`00Kg]_N`0CKg/5000LF]H2
000gF]H00`00Kg]_N`03Kg/00`00F]IJeP0@F]H00`00Kg]_N`0WKg/00`00F]IJeP0WF]H01000Kg]_
Nfmk0P002E[F00<004HaAS40UDHa00<0036<<H`0AC6<00<007ooOol00Goo0008Ool00`00Oomoo`08
Ool00`00Kg]_N`0HKg/4000HF]H2000hF]H00`00Kg]_N`02Kg/00`00F]IJeP0@F]H00`00Kg]_N`0W
Kg/00`00F]IJeP0XF]H20003Kg/00`00F]IJeP05F]H00`00AS56<@2GAS400`00<H`aS014<H`00`00
Oomoo`01Ool000Uoo`8000Qoo`03001_Nfmk01a_N`<001EJeP8003UJeP03001_Nfmk009_N`03001J
eU[F00mJeP03001_Nfmk02M_N`03001JeU[F02YJeP05001_NfmkKg/00005F]H00`00AS56<@2HAS40
0`00<H`aS014<H`00`00Oomoo`01Ool001=oo`03001_Nfmk01m_N`<0019JeP8003YJeP03001_Nfmk
009_N`03001JeU[F00iJeP03001_Nfmk02I_N`03001JeU[F02aJeP80009_N`8000=JeP030016<DHa
09U6<@03000aS36<04<aS003001oogoo005oo`004goo00<006mkKg/08Vmk10003e[F0P00>E[F00<0
06mkKg/00Vmk00<005[FF]H03E[F00<006mkKg/09fmk00<005[FF]H0;U[F00L006mkKg]_N`00F]H0
002LAS400`00<H`aS013<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02I_N`D000YJeP8003YJeP03
001_Nfmk009_N`03001JeU[F00aJeP03001_Nfmk02M_N`03001JeU[F02mJeP80009_N`H009U6<@03
000aS36<048aS003001oogoo005oo`004goo00<006mkKg/0:fmk10001U[F0P00>e[F00<006mkKg/0
0Vmk00<005[FF]H02e[F00<006mkKg/09fmk00<005[FF]H0<E[F00D006mkKg]_N`0000=JeQ/007i6
<@03000aS36<048aS003001oogoo005oo`004goo00<006mkKg/0;fmk1@0000=JeP000000>e[F00<0
06mkKg/00fmk00<005[FF]H02U[F00<006mkKg/09Vmk00<005[FF]H0<e[F0P000Vmk00<005[FF]H0
6e[F6`00I4Ha00<0036<<H`0@C6<00<007ooOol00Goo000COol00`00Kg]_N`0dKg/5000jF]H00`00
Kg]_N`02Kg/00`00F]IJeP0:F]H00`00Kg]_N`0VKg/00`00F]IJeP0eF]H00`00Kg]_N`02000fF]HK
001:AS400`00<H`aS010<H`00`00Oomoo`01Ool001=oo`03001_Nfmk03E_N`80009_N`D003IJeP03
001_Nfmk009_N`03001JeU[F00QJeP03001_Nfmk02M_N`03001JeU[F03IJeP80009_N`03001JeU[F
04iJeQ`002i6<@03000aS36<040aS003001oogoo005oo`004goo00<006mkKg/0=Fmk0P001fmk1@00
<U[F00<006mkKg/00Vmk00<005[FF]H01e[F00<006mkKg/09fmk00<005[FF]H0>5[F00@006mkKg/0
06]JeQ8001e6<@03000aS36<03laS003001oogoo005oo`004goo00<006mkKg/0=6mk0P003Fmk1@00
;U[F00D006mkKg]_N`0000UJeP03001_Nfmk02M_N`03001JeU[F03UJeP800003Kg/005[F07]JeQ80
00]6<@03000aS36<03laS003001oogoo005oo`004goo00<006mkKg/0=6mk0P004Vmk1000:U[F00<0
06mkKg/00Vmk00<005[FF]H01U[F00<006mkKg/09Vmk00<005[FF]H0?5[F00@006mk000008aJePl0
03haS003001oogoo005oo`004goo00<006mkKg/0=6mk0P005Vmk1@009U[F00<006mkKg/00Vmk00<0
05[FF]H015[F00<006mkKg/09fmk00<005[FF]H0?E[F0P0000=_N`00F]H0UU[F00<004HaAS401@00
>C6<00<007ooOol00Goo000COol00`00Kg]_N`0dKg/2000KKg/4000SF]H01@00Kg]_Nfmk00001U[F
00<006mkKg/09fmk00<005[FF]H0?e[F1000UE[F00<004HaAS401DHa1@00=36<00<007ooOol00Goo
000COol00`00Kg]_N`0dKg/2000OKg/3000QF]H01@00Kg]_Nfmk00001E[F00<006mkKg/09Vmk00<0
05[FF]H0@U[F00<006mk0000UE[F00<004HaAS402DHa1@00;c6<00<007ooOol00Goo000COol00`00
Kg]_N`0cKg/2000SKg/3000NF]H00`00Kg]_N`02Kg/01@00F]IJeU[F0000:Fmk00<005[FF]H0@e[F
1000Te[F00<004HaAS403THa1`00:36<00<007ooOol00Goo000COol00`00Kg]_N`0cKg/2000VKg/4
000KF]H00`00Kg]_N`02Kg/01000F]IJeP00:Fmk00<005[FF]H0AE[F0`00TU[F00<004HaAS405DHa
1P008S6<00<007ooOol00Goo000COol2000dKg/2000ZKg/5000GF]H01@00Kg]_Nfmk00000U[F00<0
06mkKg/09Vmk00<005[FF]H0B5[F0`00T5[F00<004HaAS406dHa1@007C6<00<007ooOol00Goo000C
Ool01000Kg/00000<Vmk0P00;fmk10004e[F00<006mkKg/00Vmk0P00:Fmk00<005[FF]H0BE[F0`00
Se[F00<004HaAS4084Ha1@00636<00<007ooOol00Goo000COol01000Kg]_Nfmk0P00<6mk0P00<fmk
1@003e[F00<006mkKg/00Vmk00<006mkKg/09fmk00<005[FF]H0Be[F0P00SU[F00<004HaAS409DHa
1@004c6<00<007ooOol00Goo000COol00`00Kg]_N`03Kg/00`00Kg]_N`0]Kg/2000hKg/70009F]H0
1@00Kg]_Nfmk0000:6mk00<005[FF]H0CE[F0`00S5[F00<004HaAS40:THa10003c6<00<007ooOol0
0Goo000COol00`00Kg]_N`04Kg/2000]Kg/2000oKg/60004F]H00`00Kg]_N`02000WKg/00`00F]IJ
eP1>F]H3002;F]H00`00AS56<@0^AS45000:<H`00`00Oomoo`01Ool001=oo`03001_Nfmk00I_N`80
02Y_N`8004I_N`<00004F]H006mk0002Ool00`00Kg]_N`0TKg/00`00F]IJeP1@F]H2002:F]H00`00
AS56<@0cAS440006<H`00`00Oomoo`01Ool001=oo`03001_Nfmk00Q_N`8002Q_N`8004U_N`@000=o
o`03001_Nfmk029_N`03001JeU[F059JeP8008UJeP030016<DHa03M6<@D00003<H`007oo009oo`00
4goo00<006mkKg/02Vmk0P009Vmk0P00C6mk00<007ooOol00Woo00<006mkKg/08Fmk00<005[FF]H0
De[F0`00Qe[F00<004HaAS40?4Ha0P000goo000COol00`00Kg]_N`0<Kg/2000TKg/2001<Kg/00`00
Oomoo`02Ool00`00Kg]_N`0PKg/00`00F]IJeP1EF]H30026F]H00`00AS56<@0mAS400`00Oomoo`01
Ool001=oo`03001_Nfmk00i_N`80029_N`8004e_N`03001oogoo009oo`03001_Nfmk01m_N`03001J
eU[F05MJeP<0081JePX003Y6<@03001oogoo005oo`004goo00<006mkKg/046mk00<006mkKg/07fmk
0P00CVmk00<007ooOol00Woo00<006mkKg/07Vmk00<005[FF]H0F5[F0`00MU[F2@0014Ha00<0036<
<H`00c6<4`009dHa00<007ooOol00Goo000COol00`00Kg]_N`0AKg/2000OKg/2001?Kg/00`00Oomo
o`02Ool00`00Kg]_N`0LKg/00`00F]IJeP1KF]H3001[F]H9000>AS400`00<H`aS00E<H`9000NAS40
0`00Oomoo`01Ool001=oo`03001_Nfmk01=_N`8001e_N`8004m_N`03001oogoo009oo`03001_Nfmk
01a_N`03001JeU[F05aJeP<0065JePT001Q6<@03000aS36<01daS0T001E6<@03001oogoo005oo`00
4goo00<006mkKg/05Fmk0P006fmk0P00D6mk00<007ooOol00Woo00<006mkKg/06Vmk00<005[FF]H0
Ge[F0`00EE[F2P008THa00<0036<<H`09C6<4P000dHa00<007ooOol00Goo000COol00`00Kg]_N`0G
Kg/2000HKg/2001BKg/00`00Oomoo`02Ool00`00Kg]_N`0IKg/00`00F]IJeP1PF]H3001;F]H9000]
AS400`00<H`aS00f<H`40003Ool001=oo`03001_Nfmk01U_N`8001I_N`8005=_N`05001oogooOol0
000JKg/00`00F]IJeP1SF]H2000hF]HB000fAS400`00<H`aS00i<H`00`00Oomoo`01Ool001=oo`03
001_Nfmk01]_N`03001_Nfmk01=_N`8005=_N`03001oogoo009oo`03001_Nfmk01M_N`03001JeU[F
06AJeP<002eJePT004U6<@03000aS36<03PaS003001oogoo005oo`004goo00<006mkKg/076mk0P00
4fmk0P00E6mk00<007ooOol00Woo00<006mkKg/05Vmk00<005[FF]H0IU[F0P008U[F2P00DdHa00<0
036<<H`0=c6<00<007ooOol00Goo000COol00`00Kg]_N`0NKg/2000AKg/2001EKg/00`00Oomoo`02
Ool00`00Kg]_N`0DKg/00`00F]IJeP1XF]H2000HF]H9001NAS400`00<H`aS00f<H`00`00Oomoo`01
Ool001=oo`03001_Nfmk021_N`8000m_N`8005E_N`03001oogoo009oo`03001_Nfmk01A_N`03001J
eU[F06YJeP03001JeU[F00=JeQ8006M6<@03000aS36<03HaS003001oogoo005oo`004goo00<006mk
Kg/08Vmk0P003Fmk0P00EVmk00<007ooOol00Woo00<006mkKg/04fmk00<005[FF]H0Je[F1@00NTHa
00<0036<<H`0=C6<00<007ooOol00Goo000COol00`00Kg]_N`0TKg/00`00Kg]_N`0:Kg/00`00Kg]_
N`1FKg/00`00Oomoo`02Ool00`00Kg]_N`0AKg/00`00F]IJeP1/F]H00`00AS56<@1mAS400`00<H`a
S00d<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02E_N`8000Y_N`03001_Nfmk05I_N`03001oogoo
009oo`03001_Nfmk015_N`03001JeU[F06aJeP030016<DHa07e6<@03000aS36<03@aS003001oogoo
005oo`004goo00<006mkKg/09fmk0P001fmk0P00FFmk00<007ooOol00Woo00<006mkKg/046mk00<0
05[FF]H0K5[F00<004HaAS40OTHa00<0036<<H`0<c6<00<007ooOol00Goo000COol00`00Kg]_N`0Y
Kg/20005Kg/2001JKg/00`00Oomoo`02Ool00`00Kg]_N`0>Kg/00`00F]IJeP1]F]H00`00AS56<@1n
AS400`00<H`aS00c<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02]_N`8000=_N`8005Y_N`03001o
ogoo00=oo`03001_Nfmk00e_N`03001JeU[F06eJeP030016<DHa07m6<@03000aS36<038aS003001o
ogoo005oo`004goo00<006mkKg/0;Fmk0P0000=_N`00Kg/0Ffmk00<007ooOol00goo00<006mkKg/0
36mk00<005[FF]H0KE[F00<004HaAS40P4Ha00<0036<<H`0<C6<00<007ooOol00Goo000COol00`00
Kg]_N`0_Kg/2001LKg/00`00Oomoo`03Ool00`00Kg]_N`0;Kg/00`00F]IJeP1^F]H00`00AS56<@20
AS400`00<H`aS00a<H`00`00Oomoo`01Ool001=oo`03001_Nfmk031_N`8005a_N`03001oogoo00=o
o`03001_Nfmk00Y_N`03001JeU[F06iJeP030016<DHa0856<@03000aS36<030aS003001oogoo005o
o`004goo00<006mkKg/0<6mk00@006mk000005]_N`03001oogoo00=oo`03001_Nfmk00U_N`03001J
eU[F06iJeP030016<DHa0856<@03000aS36<030aS003001oogoo005oo`004goo00<006mkKg/0<6mk
00@006mkKg]_N`8005U_N`03001oogoo00Aoo`03001_Nfmk00M_N`03001JeU[F06mJeP030016<DHa
0896<@03000aS36<02laS003001oogoo005oo`004goo00<006mkKg/0;fmk0P001Fmk0P00F6mk00<0
07ooOol00goo00<006mkKg/01fmk00<005[FF]H0Ke[F00<004HaAS40PdHa00<0036<<H`0;S6<00<0
07ooOol00Goo000COol00`00Kg]_N`0_Kg/20007Kg/2001FKg/00`00Oomoo`04Ool00`00Kg]_N`06
Kg/00`00F]IJeP1_F]H00`00AS56<@23AS400`00<H`aS00^<H`00`00Oomoo`01Ool001=oo`03001_
Nfmk02m_N`8000U_N`8005E_N`03001oogoo00Aoo`03001_Nfmk00A_N`03001JeU[F071JeP030016
<DHa08A6<@03000aS36<02daS003001oogoo005oo`004goo00<006mkKg/0;fmk0P002fmk00<006mk
Kg/0DVmk00<007ooOol017oo00<006mkKg/016mk00<005[FF]H0L5[F00<004HaAS40QDHa00<0036<
<H`0;36<00<007ooOol00Goo000COol00`00Kg]_N`0_Kg/2000<Kg/2001CKg/00`00Oomoo`04Ool0
0`00Kg]_N`03Kg/00`00F]IJeP1`F]H00`00AS56<@25AS400`00<H`aS00/<H`00`00Oomoo`01Ool0
01=oo`03001_Nfmk02m_N`8000i_N`80059_N`03001oogoo00Aoo`05001_NfmkKg/0001cF]H00`00
AS56<@26AS400`00<H`aS00[<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02m_N`80011_N`80051_
N`03001oogoo00Eoo`04001_Nfmk001cF]H00`00AS56<@27AS400`00<H`aS00Z<H`00`00Oomoo`01
Ool001=oo`03001_Nfmk02m_N`03001_Nfmk015_N`8004m_N`03001oogoo00Aoo`04001_Nfmk001c
F]H00`00AS56<@27AS400`00<H`aS00Z<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02m_N`03001_
Nfmk01=_N`03001_Nfmk04e_N`03001oogoo00Aoo`8007AJeP030016<DHa08Q6<@03000aS36<02Ta
S003001oogoo005oo`004goo00<006mkKg/0;fmk00<006mkKg/056mk0P00CFmk00<007ooOol01Goo
00<005[FF]H0LU[F00<004HaAS40RDHa00<0036<<H`0:36<00<007ooOol00Goo000COol00`00Kg]_
N`0_Kg/00`00Kg]_N`0FKg/2001<Kg/00`00Oomoo`04Ool2001cF]H00`00AS56<@2:AS400`00<H`a
S00W<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02m_N`03001_Nfmk01Q_N`8004]_N`03001oogoo
00Aoo`80079JeP030016<DHa08]6<@03000aS36<02HaS003001oogoo005oo`004goo00<006mkKg/0
;Vmk00<006mkKg/06fmk0P00BFmk00<007ooOol017oo00<006mk0000L5[F00<004HaAS40S4Ha00<0
036<<H`09S6<00<007ooOol00Goo000COol00`00Kg]_N`0^Kg/00`00Kg]_N`0MKg/20018Kg/00`00
Oomoo`04Ool00`00Kg/0001_F]H00`00AS56<@2=AS400`00<H`aS00U<H`00`00Oomoo`01Ool001=o
o`03001_Nfmk02i_N`03001_Nfmk01m_N`8004M_N`03001oogoo00=oo`04001_Nfmk001^F]H00`00
AS56<@2>AS400`00<H`aS00T<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02i_N`03001_Nfmk025_
N`03001_Nfmk04A_N`03001oogoo00Aoo`04001_Nfmk001]F]H00`00AS56<@2?AS400`00<H`aS00S
<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02i_N`03001_Nfmk029_N`8004E_N`03001oogoo00=o
o`05001_NfmkKg/0001/F]H00`00AS56<@2?AS400`00<H`aS00S<H`00`00Oomoo`01Ool001=oo`03
001_Nfmk02i_N`03001_Nfmk02A_N`8004A_N`03001oogoo00=oo`05001_NfmkKg/0001[F]H00`00
AS56<@2@AS400`00<H`aS00R<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02e_N`8002Q_N`80049_
N`03001oogoo00=oo`05001_NfmkKg/0001[F]H00`00AS56<@2AAS400`00<H`aS00Q<H`00`00Oomo
o`01Ool001=oo`03001_Nfmk02e_N`8000a_Nb40041_N`03001oogoo00=oo`05001_NfmkKg/0001Z
F]H00`00AS56<@2AAS400`00<H`aS00Q<H`00`00Oomoo`01Ool001=oo`03001_Nfmk02Q_Na<0025J
ePD003a_N`03001oogoo009oo`03001_Nfmk009_N`03001JeU[F06MJeP030016<DHa0996<@03000a
S36<020aS003001oogoo005oo`004goo00<006mkKg/05Fmk4`001E[F0P00<U[F1000>6mk00<007oo
Ool00goo00<006mkKg/00Vmk00<005[FF]H0IU[F00<004HaAS40TdHa00<0036<<H`07c6<00<007oo
Ool00Goo000COol00`00Kg]_N`0<Kg/9000HF]H2000fF]H5000dKg/00`00Oomoo`03Ool00`00Kg]_
N`02Kg/00`00F]IJeP1UF]H00`00AS56<@2CAS400`00<H`aS00O<H`00`00Oomoo`01Ool001=oo`03
001_Nfmk009_N`X0025JeP03001JeU[F03YJePH002m_N`03001oogoo009oo`03001_Nfmk00=_N`03
001JeU[F06AJeP030016<DHa09A6<@03000aS36<01haS003001oogoo005oo`0027oo0`0027oo1@00
:e[F00<005[FF]H0@5[F1P00:Fmk00<007ooOol00goo00<006mkKg/00fmk00<005[FF]H0He[F00<0
04HaAS40UDHa00<0036<<H`07C6<00<007ooOol00Goo0007Ool01@00Oomoogoo00001goo00<005[F
F]H0;5[F0P00B5[F1@009Fmk00<007ooOol00Woo00<006mkKg/016mk00<005[FF]H0HU[F00<004Ha
AS40UDHa00<0036<<H`07C6<00<007ooOol00Goo0007Ool01@00Oomoogoo00001goo00<005[FF]H0
;5[F0P00CE[F10008Vmk00<007ooOol00Woo00<006mkKg/016mk00<005[FF]H0HE[F00<004HaAS40
UTHa00<0036<<H`0736<00<007ooOol00Goo0008Ool30008Ool00`00F]IJeP0/F]H2001AF]H3000O
Kg/00`00Oomoo`02Ool00`00Kg]_N`04Kg/00`00F]IJeP1QF]H00`00AS56<@2GAS400`00<H`aS00K
<H`00`00Oomoo`01Ool000Moo`05001oogooOol00007Ool00`00F]IJeP0/F]H00`00F]IJeP1CF]H3
000MKg/00`00Oomoo`02Ool00`00Kg]_N`04Kg/00`00F]IJeP1PF]H00`00AS56<@2GAS400`00<H`a
S00K<H`00`00Oomoo`01Ool000Moo`05001oogooOol00007Ool00`00F]IJeP0/F]H00`00F]IJeP1F
F]H3000KKg/01@00Oomoogoo00001fmk00<005[FF]H0Ge[F00<004HaAS40V4Ha00<0036<<H`06S6<
00<007ooOol00Goo0008Ool30008Ool00`00F]IJeP0/F]H00`00F]IJeP1IF]H5000FKg/00`00Oomo
o`02Ool00`00Kg]_N`05Kg/00`00F]IJeP1MF]H00`00AS56<@2JAS400`00<H`aS00I<H`00`00Oomo
o`01Ool001=oo`03001JeU[F02aJeP03001JeU[F05iJeP@001=_N`05001oogooOol00008Kg/00`00
F]IJeP1LF]H00`00AS56<@2JAS400`00<H`aS00I<H`00`00Oomoo`01Ool001=oo`03001JeU[F02]J
eP8006AJePD000m_N`04001oogoo0009Kg/00`00F]IJeP1KF]H00`00AS56<@2KAS400`00<H`aS00H
<H`00`00Oomoo`01Ool001=oo`03001JeU[F02]JeP8006UJeP@000]_N`05001oogooOol00009Kg/0
0`00F]IJeP1JF]H00`00AS56<@2LAS400`00<H`aS00G<H`00`00Oomoo`01Ool001=oo`03001JeU[F
02]JeP8006eJePD000M_N`04001oogoo000:Kg/00`00F]IJeP1IF]H00`00AS56<@2LAS400`00<H`a
S00G<H`00`00Oomoo`01Ool001=oo`03001JeU[F02]JeP03001JeU[F075JeP@000A_N`04001oogoo
000:Kg/00`00F]IJeP1HF]H00`00AS56<@2MAS400`00<H`aS00F<H`00`00Oomoo`01Ool001=oo`03
001JeU[F02]JeP03001JeU[F07EJeP<00005Kg/007ooOol0000:Kg/00`00F]IJeP1HF]H00`00AS56
<@2NAS400`00<H`aS00E<H`00`00Oomoo`01Ool001=oo`03001JeU[F02YJeP8007YJeP<0009oo`03
001_Nfmk00Q_N`03001JeU[F05MJeP030016<DHa09i6<@03000aS36<01DaS003001oogoo005oo`00
4goo00<005[FF]H0:U[F0P00OE[F00@007ooOol000Y_N`03001JeU[F05IJeP030016<DHa09m6<@03
000aS36<01@aS003001oogoo005oo`004goo00<005[FF]H0:U[F0P00OE[F00D007ooOomoo`0000Y_
N`03001JeU[F05EJeP030016<DHa0:16<@03000aS36<01<aS003001oogoo005oo`004goo00<005[F
F]H0:U[F0P00OE[F0P000Woo00<006mkKg/02Fmk00<005[FF]H0E5[F00<004HaAS40X4Ha00<0036<
<H`04c6<00<007ooOol00Goo000COol00`00F]IJeP0ZF]H2001nF]H20002Ool00`00Kg]_N`09Kg/0
0`00F]IJeP1CF]H00`00AS56<@2QAS400`00<H`aS00B<H`00`00Oomoo`01Ool001=oo`03001JeU[F
02YJeP03001JeU[F07eJeP8000=oo`03001_Nfmk00U_N`03001JeU[F059JeP030016<DHa0:96<@03
000aS36<014aS003001oogoo005oo`004goo00<005[FF]H0:U[F00<005[FF]H0OE[F00<006mk0000
0goo00<006mkKg/02Fmk00<005[FF]H0DE[F00<004HaAS40XTHa00<0036<<H`04C6<00<007ooOol0
0Goo000COol00`00F]IJeP0YF]H2001oF]H00`00Kg/00003Ool00`00Kg]_N`0:Kg/00`00F]IJeP1@
F]H00`00AS56<@2SAS400`00<H`aS00@<H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP8007mJ
eP04001_Nfmk0003Ool00`00Kg]_N`09Kg/00`00F]IJeP1@F]H00`00AS56<@2SAS400`00<H`aS00@
<H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP80081JeP04001_Nfmk0002Ool00`00Kg]_N`0:
Kg/00`00F]IJeP1?F]H00`00AS56<@2TAS400`00<H`aS00?<H`00`00Oomoo`01Ool001=oo`03001J
eU[F02UJeP03001JeU[F07mJeP04001_Nfmk0003Ool00`00Kg]_N`0:Kg/00`00F]IJeP1>F]H00`00
AS56<@2TAS400`00<H`aS00?<H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP03001JeU[F07mJ
eP05001_NfmkKg/00003Ool00`00Kg]_N`0:Kg/00`00F]IJeP1<F]H00`00AS56<@2VAS400`00<H`a
S00><H`00`00Oomoo`01Ool001=oo`03001JeU[F02UJeP03001JeU[F07mJeP05001_NfmkKg/00003
Ool00`00Kg]_N`0;Kg/00`00F]IJeP1;F]H00`00AS56<@2VAS400`00<H`aS00><H`00`00Oomoo`01
Ool001=oo`03001JeU[F02UJeP03001JeU[F07mJeP03001_Nfmk009_N`05001oogooOol0000=Kg/0
0`00F]IJeP1:F]H00`00AS56<@2WAS400`00<H`aS00=<H`00`00Oomoo`01Ool001=oo`03001JeU[F
02QJeP80089JeP03001_Nfmk009_N`04001oogoo000>Kg/00`00F]IJeP19F]H00`00AS56<@2WAS40
0`00<H`aS00=<H`00`00Oomoo`01Ool001=oo`03001JeU[F02QJeP80089JeP03001_Nfmk009_N`05
001oogooOol0000>Kg/00`00F]IJeP18F]H00`00AS56<@2XAS400`00<H`aS00<<H`00`00Oomoo`01
Ool001=oo`03001JeU[F02QJeP80089JeP03001_Nfmk00=_N`04001oogoo000?Kg/00`00F]IJeP17
F]H00`00AS56<@2XAS400`00<H`aS00<<H`00`00Oomoo`01Ool001=oo`03001JeU[F02QJeP03001J
eU[F085JeP03001_Nfmk00A_N`04001oogoo000>Kg/00`00F]IJeP17F]H00`00AS56<@2YAS400`00
<H`aS00;<H`00`00Oomoo`01Ool001=oo`03001JeU[F02QJeP03001JeU[F085JeP03001_Nfmk00E_
N`03001oo`0000m_N`03001JeU[F04IJeP030016<DHa0:Y6<@03000aS36<00XaS003001oogoo005o
o`004goo00<005[FF]H09e[F0P00Q5[F00<006mkKg/016mk00@007ooOol000m_N`03001JeU[F04EJ
eP030016<DHa0:Y6<@03000aS36<00XaS003001oogoo005oo`004goo00<005[FF]H09e[F0P00Q5[F
00<006mkKg/01Fmk00@007ooOol000m_N`03001JeU[F04=JeP030016<DHa0:a6<@03000aS36<00Ta
S003001oogoo005oo`004goo00<005[FF]H09e[F0P00Q5[F00<006mkKg/01Vmk00<007oo000046mk
00<005[FF]H0@U[F00<004HaAS40[DHa00<0036<<H`0236<00<007ooOol00Goo000COol00`00F]IJ
eP0WF]H20025F]H00`00Kg]_N`05Kg/01000Oomoo`003fmk00<005[FF]H0@U[F00<004HaAS40[DHa
00<0036<<H`0236<00<007ooOol00Goo000COol00`00F]IJeP0WF]H20025F]H00`00Kg]_N`06Kg/0
0`00Ool0000@Kg/00`00F]IJeP11F]H00`00AS56<@2^AS400`00<H`aS007<H`00`00Oomoo`01Ool0
01=oo`03001JeU[F02MJeP03001JeU[F08AJeP03001_Nfmk00M_N`03001oo`00011_N`03001JeU[F
041JeP030016<DHa0:m6<@03000aS36<00HaS003001oogoo005oo`004goo00<005[FF]H09e[F00<0
05[FF]H0QE[F00<006mkKg/01Vmk00<007oo00004Fmk00<005[FF]H0?e[F00<004HaAS40[dHa00<0
036<<H`01S6<00<007ooOol00Goo000COol00`00F]IJeP0VF]H20027F]H00`00Kg]_N`07Kg/00`00
Ool0000@Kg/00`00F]IJeP0oF]H00`00AS56<@2`AS400`00<H`aS005<H`00`00Oomoo`01Ool001=o
o`03001JeU[F02IJeP8008MJeP03001_Nfmk00Q_N`03001oo`00011_N`03001JeU[F03iJeP030016
<DHa0;56<@03000aS36<00@aS003001oogoo005oo`004goo00<005[FF]H09U[F0P00R5[F00<006mk
Kg/026mk0P004Fmk00<005[FF]H0?E[F00<004HaAS40/DHa00<0036<<H`0136<00<007ooOol00Goo
000COol00`00F]IJeP0VF]H00`00F]IJeP27F]H00`00Kg]_N`08Kg/00`00Ool0000AKg/00`00F]IJ
eP0kF]H00`00AS56<@2cAS400`00<H`aS003<H`00`00Oomoo`01Ool001=oo`03001JeU[F02IJeP03
001JeU[F08MJeP03001_Nfmk00U_N`80019_N`03001JeU[F03YJeP030016<DHa0;A6<@03000aS36<
008aS003001oogoo005oo`004goo00<005[FF]H09U[F00<005[FF]H0Qe[F00<006mkKg/02Vmk0P00
4Vmk00<005[FF]H0>E[F00<004HaAS40]4Ha00<0036<<H`00S6<00<007ooOol00Goo000COol00`00
F]IJeP0VF]H00`00F]IJeP28F]H00`00Kg]_N`09Kg/00`00Ool0000BKg/00`00F]IJeP0hF]H00`00
AS56<@2eAS401@00<H`aS36<00000goo000COol00`00F]IJeP0UF]H2002:F]H00`00Kg]_N`0:Kg/2
000CKg/00`00F]IJeP0gF]H00`00AS56<@2fAS401000<H`aS0000goo000COol00`00F]IJeP0UF]H2
002:F]H00`00Kg]_N`0;Kg/2000CKg/00`00F]IJeP0fF]H00`00AS56<@2fAS401000<H`aS0000goo
000COol00`00F]IJeP0UF]H2002:F]H00`00Kg]_N`0;Kg/00`00Ool0000BKg/00`00F]IJeP0fF]H0
0`00AS56<@2gAS400`00<H`00003Ool001=oo`03001JeU[F02EJeP03001JeU[F08UJeP03001_Nfmk
00a_N`8001=_N`03001JeU[F03EJeP030016<DHa0;Q6<@8000=oo`004goo00<005[FF]H09E[F00<0
05[FF]H0RU[F00<006mkKg/036mk0P004fmk00<005[FF]H0=5[F00<004HaAS40^DHa00<007ooOol0
0Goo000COol00`00F]IJeP0TF]H2002<F]H00`00Kg]_N`0=Kg/2000CKg/00`00F]IJeP0bF]H00`00
AS56<@2jAS400`00Oomoo`01Ool001=oo`03001JeU[F02AJeP8008aJeP03001_Nfmk00e_N`8001A_
N`03001JeU[F035JeP030016<DHa0;Y6<@03001oogoo005oo`004goo00<005[FF]H095[F0P00S5[F
00<006mkKg/03Vmk0P004fmk00<005[FF]H0<E[F00<004HaAS40^THa00<007ooOol00Goo000COol0
0`00F]IJeP0TF]H2002=F]H00`00Kg]_N`0>Kg/2000CKg/00`00F]IJeP0`F]H00`00AS56<@2jAS40
0`00Oomoo`01Ool001=oo`03001JeU[F02AJeP8008eJeP03001_Nfmk00i_N`@0019_N`03001JeU[F
02mJeP030016<DHa0;Y6<@03001oogoo005oo`004goo00<005[FF]H095[F00<005[FF]H0S5[F00<0
06mkKg/03fmk0P0000=_N`0000004Fmk00<005[FF]H0;U[F00<004HaAS40^THa00<007ooOol00Goo
000COol00`00F]IJeP0TF]H00`00F]IJeP2=F]H00`00Kg]_N`0?Kg/01@00Kg]_Nfmk000046mk00<0
05[FF]H0;U[F00<004HaAS40^THa00<007ooOol00Goo000COol00`00F]IJeP0SF]H2002?F]H00`00
Kg]_N`0?Kg/00`00Kg]_N`02Kg/2000?Kg/00`00F]IJeP0]F]H00`00AS56<@2jAS400`00Oomoo`01
Ool001=oo`03001JeU[F02=JeP8008mJeP03001_Nfmk011_N`03001_Nfmk00=_N`8000i_N`03001J
eU[F02aJeP030016<DHa0;Y6<@03001oogoo005oo`004goo00<005[FF]H08e[F0P00T5[F00<006mk
Kg/03fmk00<006mkKg/01Fmk0P003Fmk00<005[FF]H0:U[F00<004HaAS40^dHa00<007ooOol00Goo
000COol00`00F]IJeP0SF]H00`00F]IJeP2?F]H00`00Kg]_N`0@Kg/00`00Kg]_N`06Kg/2000<Kg/0
0`00F]IJeP0YF]H00`00AS56<@2kAS400`00Oomoo`01Ool001=oo`03001JeU[F02=JeP03001JeU[F
08mJeP03001_Nfmk011_N`8000U_N`03001_Nfmk00U_N`03001JeU[F02UJeP030016<DHa0;]6<@03
001oogoo005oo`004goo00<005[FF]H08e[F00<005[FF]H0Se[F00<006mkKg/046mk0P002Vmk0P00
2Vmk00<005[FF]H0:5[F00<004HaAS40^dHa00<007ooOol00Goo000COol00`00F]IJeP0SF]H00`00
F]IJeP2@F]H00`00Kg]_N`0@Kg/2000;Kg/20009Kg/00`00F]IJeP0WF]H00`00AS56<@2kAS400`00
Oomoo`01Ool001=oo`03001JeU[F029JeP03001JeU[F095JeP03001_Nfmk011_N`8000e_N`8000Q_
N`03001JeU[F02IJeP030016<DHa0;]6<@03001oogoo005oo`004goo00<005[FF]H08U[F00<005[F
F]H0TE[F00<006mkKg/04Fmk0P003Vmk0P001Vmk00<005[FF]H09U[F00<004HaAS40^dHa00<007oo
Ool00Goo000COol00`00F]IJeP0RF]H00`00F]IJeP2BF]H00`00Kg]_N`0AKg/00`00Kg]_N`0>Kg/2
0005Kg/00`00F]IJeP0UF]H00`00AS56<@2kAS400`00Oomoo`01Ool001=oo`03001JeU[F029JeP03
001JeU[F099JeP03001_Nfmk015_N`03001_Nfmk011_N`8000A_N`03001JeU[F02AJeP030016<DHa
0;]6<@03001oogoo005oo`004goo00<005[FF]H08U[F00<005[FF]H0TU[F00<006mkKg/04Vmk00<0
06mkKg/04Fmk0P000fmk00<005[FF]H08U[F00<004HaAS40_4Ha00<007ooOol00Goo000COol00`00
F]IJeP0QF]H00`00F]IJeP2DF]H00`00Kg]_N`0AKg/00`00Kg]_N`0CKg/20002Kg/00`00F]IJeP0Q
F]H00`00AS56<@2lAS400`00Oomoo`01Ool001=oo`03001JeU[F025JeP03001JeU[F09AJeP03001_
Nfmk019_N`03001_Nfmk01A_N`800003Kg/005[F025JeP030016<DHa0;a6<@03001oogoo005oo`00
4goo00<005[FF]H08E[F00<005[FF]H0U5[F00<006mkKg/04fmk00<006mkKg/05Fmk00<006mk0000
8E[F00<004HaAS40_4Ha00<007ooOol00Goo000COol00`00F]IJeP0QF]H00`00F]IJeP2DF]H00`00
Kg]_N`0CKg/00`00Kg]_N`0FKg/3000PF]H00`00AS56<@2lAS400`00Oomoo`01Ool001=oo`03001J
eU[F021JeP8009MJeP03001_Nfmk01=_N`03001_Nfmk01M_N`8001mJeP030016<DHa0;a6<@03001o
ogoo005oo`004goo00<005[FF]H085[F0P00Ue[F00<006mkKg/04fmk00<006mkKg/066mk0`007E[F
00<004HaAS40_4Ha00<007ooOol00Goo000COol00`00F]IJeP0PF]H2002GF]H00`00Kg]_N`0CKg/2
000JKg/01000F]H000006e[F00<004HaAS40_4Ha00<007ooOol00Goo0002Ool30004Ool20008Ool0
0`00F]IJeP0PF]H00`00F]IJeP2FF]H00`00Kg]_N`0DKg/2000JKg/01000F]IJeP006U[F00<004Ha
AS40_4Ha00<007ooOol00Goo0003Ool00`00Oomoo`02Ool01000Oomoo`001goo00<005[FF]H085[F
00<005[FF]H0UU[F00<006mkKg/056mk00<005[F00006Fmk00@005[FF]IJeP8001MJeP030016<DHa
0;e6<@03001oogoo005oo`000goo00<007ooOol00Woo00@007ooOol000Moo`03001JeU[F01mJeP80
09UJeP03001_Nfmk01=_N`04001JeU[F000IKg/00`00F]IJeP02F]H2000EF]H00`00AS56<@2mAS40
0`00Oomoo`01Ool000=oo`03001oogoo009oo`04001oogoo0007Ool00`00F]IJeP0OF]H2002IF]H0
0`00Kg]_N`0CKg/01@00F]IJeU[F000066mk00<005[FF]H015[F0P004e[F00<004HaAS40_DHa00<0
07ooOol00Goo0003Ool00`00Oomoo`02Ool01000Oomoo`001goo00<005[FF]H07e[F0P00VE[F00<0
06mkKg/04fmk00<005[FF]H00U[F00<006mkKg/05Vmk00<005[FF]H01E[F0P004E[F00<004HaAS40
_DHa00<007ooOol00Goo0002Ool20004Ool01000Oomoo`001goo00<005[FF]H07e[F0P00VE[F00<0
06mkKg/056mk00<005[FF]H00U[F00<006mkKg/05Vmk00<005[FF]H01U[F0P003e[F00<004HaAS40
_DHa00<007ooOol00Goo0003Ool00`00Oomoo`03Ool20008Ool00`00F]IJeP0OF]H2002JF]H00`00
Kg]_N`0CKg/00`00F]IJeP03F]H00`00Kg]_N`0EKg/00`00F]IJeP08F]H2000=F]H00`00AS56<@2m
AS400`00Oomoo`01Ool001=oo`03001JeU[F01mJeP03001JeU[F09UJeP03001_Nfmk01=_N`03001J
eU[F00=JeP03001_Nfmk01I_N`03001JeU[F00UJeP8000]JeP030016<DHa0;e6<@03001oogoo005o
o`004goo00<005[FF]H07e[F00<005[FF]H0VE[F00<006mkKg/04fmk00<005[FF]H015[F00<006mk
Kg/05Fmk00<005[FF]H02e[F00<005[FF]H01e[F00<004HaAS40_THa00<007ooOol00Goo000COol0
0`00F]IJeP0NF]H2002LF]H00`00Kg]_N`0CKg/00`00F]IJeP04F]H00`00Kg]_N`0EKg/00`00F]IJ
eP0;F]H20007F]H00`00AS56<@2nAS400`00Oomoo`01Ool001=oo`03001JeU[F01iJeP8009aJeP03
001_Nfmk01=_N`03001JeU[F00EJeP03001_Nfmk01E_N`03001JeU[F00aJeP03001JeU[F00AJeP03
0016<DHa0;i6<@03001oogoo005oo`004goo00<005[FF]H07U[F0P00W5[F00<006mkKg/04fmk00<0
05[FF]H01U[F00<006mkKg/056mk00<005[FF]H03E[F0P0015[F00<004HaAS40_THa00<007ooOol0
0Goo000COol00`00F]IJeP0NF]H00`00F]IJeP2LF]H00`00Kg]_N`0BKg/00`00F]IJeP07F]H00`00
Kg]_N`0DKg/00`00F]IJeP0>F]H01@00F]IJeU[F0000`4Ha00<007ooOol00Goo000COol00`00F]IJ
eP0NF]H00`00F]IJeP2LF]H00`00Kg]_N`0BKg/00`00F]IJeP08F]H00`00Kg]_N`0DKg/00`00F]IJ
eP0>F]H30031AS400`00Oomoo`01Ool001=oo`03001JeU[F01iJeP03001JeU[F09aJeP03001_Nfmk
01=_N`03001JeU[F00QJeP03001_Nfmk01=_N`03001JeU[F011JeP800<16<@03001oogoo005oo`00
4goo00<005[FF]H07U[F00<005[FF]H0WE[F00<006mkKg/04Vmk00<005[FF]H02E[F00<006mkKg/0
4fmk00<005[FF]H03e[F00@004Ha00000;i6<@03001oogoo005oo`004goo00<005[FF]H07E[F00<0
05[FF]H0WU[F00<006mkKg/04Vmk00<005[FF]H02U[F00<006mkKg/04fmk00<005[FF]H03U[F00D0
04HaAS56<@000;e6<@03001oogoo005oo`004goo00<005[FF]H07E[F00<005[FF]H0WU[F00<006mk
Kg/04Vmk00<005[FF]H02e[F00<006mkKg/04Vmk00<005[FF]H03U[F00<004HaAS400THa0P00^dHa
00<007ooOol00Goo000COol00`00F]IJeP0MF]H00`00F]IJeP2OF]H00`00Kg]_N`0BKg/00`00F]IJ
eP0;F]H00`00Kg]_N`0BKg/00`00F]IJeP0>F]H00`00AS56<@03AS42002iAS400`00Oomoo`01Ool0
01=oo`03001JeU[F01eJeP03001JeU[F09mJeP03001_Nfmk019_N`03001JeU[F00aJeP03001_Nfmk
019_N`03001JeU[F00eJeP030016<DHa00E6<@800;M6<@03001oogoo005oo`004goo00<005[FF]H0
7E[F00<005[FF]H0We[F00<006mkKg/04Vmk00<005[FF]H03E[F00<006mkKg/04Fmk00<005[FF]H0
3E[F00<004HaAS401dHa0P00]DHa00<007ooOol00Goo000COol00`00F]IJeP0LF]H00`00F]IJeP2Q
F]H00`00Kg]_N`0AKg/00`00F]IJeP0>F]H00`00Kg]_N`0AKg/00`00F]IJeP0<F]H00`00AS56<@09
AS42002cAS400`00Oomoo`01Ool001=oo`03001JeU[F01aJeP03001JeU[F0:5JeP03001_Nfmk015_
N`03001JeU[F00mJeP03001_Nfmk015_N`03001JeU[F00]JeP030016<DHa00]6<@800;56<@03001o
ogoo005oo`004goo00<005[FF]H075[F00<005[FF]H0XE[F00<006mkKg/04Vmk00<005[FF]H03e[F
00<006mkKg/046mk00<005[FF]H02e[F00<004HaAS403DHa0P00[dHa00<007ooOol00Goo000COol0
0`00F]IJeP0LF]H00`00F]IJeP2QF]H00`00Kg]_N`0BKg/00`00F]IJeP0@F]H00`00Kg]_N`0@Kg/0
0`00F]IJeP0:F]H00`00AS56<@0?AS42002]AS400`00Oomoo`01Ool001=oo`03001JeU[F01aJeP03
001JeU[F0:9JeP03001_Nfmk015_N`03001JeU[F015JeP03001_Nfmk011_N`03001JeU[F00UJeP03
0016<DHa0156<@800:]6<@03001oogoo005oo`004goo00<005[FF]H06e[F00<005[FF]H0Xe[F00<0
06mkKg/04Fmk00<005[FF]H04E[F00<006mkKg/046mk00<005[FF]H02E[F00<004HaAS404dHa00<0
04HaAS40Z4Ha00<007ooOol00Goo000COol00`00F]IJeP0KF]H00`00F]IJeP2SF]H00`00Kg]_N`0B
Kg/00`00F]IJeP0AF]H00`00Kg]_N`0@Kg/00`00F]IJeP08F]H00`00AS56<@0DAS42002XAS400`00
Oomoo`01Ool001=oo`03001JeU[F01]JeP03001JeU[F0:AJeP03001_Nfmk015_N`03001JeU[F019J
eP03001_Nfmk011_N`03001JeU[F00MJeP030016<DHa01I6<@800:I6<@03001oogoo005oo`004goo
00<005[FF]H06e[F00<005[FF]H0Y5[F00<006mkKg/04Fmk00<005[FF]H04e[F00<006mkKg/03fmk
00<005[FF]H01e[F00<004HaAS4064Ha0P00Y4Ha00<007ooOol00Goo000COol00`00F]IJeP0KF]H0
0`00F]IJeP2TF]H00`00Kg]_N`0AKg/00`00F]IJeP0DF]H00`00Kg]_N`0?Kg/00`00F]IJeP06F]H0
0`00AS56<@0JAS42002RAS400`00Oomoo`01Ool001=oo`03001JeU[F01YJeP03001JeU[F0:IJeP03
001_Nfmk011_N`03001JeU[F01AJeP03001_Nfmk011_N`03001JeU[F00EJeP030016<DHa01a6<@03
0016<DHa09m6<@03001oogoo005oo`004goo00<005[FF]H06U[F00<005[FF]H0YU[F00<006mkKg/0
4Fmk00<005[FF]H055[F00<006mkKg/03fmk00<005[FF]H01E[F00<004HaAS407DHa0P00WdHa00<0
07ooOol00Goo000COol00`00F]IJeP0JF]H00`00F]IJeP2VF]H00`00Kg]_N`0AKg/00`00F]IJeP0E
F]H00`00Kg]_N`0?Kg/00`00F]IJeP04F]H00`00AS56<@0OAS42002MAS400`00Oomoo`01Ool001=o
o`03001JeU[F01YJeP03001JeU[F0:MJeP03001_Nfmk011_N`03001JeU[F01IJeP03001_Nfmk00m_
N`03001JeU[F00=JeP030016<DHa0256<@8009]6<@03001oogoo005oo`004goo00<005[FF]H06U[F
00<005[FF]H0Ye[F00<006mkKg/046mk00<005[FF]H05e[F00<006mkKg/03Vmk00<005[FF]H00e[F
00<004HaAS408dHa0P00VDHa00<007ooOol00Goo000COol00`00F]IJeP0JF]H00`00F]IJeP2WF]H0
0`00Kg]_N`0AKg/00`00F]IJeP0FF]H00`00Kg]_N`0?Kg/00`00F]IJeP02F]H00`00AS56<@0UAS42
002GAS400`00Oomoo`01Ool001=oo`03001JeU[F01UJeP03001JeU[F0:UJeP03001_Nfmk011_N`03
001JeU[F01MJeP03001_Nfmk00m_N`05001JeU[FF]H0000YAS42002EAS400`00Oomoo`01Ool001=o
o`03001JeU[F01UJeP03001JeU[F0:UJeP03001_Nfmk011_N`03001JeU[F01QJeP03001_Nfmk00i_
N`05001JeU[FF]H0000[AS42002CAS400`00Oomoo`01Ool001=oo`03001JeU[F01UJeP03001JeU[F
0:UJeP03001_Nfmk011_N`03001JeU[F01UJeP03001_Nfmk00i_N`04001JeU[F000]AS400`00AS56
<@2@AS400`00Oomoo`01Ool001=oo`03001JeU[F01UJeP03001JeU[F0:YJeP03001_Nfmk00m_N`03
001JeU[F01YJeP03001_Nfmk00e_N`04001JeU[F000^AS42002@AS400`00Oomoo`01Ool001=oo`03
001JeU[F01UJeP03001JeU[F0:YJeP03001_Nfmk011_N`03001JeU[F01YJeP03001_Nfmk00e_N`03
001JeP000316<@030016<DHa08e6<@03001oogoo005oo`004goo00<005[FF]H06E[F00<005[FF]H0
ZU[F00<006mkKg/046mk00<005[FF]H06e[F00<006mkKg/03Fmk0P00<DHa0P00SDHa00<007ooOol0
0Goo000COol00`00F]IJeP0IF]H00`00F]IJeP2ZF]H00`00Kg]_N`0@Kg/00`00F]IJeP0LF]H00`00
Kg]_N`0<Kg/2000cAS400`00AS56<@2:AS400`00Oomoo`01Ool001=oo`03001JeU[F01QJeP03001J
eU[F0:aJeP03001_Nfmk00m_N`03001JeU[F01eJeQ0003A6<@8008Y6<@03001oogoo005oo`004goo
00<005[FF]H065[F00<005[FF]H0[5[F00<006mkKg/03fmk00<005[FF]H07E[F00<005[FF]H035[F
00<004HaAS40=4Ha0P00R4Ha00<007ooOol00Goo000COol00`00F]IJeP0HF]H00`00F]IJeP2/F]H0
0`00Kg]_N`0@Kg/00`00F]IJeP0LF]H2000>F]H00`00AS56<@0eAS420026AS400`00Oomoo`01Ool0
01=oo`03001JeU[F01QJeP03001JeU[F0:eJeP03001_Nfmk00m_N`03001JeU[F01eJeP03001JeU[F
00aJeP030016<DHa03M6<@030016<DHa08=6<@03001oogoo005oo`004goo00<005[FF]H065[F00<0
05[FF]H0[E[F00<006mkKg/03fmk00<005[FF]H07E[F0P003U[F00<004HaAS40=dHa0P00PdHa00<0
07ooOol00Goo000COol00`00F]IJeP0GF]H00`00F]IJeP2^F]H00`00Kg]_N`0?Kg/00`00F]IJeP0M
F]H00`00AS40000=F]H00`00AS56<@0iAS420021AS400`00Oomoo`01Ool001=oo`03001JeU[F01MJ
eP03001JeU[F0:mJeP03001_Nfmk00i_N`03001JeU[F01eJeP030016<@0000iJeP030016<DHa03Y6
<@8007m6<@03001oogoo005oo`004goo00<005[FF]H05e[F00<005[FF]H0[e[F00<006mkKg/03fmk
00<005[FF]H075[F00@004HaAS4000eJeP030016<DHa03a6<@8007e6<@03001oogoo005oo`004goo
00<005[FF]H05e[F00<005[FF]H0[e[F00<006mkKg/03fmk00<005[FF]H07E[F00<004Ha00003U[F
00<004HaAS40?DHa0P00NdHa00<007ooOol00Goo000COol00`00F]IJeP0GF]H00`00F]IJeP2`F]H0
0`00Kg]_N`0>Kg/00`00F]IJeP0MF]H01000AS56<@003U[F00<004HaAS40?THa0P00NDHa00<007oo
Ool00Goo000COol00`00F]IJeP0FF]H00`00F]IJeP2aF]H00`00Kg]_N`0?Kg/00`00F]IJeP0LF]H0
1000AS56<@003U[F00<004HaAS40@4Ha0P00MdHa00<007ooOol00Goo000COol00`00F]IJeP0FF]H0
0`00F]IJeP2aF]H00`00Kg]_N`0?Kg/00`00F]IJeP0LF]H01@00AS56<DHa00003U[F00<004HaAS40
@DHa0P00MDHa00<007ooOol00Goo000COol00`00F]IJeP0FF]H00`00F]IJeP2bF]H00`00Kg]_N`0>
Kg/00`00F]IJeP0LF]H01@00AS56<DHa00003U[F00<004HaAS40@dHa0P00LdHa00<007ooOol00Goo
000COol00`00F]IJeP0FF]H00`00F]IJeP2bF]H00`00Kg]_N`0?Kg/00`00F]IJeP0KF]H00`00AS56
<@02AS400`00F]IJeP0<F]H00`00AS56<@14AS400`00AS56<@1`AS400`00Oomoo`01Ool001=oo`03
001JeU[F01IJeP03001JeU[F0;9JeP03001_Nfmk00m_N`03001JeU[F01aJeP030016<DHa0096<@03
001JeU[F00]JeP030016<DHa04E6<@800716<@03001oogoo005oo`004goo00<005[FF]H05E[F00<0
05[FF]H0]5[F00<006mkKg/03Vmk00<005[FF]H075[F00<004HaAS400THa00<005[FF]H035[F00<0
04HaAS40ATHa0P00KTHa00<007ooOol00Goo000COol00`00F]IJeP0EF]H00`00F]IJeP2dF]H00`00
Kg]_N`0?Kg/00`00F]IJeP0KF]H00`00AS56<@03AS400`00F]IJeP0;F]H00`00AS56<@18AS42001/
AS400`00Oomoo`01Ool001=oo`03001JeU[F01EJeP03001JeU[F0;AJeP03001_Nfmk00m_N`03001J
eU[F01]JeP030016<DHa00=6<@03001JeU[F00aJeP030016<DHa04U6<@8006Y6<@03001oogoo005o
o`004goo00<005[FF]H05E[F00<005[FF]H0]5[F00<006mkKg/03fmk00<005[FF]H06e[F00<004Ha
AS4014Ha00<005[FF]H02e[F00<004HaAS40BdHa00<004HaAS40IdHa00<007ooOol00Goo000COol0
0`00F]IJeP0DF]H00`00F]IJeP2fF]H00`00Kg]_N`0>Kg/00`00F]IJeP0KF]H00`00AS56<@04AS40
0`00F]IJeP0<F]H00`00AS56<@1;AS42001WAS400`00Oomoo`01Ool001=oo`03001JeU[F01AJeP03
001JeU[F0;IJeP03001_Nfmk00m_N`03001JeU[F01YJeP030016<DHa00E6<@03001JeU[F00aJeP03
0016<DHa04a6<@8006E6<@03001oogoo005oo`004goo00<005[FF]H055[F00<005[FF]H0]U[F00<0
06mkKg/03fmk00<005[FF]H06e[F00<004HaAS4014Ha00<005[FF]H035[F00<004HaAS40CTHa0P00
HdHa00<007ooOol00Goo000COol00`00F]IJeP0DF]H00`00F]IJeP2gF]H00`00Kg]_N`0>Kg/00`00
F]IJeP0KF]H00`00AS56<@05AS400`00F]IJeP0<F]H00`00AS56<@1?AS400`00AS56<@1PAS400`00
Oomoo`01Ool001=oo`03001JeU[F01AJeP03001JeU[F0;MJeP03001_Nfmk00i_N`03001JeU[F01]J
eP030016<DHa00E6<@03001JeU[F00aJeP030016<DHa0516<@800616<@03001oogoo005oo`004goo
00<005[FF]H04e[F00<005[FF]H0^5[F00<006mkKg/03Vmk00<005[FF]H06e[F00<004HaAS401THa
00<005[FF]H035[F00<004HaAS40DDHa0P00GTHa00<007ooOol00Goo000COol00`00F]IJeP0CF]H0
0`00F]IJeP2iF]H00`00Kg]_N`0>Kg/00`00F]IJeP0KF]H00`00AS56<@05AS400`00F]IJeP0<F]H0
0`00AS56<@1CAS400`00AS56<@1KAS400`00Oomoo`01Ool001=oo`03001JeU[F01=JeP03001JeU[F
0;UJeP03001_Nfmk00i_N`03001JeU[F01]JeP030016<DHa00I6<@03001JeU[F00aJeP030016<DHa
05=6<@8005]6<@03001oogoo005oo`004goo00<005[FF]H04e[F00<005[FF]H0^E[F00<006mkKg/0
3Vmk00<005[FF]H06e[F00<004HaAS401THa00<005[FF]H035[F00<004HaAS40EDHa0P00FDHa00<0
07ooOol00Goo000COol00`00F]IJeP0CF]H00`00F]IJeP2jF]H00`00Kg]_N`0>Kg/00`00F]IJeP0J
F]H00`00AS56<@07AS400`00F]IJeP0<F]H00`00AS56<@1FAS42001GAS400`00Oomoo`01Ool001=o
o`03001JeU[F019JeP03001JeU[F0;]JeP03001_Nfmk00i_N`03001JeU[F01]JeP030016<DHa00I6
<@03001JeU[F00eJeP030016<DHa05M6<@030016<DHa05A6<@03001oogoo005oo`004goo00<005[F
F]H04U[F00<005[FF]H0^e[F00<006mkKg/03Vmk00<005[FF]H06e[F00<004HaAS401dHa00<005[F
F]H035[F00<004HaAS40F4Ha0P00E4Ha00<007ooOol00Goo000COol00`00F]IJeP0BF]H00`00F]IJ
eP2lF]H00`00Kg]_N`0>Kg/00`00F]IJeP0JF]H00`00AS56<@07AS400`00F]IJeP0=F]H00`00AS56
<@1IAS42001BAS400`00Oomoo`01Ool0009oo`<0009oo`D000Moo`03001JeU[F019JeP03001JeU[F
0;aJeP03001_Nfmk00i_N`03001JeU[F01YJeP030016<DHa00Q6<@03001JeU[F00aJeP030016<DHa
05]6<@800516<@03001oogoo005oo`000goo00<007ooOol00Woo00@007ooOol000Moo`03001JeU[F
019JeP03001JeU[F0;aJeP03001_Nfmk00i_N`03001JeU[F01YJeP030016<DHa00Q6<@03001JeU[F
00eJeP030016<DHa05a6<@030016<DHa04e6<@03001oogoo005oo`000goo00<007ooOol00goo00<0
07ooOol01goo00<005[FF]H04E[F00<005[FF]H0_U[F00<006mkKg/03Vmk00<005[FF]H06U[F00<0
04HaAS4024Ha00<005[FF]H035[F00<004HaAS40GDHa0P00CDHa00<007ooOol00Goo0003Ool00`00
Oomoo`04Ool00`00Oomoo`06Oooo003>0003Ool000=oo`05001oogooOol00003Ool00`00Oomoo`3o
OooFOol0009oo`8000=oo`05001oogooOol0003oOooHOol000=oo`03001oogoo009oo`<00?moomUo
o`00ogooi7oo003oOooTOol00001\
\>"],
  ImageRangeCache->{{{0, 482}, {482, 0}} -> {617.187, -0.420141, 0.652181, \
0.0260655}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["contour data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["runs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\


(*------------------------------*)
(*  ksp pl bi g mu (liq = 0.1)  *) 

{{8.00, 751.8},
{9.00, 757.9},
{10.00, 764.4},
{11.00, 771.3},
{12.00, 778.7}};

(*------------------------------*)
(*  ksp pl bi g mu (liq = 0.1 sill)  *) 

{9.37, 760.3};

(*------------------------------*)
(*  ksp pl bi g sill (liq = 0.1 mu)  *) 

{6.59, 717.0};

(*------------------------------*)
(*  ksp pl bi sill (liq = 0.1 g)  *) 

{5.47, 723.2};

(*------------------------------*)
(*  ksp pl bi sill (liq = 0.1 cd)  *) 

{4.28, 709.5};

(*------------------------------*)
(*  ksp pl bi cd sill (liq = 0.1 H2O)  *) 

{3.19, 664.2};

(*___________________________________________________*)

(*------------------------------*)
(*  ksp bi g mu sill (liq = 0.2)  *) 

{{8.00, 744.7},
{8.50, 753.8},
{9.00, 762.9},
{9.50, 771.9},
{10.00, 780.8},
{10.50, 789.6}};

(*------------------------------*)
(*  ksp bi g sill (liq = 0.2 mu)  *) 

{7.99, 744.4};

(*------------------------------*)
(*  ksp bi g sill (liq = 0.2 pl)  *) 

{6.33, 744.6};

(*------------------------------*)
(*  ksp pl bi g sill (liq = 0.2)  *) 

{{4.00, 745.3},
{4.50, 746.1},
{5.00, 746.4},
{5.50, 746.1},
{6.00, 745.4}};

(*------------------------------*)
(*  ksp pl bi g sill (liq = 0.2 cd)  *) 

{5.29, 746.3};

(*------------------------------*)
(*  ksp pl bi cd g (liq = 0.2 sill)  *) 

{4.75, 732.1};

(*------------------------------*)
(*  ksp pl bi cd (liq = 0.2 g)  *) 

{2.48, 742.6};

(*------------------------------*)
(*  ksp pl bi cd (liq = 0.2 H2O)  *) 

{1.42, 716.6},

(*___________________________________________________*)


(*------------------------------*)
(*  ksp bi g sill (liq = 0.3)  *) 

{{5.00, 778.4},
{6.00, 784.0},
{7.00, 788.3},
{8.00, 791.3},
{9.00, 793.2},
{10.00, 794.2},
{11.00, 794.6},
{12.00, 794.2}};

(*------------------------------*)
(*  ksp bi g sill (liq = 0.3 cd)  *) 

{6.35, 785.6};

(*------------------------------*)
(*  ksp bi cd g (liq = 0.3 sill)  *) 

{5.99, 774.9};

(*------------------------------*)
(*  ksp bi cd g (liq = 0.3)  *) 

{{2.00, 758.3},
{2.50, 763.5},
{3.00, 767.6},
{3.50, 770.8},
{4.00, 773.1},
{4.50, 774.6},
{5.00, 775.4},
{5.50, 775.5},
{6.00, 774.9}};

(*------------------------------*)
(*  ksp bi cd g (liq = 0.3 opx)  *) 

{3.14, 768.6};

(*------------------------------*)
(*  ksp bi cd g opx (liq = 0.3 pl)  *) 

{2.76, 761.1};

(*------------------------------*)
(*  ksp pl bi cd opx (liq = 0.3 g)  *) 

{2.38, 754.1};

(*------------------------------*)
(*  ksp pl bi cd opx (liq = 0.3)  *) 

{{1.00, 733.7},
{1.25, 737.6},
{1.50, 741.4},
{1.75, 745.1},
{2.00, 748.7},
{2.25, 752.3},
{2.50, 755.7},
{2.75, 759.0},
{3.00, 762.3}};

(*___________________________________________________*)

(*------------------------------*)
(*  ksp g sill (liq = 0.4) *)

{{6.00, 814.8},
{8.00, 850.6}, 
{10.00, 883.1}, 
{12.00, 912.9}};

(*------------------------------*)
(*  ksp g sill (liq = 0.4  cd) *)

{6.95, 832.3};

(*------------------------------*)
(*  ksp cd g (liq = 0.4  sill) *)

{6.26, 842.1};

(*------------------------------*)
(*  ksp cd g (liq = 0.4  opx)  *) 

{4.72, 818.1};

(*------------------------------*)
(*  ksp cd g opx (liq = 0.4  pl)  *) 

{2.76, 781.3};

(*------------------------------*)
(*  ksp pl cd opx (liq = 0.4  g)  *) 

{2.66, 780.0};

(*------------------------------*)
(*  ksp pl cd opx (liq = 0.4  H2O)  *) 

{1.08, 746.7};


(*___________________________________________________*)

(*------------------------------*)
(*  ksp g sill (liq = 0.5 )  *) 

{{6.00, 868.8},
{7.00, 888.0},
{8.00, 906.4},
{9.00, 924.0},
{10.00, 940.9}};

(*------------------------------*)
(*  ksp g sill (liq = 0.5 cd)  *) 

{6.76, 883.5};

(*------------------------------*)
(*  ksp cd g (liq = 0.5 sill)  *) 

{6.34, 884.5};

(*------------------------------*)
(*  ksp cd g (liq = 0.5 opx)  *) 

{4.90, 862.6};

(*------------------------------*)
(*  ksp cd opx (liq = 0.5 g)  *) 

{3.20, 828.7};

(*------------------------------*)
(*  ksp cd opx (liq = 0.5)  *) 

{{1.00, 782.8},
{1.25, 788.4},
{1.50, 793.9},
{1.75, 799.3},
{2.00, 804.6},
{2.25, 809.9},
{2.50, 815.0},
{2.75, 820.0},
{3.00, 824.9},
{3.25, 829.7},
{3.50, 834.5},
{3.75, 839.1},
{4.00, 843.6}}


(*___________________________________________________*)

(*------------------------------*)
(*  cd g (liq = 0.6 opx)  *) 

{5.59, 942.6};

(*------------------------------*)
(*  cd opx (liq g)  *) 

{4.27, 908.3};

(*------------------------------*)
(*  cd opx (liq = 0.6)  *) 

{{1.00, 858.4},
{2.00, 874.2},
{3.00, 889.7},
{4.00, 904.5}};

(*------------------------------*)
(*  cd opx (liq H2O)  *) 

{0.64, 852.5};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["contours assembled", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
lc1 = Map[Reverse,
      {{3.19, 664.2},
       {4.28, 709.5},
       {5.47, 723.2},
       {6.59, 717.0},
       {9.37, 760.3},
       
       {10.00, 764.4},
       {11.00, 771.3},
       {12.00, 778.7}}];
       
lc2 = Map[Reverse,
       {{1.42, 716.6},
        {2.48, 742.6},
        {4.75, 732.1},
        {5.29, 746.3},
        {6.33, 744.6},
        {7.99, 744.4},
        {9.00, 762.9},
        {10.00, 780.8}}];

lc3 = Map[Reverse,
        {{1.00, 733.7},
         {2.38, 754.1},
         {2.76, 761.1},
         {3.14, 768.6},
         {4.00, 773.1},
         {5.00, 775.4},
         {5.99, 774.9},
         {6.35, 785.6},
         {7.00, 788.3},
         {8.00, 791.3},
         {9.00, 793.2},
         {10.00, 794.2}}];

lc4 = Map[Reverse,
       {{1.08, 746.7},
        {2.66, 780.0},
        {4.72, 818.1},
        {6.26, 842.1},
        {6.95, 832.3},
        {8.00, 850.6},  
        {10.00, 883.1} }];
        
lc5 = Map[Reverse,
        {{1.00, 782.8},
        {1.50, 793.9},
        {2.00, 804.6},
        {2.50, 815.0},
        {3.20, 828.7},
        {4.90, 862.6},
        {6.34, 884.5},
        {6.76, 883.5},
        {8.00, 906.4},
        {9.00, 924.0},
        {10.00, 940.9} }];
        
lc6 = Map[Reverse,
       {{0.64, 852.5},
        {1.00, 858.4},
        {2.00, 874.2},
        {3.00, 889.7},
        {4.27, 908.3},
        {5.59, 942.6} }];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["contour drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["draw function", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{2,1};\n   \n \n \t\tas1 = makeline[ka, trp, ll];\n \t\tas2 = makeline[sk, \
trp, i7];\n \t\tas3 = makeline[as, trp, lr];\n \t\tas21 = makeline[sk, i10, \
ur];\n \t\t\n \t\tlu1 = makeline[u1, ul, i1];\n \t\tlu2 = makeline[u2, i2, \
i50];\n \t\tlu3 = makeline[u3, ul, i1];\n \t\tlu4 = makeline[u4, i2, ll];\n \t\
\tlu5 = makeline[u5, i1, i3];\n \t\tlu6 = makeline[u6, i2, i3];\n \t\tlu7 = \
makeline[u7, ul, i4];\n \t\tlu8 = makeline[u8, i4, i5];\n \t\tlu9 = \
makeline[u9, i5, i6];\n \t\tlu10 = makeline[u10, i49, i6];\n \t\tlu11 = \
makeline[u11, i1, i4];\n \t\tlu12 = makeline[u12, i2, i6];\n \t\tlu13 = \
makeline[u13, i8, ur];\n \t\tlu14 = makeline[u14, i4, i7];\n \t\tlu15 = \
makeline[u15, i7, i8];\n \t\tlu16 = makeline[u16, i9, i8];\n \t\tlu17 = \
makeline[u17, i6, i9];\n \t\tlu18 = makeline[u18, i11, ur];\n \t\tlu19 = \
makeline[u19, i11, i15];\n \t\tlu20 = makeline[u20, i8, i10];\n \t\tlu21 = \
makeline[u21, i10, i11];\n \t\tlu22 = makeline[u22, i14, i12];\n \t\tlu23 = \
makeline[u23, i12, i11];\n \t\tlu24 = makeline[u24, i13, i16];\n \t\tlu25 = \
makeline[u25, i13, i14];\n \t\tlu26 = makeline[u26, i15, ur];\n \t\tlu27 = \
makeline[u27, i15, ur];\n \t\tlu28 = makeline[u28, i16, ur];\n \t\tlu29 = \
makeline[u29, i16, i15];\n \t\tlu30 = makeline[u30, i14, i17];\n \t\tlu31 = \
makeline[u31, i14, i18];\n \t\tlu32 = makeline[u32, i18, i23];\n \t\tlu33 = \
makeline[u33, i49, i9];\n \t\tlu34 = makeline[u34, i48, i17];\n \t\tlu35 = \
makeline[u35, i19, i17];\n \t\tlu36 = connect[i9, i17];\n \t\tlu37 = \
makeline[u37, i18, i19];\n \t\tlu38 = makeline[u38, i45, i19];\n \t\tlu39 = \
makeline[u39, i20, i23];\n \t\tlu40 = makeline[u40, i20, i21];\n \t\tlu41 = \
makeline[u41, i21, i22];\n \t\tlu42 = makeline[u42, i43, i22];\n \t\tlu43 = \
connect[i18, i21];\n \t\tlu44 = connect[i19, i22];\n \t\tlu45 = makeline[u45, \
i25, i20];\n \t\tlu46 = makeline[u46, i33, i20];\n \t\tlu47 = makeline[u47, \
i24, i23];\n \t\tlu48 = makeline[u48, i16, i24];\n \t\tlu49 = makeline[u49, \
i23, i34];\n \t\tlu50 = makeline[u50, i21, i26];\n \t\tlu51 = makeline[u51, \
i22, i27];\n \t\tlu52 = makeline[u52, i25, i26];\n \t\tlu53 = makeline[u53, \
i26, i27];\n \t\tlu54 = makeline[u54, i25, i28];\n \t\tlu55 = makeline[u55, \
i28, i29];\n \t\tlu56 = makeline[u56, i25, i30];\n \t\tlu57 = connect[i26, \
i28];\n \t\tlu58 = connect[i27, i29];\n \t\tlu59 = makeline[u59, i30, i31];\n \
\t\tlu60 = makeline[u60, i31, i32];\n \t\tlu61 = makeline[u61, i28, i32];\n \t\
\tlu62 = makeline[u62, i29, i32];\n \t\tlu63 = makeline[u63, i29, i39];\n \t\t\
lu64 = makeline[u64, i32, i38];\n \t\tlu65 = makeline[u65, i31, i37];\n \t\t\
lu66 = makeline[u66, i31, ur];\n \t\tlu67 = makeline[u67, i33, i30];\n \t\t\
lu68 = makeline[u68, i33, i34];\n \t\tlu69 = makeline[u69, ur, i34];\n \t\t\
lu70 = makeline[u70, i35, i34];\n \t\tlu71 = makeline[u71, ur, i35];\n \t\t\
lu72 = makeline[u72, lr, i35];\n \t\tlu73 = makeline[u73, ur, i30];\n \t\t\
lu74 = makeline[u74, i35, i33];\n \t\tlu75 = makeline[u75, i37, i36];\n \t\t\
lu76 = makeline[u76, ur, i36];\n \t\tlu77 = makeline[u77, lr, i36];\n \t\t\
lu78 = makeline[u78, lr, i36];\n \t\tlu79 = makeline[u79, lr, i37];\n \t\t\
lu80 = makeline[u80, lr, ul];\n \t\tlu81 = makeline[u81, i37, i38];\n \t\t\
lu82 = makeline[u82, lr, i38];\n \t\tlu83 = makeline[u83, i39, i38];\n \t\t\
lu84 = makeline[u84, i40, lr];\n \t\tlu85 = makeline[u85, i27, i41];\n \t\t\
lu86 = makeline[u86, i39, i41];\n \t\tlu87 = makeline[u87, i41, i42];\n \t\t\
lu88 = makeline[u88, i40, ll];\n \t\tlu89 = makeline[u89, i39, i40];\n \t\t\
lu90 = connect[i40, i42];\n \t\tlu91 = makeline[u91, i42, ll];\n \t\tlu92 = \
makeline[u92, i41, i43];\n \t\tlu93 = makeline[u93, i42, i44];\n \t\tlu94 = \
makeline[u94, i44, i51];\n \t\tlu95 = makeline[u95, i46,i52];\n \t\tlu96 = \
connect[i43, i44];\n \t\tlu97 = connect[i43, i45];\n \t\tlu98 = connect[i45, \
i46];\n \t\tlu99 = connect[i44, i46];\n \t\tlu100 = makeline[u100, i45, i48];\
\n \t\tlu101 = makeline[u101, i46, i47];\n \t\tlu102 = makeline[u102, i47, \
i52];\n \t\tlu103 = makeline[u103, i50, i53];\n \t\tlu104 = connect[i47, \
i48];\n \t\tlu105 = connect[i49, i48];\n \t\tlu106 = connect[i49, i50];\n \t\t\
lu107 = connect[i47, i50];\n \t\tlu108 = makeline[u108, ll, i53];\n \t\tlu109 \
= makeline[u109, i51, i52];\n \t\tlu110 = connect[i52, i53];\n  \t \n   \
Show[Graphics[\n   \t\t\t\t\t\t\t{GrayLevel[0.85],\n          \
area[{lu1,lu11,lu7}],\n          area[{lu13,lu20,lu21,lu18}],\n          \
area[{lu19,lu29,lu24,lu25,lu22,lu23}],\n          area[{lu52,lu54,lu57}],\n   \
       area[{lu61,lu55,lu62}],\n          area[{lu3,lu5,lu6,lu4}],\n          \
area[{lu14,lu15,lu16,lu17,lu9,lu8}],\n          area[{lu82,lu83,lu89,lu84}], \
\n          area[{lu58,lu63,lu86,lu85}],\n          \
area[{lu41,lu50,lu53,lu51}],\n          area[{lu91,lu90,lu88}],\n          \
area[{lu92,lu87,lu93,lu96}],\n          area[{lu32,lu39,lu40,lu43}],\n        \
  area[{lu30,lu31,lu37,lu35}],\n          area[{lu94,lu99,lu95}],\n          \
area[{lu38,lu44,lu42,lu97}],\n          area[{lu98,lu100,lu104,lu101}],\n     \
     area[{lu33,lu36,lu34,lu105}],\n         \n              \n          \n   \
       GrayLevel[0.7],\n          area[{lu1,lu3}],\n          \
area[{lu7,lu14,lu15,lu13}],\n          area[{lu18,lu19,lu26}],\n          \
area[{lu27,lu29,lu28}],\n          area[{lu25,lu24,lu48,lu47,lu32,lu31}],\n   \
       area[{lu49,lu68,lu46,lu39}],\n          \
area[{lu54,lu56,lu59,lu60,lu61}], \n          area[{lu40,lu45,lu52,lu50}],\n  \
        area[{lu84,lu88}],\n          area[{lu62,lu64,lu83,lu63}],\n          \
area[{lu51,lu85,lu92,lu42}],\n          area[{lu91,lu93,lu94}],\n          \
area[{lu34,lu35,lu38,lu100}],\n          area[{lu95,lu102,lu101}],\n          \
area[{lu4,lu2,lu103,lu108}],\n          area[{lu33,lu10,lu17}],\n          \n \
          \n          GrayLevel[0.55],\n          area[{lu26,lu27}],\n        \
  area[{lu28,lu48,lu47,lu49,lu69}],\n          area[{lu70,lu68,lu74}],\n      \
    area[{lu66,lu59,lu73}],\n          area[{lu56,lu45,lu46,lu67}], \n        \
  area[{lu60,lu65,lu81,lu64}],\n          area[{lu79,lu75,lu77}],\n          \
\n          \n          GrayLevel[0.4], \n          area[{lu69,lu70,lu71}],\n \
         area[{lu73,lu67,lu74,lu72}],\n          area[{lu66,lu65,lu75,lu76}],\
\n          area[{lu77,lu78}],\n          \n          GrayLevel[0.25],\n      \
    area[{lu71,lu72}],\n          area[{lu76,lu78}],\n   \n          \
GrayLevel[0],\n           AbsoluteThickness[0.3],\n         \n           \
drawline[as1],\n           drawline[as2],\n           drawline[as21],\n       \
   \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu1],\n          \tdrawline[lu2],\n          \t\
drawline[lu3],\n          \tdrawline[lu4],\n          \tdrawline[lu5],\n      \
    \tdrawline[lu6],\n          \t\n          \tdrawline[lu7],\n          \t\
drawline[lu8],\n          \tdrawline[lu9],\n          \tdrawline[lu10],\n     \
     \tdrawline[lu11],\n          \tdrawline[lu12],\n          \t\
drawline[lu13],\n          \tdrawline[lu14],\n          \tdrawline[lu15],\n   \
       \tdrawline[lu16],\n          \tdrawline[lu17],\n          \t\
drawline[lu18],\n          \t\n          \tdrawline[lu19],\n          \t\
drawline[lu20],\n          \tdrawline[lu21],\n          \tdrawline[lu22],\n   \
       \tdrawline[lu23],\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu24],\n          \tdrawline[lu25],\n          \t\
drawline[lu26],\n          \tdrawline[lu27],\n          \tdrawline[lu28],\n   \
       \tdrawline[lu29],\n          \tdrawline[lu30],\n          \t\
drawline[lu31],\n          \t\n          \tdrawline[lu32],\n          \t\
drawline[lu33],\n          \t\n          \tdrawline[lu34],\n          \t\
drawline[lu35],\n          \tdrawline[lu36],\n          \tdrawline[lu37],\n   \
       \tdrawline[lu38],\n          \tdrawline[lu39],\n          \t\
drawline[lu40],\n          \tdrawline[lu41],\n          \tdrawline[lu42],\n   \
       \tdrawline[lu43],\n          \tdrawline[lu44],\n          \t\
drawline[lu45],\n          \tdrawline[lu46],\n          \t\n          \t\
drawline[lu47],\n          \tdrawline[lu48],\n          \tdrawline[lu49],\n   \
       \tdrawline[lu50],\n          \tdrawline[lu51],\n          \t\
drawline[lu52],\n          \tdrawline[lu53],\n          \tdrawline[lu54],\n   \
       \tdrawline[lu55],\n          \tdrawline[lu56],\n          \t\n         \
 \tdrawline[lu57],\n          \tdrawline[lu58],\n          \tdrawline[lu59],\n\
          \tdrawline[lu60],\n          \tdrawline[lu61],\n          \t\
drawline[lu62],\n          \tdrawline[lu63],\n          \tdrawline[lu64],\n   \
       \tdrawline[lu65],\n          \tdrawline[lu66],\n          \t\
drawline[lu67],\n          \tdrawline[lu68],\n          \tdrawline[lu69],\n   \
       \tdrawline[lu70],\n          \tdrawline[lu71],\n          \t\
drawline[lu72],\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu73],\n          \tdrawline[lu74],\n          \t\
drawline[lu75],\n          \tdrawline[lu76],\n          \tdrawline[lu77],\n   \
       \tdrawline[lu78],\n          \tdrawline[lu79],\n          \t\n         \
 \tdrawline[lu81],\n          \tdrawline[lu82],\n          \tdrawline[lu83],\n\
          \tdrawline[lu84],\n          \tdrawline[lu85],\n          \t\
drawline[lu86],\n          \tdrawline[lu87],\n          \tdrawline[lu88],\n   \
       \tdrawline[lu89],\n          \tdrawline[lu90],\n          \t\
drawline[lu91],\n          \tdrawline[lu92],\n          \tdrawline[lu93],\n   \
       \tdrawline[lu94],\n          \tdrawline[lu95],\n          \t\
drawline[lu96],\n          \tdrawline[lu97],\n          \tdrawline[lu98],\n   \
       \tdrawline[lu99],\n          \tdrawline[lu100],\n          \t\
drawline[lu101],\n          \tdrawline[lu102],\n          \tdrawline[lu103],\n\
          \tdrawline[lu104],\n          \tdrawline[lu105],\n          \t\
drawline[lu106],\n          \tdrawline[lu107],\n          \tdrawline[lu108],\n\
          \tdrawline[lu109],\n          \tdrawline[lu110],\n           \n     \
      drawline[lc1],\n           drawline[lc2],\n           drawline[lc3],\n  \
         drawline[lc4],\n           drawline[lc5],\n           drawline[lc6],\
\n           \n           outline}],\n               \n         AspectRatio \
-> 1, Frame -> True,\n         PlotRange -> {{xlow, xhigh}, {ylow, yhigh}} \
]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 630; xhigh = 930; ylow = 0.01; yhigh = 12;
drawing;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.1 0.00333333 -0.000834028 0.0834028 [
[(650)] .06667 0 0 2 Msboxa
[(700)] .23333 0 0 2 Msboxa
[(750)] .4 0 0 2 Msboxa
[(800)] .56667 0 0 2 Msboxa
[(850)] .73333 0 0 2 Msboxa
[(900)] .9 0 0 2 Msboxa
[(2)] -0.0125 .16597 1 0 Msboxa
[(4)] -0.0125 .33278 1 0 Msboxa
[(6)] -0.0125 .49958 1 0 Msboxa
[(8)] -0.0125 .66639 1 0 Msboxa
[(10)] -0.0125 .83319 1 0 Msboxa
[(12)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06667 0 m
.06667 .00625 L
s
P
[(650)] .06667 0 0 2 Mshowa
p
.002 w
.23333 0 m
.23333 .00625 L
s
P
[(700)] .23333 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(750)] .4 0 0 2 Mshowa
p
.002 w
.56667 0 m
.56667 .00625 L
s
P
[(800)] .56667 0 0 2 Mshowa
p
.002 w
.73333 0 m
.73333 .00625 L
s
P
[(850)] .73333 0 0 2 Mshowa
p
.002 w
.9 0 m
.9 .00625 L
s
P
[(900)] .9 0 0 2 Mshowa
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.33333 0 m
.33333 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.66667 0 m
.66667 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .16597 m
.00625 .16597 L
s
P
[(2)] -0.0125 .16597 1 0 Mshowa
p
.002 w
0 .33278 m
.00625 .33278 L
s
P
[(4)] -0.0125 .33278 1 0 Mshowa
p
.002 w
0 .49958 m
.00625 .49958 L
s
P
[(6)] -0.0125 .49958 1 0 Mshowa
p
.002 w
0 .66639 m
.00625 .66639 L
s
P
[(8)] -0.0125 .66639 1 0 Mshowa
p
.002 w
0 .83319 m
.00625 .83319 L
s
P
[(10)] -0.0125 .83319 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(12)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .03253 m
.00375 .03253 L
s
P
p
.001 w
0 .06589 m
.00375 .06589 L
s
P
p
.001 w
0 .09925 m
.00375 .09925 L
s
P
p
.001 w
0 .13261 m
.00375 .13261 L
s
P
p
.001 w
0 .19933 m
.00375 .19933 L
s
P
p
.001 w
0 .23269 m
.00375 .23269 L
s
P
p
.001 w
0 .26606 m
.00375 .26606 L
s
P
p
.001 w
0 .29942 m
.00375 .29942 L
s
P
p
.001 w
0 .36614 m
.00375 .36614 L
s
P
p
.001 w
0 .3995 m
.00375 .3995 L
s
P
p
.001 w
0 .43286 m
.00375 .43286 L
s
P
p
.001 w
0 .46622 m
.00375 .46622 L
s
P
p
.001 w
0 .53294 m
.00375 .53294 L
s
P
p
.001 w
0 .56631 m
.00375 .56631 L
s
P
p
.001 w
0 .59967 m
.00375 .59967 L
s
P
p
.001 w
0 .63303 m
.00375 .63303 L
s
P
p
.001 w
0 .69975 m
.00375 .69975 L
s
P
p
.001 w
0 .73311 m
.00375 .73311 L
s
P
p
.001 w
0 .76647 m
.00375 .76647 L
s
P
p
.001 w
0 .79983 m
.00375 .79983 L
s
P
p
.001 w
0 .86656 m
.00375 .86656 L
s
P
p
.001 w
0 .89992 m
.00375 .89992 L
s
P
p
.001 w
0 .93328 m
.00375 .93328 L
s
P
p
.001 w
0 .96664 m
.00375 .96664 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.06667 .99375 m
.06667 1 L
s
P
p
.002 w
.23333 .99375 m
.23333 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.56667 .99375 m
.56667 1 L
s
P
p
.002 w
.73333 .99375 m
.73333 1 L
s
P
p
.002 w
.9 .99375 m
.9 1 L
s
P
p
.001 w
.1 .99625 m
.1 1 L
s
P
p
.001 w
.13333 .99625 m
.13333 1 L
s
P
p
.001 w
.16667 .99625 m
.16667 1 L
s
P
p
.001 w
.2 .99625 m
.2 1 L
s
P
p
.001 w
.26667 .99625 m
.26667 1 L
s
P
p
.001 w
.3 .99625 m
.3 1 L
s
P
p
.001 w
.33333 .99625 m
.33333 1 L
s
P
p
.001 w
.36667 .99625 m
.36667 1 L
s
P
p
.001 w
.43333 .99625 m
.43333 1 L
s
P
p
.001 w
.46667 .99625 m
.46667 1 L
s
P
p
.001 w
.5 .99625 m
.5 1 L
s
P
p
.001 w
.53333 .99625 m
.53333 1 L
s
P
p
.001 w
.6 .99625 m
.6 1 L
s
P
p
.001 w
.63333 .99625 m
.63333 1 L
s
P
p
.001 w
.66667 .99625 m
.66667 1 L
s
P
p
.001 w
.7 .99625 m
.7 1 L
s
P
p
.001 w
.76667 .99625 m
.76667 1 L
s
P
p
.001 w
.8 .99625 m
.8 1 L
s
P
p
.001 w
.83333 .99625 m
.83333 1 L
s
P
p
.001 w
.86667 .99625 m
.86667 1 L
s
P
p
.001 w
.03333 .99625 m
.03333 1 L
s
P
p
.001 w
.93333 .99625 m
.93333 1 L
s
P
p
.001 w
.96667 .99625 m
.96667 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .16597 m
1 .16597 L
s
P
p
.002 w
.99375 .33278 m
1 .33278 L
s
P
p
.002 w
.99375 .49958 m
1 .49958 L
s
P
p
.002 w
.99375 .66639 m
1 .66639 L
s
P
p
.002 w
.99375 .83319 m
1 .83319 L
s
P
p
.001 w
.99625 .03253 m
1 .03253 L
s
P
p
.001 w
.99625 .06589 m
1 .06589 L
s
P
p
.001 w
.99625 .09925 m
1 .09925 L
s
P
p
.001 w
.99625 .13261 m
1 .13261 L
s
P
p
.001 w
.99625 .19933 m
1 .19933 L
s
P
p
.001 w
.99625 .23269 m
1 .23269 L
s
P
p
.001 w
.99625 .26606 m
1 .26606 L
s
P
p
.001 w
.99625 .29942 m
1 .29942 L
s
P
p
.001 w
.99625 .36614 m
1 .36614 L
s
P
p
.001 w
.99625 .3995 m
1 .3995 L
s
P
p
.001 w
.99625 .43286 m
1 .43286 L
s
P
p
.001 w
.99625 .46622 m
1 .46622 L
s
P
p
.001 w
.99625 .53294 m
1 .53294 L
s
P
p
.001 w
.99625 .56631 m
1 .56631 L
s
P
p
.001 w
.99625 .59967 m
1 .59967 L
s
P
p
.001 w
.99625 .63303 m
1 .63303 L
s
P
p
.001 w
.99625 .69975 m
1 .69975 L
s
P
p
.001 w
.99625 .73311 m
1 .73311 L
s
P
p
.001 w
.99625 .76647 m
1 .76647 L
s
P
p
.001 w
.99625 .79983 m
1 .79983 L
s
P
p
.001 w
.99625 .86656 m
1 .86656 L
s
P
p
.001 w
.99625 .89992 m
1 .89992 L
s
P
p
.001 w
.99625 .93328 m
1 .93328 L
s
P
p
.001 w
.99625 .96664 m
1 .96664 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
.04367 1 m
.04792 .97954 L
.05185 .95908 L
.05577 .93863 L
.0597 .91817 L
.06363 .89771 L
.06726 .87725 L
.07085 .85679 L
.07445 .83633 L
.07805 .81588 L
.08166 .79542 L
.08499 .77496 L
.08825 .7545 L
.09152 .73404 L
.09479 .71358 L
.09808 .69313 L
.10111 .67267 L
.104 .65221 L
.104 .65221 L
.10533 .65304 L
.10533 .65304 L
.10222 .67345 L
.09894 .69386 L
.09568 .71427 L
.09242 .73468 L
.08905 .75509 L
.08556 .7755 L
.08205 .79591 L
.07837 .81632 L
.07505 .83673 L
.07138 .85714 L
.06747 .87755 L
.06368 .89795 L
.05998 .91836 L
.05601 .93877 L
.05218 .95918 L
.04808 .97959 L
.044 1 L
F
.46267 1 m
.45576 .97943 L
.44918 .95885 L
.4426 .93828 L
.43602 .91771 L
.42975 .89714 L
.42351 .87656 L
.41725 .85599 L
.4113 .83542 L
.40539 .81485 L
.39945 .79427 L
.39381 .7737 L
.38853 .75313 L
.38298 .73255 L
.37764 .71198 L
.37267 .69141 L
.37267 .69141 L
.3875 .71289 L
.40252 .73436 L
.41728 .75584 L
.43167 .77731 L
.43167 .77731 L
.43782 .78837 L
.4441 .79942 L
.45024 .81047 L
.456 .82152 L
.456 .82152 L
.46 .84135 L
.46424 .86118 L
.46869 .88101 L
.4732 .90084 L
.47797 .92067 L
.48276 .94051 L
.48788 .96034 L
.49328 .98017 L
.49867 1 L
F
.456 .82152 m
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
.54767 .9241 L
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
.57933 .92327 L
.56676 .90309 L
.55358 .8829 L
.54055 .86272 L
.52745 .84254 L
.51433 .82235 L
.51433 .82235 L
.49834 .80284 L
.48271 .78332 L
.46668 .7638 L
.45037 .74429 L
.43376 .72477 L
.41686 .70525 L
.39967 .68574 L
.38218 .66622 L
.3644 .64671 L
.34667 .62719 L
.34667 .62719 L
.35594 .64606 L
.36619 .66493 L
.3767 .6838 L
.38777 .70267 L
.39891 .72154 L
.41044 .74041 L
.42224 .75928 L
.434 .77815 L
.434 .77815 L
.43951 .78899 L
.445 .79983 L
.45049 .81068 L
.456 .82152 L
F
.43433 .23019 m
.45189 .25 L
.46971 .26981 L
.48754 .28962 L
.50515 .30942 L
.52257 .32923 L
.53964 .34904 L
.55665 .36885 L
.57333 .38866 L
.57333 .38866 L
.55783 .36885 L
.54201 .34904 L
.52651 .32923 L
.5108 .30942 L
.49519 .28962 L
.47932 .26981 L
.46382 .25 L
.44833 .23019 L
.44833 .23019 L
.43433 .23019 L
F
.54467 .22769 m
.5254 .22889 L
.50613 .2293 L
.48687 .22976 L
.4676 .23018 L
.44833 .23019 L
.44833 .23019 L
.433 .21101 L
.433 .21101 L
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
F
0 .66055 m
.0208 .65842 L
.0416 .65654 L
.0624 .65501 L
.0832 .65356 L
.104 .65221 L
.104 .65221 L
.10593 .63943 L
.10754 .62665 L
.10892 .61387 L
.1102 .60108 L
.1102 .60108 L
.11226 .58071 L
.11471 .56034 L
.11696 .53997 L
.12167 .5196 L
.12167 .5196 L
.10139 .5149 L
.08111 .50992 L
.06083 .5048 L
.04056 .49972 L
.02028 .49465 L
0 .48957 L
F
.10533 .65304 m
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
.1995 .64971 L
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
.37267 .69141 L
.35988 .67199 L
.34723 .65257 L
.33441 .63315 L
.32199 .61373 L
.30956 .5943 L
.29729 .57488 L
.28533 .55546 L
.28533 .55546 L
.26517 .55098 L
.245 .54694 L
.22483 .54275 L
.20467 .53818 L
.1845 .53364 L
.16433 .52907 L
.14417 .52439 L
.124 .5196 L
.124 .5196 L
.12002 .54003 L
.11654 .56047 L
.11391 .5809 L
.11133 .60133 L
.11133 .60133 L
.1099 .61426 L
.10837 .62719 L
.10682 .64012 L
.10533 .65304 L
F
.89833 0 m
.878 .00137 L
.85767 .0023 L
.83733 .00323 L
.817 .00465 L
.79667 .0067 L
.77633 .00822 L
.756 .01072 L
.73567 .0127 L
.71533 .0155 L
.695 .01824 L
.67467 .02091 L
.65433 .02428 L
.634 .0278 L
.61367 .03148 L
.59333 .03525 L
.573 .03943 L
.55267 .04306 L
.53233 .04785 L
.512 .05309 L
.49167 .05837 L
.47133 .06422 L
.47133 .06422 L
.4514 .06976 L
.43147 .07548 L
.41153 .08174 L
.3916 .08858 L
.37167 .09591 L
.37167 .09591 L
.36075 .0942 L
.34983 .09231 L
.33892 .09057 L
.328 .08924 L
.328 .08924 L
.34836 .08151 L
.36872 .0744 L
.38908 .06861 L
.40944 .06299 L
.42981 .05824 L
.45017 .05333 L
.47053 .04839 L
.49089 .04436 L
.51125 .04023 L
.53161 .03697 L
.55197 .03304 L
.57233 .03001 L
.59269 .02695 L
.61306 .02389 L
.63342 .02084 L
.65378 .01796 L
.67414 .01556 L
.6945 .01302 L
.71486 .01102 L
.73522 .00899 L
.75558 .00695 L
.77594 .00496 L
.79631 .00221 L
.81667 0 L
F
.38867 .18515 m
.433 .21101 L
.433 .21101 L
.42348 .19183 L
.41347 .17264 L
.40352 .15346 L
.39325 .13428 L
.38254 .1151 L
.37167 .09591 L
.37167 .09591 L
.36358 .09608 L
.3555 .096 L
.34742 .09567 L
.33933 .09508 L
.33933 .09508 L
.34972 .11309 L
.35984 .13111 L
.36958 .14912 L
.37897 .16714 L
.38867 .18515 L
F
.29333 .35196 m
.309 .36644 L
.32467 .38071 L
.34033 .39475 L
.356 .40867 L
.356 .40867 L
.36454 .38884 L
.37337 .36901 L
.38197 .34918 L
.39087 .32935 L
.39975 .30952 L
.40861 .28969 L
.41716 .26985 L
.42572 .25002 L
.43433 .23019 L
.43433 .23019 L
.42292 .21863 L
.4115 .20719 L
.40008 .19623 L
.38867 .18515 L
.38867 .18515 L
.37539 .20601 L
.36236 .22686 L
.34967 .24771 L
.3373 .26856 L
.32558 .28941 L
.31422 .31026 L
.3035 .33111 L
.29333 .35196 L
F
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
.30633 .09008 L
.328 .08924 L
.328 .08924 L
.3075 .08143 L
.287 .07463 L
.2665 .06832 L
.246 .06258 L
.2255 .05735 L
.205 .05253 L
.1845 .04813 L
.164 .04412 L
.1435 .04045 L
.123 .03706 L
.1025 .03396 L
.082 .03111 L
.0615 .02851 L
.041 .02612 L
.0205 .02391 L
0 .02186 L
F
.123 .26105 m
.14267 .23594 L
.16233 .21352 L
.182 .19381 L
.20167 .17602 L
.22133 .16027 L
.241 .14606 L
.26067 .13341 L
.28033 .12228 L
.3 .1123 L
.31967 .10323 L
.33933 .09508 L
.33933 .09508 L
.33108 .09365 L
.32283 .09233 L
.31458 .09114 L
.30633 .09008 L
.30633 .09008 L
.2865 .09901 L
.26667 .10896 L
.24683 .12007 L
.227 .13261 L
.20717 .14706 L
.18733 .16359 L
.1675 .18215 L
.14767 .20345 L
.12783 .22759 L
.108 .25605 L
.108 .25605 L
.123 .26105 L
F
.40333 .45288 m
.42317 .46544 L
.443 .4783 L
.46283 .49131 L
.48267 .50444 L
.5025 .51765 L
.52233 .53094 L
.54217 .54434 L
.562 .55783 L
.58183 .5713 L
.60167 .58465 L
.60167 .58465 L
.58213 .57065 L
.5626 .55653 L
.54307 .54231 L
.52353 .52788 L
.504 .51376 L
.504 .51376 L
.48286 .49852 L
.46171 .48341 L
.44057 .4683 L
.41943 .45317 L
.39829 .43822 L
.37714 .42327 L
.356 .40867 L
.356 .40867 L
.40333 .45288 L
F
.28733 .54462 m
.30261 .56526 L
.31739 .5859 L
.33191 .60655 L
.34667 .62719 L
.34667 .62719 L
.35388 .60782 L
.36074 .58845 L
.36778 .56909 L
.37476 .54972 L
.38122 .53035 L
.38725 .51098 L
.39301 .49161 L
.39842 .47225 L
.40333 .45288 L
.40333 .45288 L
.38308 .43696 L
.36283 .42045 L
.34258 .40366 L
.32233 .38616 L
.32233 .38616 L
.31961 .40596 L
.31639 .42577 L
.31262 .44558 L
.30839 .46539 L
.30364 .4852 L
.2982 .505 L
.29284 .52481 L
.28733 .54462 L
F
0 .20367 m
.0216 .21406 L
.0432 .22445 L
.0648 .2348 L
.0864 .24513 L
.108 .25605 L
.108 .25605 L
.093 .26772 L
.093 .26772 L
.07092 .2568 L
.04883 .24583 L
.02675 .235 L
.00467 .22435 L
F
.103 .27106 m
.12294 .28136 L
.14288 .29177 L
.16282 .30231 L
.18276 .31281 L
.2027 .32331 L
.22264 .33381 L
.24258 .34431 L
.26252 .35489 L
.28245 .3655 L
.30239 .37577 L
.32233 .38616 L
.32233 .38616 L
.29333 .35196 L
.29333 .35196 L
.27441 .34178 L
.25548 .33161 L
.23656 .32157 L
.21763 .31155 L
.1987 .30152 L
.17978 .29149 L
.16085 .28154 L
.14193 .27145 L
.123 .26105 L
.123 .26105 L
.103 .27106 L
F
.093 .26772 m
.103 .27106 L
.103 .27106 L
.093 .29608 L
.093 .29608 L
.08367 .29108 L
.08367 .29108 L
.093 .26772 L
F
.07967 .28857 m
.09549 .3091 L
.11182 .32963 L
.12796 .35016 L
.14405 .37069 L
.15984 .39122 L
.17587 .41175 L
.1917 .43228 L
.20744 .45281 L
.2232 .47334 L
.23897 .49387 L
.25446 .5144 L
.27018 .53493 L
.28533 .55546 L
.28533 .55546 L
.28733 .54462 L
.28733 .54462 L
.27164 .52391 L
.25578 .5032 L
.23989 .48249 L
.22371 .46177 L
.20777 .44106 L
.19161 .42035 L
.17538 .39964 L
.15917 .37893 L
.14268 .35822 L
.12611 .3375 L
.10956 .31679 L
.093 .29608 L
.093 .29608 L
.07967 .28857 L
F
.7 g
.04367 1 m
.04792 .97954 L
.05185 .95908 L
.05577 .93863 L
.0597 .91817 L
.06363 .89771 L
.06726 .87725 L
.07085 .85679 L
.07445 .83633 L
.07805 .81588 L
.08166 .79542 L
.08499 .77496 L
.08825 .7545 L
.09152 .73404 L
.09479 .71358 L
.09808 .69313 L
.10111 .67267 L
.104 .65221 L
.104 .65221 L
.0832 .65356 L
.0624 .65501 L
.0416 .65654 L
.0208 .65842 L
0 .66055 L
0 1 L
F
.044 1 m
.04808 .97959 L
.05218 .95918 L
.05601 .93877 L
.05998 .91836 L
.06368 .89795 L
.06747 .87755 L
.07138 .85714 L
.07505 .83673 L
.07837 .81632 L
.08205 .79591 L
.08556 .7755 L
.08905 .75509 L
.09242 .73468 L
.09568 .71427 L
.09894 .69386 L
.10222 .67345 L
.10533 .65304 L
.10533 .65304 L
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
.1995 .64971 L
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
.37267 .69141 L
.37764 .71198 L
.38298 .73255 L
.38853 .75313 L
.39381 .7737 L
.39945 .79427 L
.40539 .81485 L
.4113 .83542 L
.41725 .85599 L
.42351 .87656 L
.42975 .89714 L
.43602 .91771 L
.4426 .93828 L
.44918 .95885 L
.45576 .97943 L
.46267 1 L
F
.49867 1 m
.49328 .98017 L
.48788 .96034 L
.48276 .94051 L
.47797 .92067 L
.4732 .90084 L
.46869 .88101 L
.46424 .86118 L
.46 .84135 L
.456 .82152 L
.456 .82152 L
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
.54767 .9241 L
.55142 .94308 L
.5551 .96205 L
.55906 .98103 L
.563 1 L
F
.58933 1 m
.58548 .99294 L
.56657 .95813 L
.54767 .9241 L
.54767 .9241 L
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
.57933 .92327 L
.59819 .95742 L
.61705 .99147 L
.62167 1 L
F
.34667 .62719 m
.3644 .64671 L
.38218 .66622 L
.39967 .68574 L
.41686 .70525 L
.43376 .72477 L
.45037 .74429 L
.46668 .7638 L
.48271 .78332 L
.49834 .80284 L
.51433 .82235 L
.51433 .82235 L
.52745 .84254 L
.54055 .86272 L
.55358 .8829 L
.56676 .90309 L
.57933 .92327 L
.57933 .92327 L
.57933 .90701 L
.57933 .89074 L
.5794 .87448 L
.579 .85822 L
.579 .85822 L
.5816 .83868 L
.58414 .81913 L
.58663 .79959 L
.58917 .78005 L
.59133 .76051 L
.59334 .74097 L
.59533 .72143 L
.59675 .70189 L
.59799 .68235 L
.59919 .66281 L
.60012 .64327 L
.60102 .62373 L
.60133 .60419 L
.60167 .58465 L
.60167 .58465 L
.58183 .5713 L
.562 .55783 L
.54217 .54434 L
.52233 .53094 L
.5025 .51765 L
.48267 .50444 L
.46283 .49131 L
.443 .4783 L
.42317 .46544 L
.40333 .45288 L
.40333 .45288 L
.39842 .47225 L
.39301 .49161 L
.38725 .51098 L
.38122 .53035 L
.37476 .54972 L
.36778 .56909 L
.36074 .58845 L
.35388 .60782 L
.34667 .62719 L
F
.60167 .58465 m
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
.86133 .5613 L
.86089 .55317 L
.86033 .54504 L
.85953 .53691 L
.85833 .52877 L
.85833 .52877 L
.83865 .52742 L
.81896 .52634 L
.79928 .5254 L
.77959 .52442 L
.75991 .5234 L
.74022 .52241 L
.72054 .52177 L
.70085 .52129 L
.68117 .52032 L
.66148 .51946 L
.6418 .51899 L
.62211 .51821 L
.60243 .51721 L
.58274 .51667 L
.56306 .51609 L
.54337 .51509 L
.52369 .5143 L
.504 .51376 L
.504 .51376 L
.52353 .52788 L
.54307 .54231 L
.5626 .55653 L
.58213 .57065 L
.60167 .58465 L
F
.44833 .23019 m
.46382 .25 L
.47932 .26981 L
.49519 .28962 L
.5108 .30942 L
.52651 .32923 L
.54201 .34904 L
.55783 .36885 L
.57333 .38866 L
.57333 .38866 L
.59261 .39053 L
.61188 .3921 L
.63115 .39351 L
.65042 .39489 L
.6697 .39644 L
.68897 .39835 L
.70824 .40029 L
.72752 .40222 L
.74679 .40445 L
.76606 .40693 L
.78533 .40951 L
.78533 .40951 L
.77285 .39009 L
.75976 .37067 L
.74657 .35125 L
.73264 .33182 L
.71822 .3124 L
.70336 .29298 L
.688 .27356 L
.688 .27356 L
.66752 .26715 L
.64705 .26101 L
.62657 .25472 L
.6061 .24805 L
.58562 .2414 L
.56514 .23466 L
.54467 .22769 L
.54467 .22769 L
.5254 .22889 L
.50613 .2293 L
.48687 .22976 L
.4676 .23018 L
.44833 .23019 L
F
.356 .40867 m
.37714 .42327 L
.39829 .43822 L
.41943 .45317 L
.44057 .4683 L
.46171 .48341 L
.48286 .49852 L
.504 .51376 L
.504 .51376 L
.51711 .49291 L
.52967 .47206 L
.54181 .45121 L
.55328 .43036 L
.56387 .40951 L
.57333 .38866 L
.57333 .38866 L
.55665 .36885 L
.53964 .34904 L
.52257 .32923 L
.50515 .30942 L
.48754 .28962 L
.46971 .26981 L
.45189 .25 L
.43433 .23019 L
.43433 .23019 L
.42572 .25002 L
.41716 .26985 L
.40861 .28969 L
.39975 .30952 L
.39087 .32935 L
.38197 .34918 L
.37337 .36901 L
.36454 .38884 L
.356 .40867 L
F
.81667 0 m
.79631 .00221 L
.77594 .00496 L
.75558 .00695 L
.73522 .00899 L
.71486 .01102 L
.6945 .01302 L
.67414 .01556 L
.65378 .01796 L
.63342 .02084 L
.61306 .02389 L
.59269 .02695 L
.57233 .03001 L
.55197 .03304 L
.53161 .03697 L
.51125 .04023 L
.49089 .04436 L
.47053 .04839 L
.45017 .05333 L
.42981 .05824 L
.40944 .06299 L
.38908 .06861 L
.36872 .0744 L
.34836 .08151 L
.328 .08924 L
.328 .08924 L
.3075 .08143 L
.287 .07463 L
.2665 .06832 L
.246 .06258 L
.2255 .05735 L
.205 .05253 L
.1845 .04813 L
.164 .04412 L
.1435 .04045 L
.123 .03706 L
.1025 .03396 L
.082 .03111 L
.0615 .02851 L
.041 .02612 L
.0205 .02391 L
0 .02186 L
0 0 L
F
.433 .21101 m
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
.54467 .22769 L
.5365 .20726 L
.52835 .18682 L
.51985 .16639 L
.51082 .14595 L
.50143 .12552 L
.49184 .10509 L
.48172 .08465 L
.47133 .06422 L
.47133 .06422 L
.4514 .06976 L
.43147 .07548 L
.41153 .08174 L
.3916 .08858 L
.37167 .09591 L
.37167 .09591 L
.38254 .1151 L
.39325 .13428 L
.40352 .15346 L
.41347 .17264 L
.42348 .19183 L
.433 .21101 L
F
.29333 .35196 m
.3035 .33111 L
.31422 .31026 L
.32558 .28941 L
.3373 .26856 L
.34967 .24771 L
.36236 .22686 L
.37539 .20601 L
.38867 .18515 L
.38867 .18515 L
.37897 .16714 L
.36958 .14912 L
.35984 .13111 L
.34972 .11309 L
.33933 .09508 L
.33933 .09508 L
.31967 .10323 L
.3 .1123 L
.28033 .12228 L
.26067 .13341 L
.241 .14606 L
.22133 .16027 L
.20167 .17602 L
.182 .19381 L
.16233 .21352 L
.14267 .23594 L
.123 .26105 L
.123 .26105 L
.14193 .27145 L
.16085 .28154 L
.17978 .29149 L
.1987 .30152 L
.21763 .31155 L
.23656 .32157 L
.25548 .33161 L
.27441 .34178 L
.29333 .35196 L
F
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
.30633 .09008 L
.2865 .09901 L
.26667 .10896 L
.24683 .12007 L
.227 .13261 L
.20717 .14706 L
.18733 .16359 L
.1675 .18215 L
.14767 .20345 L
.12783 .22759 L
.108 .25605 L
.108 .25605 L
.0864 .24513 L
.0648 .2348 L
.0432 .22445 L
.0216 .21406 L
0 .20367 L
F
.093 .29608 m
.10956 .31679 L
.12611 .3375 L
.14268 .35822 L
.15917 .37893 L
.17538 .39964 L
.19161 .42035 L
.20777 .44106 L
.22371 .46177 L
.23989 .48249 L
.25578 .5032 L
.27164 .52391 L
.28733 .54462 L
.28733 .54462 L
.29284 .52481 L
.2982 .505 L
.30364 .4852 L
.30839 .46539 L
.31262 .44558 L
.31639 .42577 L
.31961 .40596 L
.32233 .38616 L
.32233 .38616 L
.30239 .37577 L
.28245 .3655 L
.26252 .35489 L
.24258 .34431 L
.22264 .33381 L
.2027 .32331 L
.18276 .31281 L
.16282 .30231 L
.14288 .29177 L
.12294 .28136 L
.103 .27106 L
.103 .27106 L
.093 .29608 L
F
.093 .26772 m
.07092 .2568 L
.04883 .24583 L
.02675 .235 L
.00467 .22435 L
.00467 .22435 L
.02442 .24048 L
.04417 .25711 L
.06392 .27402 L
.08367 .29108 L
.08367 .29108 L
.093 .26772 L
F
0 .48957 m
.02028 .49465 L
.04056 .49972 L
.06083 .5048 L
.08111 .50992 L
.10139 .5149 L
.12167 .5196 L
.12167 .5196 L
.11877 .50028 L
.11599 .48096 L
.11294 .46163 L
.10986 .44231 L
.10657 .42299 L
.10297 .40367 L
.09907 .38435 L
.09506 .36503 L
.09091 .3457 L
.08658 .32638 L
.08224 .30706 L
.07767 .28774 L
.07767 .28774 L
.05908 .27199 L
.0405 .25611 L
.02192 .24032 L
.00333 .22519 L
.00333 .22519 L
0 .22455 L
F
.28533 .55546 m
.27018 .53493 L
.25446 .5144 L
.23897 .49387 L
.2232 .47334 L
.20744 .45281 L
.1917 .43228 L
.17587 .41175 L
.15984 .39122 L
.14405 .37069 L
.12796 .35016 L
.11182 .32963 L
.09549 .3091 L
.07967 .28857 L
.07967 .28857 L
.08398 .30783 L
.08865 .32708 L
.09299 .34633 L
.09721 .36558 L
.10142 .38483 L
.10518 .40409 L
.10862 .42334 L
.11208 .44259 L
.11558 .46184 L
.11842 .4811 L
.12144 .50035 L
.124 .5196 L
.124 .5196 L
.14417 .52439 L
.16433 .52907 L
.1845 .53364 L
.20467 .53818 L
.22483 .54275 L
.245 .54694 L
.26517 .55098 L
.28533 .55546 L
F
.55 g
.563 1 m
.55906 .98103 L
.5551 .96205 L
.55142 .94308 L
.54767 .9241 L
.54767 .9241 L
.56657 .95813 L
.58548 .99294 L
.58933 1 L
F
.62167 1 m
.61705 .99147 L
.59819 .95742 L
.57933 .92327 L
.57933 .92327 L
.57933 .90701 L
.57933 .89074 L
.5794 .87448 L
.579 .85822 L
.579 .85822 L
.5816 .83868 L
.58414 .81913 L
.58663 .79959 L
.58917 .78005 L
.59133 .76051 L
.59334 .74097 L
.59533 .72143 L
.59675 .70189 L
.59799 .68235 L
.59919 .66281 L
.60012 .64327 L
.60102 .62373 L
.60133 .60419 L
.60167 .58465 L
.60167 .58465 L
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
.86133 .5613 L
.87514 .58124 L
.88884 .60118 L
.90256 .62112 L
.91602 .64106 L
.92915 .66101 L
.94221 .68095 L
.9553 .70089 L
.96816 .72083 L
.9809 .74077 L
.99367 .76071 L
1 .77064 L
1 1 L
F
1 .57214 m
.98019 .57041 L
.96038 .56865 L
.94057 .56692 L
.92076 .56537 L
.90095 .56396 L
.88114 .56262 L
.86133 .5613 L
.86133 .5613 L
.86089 .55317 L
.86033 .54504 L
.85953 .53691 L
.85833 .52877 L
.85833 .52877 L
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
F
1 .38198 m
.9805 .37462 L
.961 .36732 L
.9415 .35998 L
.922 .35294 L
.9025 .34615 L
.883 .33933 L
.8635 .3325 L
.844 .32567 L
.8245 .31881 L
.805 .31198 L
.7855 .30549 L
.766 .2992 L
.7465 .29287 L
.727 .2865 L
.7075 .28008 L
.688 .27356 L
.688 .27356 L
.70336 .29298 L
.71822 .3124 L
.73264 .33182 L
.74657 .35125 L
.75976 .37067 L
.77285 .39009 L
.78533 .40951 L
.78533 .40951 L
.80485 .41284 L
.82436 .41623 L
.84388 .41991 L
.86339 .42385 L
.88291 .42772 L
.90242 .43172 L
.92194 .43609 L
.94145 .4405 L
.96097 .44489 L
.98048 .44961 L
1 .45455 L
F
.78533 .40951 m
.76606 .40693 L
.74679 .40445 L
.72752 .40222 L
.70824 .40029 L
.68897 .39835 L
.6697 .39644 L
.65042 .39489 L
.63115 .39351 L
.61188 .3921 L
.59261 .39053 L
.57333 .38866 L
.57333 .38866 L
.56387 .40951 L
.55328 .43036 L
.54181 .45121 L
.52967 .47206 L
.51711 .49291 L
.504 .51376 L
.504 .51376 L
.52369 .5143 L
.54337 .51509 L
.56306 .51609 L
.58274 .51667 L
.60243 .51721 L
.62211 .51821 L
.6418 .51899 L
.66148 .51946 L
.68117 .52032 L
.70085 .52129 L
.72054 .52177 L
.74022 .52241 L
.75991 .5234 L
.77959 .52442 L
.79928 .5254 L
.81896 .52634 L
.83865 .52742 L
.85833 .52877 L
.85833 .52877 L
.84746 .5089 L
.8359 .48902 L
.82412 .46914 L
.81149 .44926 L
.7987 .42939 L
.78533 .40951 L
F
.54467 .22769 m
.56514 .23466 L
.58562 .2414 L
.6061 .24805 L
.62657 .25472 L
.64705 .26101 L
.66752 .26715 L
.688 .27356 L
.688 .27356 L
.67155 .25423 L
.6549 .23489 L
.63793 .21556 L
.62056 .19622 L
.60296 .17689 L
.58476 .15756 L
.56664 .13822 L
.54791 .11889 L
.52897 .09955 L
.50955 .08022 L
.48933 .06088 L
.48933 .06088 L
.47133 .06422 L
.47133 .06422 L
.48172 .08465 L
.49184 .10509 L
.50143 .12552 L
.51082 .14595 L
.51985 .16639 L
.52835 .18682 L
.5365 .20726 L
.54467 .22769 L
F
.919 0 m
.89854 .00076 L
.87808 .00174 L
.85762 .00293 L
.83716 .00433 L
.8167 .00594 L
.79624 .00775 L
.77578 .00976 L
.75532 .01198 L
.73486 .01438 L
.7144 .01698 L
.69394 .01976 L
.67348 .02277 L
.65302 .02596 L
.63256 .02932 L
.6121 .03297 L
.59163 .03682 L
.57117 .0409 L
.55071 .04534 L
.53025 .04998 L
.50979 .05505 L
.48933 .06088 L
.48933 .06088 L
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
.868 .04587 L
.88686 .03826 L
.90571 .03134 L
.92457 .02514 L
.94343 .01977 L
.96229 .01516 L
.98114 .01098 L
1 .00751 L
1 0 L
F
.4 g
1 .77064 m
.99367 .76071 L
.9809 .74077 L
.96816 .72083 L
.9553 .70089 L
.94221 .68095 L
.92915 .66101 L
.91602 .64106 L
.90256 .62112 L
.88884 .60118 L
.87514 .58124 L
.86133 .5613 L
.86133 .5613 L
.88114 .56262 L
.90095 .56396 L
.92076 .56537 L
.94057 .56692 L
.96038 .56865 L
.98019 .57041 L
1 .57214 L
F
1 .45455 m
.98048 .44961 L
.96097 .44489 L
.94145 .4405 L
.92194 .43609 L
.90242 .43172 L
.88291 .42772 L
.86339 .42385 L
.84388 .41991 L
.82436 .41623 L
.80485 .41284 L
.78533 .40951 L
.78533 .40951 L
.7987 .42939 L
.81149 .44926 L
.82412 .46914 L
.8359 .48902 L
.84746 .5089 L
.85833 .52877 L
.85833 .52877 L
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
F
1 .38198 m
.9805 .37462 L
.961 .36732 L
.9415 .35998 L
.922 .35294 L
.9025 .34615 L
.883 .33933 L
.8635 .3325 L
.844 .32567 L
.8245 .31881 L
.805 .31198 L
.7855 .30549 L
.766 .2992 L
.7465 .29287 L
.727 .2865 L
.7075 .28008 L
.688 .27356 L
.688 .27356 L
.67155 .25423 L
.6549 .23489 L
.63793 .21556 L
.62056 .19622 L
.60296 .17689 L
.58476 .15756 L
.56664 .13822 L
.54791 .11889 L
.52897 .09955 L
.50955 .08022 L
.48933 .06088 L
.48933 .06088 L
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
.868 .04587 L
.88494 .06556 L
.90212 .08526 L
.91961 .10495 L
.9375 .12464 L
.95586 .14433 L
.97477 .16403 L
.99431 .18372 L
1 .18932 L
F
1 .00751 m
.98114 .01098 L
.96229 .01516 L
.94343 .01977 L
.92457 .02514 L
.90571 .03134 L
.88686 .03826 L
.868 .04587 L
.868 .04587 L
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
F
.25 g
p
P
1 .18932 m
.99431 .18372 L
.97477 .16403 L
.95586 .14433 L
.9375 .12464 L
.91961 .10495 L
.90212 .08526 L
.88494 .06556 L
.868 .04587 L
.868 .04587 L
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
F
0 g
.3 Mabswid
s
0 .54133 m
.0199 .55208 L
.05601 .5716 L
.09203 .59113 L
.12796 .61066 L
.16379 .63018 L
.1995 .64971 L
s
.43167 .77731 m
.45196 .78862 L
.47226 .79984 L
.49256 .81098 L
.51286 .82206 L
.53315 .8331 L
.55345 .84429 L
.57375 .85549 L
.59405 .8667 L
.61435 .87793 L
.63464 .88917 L
.65494 .90043 L
.67524 .9117 L
.69554 .92298 L
.71583 .93428 L
.73613 .94559 L
.75643 .95692 L
.77673 .96827 L
.79702 .97963 L
.81732 .99101 L
.83333 1 L
s
.104 .65221 m
.10111 .67267 L
.09808 .69313 L
.09479 .71358 L
.09152 .73404 L
.08825 .7545 L
.08499 .77496 L
.08166 .79542 L
.07805 .81588 L
.07445 .83633 L
.07085 .85679 L
.06726 .87725 L
.06363 .89771 L
.0597 .91817 L
.05577 .93863 L
.05185 .95908 L
.04792 .97954 L
s
.04367 1 m
.04792 .97954 L
s
s
.07767 .28774 m
.08224 .30706 L
.08658 .32638 L
.09091 .3457 L
.09506 .36503 L
.09907 .38435 L
.10297 .40367 L
.10657 .42299 L
.10986 .44231 L
.11294 .46163 L
.11599 .48096 L
.11877 .50028 L
.12167 .5196 L
s
0 .66055 m
.0208 .65842 L
.0416 .65654 L
.0624 .65501 L
.0832 .65356 L
.104 .65221 L
s
0 .48957 m
.02028 .49465 L
.04056 .49972 L
.06083 .5048 L
.08111 .50992 L
.10139 .5149 L
.12167 .5196 L
s
.1102 .60108 m
.10892 .61387 L
.10754 .62665 L
.10593 .63943 L
.104 .65221 L
s
.12167 .5196 m
.11696 .53997 L
.11471 .56034 L
.11226 .58071 L
.1102 .60108 L
s
.10533 .65304 m
.10222 .67345 L
.09894 .69386 L
.09568 .71427 L
.09242 .73468 L
.08905 .75509 L
.08556 .7755 L
.08205 .79591 L
.07837 .81632 L
.07505 .83673 L
.07138 .85714 L
.06747 .87755 L
.06368 .89795 L
.05998 .91836 L
.05601 .93877 L
.05218 .95918 L
.04808 .97959 L
.044 1 L
s
.11133 .60133 m
.1099 .61426 L
.10837 .62719 L
.10682 .64012 L
.10533 .65304 L
s
.124 .5196 m
.12002 .54003 L
.11654 .56047 L
.11391 .5809 L
.11133 .60133 L
s
.07967 .28857 m
.08398 .30783 L
.08865 .32708 L
.09299 .34633 L
.09721 .36558 L
.10142 .38483 L
.10518 .40409 L
.10862 .42334 L
.11208 .44259 L
.11558 .46184 L
.11842 .4811 L
.12144 .50035 L
.124 .5196 L
s
.104 .65221 m
.10533 .65304 L
s
.12167 .5196 m
.124 .5196 L
s
.37267 .69141 m
.37764 .71198 L
.38298 .73255 L
.38853 .75313 L
.39381 .7737 L
.39945 .79427 L
.40539 .81485 L
.4113 .83542 L
.41725 .85599 L
.42351 .87656 L
.42975 .89714 L
.43602 .91771 L
.4426 .93828 L
.44918 .95885 L
.45576 .97943 L
.46267 1 L
s
.10533 .65304 m
.12417 .65188 L
.143 .65106 L
.16183 .65063 L
.18067 .65014 L
.1995 .64971 L
s
.1995 .64971 m
.21874 .65399 L
.23798 .65813 L
.25722 .66193 L
.27646 .66628 L
.2957 .67115 L
.31494 .67552 L
.33419 .67994 L
.35343 .68502 L
.37267 .69141 L
s
.28533 .55546 m
.29729 .57488 L
.30956 .5943 L
.32199 .61373 L
.33441 .63315 L
.34723 .65257 L
.35988 .67199 L
.37267 .69141 L
s
.124 .5196 m
.14417 .52439 L
.16433 .52907 L
.1845 .53364 L
.20467 .53818 L
.22483 .54275 L
.245 .54694 L
.26517 .55098 L
.28533 .55546 L
s
.456 .82152 m
.46 .84135 L
.46424 .86118 L
.46869 .88101 L
.4732 .90084 L
.47797 .92067 L
.48276 .94051 L
.48788 .96034 L
.49328 .98017 L
.49867 1 L
s
.456 .82152 m
.47434 .84204 L
.4931 .86255 L
.5117 .88307 L
.52991 .90359 L
.54767 .9241 L
s
.37267 .69141 m
.3875 .71289 L
.40252 .73436 L
.41728 .75584 L
.43167 .77731 L
s
.43167 .77731 m
.43782 .78837 L
.4441 .79942 L
.45024 .81047 L
.456 .82152 L
s
.34667 .62719 m
.35594 .64606 L
.36619 .66493 L
.3767 .6838 L
.38777 .70267 L
.39891 .72154 L
.41044 .74041 L
.42224 .75928 L
.434 .77815 L
s
.434 .77815 m
.43951 .78899 L
.445 .79983 L
.45049 .81068 L
.456 .82152 L
s
.51433 .82235 m
.52745 .84254 L
.54055 .86272 L
.55358 .8829 L
.56676 .90309 L
.57933 .92327 L
s
.34667 .62719 m
.3644 .64671 L
.38218 .66622 L
.39967 .68574 L
.41686 .70525 L
.43376 .72477 L
.45037 .74429 L
.46668 .7638 L
.48271 .78332 L
.49834 .80284 L
.51433 .82235 L
s
.54767 .9241 m
.55142 .94308 L
.5551 .96205 L
.55906 .98103 L
.563 1 L
s
.54767 .9241 m
.56657 .95813 L
.58548 .99294 L
.58933 1 L
s
.57933 .92327 m
.59819 .95742 L
.61705 .99147 L
.62167 1 L
s
.54767 .9241 m
.55558 .92389 L
.5635 .92369 L
.57142 .92348 L
.57933 .92327 L
s
.28733 .54462 m
.30261 .56526 L
.31739 .5859 L
.33191 .60655 L
.34667 .62719 L
s
.40333 .45288 m
.39842 .47225 L
.39301 .49161 L
.38725 .51098 L
.38122 .53035 L
.37476 .54972 L
.36778 .56909 L
.36074 .58845 L
.35388 .60782 L
.34667 .62719 L
s
.40333 .45288 m
.42317 .46544 L
.443 .4783 L
.46283 .49131 L
.48267 .50444 L
.5025 .51765 L
.52233 .53094 L
.54217 .54434 L
.562 .55783 L
.58183 .5713 L
.60167 .58465 L
s
.07967 .28857 m
.09549 .3091 L
.11182 .32963 L
.12796 .35016 L
.14405 .37069 L
.15984 .39122 L
.17587 .41175 L
.1917 .43228 L
.20744 .45281 L
.2232 .47334 L
.23897 .49387 L
.25446 .5144 L
.27018 .53493 L
.28533 .55546 L
s
.093 .29608 m
.10956 .31679 L
.12611 .3375 L
.14268 .35822 L
.15917 .37893 L
.17538 .39964 L
.19161 .42035 L
.20777 .44106 L
.22371 .46177 L
.23989 .48249 L
.25578 .5032 L
.27164 .52391 L
.28733 .54462 L
s
.32233 .38616 m
.31961 .40596 L
.31639 .42577 L
.31262 .44558 L
.30839 .46539 L
.30364 .4852 L
.2982 .505 L
.29284 .52481 L
.28733 .54462 L
s
.28533 .55546 m
.28733 .54462 L
s
.32233 .38616 m
.34258 .40366 L
.36283 .42045 L
.38308 .43696 L
.40333 .45288 L
s
.103 .27106 m
.12294 .28136 L
.14288 .29177 L
.16282 .30231 L
.18276 .31281 L
.2027 .32331 L
.22264 .33381 L
.24258 .34431 L
.26252 .35489 L
.28245 .3655 L
.30239 .37577 L
.32233 .38616 L
s
.504 .51376 m
.52353 .52788 L
.54307 .54231 L
.5626 .55653 L
.58213 .57065 L
.60167 .58465 L
s
.356 .40867 m
.37714 .42327 L
.39829 .43822 L
.41943 .45317 L
.44057 .4683 L
.46171 .48341 L
.48286 .49852 L
.504 .51376 L
s
.29333 .35196 m
.309 .36644 L
.32467 .38071 L
.34033 .39475 L
.356 .40867 L
s
.123 .26105 m
.14193 .27145 L
.16085 .28154 L
.17978 .29149 L
.1987 .30152 L
.21763 .31155 L
.23656 .32157 L
.25548 .33161 L
.27441 .34178 L
.29333 .35196 L
s
.40333 .45288 m
.356 .40867 L
s
.32233 .38616 m
.29333 .35196 L
s
.57333 .38866 m
.56387 .40951 L
.55328 .43036 L
.54181 .45121 L
.52967 .47206 L
.51711 .49291 L
.504 .51376 L
s
.504 .51376 m
.52369 .5143 L
.54337 .51509 L
.56306 .51609 L
.58274 .51667 L
.60243 .51721 L
.62211 .51821 L
.6418 .51899 L
.66148 .51946 L
.68117 .52032 L
.70085 .52129 L
.72054 .52177 L
.74022 .52241 L
.75991 .5234 L
.77959 .52442 L
.79928 .5254 L
.81896 .52634 L
.83865 .52742 L
.85833 .52877 L
s
.60167 .58465 m
.60133 .60419 L
.60102 .62373 L
.60012 .64327 L
.59919 .66281 L
.59799 .68235 L
.59675 .70189 L
.59533 .72143 L
.59334 .74097 L
.59133 .76051 L
.58917 .78005 L
.58663 .79959 L
.58414 .81913 L
.5816 .83868 L
.579 .85822 L
s
.579 .85822 m
.5794 .87448 L
.57933 .89074 L
.57933 .90701 L
.57933 .92327 L
s
.60167 .58465 m
.62164 .58308 L
.64162 .58155 L
.66159 .58006 L
.68156 .57816 L
.70154 .57619 L
.72151 .57471 L
.74149 .57304 L
.76146 .57102 L
.78144 .569 L
.80141 .567 L
.82138 .56497 L
.84136 .56305 L
.86133 .5613 L
s
.43433 .23019 m
.42572 .25002 L
.41716 .26985 L
.40861 .28969 L
.39975 .30952 L
.39087 .32935 L
.38197 .34918 L
.37337 .36901 L
.36454 .38884 L
.356 .40867 L
s
.38867 .18515 m
.37539 .20601 L
.36236 .22686 L
.34967 .24771 L
.3373 .26856 L
.32558 .28941 L
.31422 .31026 L
.3035 .33111 L
.29333 .35196 L
s
.43433 .23019 m
.45189 .25 L
.46971 .26981 L
.48754 .28962 L
.50515 .30942 L
.52257 .32923 L
.53964 .34904 L
.55665 .36885 L
.57333 .38866 L
s
.38867 .18515 m
.40008 .19623 L
.4115 .20719 L
.42292 .21863 L
.43433 .23019 L
s
.44833 .23019 m
.46382 .25 L
.47932 .26981 L
.49519 .28962 L
.5108 .30942 L
.52651 .32923 L
.54201 .34904 L
.55783 .36885 L
.57333 .38866 L
s
.433 .21101 m
.44833 .23019 L
s
.57333 .38866 m
.59261 .39053 L
.61188 .3921 L
.63115 .39351 L
.65042 .39489 L
.6697 .39644 L
.68897 .39835 L
.70824 .40029 L
.72752 .40222 L
.74679 .40445 L
.76606 .40693 L
.78533 .40951 L
s
.43433 .23019 m
.44833 .23019 L
s
.38867 .18515 m
.433 .21101 L
s
.688 .27356 m
.70336 .29298 L
.71822 .3124 L
.73264 .33182 L
.74657 .35125 L
.75976 .37067 L
.77285 .39009 L
.78533 .40951 L
s
.54467 .22769 m
.56514 .23466 L
.58562 .2414 L
.6061 .24805 L
.62657 .25472 L
.64705 .26101 L
.66752 .26715 L
.688 .27356 L
s
.44833 .23019 m
.4676 .23018 L
.48687 .22976 L
.50613 .2293 L
.5254 .22889 L
.54467 .22769 L
s
.433 .21101 m
.45161 .21366 L
.47022 .21634 L
.48883 .21906 L
.50744 .22185 L
.52606 .22472 L
.54467 .22769 L
s
.37167 .09591 m
.38254 .1151 L
.39325 .13428 L
.40352 .15346 L
.41347 .17264 L
.42348 .19183 L
.433 .21101 L
s
.47133 .06422 m
.48172 .08465 L
.49184 .10509 L
.50143 .12552 L
.51082 .14595 L
.51985 .16639 L
.52835 .18682 L
.5365 .20726 L
.54467 .22769 L
s
.48933 .06088 m
.50955 .08022 L
.52897 .09955 L
.54791 .11889 L
.56664 .13822 L
.58476 .15756 L
.60296 .17689 L
.62056 .19622 L
.63793 .21556 L
.6549 .23489 L
.67155 .25423 L
.688 .27356 L
s
.688 .27356 m
.7075 .28008 L
.727 .2865 L
.7465 .29287 L
.766 .2992 L
.7855 .30549 L
.805 .31198 L
.8245 .31881 L
.844 .32567 L
.8635 .3325 L
.883 .33933 L
.9025 .34615 L
.922 .35294 L
.9415 .35998 L
.961 .36732 L
.9805 .37462 L
s
1 .38198 m
.9805 .37462 L
s
s
.78533 .40951 m
.7987 .42939 L
.81149 .44926 L
.82412 .46914 L
.8359 .48902 L
.84746 .5089 L
.85833 .52877 L
s
.85833 .52877 m
.85953 .53691 L
.86033 .54504 L
.86089 .55317 L
.86133 .5613 L
s
.86133 .5613 m
.87514 .58124 L
.88884 .60118 L
.90256 .62112 L
.91602 .64106 L
.92915 .66101 L
.94221 .68095 L
.9553 .70089 L
.96816 .72083 L
.9809 .74077 L
.99367 .76071 L
1 .77064 L
s
.86133 .5613 m
.88114 .56262 L
.90095 .56396 L
.92076 .56537 L
.94057 .56692 L
.96038 .56865 L
.98019 .57041 L
s
1 .57214 m
.98019 .57041 L
s
s
s
s
.78533 .40951 m
.80485 .41284 L
.82436 .41623 L
.84388 .41991 L
.86339 .42385 L
.88291 .42772 L
.90242 .43172 L
.92194 .43609 L
.94145 .4405 L
.96097 .44489 L
.98048 .44961 L
s
1 .45455 m
.98048 .44961 L
s
s
.85833 .52877 m
.87857 .53232 L
.89881 .53605 L
.91905 .54006 L
.93929 .54414 L
.95952 .54819 L
.97976 .55225 L
1 .5563 L
s
.48933 .06088 m
.50926 .05962 L
.52919 .05925 L
.54912 .05882 L
.56905 .05832 L
.58898 .05782 L
.60891 .05736 L
.62884 .05686 L
.64877 .05594 L
.6687 .05499 L
.68863 .05451 L
.70856 .05383 L
.72849 .05281 L
.74842 .05179 L
.76835 .05079 L
.78828 .04979 L
.80821 .04879 L
.82814 .0478 L
.84807 .04682 L
.868 .04587 L
s
.868 .04587 m
.88494 .06556 L
.90212 .08526 L
.91961 .10495 L
.9375 .12464 L
.95586 .14433 L
.97477 .16403 L
.99431 .18372 L
1 .18932 L
s
.868 .04587 m
.88686 .03826 L
.90571 .03134 L
.92457 .02514 L
.94343 .01977 L
.96229 .01516 L
.98114 .01098 L
1 .00751 L
s
.868 .04587 m
.88686 .04538 L
.90571 .04492 L
.92457 .04447 L
.94343 .04371 L
.96229 .04274 L
.98114 .04212 L
1 .0417 L
s
.48933 .06088 m
.50979 .05505 L
.53025 .04998 L
.55071 .04534 L
.57117 .0409 L
.59163 .03682 L
.6121 .03297 L
.63256 .02932 L
.65302 .02596 L
.67348 .02277 L
.69394 .01976 L
.7144 .01698 L
.73486 .01438 L
.75532 .01198 L
.77578 .00976 L
.79624 .00775 L
.8167 .00594 L
.83716 .00433 L
.85762 .00293 L
.87808 .00174 L
.89854 .00076 L
.919 0 L
s
.47133 .06422 m
.48933 .06088 L
s
.47133 .06422 m
.49167 .05837 L
.512 .05309 L
.53233 .04785 L
.55267 .04306 L
.573 .03943 L
.59333 .03525 L
.61367 .03148 L
.634 .0278 L
.65433 .02428 L
.67467 .02091 L
.695 .01824 L
.71533 .0155 L
.73567 .0127 L
.756 .01072 L
.77633 .00822 L
.79667 .0067 L
.817 .00465 L
.83733 .00323 L
.85767 .0023 L
.878 .00137 L
.89833 0 L
s
.37167 .09591 m
.3916 .08858 L
.41153 .08174 L
.43147 .07548 L
.4514 .06976 L
.47133 .06422 L
s
.328 .08924 m
.34836 .08151 L
.36872 .0744 L
.38908 .06861 L
.40944 .06299 L
.42981 .05824 L
.45017 .05333 L
.47053 .04839 L
.49089 .04436 L
.51125 .04023 L
.53161 .03697 L
.55197 .03304 L
.57233 .03001 L
.59269 .02695 L
.61306 .02389 L
.63342 .02084 L
.65378 .01796 L
.67414 .01556 L
.6945 .01302 L
.71486 .01102 L
.73522 .00899 L
.75558 .00695 L
.77594 .00496 L
.79631 .00221 L
.81667 0 L
s
.33933 .09508 m
.34972 .11309 L
.35984 .13111 L
.36958 .14912 L
.37897 .16714 L
.38867 .18515 L
s
.33933 .09508 m
.34742 .09567 L
.3555 .096 L
.36358 .09608 L
.37167 .09591 L
s
.30633 .09008 m
.31458 .09114 L
.32283 .09233 L
.33108 .09365 L
.33933 .09508 L
s
0 .02186 m
.0205 .02391 L
.041 .02612 L
.0615 .02851 L
.082 .03111 L
.1025 .03396 L
.123 .03706 L
.1435 .04045 L
.164 .04412 L
.1845 .04813 L
.205 .05253 L
.2255 .05735 L
.246 .06258 L
.2665 .06832 L
.287 .07463 L
.3075 .08143 L
.328 .08924 L
s
.328 .08924 m
.33892 .09057 L
.34983 .09231 L
.36075 .0942 L
.37167 .09591 L
s
.328 .08924 m
.30633 .09008 L
s
0 .02387 m
.02042 .02611 L
.04084 .02855 L
.06127 .03121 L
.08169 .03409 L
.10211 .0372 L
.12253 .04061 L
.14296 .04437 L
.16338 .04848 L
.1838 .05297 L
.20422 .05785 L
.22464 .06316 L
.24507 .06901 L
.26549 .07544 L
.28591 .08241 L
.30633 .09008 L
s
.123 .26105 m
.14267 .23594 L
.16233 .21352 L
.182 .19381 L
.20167 .17602 L
.22133 .16027 L
.241 .14606 L
.26067 .13341 L
.28033 .12228 L
.3 .1123 L
.31967 .10323 L
.33933 .09508 L
s
.108 .25605 m
.12783 .22759 L
.14767 .20345 L
.1675 .18215 L
.18733 .16359 L
.20717 .14706 L
.227 .13261 L
.24683 .12007 L
.26667 .10896 L
.2865 .09901 L
.30633 .09008 L
s
0 .20367 m
.0216 .21406 L
.0432 .22445 L
.0648 .2348 L
.0864 .24513 L
.108 .25605 L
s
.00467 .22435 m
.02675 .235 L
.04883 .24583 L
.07092 .2568 L
.093 .26772 L
s
.123 .26105 m
.108 .25605 L
s
.123 .26105 m
.103 .27106 L
s
.103 .27106 m
.093 .26772 L
s
.108 .25605 m
.093 .26772 L
s
.103 .27106 m
.093 .29608 L
s
.093 .26772 m
.08367 .29108 L
s
.00467 .22435 m
.02442 .24048 L
.04417 .25711 L
.06392 .27402 L
.08367 .29108 L
s
.00333 .22519 m
.02192 .24032 L
.0405 .25611 L
.05908 .27199 L
.07767 .28774 L
s
.08367 .29108 m
.093 .29608 L
s
.07967 .28857 m
.093 .29608 L
s
.07967 .28857 m
.07767 .28774 L
s
.08367 .29108 m
.07767 .28774 L
s
0 .22455 m
.00333 .22519 L
s
0 .22018 m
.00467 .22435 L
s
.00467 .22435 m
.00333 .22519 L
s
.114 .26522 m
.265 .35613 L
.31067 .45538 L
.29 .54879 L
.43433 .78065 L
.448 .83319 L
.471 .9166 L
.49567 1 L
s
.28867 .1176 m
.37533 .20601 L
.34033 .39533 L
.38767 .44037 L
.382 .52711 L
.38133 .66555 L
.443 .74979 L
.50267 .83319 L
s
.34567 .08257 m
.41367 .19766 L
.437 .22936 L
.462 .26105 L
.477 .33278 L
.48467 .41618 L
.483 .49875 L
.51867 .52877 L
.52767 .58299 L
.53767 .66639 L
.544 .74979 L
.54733 .83319 L
s
.389 .08924 m
.5 .22102 L
.627 .39283 L
.707 .52127 L
.67433 .57882 L
.73533 .66639 L
.84367 .83319 L
s
.50933 .08257 m
.54633 .12427 L
.582 .16597 L
.61667 .20767 L
.66233 .26606 L
.77533 .40784 L
.84833 .52794 L
.845 .56297 L
.92133 .66639 L
.98 .74979 L
s
1 .7794 m
.98 .74979 L
s
s
.74167 .05254 m
.76133 .08257 L
.814 .16597 L
.86567 .24937 L
.92767 .3553 L
s
1 .42495 m
.92767 .3553 L
s
s
p
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{483, 483},
  ImageMargins->{{33, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["PT pseudosection - KFMASH", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}, {10, 790}, {12, 880}, {14, 968}, 
  {16, 1054}, {18, 1139}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["KFMASH points data ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*------------------------------*)
(*  bi g mu H2O (ky sill)  *) 

i1={9.12, 750.1}//Reverse;
(*------------------------------*)
(*  bi g mu liq (sill H2O)  *) 

i2={9.27, 767.7}//Reverse;
(*------------------------------*)
(*  bi g mu H2O (liq sill)  *) 

i3={9.21, 767.0}//Reverse;
(*------------------------------*)
(*  bi mu sill H2O (g liq)  *) 

i4={7.32, 744.0}//Reverse;

(*------------------------------*)
(*  bi mu liq sill (g H2O)  *) 

i5={7.31, 744.0}//Reverse;

(*------------------------------*)
(*  g liq ksp ky (bi mu)  *) 

i6={11.19, 824.5}//Reverse;
(*------------------------------*)
(*  bi g mu liq (ksp sill)  *) 

i7={9.50, 797.3}//Reverse;

(*------------------------------*)
(*  g mu liq ksp (bi ky)  *) 

i8={11.11, 823.3}//Reverse;
(*------------------------------*)
(*  bi g mu liq ksp ky sill  *) 

i9={10.57, 815.8}//Reverse;
(*------------------------------*)
(*  g liq ksp sill (bi ky)  *) 

i10={10.76, 824.5}//Reverse;

(*------------------------------*)
(*  bi mu liq sill (g ksp)  *) 

i11={7.48, 761.4}//Reverse;

(*------------------------------*)
(*  bi liq ksp sill (g mu)  *) 

i12={7.45, 760.8}//Reverse;

(*------------------------------*)
(*  g liq ksp sill (bi cd)  *) 

i13={7.27, 831.0}//Reverse;
(*------------------------------*)
(*  cd g liq ksp (bi sill)  *) 

i14={6.09, 793.7}//Reverse;
(*------------------------------*)
(*  bi liq ksp sill (cd g)  *) 

i15={5.24, 769.4}//Reverse;
(*------------------------------*)
(*  bi cd liq ksp (g sill)  *) 

i16={4.71, 755.9}//Reverse;

(*------------------------------*)
(*  cd g liq ksp (bi opx)  *) 

i17={4.58, 812.9}//Reverse;
(*------------------------------*)
(*  cd opx liq ksp (bi g)  *) 

i18={3.29, 787.0}//Reverse;
(*------------------------------*)
(*  bi cd liq ksp (g opx)  *) 

i19={2.99, 780.8}//Reverse;

(*------------------------------*)
(*  g liq sill (cd ksp)  *) 

i20={7.06, 878.8}//Reverse;
(*------------------------------*)
(*  cd g liq (ksp sill)  *) 

i21={6.21, 881.6}//Reverse;

(*------------------------------*)
(*  cd g liq (opx ksp)  *) 

i22={4.72, 861.1}//Reverse;

(*------------------------------*)
(*  cd opx liq (g ksp)  *) 

i23={3.70, 847.2}//Reverse;

(*------------------------------*)
(*  bi mu liq sill (ksp H2O)  *) 

i24={5.08, 714.6}//Reverse;
(*------------------------------*)
(*  bi mu sill H2O (liq ksp)  *) 

i25={5.08, 714.6}//Reverse;
(*------------------------------*)
(*  bi liq ksp sill (mu H2O)  *) 

i26={5.08, 714.6}//Reverse;

(*------------------------------*)
(*  bi ksp sill H2O (mu liq)  *) 

i27={5.08, 714.6}//Reverse;

(*------------------------------*)
(*  bi liq ksp sill (cd H2O)  *) 

i28={4.16, 717.6}//Reverse;
(*------------------------------*)
(*  bi ksp sill H2O (cd liq)  *) 

i29={4.16, 717.6}//Reverse;
(*------------------------------*)
(*  bi cd liq ksp (sill H2O)  *) 

i30={3.91, 718.5}//Reverse;
(*------------------------------*)
(*  bi cd ksp H2O (liq sill)  *) 

i31={3.91, 718.6}//Reverse;

(*------------------------------*)
(*  bi mu sill H2O (cd ksp)  *) 

i32={2.83, 647.6}//Reverse;
(*------------------------------*)
(*  bi ksp sill H2O (cd mu)  *) 

i33={2.81, 647.0}//Reverse;
(*------------------------------*)
(*  bi cd mu sill (ksp H2O)  *) 

i34={2.73, 644.5}//Reverse;
(*------------------------------*)
(*  bi cd mu ksp (sill H2O)  *) 

i35={2.51, 637.5}//Reverse;
(*------------------------------*)
(*  bi cd ksp H2O (mu sill)  *) 

i36={2.12, 624.9}//Reverse;

(*------------------------------*)
(*  bi cd ksp H2O (opx liq)  *) 

i37={1.49, 759.4}//Reverse;
(*------------------------------*)
(*  bi cd liq ksp (opx H2O)  *) 

i38={1.48, 759.9}//Reverse;
(*------------------------------*)
(*  cd opx ksp H2O (bi liq)  *) 

i39={1.45, 761.4}//Reverse;
(*------------------------------*)
(*  cd opx liq ksp (bi H2O)  *) 

i40={1.44, 762.1}//Reverse;

(*------------------------------*)
(*  cd opx liq (ksp H2O)  *) 

i41={0.93, 788.8}//Reverse;

(*------------------------------*)
(*  cd liq (opx H2O)  *) 

i42={0.71, 881.2}//Reverse;







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["KFMASH  data (lines 1-20)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*------------------------------*)
(*  bi g mu H2O (liq)  *) 

u1={{5.00, 741.0},
{5.25, 743.4},
{5.50, 745.7},
{5.75, 747.7},
{6.00, 749.5},
{6.25, 751.2},
{6.50, 752.8},
{6.75, 754.3},
{7.00, 755.7},
{7.25, 757.0},
{7.50, 758.3},
{7.75, 759.6},
{8.00, 760.8},
{8.25, 762.1},
{8.50, 763.4},
{8.75, 764.6},
{9.00, 765.9},
{9.25, 767.2},
{9.50, 768.5},
{9.75, 769.8},
{10.00, 771.1},
{10.25, 772.4},
{10.50, 773.7},
{10.75, 775.0},
{11.00, 776.4},
{11.25, 777.7},
{11.50, 779.1},
{11.75, 780.5},
{12.00, 781.9},
{12.25, 783.3},
{12.50, 784.7},
{12.75, 786.1},
{13.00, 787.6}};

(*------------------------------*)
(*  bi g mu liq (H2O)  *) 

u2={{5.00, 741.0},
{5.25, 743.5},
{5.50, 745.8},
{5.75, 747.8},
{6.00, 749.7},
{6.25, 751.4},
{6.50, 753.0},
{6.75, 754.5},
{7.00, 756.0},
{7.25, 757.3},
{7.50, 758.6},
{7.75, 759.9},
{8.00, 761.2},
{8.25, 762.5},
{8.50, 763.7},
{8.75, 765.0},
{9.00, 766.3},
{9.25, 767.6},
{9.50, 768.9},
{9.75, 770.2},
{10.00, 771.5},
{10.25, 772.8},
{10.50, 774.1},
{10.75, 775.4},
{11.00, 776.8},
{11.25, 778.1},
{11.50, 779.5},
{11.75, 780.9},
{12.00, 782.3},
{12.25, 783.7},
{12.50, 785.1},
{12.75, 786.5},
{13.00, 788.0}};

(*------------------------------*)
(*  bi g mu H2O (ky)  *) 

u3={{11.26, 600.0},
{11.00, 610.0},
{10.77, 620.0},
{10.56, 630.0},
{10.37, 640.0},
{10.20, 650.0},
{10.04, 660.0},
{9.90, 670.0},
{9.77, 680.0},
{9.65, 690.0},
{9.54, 700.0},
{9.44, 710.0},
{9.35, 720.0},
{9.27, 730.0},
{9.19, 740.0},
{9.12, 750.0},
{9.05, 760.0},
{8.99, 770.0},
{8.94, 780.0},
{8.89, 790.0},
{8.85, 800.0}};

(*------------------------------*)
(*  bi g mu H2O (sill)  *) 

u4={{8.85, 700.0},
{8.90, 710.0},
{8.96, 720.0},
{9.01, 730.0},
{9.06, 740.0},
{9.12, 750.0},
{9.17, 760.0},
{9.22, 770.0},
{9.28, 780.0},
{9.33, 790.0},
{9.39, 800.0}};

(*------------------------------*)
(*  bi g mu liq sill H2O  *) 

u5={{4.80, 712.3},
{5.00, 714.9},
{5.20, 717.5},
{5.40, 720.1},
{5.60, 722.6},
{5.80, 725.2},
{6.00, 727.7},
{6.20, 730.2},
{6.40, 732.7},
{6.60, 735.2},
{6.80, 737.6},
{7.00, 740.1},
{7.20, 742.6},
{7.40, 745.0},
{7.60, 747.5},
{7.80, 749.9},
{8.00, 752.3},
{8.20, 754.8},
{8.40, 757.2},
{8.60, 759.6},
{8.80, 762.0},
{9.00, 764.5},
{9.20, 766.9},
{9.40, 769.3},
{9.60, 771.7},
{9.80, 774.1},
{10.00, 776.5}};

(*------------------------------*)
(*  bi mu sill H2O (g)  *) 

u6={{2.00, 241.7},
{2.25, 266.2},
{2.50, 290.2},
{2.75, 313.7},
{3.00, 336.7},
{3.25, 359.4},
{3.50, 381.8},
{3.75, 404.0},
{4.00, 426.1},
{4.25, 448.3},
{4.50, 470.5},
{4.75, 493.0},
{5.00, 515.6},
{5.25, 538.6},
{5.50, 561.9},
{5.75, 585.6},
{6.00, 609.7},
{6.25, 634.3},
{6.50, 659.4},
{6.75, 684.9},
{7.00, 710.8},
{7.25, 737.1},
{7.50, 763.2},
{7.75, 790.0},
{8.00, 817.7}};

(*------------------------------*)
(*  bi mu sill H2O (liq)  *) 

u7={{2.00, 667.8},
{2.25, 672.1},
{2.50, 676.3},
{2.75, 680.4},
{3.00, 684.3},
{3.25, 688.2},
{3.50, 692.0},
{3.75, 695.7},
{4.00, 699.3},
{4.25, 702.9},
{4.50, 706.5},
{4.75, 710.0},
{5.00, 713.4},
{5.25, 716.8},
{5.50, 720.2},
{5.75, 723.6},
{6.00, 726.9},
{6.25, 730.2},
{6.50, 733.4},
{6.75, 736.7},
{7.00, 739.9},
{7.25, 743.1},
{7.50, 746.3},
{7.75, 749.5},
{8.00, 752.7}};

(*------------------------------*)
(*  bi mu liq sill (H2O)  *) 

u8={{2.00, 667.8},
{2.25, 672.1},
{2.50, 676.3},
{2.75, 680.4},
{3.00, 684.3},
{3.25, 688.2},
{3.50, 692.0},
{3.75, 695.7},
{4.00, 699.3},
{4.25, 702.9},
{4.50, 706.5},
{4.75, 710.0},
{5.00, 713.4},
{5.25, 716.8},
{5.50, 720.2},
{5.75, 723.6},
{6.00, 726.9},
{6.25, 730.2},
{6.50, 733.4},
{6.75, 736.7},
{7.00, 739.9},
{7.25, 743.1},
{7.50, 746.3},
{7.75, 749.5},
{8.00, 752.7}};

(*------------------------------*)
(*  bi g mu liq (sill)  *) 

u9={{9.16, 750.0},
{9.22, 760.0},
{9.28, 770.0},
{9.35, 780.0},
{9.43, 790.0},
{9.53, 800.0},
{9.71, 810.0},
{10.13, 820.0},
{10.72, 830.0}};

(*------------------------------*)
(*  bi g mu liq ksp sill  *) 

u10={{7.40, 760.0},
{7.50, 761.8},
{7.60, 763.6},
{7.70, 765.4},
{7.80, 767.2},
{7.90, 769.0},
{8.00, 770.8},
{8.10, 772.6},
{8.20, 774.4},
{8.30, 776.2},
{8.40, 778.0},
{8.50, 779.7},
{8.60, 781.5},
{8.70, 783.3},
{8.80, 785.0},
{8.90, 786.8},
{9.00, 788.6},
{9.10, 790.3},
{9.20, 792.1},
{9.30, 793.8},
{9.40, 795.6},
{9.50, 797.3},
{9.60, 799.1},
{9.70, 800.8},
{9.80, 802.5},
{9.90, 804.3},
{10.00, 806.0},
{10.10, 807.7},
{10.20, 809.4},
{10.30, 811.2},
{10.40, 812.9},
{10.50, 814.6},
{10.60, 816.3},
{10.70, 818.0},
{10.80, 819.7},
{10.90, 821.4},
{11.00, 823.1},
{11.10, 824.8},
{11.20, 826.5}};

(*------------------------------*)
(*  bi g mu liq ksp ky  *) 

u11={{10.00, 807.7},
{10.20, 810.6},
{10.40, 813.4},
{10.60, 816.2},
{10.80, 819.0},
{11.00, 821.8},
{11.20, 824.6},
{11.40, 827.4},
{11.60, 830.2},
{11.80, 832.9},
{12.00, 835.7}};

(*------------------------------*)
(*  bi g mu liq (ksp)  *) 

u12={{8.00, 787.5},
{8.25, 789.1},
{8.50, 790.7},
{8.75, 792.3},
{9.00, 794.0},
{9.25, 795.6},
{9.50, 797.3},
{9.75, 799.0},
{10.00, 800.7},
{10.25, 802.5},
{10.50, 804.3},
{10.75, 806.1},
{11.00, 807.9},
{11.25, 809.7},
{11.50, 811.6},
{11.75, 813.5},
{12.00, 815.4},
{12.25, 817.3},
{12.50, 819.2},
{12.75, 821.2},
{13.00, 823.2}};

(*------------------------------*)
(*  g mu liq ksp (bi)  *) 

u13={{8.00, 806.3},
{8.25, 807.8},
{8.50, 809.3},
{8.75, 810.7},
{9.00, 812.1},
{9.25, 813.5},
{9.50, 814.8},
{9.75, 816.1},
{10.00, 817.4},
{10.25, 818.7},
{10.50, 820.0},
{10.75, 821.4},
{11.00, 822.7},
{11.25, 824.1},
{11.50, 825.5},
{11.75, 826.9},
{12.00, 828.3},
{12.25, 829.7},
{12.50, 831.1},
{12.75, 832.5},
{13.00, 834.0}};

(*------------------------------*)
(*  g mu liq ksp (ky)  *) 

u14={{8.00, 779.4},
{8.25, 783.1},
{8.50, 786.7},
{8.75, 790.3},
{9.00, 793.9},
{9.25, 797.4},
{9.50, 801.0},
{9.75, 804.5},
{10.00, 808.0},
{10.25, 811.5},
{10.50, 815.0},
{10.75, 818.4},
{11.00, 821.8},
{11.25, 825.3},
{11.50, 828.7},
{11.75, 832.1},
{12.00, 835.4},
{12.25, 838.8},
{12.50, 842.1},
{12.75, 845.5},
{13.00, 848.8}};

(*------------------------------*)
(*  g liq ksp ky (mu)  *) 

u15={{8.00, 779.4},
{8.25, 783.1},
{8.50, 786.7},
{8.75, 790.3},
{9.00, 793.9},
{9.25, 797.5},
{9.50, 801.0},
{9.75, 804.5},
{10.00, 808.0},
{10.25, 811.5},
{10.50, 815.0},
{10.75, 818.4},
{11.00, 821.9},
{11.25, 825.3},
{11.50, 828.7},
{11.75, 832.1},
{12.00, 835.5},
{12.25, 838.8},
{12.50, 842.2},
{12.75, 845.5},
{13.00, 848.8}};

(*------------------------------*)
(*  g liq ksp ky (bi)  *) 

u16={{10.00, 824.4},
{10.25, 824.5},
{10.50, 824.5},
{10.75, 824.5},
{11.00, 824.5},
{11.25, 824.5},
{11.50, 824.4},
{11.75, 824.4},
{12.00, 824.3},
{12.25, 824.2},
{12.50, 824.1},
{12.75, 823.9},
{13.00, 823.8}};

(*------------------------------*)
(*  g liq ksp sill (bi)  *) 

u17={{5.00, 826.5},
{5.25, 827.4},
{5.50, 828.2},
{5.75, 828.9},
{6.00, 829.4},
{6.25, 829.9},
{6.50, 830.3},
{6.75, 830.6},
{7.00, 830.8},
{7.25, 831.0},
{7.50, 831.0},
{7.75, 831.0},
{8.00, 830.8},
{8.25, 830.6},
{8.50, 830.4},
{8.75, 830.0},
{9.00, 829.6},
{9.25, 829.0},
{9.50, 828.5},
{9.75, 827.8},
{10.00, 827.1},
{10.25, 826.2},
{10.50, 825.4},
{10.75, 824.5},
{11.00, 823.6}};

(*------------------------------*)
(*  bi mu liq sill (g)  *) 

u18={{6.90, 700.0},
{6.99, 710.0},
{7.09, 720.0},
{7.18, 730.0},
{7.28, 740.0},
{7.37, 750.0}};

(*------------------------------*)
(*  bi mu liq sill (ksp)  *) 

u19={{3.00, 671.4},
{3.25, 676.8},
{3.50, 682.0},
{3.75, 687.3},
{4.00, 692.5},
{4.25, 697.6},
{4.50, 702.7},
{4.75, 707.8},
{5.00, 712.9},
{5.25, 717.9},
{5.50, 722.9},
{5.75, 727.9},
{6.00, 732.8},
{6.25, 737.7},
{6.50, 742.6},
{6.75, 747.4},
{7.00, 752.3},
{7.25, 757.1},
{7.50, 761.8},
{7.75, 766.6},
{8.00, 771.3}};

(*------------------------------*)
(*  bi liq ksp sill (mu)  *) 

u20={{2.00, 649.7},
{2.25, 655.2},
{2.50, 660.7},
{2.75, 666.1},
{3.00, 671.5},
{3.25, 676.8},
{3.50, 682.1},
{3.75, 687.3},
{4.00, 692.5},
{4.25, 697.6},
{4.50, 702.8},
{4.75, 707.9},
{5.00, 712.9},
{5.25, 717.9},
{5.50, 722.9},
{5.75, 727.9},
{6.00, 732.8},
{6.25, 737.7},
{6.50, 742.6},
{6.75, 747.5},
{7.00, 752.3},
{7.25, 757.1},
{7.50, 761.9},
{7.75, 766.6},
{8.00, 771.4}};

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["KFMASH  data (lines 21-40)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*------------------------------*)
(*  bi liq ksp sill (g)  *) 

u21={{2.00, 762.6},
{2.25, 764.0},
{2.50, 765.2},
{2.75, 766.3},
{3.00, 767.3},
{3.25, 768.1},
{3.50, 768.7},
{3.75, 769.2},
{4.00, 769.6},
{4.25, 769.8},
{4.50, 769.9},
{4.75, 769.9},
{5.00, 769.7},
{5.25, 769.3},
{5.50, 768.9},
{5.75, 768.3},
{6.00, 767.6},
{6.25, 766.7},
{6.50, 765.7},
{6.75, 764.6},
{7.00, 763.4},
{7.25, 762.0},
{7.50, 760.5},
{7.75, 758.9},
{8.00, 757.3}};

(*------------------------------*)
(*  bi cd g liq ksp sill  *) 

u22={{2.60, 717.2},
{2.80, 720.0},
{3.00, 723.0},
{3.20, 726.1},
{3.40, 729.4},
{3.60, 732.8},
{3.80, 736.5},
{4.00, 740.4},
{4.20, 744.5},
{4.40, 748.8},
{4.60, 753.3},
{4.80, 758.1},
{5.00, 763.1},
{5.20, 768.3},
{5.40, 773.7},
{5.60, 779.3},
{5.80, 785.1},
{6.00, 791.0},
{6.20, 797.1},
{6.40, 803.2},
{6.60, 809.5},
{6.80, 815.9},
{7.00, 822.3},
{7.20, 828.8},
{7.40, 835.4},
{7.60, 841.9},
{7.80, 848.5},
{8.00, 855.1},
{8.20, 861.8},
{8.40, 868.4},
{8.60, 875.0},
{8.80, 881.7},
{9.00, 888.3},
{9.20, 894.9},
{9.40, 901.6},
{9.60, 908.2},
{9.80, 914.8},
{10.00, 921.5}};

(*------------------------------*)
(*  g liq ksp sill (cd)  *) 

u23={{7.37, 800.0},
{7.34, 810.0},
{7.31, 820.0},
{7.27, 830.0},
{7.23, 840.0},
{7.19, 850.0},
{7.15, 860.0},
{7.10, 870.0}};

(*------------------------------*)
(*  cd g liq ksp (sill)  *) 

u24={{6.10, 800.0},
{6.11, 810.0},
{6.13, 820.0},
{6.14, 830.0},
{6.15, 840.0},
{6.17, 850.0},
{6.18, 860.0},
{6.19, 870.0},
{6.21, 880.0}};

(*------------------------------*)
(*  cd g liq ksp (bi)  *) 

u25={{2.50, 817.3},
{2.75, 818.6},
{3.00, 819.3},
{3.25, 819.6},
{3.50, 819.3},
{3.75, 818.6},
{4.00, 817.4},
{4.25, 815.7},
{4.50, 813.6},
{4.75, 811.2},
{5.00, 808.4},
{5.25, 805.4},
{5.50, 802.1},
{5.75, 798.6},
{6.00, 795.0}};

(*------------------------------*)
(*  bi cd liq ksp (g)  *) 

u26={{2.00, 797.0},
{2.25, 792.3},
{2.50, 788.3},
{2.75, 784.4},
{3.00, 780.7},
{3.25, 776.9},
{3.50, 773.1},
{3.75, 769.4},
{4.00, 765.8},
{4.25, 762.2},
{4.50, 758.7},
{4.75, 755.3},
{5.00, 752.0},
{5.25, 748.9},
{5.50, 745.8},
{5.75, 742.9},
{6.00, 740.1}};

(*------------------------------*)
(*  bi liq ksp sill (cd)  *) 

u27={{3.80, 700.0},
{4.00, 710.0},
{4.21, 720.0},
{4.42, 730.0},
{4.63, 740.0},
{4.84, 750.0},
{5.04, 760.0},
{5.25, 770.0},
{5.46, 780.0},
{5.67, 790.0},
{5.89, 800.0}};

(*------------------------------*)
(*  bi cd liq ksp (sill)  *) 

u28={{3.52, 700.0},
{3.73, 710.0},
{3.95, 720.0},
{4.16, 730.0},
{4.37, 740.0},
{4.58, 750.0},
{4.80, 760.0},
{5.01, 770.0},
{5.22, 780.0},
{5.44, 790.0},
{5.66, 800.0}};

(*------------------------------*)
(*  bi cd g opx liq ksp  *) 

u29={{2.40, 768.3},
{2.60, 772.5},
{2.80, 776.7},
{3.00, 780.9},
{3.20, 785.1},
{3.40, 789.2},
{3.60, 793.3},
{3.80, 797.4},
{4.00, 801.5},
{4.20, 805.5},
{4.40, 809.4},
{4.60, 813.4},
{4.80, 817.3}};

(*------------------------------*)
(*  cd g liq ksp (opx)  *) 

u30={{4.54, 800.0},
{4.57, 810.0},
{4.59, 820.0},
{4.62, 830.0},
{4.65, 840.0},
{4.68, 850.0},
{4.72, 860.0}};

(*------------------------------*)
(*  cd opx liq ksp (g)  *) 

u31={{3.37, 800.0},
{3.44, 810.0},
{3.51, 820.0},
{3.57, 830.0},
{3.65, 840.0}};

(*------------------------------*)
(*  cd opx liq ksp (bi)  *) 

u32={{0.40, 745.7},
{0.60, 749.0},
{0.80, 752.2},
{1.00, 755.4},
{1.20, 758.4},
{1.40, 761.5},
{1.60, 764.4},
{1.80, 767.3},
{2.00, 770.1},
{2.20, 772.9},
{2.40, 775.6},
{2.60, 778.2},
{2.80, 780.8},
{3.00, 783.4},
{3.20, 785.9},
{3.40, 788.3},
{3.60, 790.7},
{3.80, 793.0},
{4.00, 795.3}};

(*------------------------------*)
(*  bi cd liq ksp (opx)  *) 

u33={{0.20, 739.2},
{0.40, 742.7},
{0.60, 746.0},
{0.80, 749.3},
{1.00, 752.5},
{1.20, 755.6},
{1.40, 758.7},
{1.60, 761.7},
{1.80, 764.6},
{2.00, 767.5},
{2.20, 770.3},
{2.40, 773.0},
{2.60, 775.7},
{2.80, 778.3},
{3.00, 780.9},
{3.20, 783.4},
{3.40, 785.8},
{3.60, 788.2},
{3.80, 790.6},
{4.00, 792.9}};

(*------------------------------*)
(*  g liq sill (ksp)  *) 

u34={{6.00, 863.3},
{6.25, 867.1},
{6.50, 870.7},
{6.75, 874.4},
{7.00, 878.0},
{7.25, 881.5},
{7.50, 884.9},
{7.75, 888.3},
{8.00, 891.7},
{8.25, 894.9},
{8.50, 898.2},
{8.75, 901.3},
{9.00, 904.5},
{9.25, 907.5},
{9.50, 910.6},
{9.75, 913.5},
{10.00, 916.5},
{10.25, 919.4},
{10.50, 922.2},
{10.75, 925.0},
{11.00, 927.7},
{11.25, 930.4},
{11.50, 933.1},
{11.75, 935.7},
{12.00, 938.2},
{12.25, 940.8},
{12.50, 943.3},
{12.75, 945.7},
{13.00, 948.1}};

(*------------------------------*)
(*  cd g liq sill (ksp)  *) 

u35={{6.40, 881.4},
{6.50, 881.3},
{6.60, 881.0},
{6.70, 880.7},
{6.80, 880.3},
{6.90, 879.8}};

(*------------------------------*)
(*  cd g liq (ksp)  *) 

u36={{4.00, 849.3},
{4.20, 852.7},
{4.40, 856.0},
{4.60, 859.2},
{4.80, 862.3},
{5.00, 865.3},
{5.20, 868.3},
{5.40, 871.1},
{5.60, 873.8},
{5.80, 876.5},
{6.00, 879.0},
{6.20, 881.5},
{6.40, 883.8},
{6.60, 886.1},
{6.80, 888.2},
{7.00, 890.3}};

(*------------------------------*)
(*  g liq sill (cd)  *) 

u37={{6.99, 850.0},
{7.01, 860.0},
{7.04, 870.0},
{7.06, 880.0},
{7.09, 890.0},
{7.11, 900.0},
{7.13, 910.0},
{7.16, 920.0},
{7.18, 930.0},
{7.20, 940.0},
{7.23, 950.0},
{7.25, 960.0},
{7.27, 970.0},
{7.30, 980.0},
{7.33, 990.0},
{7.35, 1000.0},
{7.38, 1010.0}};

(*------------------------------*)
(*  cd g liq (sill)  *) 

u38={{5.99, 850.0},
{6.06, 860.0},
{6.13, 870.0},
{6.20, 880.0},
{6.27, 890.0},
{6.34, 900.0},
{6.41, 910.0},
{6.49, 920.0},
{6.57, 930.0},
{6.65, 940.0},
{6.73, 950.0},
{6.82, 960.0},
{6.91, 970.0},
{7.00, 980.0},
{7.10, 990.0},
{7.20, 1000.0},
{7.31, 1010.0}};

(*------------------------------*)
(*  cd g liq (opx)  *) 

u39={{4.66, 850.0},
{4.72, 860.0},
{4.78, 870.0},
{4.85, 880.0},
{4.91, 890.0},
{4.98, 900.0},
{5.06, 910.0},
{5.14, 920.0},
{5.22, 930.0},
{5.32, 940.0},
{5.42, 950.0},
{5.52, 960.0},
{5.64, 970.0},
{5.78, 980.0},
{5.92, 990.0},
{6.09, 1000.0},
{6.27, 1010.0},
{6.47, 1020.0},
{6.69, 1030.0},
{6.92, 1040.0},
{7.17, 1050.0}};

(*------------------------------*)
(*  cd g opx liq (ksp)  *) 

u40={{3.80, 848.6},
{4.00, 851.4},
{4.20, 854.1},
{4.40, 856.8},
{4.60, 859.5}};








\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["KFMASH  data (lines 41-> )", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*------------------------------*)
(*  cd opx liq (ksp)  *) 

u41={{0.20, 770.7},
{0.40, 775.8},
{0.60, 780.7},
{0.80, 785.6},
{1.00, 790.3},
{1.20, 795.0},
{1.40, 799.6},
{1.60, 804.1},
{1.80, 808.6},
{2.00, 812.9},
{2.20, 817.2},
{2.40, 821.5},
{2.60, 825.6},
{2.80, 829.7},
{3.00, 833.7},
{3.20, 837.6},
{3.40, 841.5},
{3.60, 845.3},
{3.80, 849.0},
{4.00, 852.7},
{4.20, 856.3},
{4.40, 859.8},
{4.60, 863.3},
{4.80, 866.6},
{5.00, 869.9}};

(*------------------------------*)
(*  cd opx liq (g)  *) 

u42={{3.27, 800.0},
{3.36, 810.0},
{3.45, 820.0},
{3.54, 830.0},
{3.63, 840.0},
{3.73, 850.0},
{3.83, 860.0},
{3.93, 870.0},
{4.03, 880.0},
{4.14, 890.0},
{4.26, 900.0},
{4.38, 910.0},
{4.50, 920.0},
{4.63, 930.0},
{4.77, 940.0},
{4.91, 950.0},
{5.06, 960.0},
{5.22, 970.0},
{5.38, 980.0},
{5.56, 990.0},
{5.74, 1000.0},
{5.93, 1010.0},
{6.13, 1020.0},
{6.33, 1030.0},
{6.54, 1040.0},
{6.76, 1050.0}};

(*------------------------------*)
(*  bi liq ksp sill (H2O)  *) 

u43={{3.00, 724.4},
{3.20, 722.8},
{3.40, 721.5},
{3.60, 720.3},
{3.80, 719.2},
{4.00, 718.3},
{4.20, 717.4},
{4.40, 716.7},
{4.60, 716.0},
{4.80, 715.4},
{5.00, 714.8},
{5.20, 714.3},
{5.40, 713.8},
{5.60, 713.4},
{5.80, 712.9},
{6.00, 712.6}};

(*------------------------------*)
(*  bi ksp sill H2O (liq)  *) 

u44={{3.00, 724.4},
{3.20, 722.8},
{3.40, 721.5},
{3.60, 720.3},
{3.80, 719.2},
{4.00, 718.3},
{4.20, 717.4},
{4.40, 716.7},
{4.60, 716.0},
{4.80, 715.4},
{5.00, 714.8},
{5.20, 714.3},
{5.40, 713.8},
{5.60, 713.4},
{5.80, 712.9},
{6.00, 712.6}};

(*------------------------------*)
(*  bi ksp sill H2O (mu)  *) 

u45={{1.00, 581.4},
{1.20, 590.2},
{1.40, 598.3},
{1.60, 605.9},
{1.80, 613.1},
{2.00, 620.2},
{2.20, 627.0},
{2.40, 633.7},
{2.60, 640.2},
{2.80, 646.6},
{3.00, 652.9},
{3.20, 659.1},
{3.40, 665.3},
{3.60, 671.3},
{3.80, 677.3},
{4.00, 683.2},
{4.20, 689.1},
{4.40, 694.9},
{4.60, 700.7},
{4.80, 706.5},
{5.00, 712.2},
{5.20, 717.9},
{5.40, 723.6},
{5.60, 729.2},
{5.80, 734.8},
{6.00, 740.4}};

(*------------------------------*)
(*  bi mu sill H2O (ksp)  *) 

u46={{1.00, 581.4},
{1.20, 590.2},
{1.40, 598.3},
{1.60, 605.9},
{1.80, 613.1},
{2.00, 620.1},
{2.20, 627.0},
{2.40, 633.7},
{2.60, 640.2},
{2.80, 646.6},
{3.00, 652.9},
{3.20, 659.1},
{3.40, 665.2},
{3.60, 671.3},
{3.80, 677.3},
{4.00, 683.2},
{4.20, 689.1},
{4.40, 694.9},
{4.60, 700.7},
{4.80, 706.5},
{5.00, 712.2},
{5.20, 717.9},
{5.40, 723.5},
{5.60, 729.2},
{5.80, 734.8},
{6.00, 740.4}};

(*------------------------------*)
(*  bi cd liq ksp sill H2O  *) 

u47={{3.00, 723.8},
{3.10, 723.1},
{3.20, 722.4},
{3.30, 721.7},
{3.40, 721.1},
{3.50, 720.5},
{3.60, 720.0},
{3.70, 719.5},
{3.80, 719.0},
{3.90, 718.6},
{4.00, 718.2},
{4.10, 717.8},
{4.20, 717.5},
{4.30, 717.1},
{4.40, 716.8},
{4.50, 716.5},
{4.60, 716.2},
{4.70, 715.9},
{4.80, 715.7},
{4.90, 715.4},
{5.00, 715.2}};

(*------------------------------*)
(*  bi cd liq ksp (H2O)  *) 

u48={{1.00, 778.0},
{1.20, 769.8},
{1.40, 762.6},
{1.60, 756.3},
{1.80, 750.8},
{2.00, 746.1},
{2.20, 741.8},
{2.40, 738.0},
{2.60, 734.6},
{2.80, 731.6},
{3.00, 728.8},
{3.20, 726.3},
{3.40, 723.9},
{3.60, 721.7},
{3.80, 719.7},
{4.00, 717.7}};

(*------------------------------*)
(*  bi cd ksp H2O (liq)  *) 

u49={{0.80, 784.6},
{1.00, 777.0},
{1.20, 769.3},
{1.40, 762.3},
{1.60, 756.2},
{1.80, 750.7},
{2.00, 746.0},
{2.20, 741.8},
{2.40, 738.0},
{2.60, 734.6},
{2.80, 731.5},
{3.00, 728.8},
{3.20, 726.2},
{3.40, 723.9},
{3.60, 721.7},
{3.80, 719.6},
{4.00, 717.7}};

(*------------------------------*)
(*  bi cd ksp H2O (sill)  *) 

u50={{0.20, 498.1},
{0.40, 523.2},
{0.60, 539.0},
{0.80, 551.8},
{1.00, 563.5},
{1.20, 574.8},
{1.40, 585.9},
{1.60, 596.8},
{1.80, 607.6},
{2.00, 618.4},
{2.20, 629.2},
{2.40, 639.9},
{2.60, 650.5},
{2.80, 661.1},
{3.00, 671.6},
{3.20, 682.1},
{3.40, 692.5},
{3.60, 702.8},
{3.80, 713.1},
{4.00, 723.4}};

(*------------------------------*)
(*  bi ksp sill H2O (cd)  *) 

u51={{0.20, 485.9},
{0.40, 510.1},
{0.60, 525.2},
{0.80, 537.6},
{1.00, 549.2},
{1.20, 560.4},
{1.40, 571.4},
{1.60, 582.2},
{1.80, 593.0},
{2.00, 603.7},
{2.20, 614.4},
{2.40, 625.0},
{2.60, 635.7},
{2.80, 646.3},
{3.00, 657.0},
{3.20, 667.5},
{3.40, 678.0},
{3.60, 688.5},
{3.80, 698.9},
{4.00, 709.3}};

(*------------------------------*)
(*  bi cd mu ksp sill H2O  *) 

u52={{2.00, 620.8},
{2.05, 622.5},
{2.10, 624.2},
{2.15, 625.9},
{2.20, 627.5},
{2.25, 629.2},
{2.30, 630.8},
{2.35, 632.5},
{2.40, 634.1},
{2.45, 635.7},
{2.50, 637.3},
{2.55, 638.9},
{2.60, 640.4},
{2.65, 642.0},
{2.70, 643.6},
{2.75, 645.1},
{2.80, 646.6},
{2.85, 648.2},
{2.90, 649.7},
{2.95, 651.2},
{3.00, 652.7}};

(*------------------------------*)
(*  bi mu sill H2O (cd)  *) 

u53={{2.47, 600.0},
{2.51, 605.0},
{2.54, 610.0},
{2.58, 615.0},
{2.62, 620.0},
{2.66, 625.0},
{2.70, 630.0},
{2.74, 635.0},
{2.78, 640.0},
{2.81, 645.0},
{2.85, 650.0},
{2.89, 655.0},
{2.92, 660.0}};

(*------------------------------*)
(*  bi cd mu sill (H2O)  *) 

u54={{2.39, 600.0},
{2.43, 605.0},
{2.47, 610.0},
{2.50, 615.0},
{2.54, 620.0},
{2.58, 625.0},
{2.62, 630.0},
{2.66, 635.0},
{2.70, 640.0},
{2.73, 645.0},
{2.77, 650.0},
{2.81, 655.0},
{2.84, 660.0}};

(*------------------------------*)
(*  bi cd mu sill (ksp)  *) 

u55={{2.01, 600.0},
{2.09, 605.0},
{2.17, 610.0},
{2.25, 615.0},
{2.33, 620.0},
{2.41, 625.0},
{2.49, 630.0},
{2.57, 635.0},
{2.65, 640.0},
{2.74, 645.0},
{2.82, 650.0},
{2.91, 655.0},
{2.99, 660.0}};

(*------------------------------*)
(*  bi cd mu ksp (sill)  *) 

u56={{1.92, 600.0},
{2.00, 605.0},
{2.07, 610.0},
{2.15, 615.0},
{2.23, 620.0},
{2.31, 625.0},
{2.39, 630.0},
{2.47, 635.0},
{2.55, 640.0},
{2.63, 645.0},
{2.71, 650.0},
{2.80, 655.0},
{2.88, 660.0}};

(*------------------------------*)
(*  bi cd mu ksp (H2O)  *) 

u57={{1.61, 600.0},
{1.72, 605.0},
{1.84, 610.0},
{1.96, 615.0},
{2.08, 620.0},
{2.20, 625.0},
{2.32, 630.0},
{2.45, 635.0},
{2.57, 640.0},
{2.69, 645.0},
{2.82, 650.0}};

(*------------------------------*)
(*  bi cd ksp H2O (mu)  *) 

u58={{1.54, 600.0},
{1.65, 605.0},
{1.77, 610.0},
{1.88, 615.0},
{2.00, 620.0},
{2.12, 625.0},
{2.24, 630.0},
{2.37, 635.0},
{2.49, 640.0},
{2.62, 645.0},
{2.74, 650.0}};

(*------------------------------*)
(*  bi cd opx liq ksp H2O  *) 

u59={{1.00, 792.9},
{1.10, 784.1},
{1.20, 776.6},
{1.30, 770.0},
{1.40, 764.2},
{1.50, 759.0},
{1.60, 754.1}};

(*------------------------------*)
(*  bi cd ksp H2O (opx)  *) 

u60={{0.00, 345.6},
{0.20, 610.4},
{0.40, 661.2},
{0.60, 691.5},
{0.80, 712.9},
{1.00, 729.5},
{1.20, 743.1},
{1.40, 754.7},
{1.60, 764.9},
{1.80, 774.1},
{2.00, 782.4}};

(*------------------------------*)
(*  cd opx ksp H2O (bi)  *) 

u61={{0.00, 345.8},
{0.20, 613.9},
{0.40, 665.0},
{0.60, 695.3},
{0.80, 716.8},
{1.00, 733.4},
{1.20, 747.1},
{1.40, 758.7},
{1.60, 768.9},
{1.80, 778.0},
{2.00, 786.3}};

(*------------------------------*)
(*  cd opx ksp H2O (liq)  *) 

u62={{0.00, 936.1},
{0.10, 891.9},
{0.20, 870.5},
{0.30, 853.8},
{0.40, 839.6},
{0.50, 827.4},
{0.60, 816.5},
{0.70, 806.9},
{0.80, 798.4},
{1.00, 783.9},
{1.20, 772.5},
{1.40, 763.4},
{1.60, 756.1},
{1.80, 750.1},
{2.00, 745.1}};

(*------------------------------*)
(*  cd opx liq ksp (H2O)  *) 

u63={{1.00, 784.3},
{1.20, 772.8},
{1.40, 763.6},
{1.60, 756.3},
{1.80, 750.2},
{2.00, 745.2}};

(*------------------------------*)
(*  cd opx liq H2O (ksp)  *) 

u64={{0.00, 939.2},
{0.10, 893.5},
{0.20, 871.9},
{0.30, 854.7},
{0.40, 840.4},
{0.50, 828.0},
{0.60, 817.1},
{0.70, 807.4},
{0.80, 798.8},
{0.90, 791.1}};

(*------------------------------*)
(*  cd opx liq (H2O)  *) 

u65={{0.98, 750.0},
{0.97, 760.0},
{0.96, 770.0},
{0.95, 780.0},
{0.93, 790.0},
{0.91, 800.0},
{0.90, 810.0},
{0.87, 820.0},
{0.85, 830.0},
{0.83, 840.0},
{0.80, 850.0},
{0.77, 860.0},
{0.74, 870.0}};

(*------------------------------*)
(*  cd liq (opx)  *) 

u66={{0.20, 870.7},
{0.40, 874.8},
{0.60, 878.9},
{0.80, 883.1},
{1.00, 887.4},
{1.20, 891.7},
{1.40, 896.1},
{1.60, 900.6},
{1.80, 905.1},
{2.00, 909.8},
{2.20, 914.5},
{2.40, 919.4},
{2.60, 924.4},
{2.80, 929.5},
{3.00, 934.7},
{3.20, 940.1},
{3.40, 945.7},
{3.60, 951.5},
{3.80, 957.5},
{4.00, 963.8},
{4.20, 970.4},
{4.40, 977.3},
{4.60, 984.7},
{4.80, 992.5},
{5.00, 1001.1},
{5.20, 1010.5},
{5.40, 1021.2},
{5.60, 1034.0},
{5.80, 1051.2}};

(*------------------------------*)
(*  cd liq (H2O)  *) 

u67={{0.75, 850.0},
{0.74, 860.0},
{0.73, 870.0},
{0.71, 880.0},
{0.70, 890.0},
{0.68, 900.0},
{0.66, 910.0},
{0.64, 920.0},
{0.63, 930.0},
{0.61, 940.0},
{0.58, 950.0},
{0.56, 960.0},
{0.54, 970.0},
{0.52, 980.0},
{0.50, 990.0},
{0.47, 1000.0},
{0.45, 1010.0},
{0.43, 1020.0},
{0.41, 1030.0},
{0.38, 1040.0},
{0.36, 1050.0}};

(*------------------------------*)
(*  cd liq H2O (opx)  *) 

u68={{0.55, 890.0},
{0.39, 900.0},
{0.27, 910.0},
{0.17, 920.0},
{0.09, 930.0},
{0.04, 940.0},
{0.03, 942.0},
{0.02, 944.0},
{0.02, 946.0},
{0.01, 948.0},
{0.01, 950.0}};



\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{2,1};\n   \n \n \t\tas1 = makeline[ka, trp, ll];\n \t\tas2 = makeline[sk, \
trp, i1];\n \t\tas3 = makeline[as, trp, lr];\n \t\tas2a = makeline[sk, ur, \
i9];\n \t\n \t\t\n \t\tlu1 = makeline[u1, i3, ur];\n \t\tlu2 = makeline[u2, \
i2, ur];\n \t\tlu3 = makeline[u3, ul, i1];\n \t\tlu4 = makeline[u4, i1, i3];\n\
 \t\tlu5 = makeline[u5, i5, i2];\n \t\tlu6 = makeline[u6, ll, i4];\n \t\tlu7 \
= makeline[u7, i25, i4];\n \t\tlu8 = makeline[u8, i24, i5];\n \t\tlu9 = \
makeline[u9, i7, i2];\n \t\tlu10 = makeline[u10, i12, i9];\n   lu11a = \
makeline[u11, i8, i9];\n   lu11b = makeline[u11, i8, i6];\n   lu12 = \
makeline[u12, i7, ur];\n   lu13 = makeline[u13, i8, ur];\n   lu14 = \
makeline[u14, i8, ur];\n   lu15 = makeline[u15, i6, ur];\n   lu16 = \
makeline[u16, i6, i10];\n   lu17 = makeline[u17, i10, i13];\n   lu18 = \
makeline[u18, i11, i5];\n   lu19 = makeline[u19, i11, i24];\n   lu20 = \
makeline[u20, i12, i26];\n   lu21 = makeline[u21, i12, i15];\n   lu22 = \
makeline[u22, i13, i16];\n   lu23 = makeline[u23, i13, i20];\n   lu24 = \
makeline[u24, i14, i21];\n   lu25 = makeline[u25, i14, i17];\n   lu26 = \
makeline[u26, i16, i19];\n   lu27 = makeline[u27, i15, i28];\n   lu28 = \
makeline[u28, i16, i30];\n   lu29 = makeline[u29, i17, i19];\n   lu30 = \
makeline[u30, i17, i22];\n   lu31 = makeline[u31, i18, i23];\n   lu32 = \
makeline[u32, i18, i40];\n   lu33 = makeline[u33, i19, i38];\n   lu34 = \
makeline[u34, i20, ur];\n   lu35 = makeline[u35, i21, i20];\n   lu36 = \
makeline[u36, i21, i22];\n   lu37 = makeline[u37, i20, ur];\n   lu38 = \
makeline[u38, i21, ur];\n   lu39 = makeline[u39, i22, ur];\n   lu40 = \
makeline[u40, i23, i22];\n   lu41 = makeline[u41, i23, i41];\n   lu42 = \
makeline[u42, i23, ur];\n   lu43 = makeline[u43, i26, i28];\n   lu44 = \
makeline[u44, i27, i29];\n   lu45 = makeline[u45, i27, i33];\n   lu46 = \
makeline[u46, i25, i32];\n   lu47 = makeline[u47, i28, i31];\n   lu48 = \
makeline[u48, i30, i38];\n   lu49 = makeline[u49, i37, i31];\n   lu50 = \
makeline[u50, i36, i31];\n   lu51 = makeline[u51, i29, i33];\n   lu52 = \
makeline[u52, i32, i36];\n   lu53 = makeline[u53, i32, ll];\n   lu54 = \
makeline[u54, i34, ll];\n   lu55 = makeline[u55, i34, ll];\n   lu56 = \
makeline[u56, i35, ll];\n   lu57 = makeline[u57, i35, ll];\n   lu58 = \
makeline[u58, i36, ll];\n   lu59 = makeline[u59, i37, i40];\n   lu60 = \
makeline[u60, i37, ll];\n   lu61 = makeline[u61, i39, ll];\n   lu62 = \
makeline[u62, i39, lr];\n   lu63 = makeline[u63, i40, i41];\n   lu64 = \
makeline[u64, i41, lr];\n   lu65 = makeline[u65, i41, i42];\n   lu66 = \
makeline[u66, i42, ur];\n   lu67 = makeline[u67, i42, lr];\n   lu68 = \
makeline[u68, i42, lr];\n   \n   \n  \n  \t\n  \t \n   Show[Graphics[\n   \t\t\
\t\t\t\t\t{GrayLevel[0.85],\n          area[{lu37,lu35,lu38}],\n          \
area[{lu39,lu40,lu42}],\n          area[{lu68,lu65,lu64}],\n          \
area[{lu15,lu16,lu17,lu23,lu34}],\n          area[{lu24,lu25,lu30,lu36}],\n   \
       area[{lu3,lu4,lu1}],\n          area[{lu2,lu9,lu12}],\n          \
area[{lu13,lu14}],\n          area[{lu6,lu7,lu46,lu53}],\n          \
area[{lu54,lu55}],\n          area[{lu56,lu57}],\n          \
area[{lu58,lu50,lu49,lu60}],\n          area[{lu61,lu62}],\n          \
area[{lu31,lu32,lu63,lu41}],\n          area[{lu33,lu26,lu28,lu48}],\n        \
  area[{lu8,lu18,lu19}],\n          area[{lu20,lu21,lu27,lu43}],\n          \
area[{lu44,lu45,lu51}],\n         \n          GrayLevel[0.65],\n          \
area[{lu68,lu67}],\n          area[{lu42,lu41,lu65,lu66}],\n          \
area[{lu34,lu37}],\n          area[{lu38,lu36,lu39}],\n         \n          \
GrayLevel[0.35],\n          area[{lu66,lu67}], \n         \n          \
GrayLevel[0.15],\n          \n         \n          GrayLevel[0],\n        \n  \
        GrayLevel[0],\n           AbsoluteThickness[0.3],\n          \n       \
    \n         \n           drawline[as1],\n           drawline[as2],\n       \
    \n           drawline[as2a],\n             \t\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu1],\n          \tdrawline[lu2],\n          \t\
drawline[lu3],\n          \tdrawline[lu4],\n          \tdrawline[lu6],\n      \
    \tdrawline[lu7],\n          \tdrawline[lu8],\n          \tdrawline[lu9],\n\
          \tdrawline[lu12],\n          \t\n          \tdrawline[lu13],\n      \
    \tdrawline[lu14],\n          \t\n          \tdrawline[lu15],\n          \t\
\n          \tdrawline[lu16],\n          \tdrawline[lu17],\n          \t\
drawline[lu18],\n          \tdrawline[lu19],\n          \tdrawline[lu20],\n   \
       \tdrawline[lu21],\n          \tdrawline[lu23],\n          \t\
drawline[lu24],\n          \tdrawline[lu25],\n          \tdrawline[lu26],\n   \
       \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu27],\n          \tdrawline[lu28],\n          \t\
drawline[lu30],\n          \tdrawline[lu31],\n          \tdrawline[lu32],\n   \
       \tdrawline[lu33],\n          \t",
    FontWeight->"Plain"],
  StyleBox["\n          \t",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu34],\n          \tdrawline[lu35],\n          \t\
drawline[lu36],\n          \tdrawline[lu37],\n          \tdrawline[lu38],\n   \
       \tdrawline[lu39],\n          \tdrawline[lu40],\n          \t\
drawline[lu41],\n          \tdrawline[lu42],\n          \tdrawline[lu43],\n   \
       \tdrawline[lu44],\n          \tdrawline[lu45],\n          \t\
drawline[lu46],\n          \tdrawline[lu48],\n          \tdrawline[lu49],\n   \
       \tdrawline[lu50],\n          \tdrawline[lu51],\n           \
drawline[lu53],\n           drawline[lu54],\n           drawline[lu55],\n     \
      drawline[lu56],\n           drawline[lu57],\n           drawline[lu58],\
\n           drawline[lu60],\n           drawline[lu61],\n           \
drawline[lu62],\n           drawline[lu63],\n           \n           \
drawline[lu64],\n           drawline[lu65],\n           drawline[lu66],\n     \
      drawline[lu67],\n           drawline[lu68],\n           \n          \t\n\
         \n          \n          AbsoluteThickness[0.6],\n          \n        \
  GrayLevel[0],\n          drawline[lu5],\n          drawline[lu10],\n        \
  drawline[lu11a],\n          drawline[lu11b],\n          drawline[lu22],\n   \
       drawline[lu29],\n          drawline[lu47],\n          drawline[lu52],\n\
          drawline[lu59],\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[0,1,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["RGBColor[0,0,1],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n           \n           \n           outline}],\n               \
\n         AspectRatio -> 1, Frame -> True,\n         PlotRange -> {{xlow, \
xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 630; xhigh = 1000; ylow = 0.01; yhigh = 12;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.7027 0.0027027 -0.000834028 0.0834028 [
[(650)] .05405 0 0 2 Msboxa
[(700)] .18919 0 0 2 Msboxa
[(750)] .32432 0 0 2 Msboxa
[(800)] .45946 0 0 2 Msboxa
[(850)] .59459 0 0 2 Msboxa
[(900)] .72973 0 0 2 Msboxa
[(950)] .86486 0 0 2 Msboxa
[(1000)] 1 0 0 2 Msboxa
[(2)] -0.0125 .16597 1 0 Msboxa
[(4)] -0.0125 .33278 1 0 Msboxa
[(6)] -0.0125 .49958 1 0 Msboxa
[(8)] -0.0125 .66639 1 0 Msboxa
[(10)] -0.0125 .83319 1 0 Msboxa
[(12)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.05405 0 m
.05405 .00625 L
s
P
[(650)] .05405 0 0 2 Mshowa
p
.002 w
.18919 0 m
.18919 .00625 L
s
P
[(700)] .18919 0 0 2 Mshowa
p
.002 w
.32432 0 m
.32432 .00625 L
s
P
[(750)] .32432 0 0 2 Mshowa
p
.002 w
.45946 0 m
.45946 .00625 L
s
P
[(800)] .45946 0 0 2 Mshowa
p
.002 w
.59459 0 m
.59459 .00625 L
s
P
[(850)] .59459 0 0 2 Mshowa
p
.002 w
.72973 0 m
.72973 .00625 L
s
P
[(900)] .72973 0 0 2 Mshowa
p
.002 w
.86486 0 m
.86486 .00625 L
s
P
[(950)] .86486 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1000)] 1 0 0 2 Mshowa
p
.001 w
.08108 0 m
.08108 .00375 L
s
P
p
.001 w
.10811 0 m
.10811 .00375 L
s
P
p
.001 w
.13514 0 m
.13514 .00375 L
s
P
p
.001 w
.16216 0 m
.16216 .00375 L
s
P
p
.001 w
.21622 0 m
.21622 .00375 L
s
P
p
.001 w
.24324 0 m
.24324 .00375 L
s
P
p
.001 w
.27027 0 m
.27027 .00375 L
s
P
p
.001 w
.2973 0 m
.2973 .00375 L
s
P
p
.001 w
.35135 0 m
.35135 .00375 L
s
P
p
.001 w
.37838 0 m
.37838 .00375 L
s
P
p
.001 w
.40541 0 m
.40541 .00375 L
s
P
p
.001 w
.43243 0 m
.43243 .00375 L
s
P
p
.001 w
.48649 0 m
.48649 .00375 L
s
P
p
.001 w
.51351 0 m
.51351 .00375 L
s
P
p
.001 w
.54054 0 m
.54054 .00375 L
s
P
p
.001 w
.56757 0 m
.56757 .00375 L
s
P
p
.001 w
.62162 0 m
.62162 .00375 L
s
P
p
.001 w
.64865 0 m
.64865 .00375 L
s
P
p
.001 w
.67568 0 m
.67568 .00375 L
s
P
p
.001 w
.7027 0 m
.7027 .00375 L
s
P
p
.001 w
.75676 0 m
.75676 .00375 L
s
P
p
.001 w
.78378 0 m
.78378 .00375 L
s
P
p
.001 w
.81081 0 m
.81081 .00375 L
s
P
p
.001 w
.83784 0 m
.83784 .00375 L
s
P
p
.001 w
.89189 0 m
.89189 .00375 L
s
P
p
.001 w
.91892 0 m
.91892 .00375 L
s
P
p
.001 w
.94595 0 m
.94595 .00375 L
s
P
p
.001 w
.97297 0 m
.97297 .00375 L
s
P
p
.001 w
.02703 0 m
.02703 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .16597 m
.00625 .16597 L
s
P
[(2)] -0.0125 .16597 1 0 Mshowa
p
.002 w
0 .33278 m
.00625 .33278 L
s
P
[(4)] -0.0125 .33278 1 0 Mshowa
p
.002 w
0 .49958 m
.00625 .49958 L
s
P
[(6)] -0.0125 .49958 1 0 Mshowa
p
.002 w
0 .66639 m
.00625 .66639 L
s
P
[(8)] -0.0125 .66639 1 0 Mshowa
p
.002 w
0 .83319 m
.00625 .83319 L
s
P
[(10)] -0.0125 .83319 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(12)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .03253 m
.00375 .03253 L
s
P
p
.001 w
0 .06589 m
.00375 .06589 L
s
P
p
.001 w
0 .09925 m
.00375 .09925 L
s
P
p
.001 w
0 .13261 m
.00375 .13261 L
s
P
p
.001 w
0 .19933 m
.00375 .19933 L
s
P
p
.001 w
0 .23269 m
.00375 .23269 L
s
P
p
.001 w
0 .26606 m
.00375 .26606 L
s
P
p
.001 w
0 .29942 m
.00375 .29942 L
s
P
p
.001 w
0 .36614 m
.00375 .36614 L
s
P
p
.001 w
0 .3995 m
.00375 .3995 L
s
P
p
.001 w
0 .43286 m
.00375 .43286 L
s
P
p
.001 w
0 .46622 m
.00375 .46622 L
s
P
p
.001 w
0 .53294 m
.00375 .53294 L
s
P
p
.001 w
0 .56631 m
.00375 .56631 L
s
P
p
.001 w
0 .59967 m
.00375 .59967 L
s
P
p
.001 w
0 .63303 m
.00375 .63303 L
s
P
p
.001 w
0 .69975 m
.00375 .69975 L
s
P
p
.001 w
0 .73311 m
.00375 .73311 L
s
P
p
.001 w
0 .76647 m
.00375 .76647 L
s
P
p
.001 w
0 .79983 m
.00375 .79983 L
s
P
p
.001 w
0 .86656 m
.00375 .86656 L
s
P
p
.001 w
0 .89992 m
.00375 .89992 L
s
P
p
.001 w
0 .93328 m
.00375 .93328 L
s
P
p
.001 w
0 .96664 m
.00375 .96664 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.05405 .99375 m
.05405 1 L
s
P
p
.002 w
.18919 .99375 m
.18919 1 L
s
P
p
.002 w
.32432 .99375 m
.32432 1 L
s
P
p
.002 w
.45946 .99375 m
.45946 1 L
s
P
p
.002 w
.59459 .99375 m
.59459 1 L
s
P
p
.002 w
.72973 .99375 m
.72973 1 L
s
P
p
.002 w
.86486 .99375 m
.86486 1 L
s
P
p
.001 w
.08108 .99625 m
.08108 1 L
s
P
p
.001 w
.10811 .99625 m
.10811 1 L
s
P
p
.001 w
.13514 .99625 m
.13514 1 L
s
P
p
.001 w
.16216 .99625 m
.16216 1 L
s
P
p
.001 w
.21622 .99625 m
.21622 1 L
s
P
p
.001 w
.24324 .99625 m
.24324 1 L
s
P
p
.001 w
.27027 .99625 m
.27027 1 L
s
P
p
.001 w
.2973 .99625 m
.2973 1 L
s
P
p
.001 w
.35135 .99625 m
.35135 1 L
s
P
p
.001 w
.37838 .99625 m
.37838 1 L
s
P
p
.001 w
.40541 .99625 m
.40541 1 L
s
P
p
.001 w
.43243 .99625 m
.43243 1 L
s
P
p
.001 w
.48649 .99625 m
.48649 1 L
s
P
p
.001 w
.51351 .99625 m
.51351 1 L
s
P
p
.001 w
.54054 .99625 m
.54054 1 L
s
P
p
.001 w
.56757 .99625 m
.56757 1 L
s
P
p
.001 w
.62162 .99625 m
.62162 1 L
s
P
p
.001 w
.64865 .99625 m
.64865 1 L
s
P
p
.001 w
.67568 .99625 m
.67568 1 L
s
P
p
.001 w
.7027 .99625 m
.7027 1 L
s
P
p
.001 w
.75676 .99625 m
.75676 1 L
s
P
p
.001 w
.78378 .99625 m
.78378 1 L
s
P
p
.001 w
.81081 .99625 m
.81081 1 L
s
P
p
.001 w
.83784 .99625 m
.83784 1 L
s
P
p
.001 w
.89189 .99625 m
.89189 1 L
s
P
p
.001 w
.91892 .99625 m
.91892 1 L
s
P
p
.001 w
.94595 .99625 m
.94595 1 L
s
P
p
.001 w
.97297 .99625 m
.97297 1 L
s
P
p
.001 w
.02703 .99625 m
.02703 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .16597 m
1 .16597 L
s
P
p
.002 w
.99375 .33278 m
1 .33278 L
s
P
p
.002 w
.99375 .49958 m
1 .49958 L
s
P
p
.002 w
.99375 .66639 m
1 .66639 L
s
P
p
.002 w
.99375 .83319 m
1 .83319 L
s
P
p
.001 w
.99625 .03253 m
1 .03253 L
s
P
p
.001 w
.99625 .06589 m
1 .06589 L
s
P
p
.001 w
.99625 .09925 m
1 .09925 L
s
P
p
.001 w
.99625 .13261 m
1 .13261 L
s
P
p
.001 w
.99625 .19933 m
1 .19933 L
s
P
p
.001 w
.99625 .23269 m
1 .23269 L
s
P
p
.001 w
.99625 .26606 m
1 .26606 L
s
P
p
.001 w
.99625 .29942 m
1 .29942 L
s
P
p
.001 w
.99625 .36614 m
1 .36614 L
s
P
p
.001 w
.99625 .3995 m
1 .3995 L
s
P
p
.001 w
.99625 .43286 m
1 .43286 L
s
P
p
.001 w
.99625 .46622 m
1 .46622 L
s
P
p
.001 w
.99625 .53294 m
1 .53294 L
s
P
p
.001 w
.99625 .56631 m
1 .56631 L
s
P
p
.001 w
.99625 .59967 m
1 .59967 L
s
P
p
.001 w
.99625 .63303 m
1 .63303 L
s
P
p
.001 w
.99625 .69975 m
1 .69975 L
s
P
p
.001 w
.99625 .73311 m
1 .73311 L
s
P
p
.001 w
.99625 .76647 m
1 .76647 L
s
P
p
.001 w
.99625 .79983 m
1 .79983 L
s
P
p
.001 w
.99625 .86656 m
1 .86656 L
s
P
p
.001 w
.99625 .89992 m
1 .89992 L
s
P
p
.001 w
.99625 .93328 m
1 .93328 L
s
P
p
.001 w
.99625 .96664 m
1 .96664 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
1 .61218 m
.97953 .61093 L
.95905 .60927 L
.93858 .60729 L
.91811 .60545 L
.89764 .60416 L
.87716 .60298 L
.85669 .60142 L
.83622 .59955 L
.81574 .59828 L
.79527 .59709 L
.7748 .59551 L
.75432 .59366 L
.73385 .59239 L
.71338 .59118 L
.69291 .5897 L
.67243 .58799 L
.67243 .58799 L
.67588 .57027 L
.67811 .55254 L
.67942 .53482 L
.68 .5171 L
.68 .5171 L
.7 .52151 L
.72 .52585 L
.74 .53011 L
.76 .53455 L
.78 .5395 L
.8 .54445 L
.82 .54939 L
.84 .55432 L
.86 .55923 L
.88 .56462 L
.9 .57023 L
.92 .57577 L
.94 .58129 L
.96 .58727 L
.98 .59346 L
1 .59967 L
F
1 .50709 m
.98024 .49655 L
.96048 .48736 L
.94073 .47893 L
.92097 .47041 L
.90121 .46281 L
.88145 .45622 L
.86169 .45023 L
.84193 .44413 L
.82218 .43793 L
.80242 .43236 L
.78266 .42758 L
.7629 .4227 L
.74314 .41777 L
.72339 .41307 L
.70363 .40886 L
.68387 .4052 L
.66411 .40121 L
.64435 .3969 L
.62459 .39283 L
.62459 .39283 L
.61535 .37156 L
.60604 .35029 L
.59672 .32902 L
.58703 .30776 L
.58703 .30776 L
.60669 .31389 L
.62636 .32006 L
.64602 .32613 L
.66569 .33214 L
.68535 .33847 L
.70502 .34529 L
.72468 .35257 L
.74435 .35988 L
.76402 .36712 L
.78368 .37444 L
.80335 .38224 L
.82301 .39054 L
.84268 .39906 L
.86234 .40756 L
.88201 .41651 L
.90167 .42596 L
.92134 .4357 L
.941 .44536 L
.96067 .45595 L
.98033 .46694 L
1 .4779 L
F
.86486 0 m
.8442 .0015 L
.82354 .0046 L
.80288 .00841 L
.78222 .01378 L
.76156 .02008 L
.7409 .02725 L
.72024 .03607 L
.69958 .04673 L
.67892 .05838 L
.67892 .05838 L
.65811 .06005 L
.6373 .06192 L
.61649 .06386 L
.59568 .06579 L
.57486 .06776 L
.55405 .06928 L
.53324 .07047 L
.51243 .07183 L
.49162 .07381 L
.47081 .07477 L
.45 .07551 L
.42919 .07673 L
.42919 .07673 L
.44951 .06846 L
.46984 .06089 L
.49016 .05402 L
.51049 .04777 L
.53081 .04203 L
.55114 .03674 L
.57146 .03188 L
.59178 .02738 L
.61211 .02324 L
.63243 .01947 L
.65276 .01601 L
.67308 .01281 L
.69341 .00991 L
.71373 .00732 L
.73405 .00506 L
.75438 .00313 L
.7747 .00157 L
.79503 .00038 L
.80337 0 L
F
.55541 1 m
.54797 .98311 L
.54052 .96622 L
.5331 .94933 L
.52568 .93244 L
.52568 .93244 L
.52568 .92348 L
.52568 .91451 L
.52568 .90555 L
.52568 .89658 L
.52568 .89658 L
.52786 .87718 L
.52988 .85777 L
.53212 .83837 L
.53402 .81896 L
.53579 .79956 L
.53724 .78015 L
.53862 .76075 L
.53993 .74134 L
.54093 .72193 L
.5418 .70253 L
.54227 .68312 L
.54278 .66372 L
.54325 .64431 L
.54324 .62491 L
.54324 .6055 L
.54324 .6055 L
.56477 .60255 L
.58631 .59984 L
.60784 .59725 L
.62937 .59433 L
.6509 .59098 L
.67243 .58799 L
.67243 .58799 L
.68142 .60761 L
.69004 .62723 L
.69869 .64685 L
.70733 .66647 L
.71547 .68609 L
.72386 .70571 L
.73179 .72533 L
.7399 .74495 L
.74765 .76457 L
.75546 .78419 L
.76302 .8038 L
.77053 .82342 L
.77806 .84304 L
.78531 .86266 L
.79242 .88228 L
.79947 .9019 L
.80632 .92152 L
.81319 .94114 L
.82003 .96076 L
.82662 .98038 L
.83297 1 L
F
.68 .5171 m
.6602 .51592 L
.64041 .51514 L
.62061 .51457 L
.60081 .514 L
.58101 .51292 L
.56122 .51185 L
.54142 .51128 L
.52162 .51073 L
.50182 .50971 L
.48203 .50861 L
.46223 .50802 L
.44243 .50709 L
.44243 .50709 L
.45226 .4861 L
.4619 .46511 L
.4711 .44412 L
.47953 .42313 L
.48735 .40214 L
.49432 .38115 L
.49432 .38115 L
.51293 .38196 L
.53154 .38357 L
.55015 .38538 L
.56876 .3871 L
.58737 .3888 L
.60598 .39066 L
.62459 .39283 L
.62459 .39283 L
.63468 .41354 L
.6447 .43425 L
.65401 .45496 L
.66309 .47567 L
.6717 .49639 L
.68 .5171 L
F
0 .8799 m
.02029 .86785 L
.04057 .85679 L
.06086 .8464 L
.08115 .8365 L
.10144 .82763 L
.12172 .81929 L
.14201 .81139 L
.1623 .80396 L
.18258 .79699 L
.20287 .7905 L
.22316 .78448 L
.24345 .77893 L
.26373 .77389 L
.28402 .76886 L
.30431 .76409 L
.32459 .7598 L
.32459 .7598 L
.33601 .76158 L
.34743 .76335 L
.35885 .76528 L
.37027 .76731 L
.37027 .76731 L
.37352 .7867 L
.37678 .80609 L
.38005 .82548 L
.38332 .84487 L
.38659 .86426 L
.38984 .88365 L
.39321 .90304 L
.39666 .92244 L
.39997 .94183 L
.4035 .96122 L
.40702 .98061 L
.41054 1 L
0 1 L
F
.41162 1 m
.40787 .9793 L
.40411 .9586 L
.40035 .9379 L
.39686 .9172 L
.39311 .8965 L
.38961 .87581 L
.38612 .85511 L
.38264 .83441 L
.37915 .81371 L
.37566 .79301 L
.37216 .77231 L
.37216 .77231 L
.39216 .77622 L
.41216 .78053 L
.43216 .78558 L
.45216 .79149 L
.45216 .79149 L
.45676 .81234 L
.46135 .83319 L
.46622 .85405 L
.47108 .8749 L
.47595 .89575 L
.48081 .9166 L
.48568 .93745 L
.49081 .9583 L
.49595 .97915 L
.50108 1 L
F
.53595 1 m
.53258 .98144 L
.52921 .96289 L
.52585 .94433 L
.52243 .92577 L
.52243 .92577 L
.53091 .94433 L
.53906 .96289 L
.5472 .98144 L
.55514 1 L
F
0 .51682 m
.03935 .529 L
.1054 .54917 L
.17244 .56934 L
.24099 .58951 L
.30811 .60967 L
.30811 .60967 L
.29949 .58892 L
.29089 .56816 L
.28207 .5474 L
.27339 .52664 L
.2646 .50588 L
.25572 .48513 L
.24666 .46437 L
.23746 .44361 L
.22865 .42285 L
.22865 .42285 L
.20913 .402 L
.18951 .38115 L
.16993 .3603 L
.15018 .33945 L
.13024 .3186 L
.10998 .29775 L
.08938 .2769 L
.06862 .25605 L
.04757 .2352 L
.04757 .2352 L
.03568 .23259 L
.02378 .23027 L
.01189 .22729 L
0 .22435 L
F
0 .21768 m
.0098 .2201 L
.01959 .22255 L
.02939 .22486 L
.03919 .22686 L
.03919 .22686 L
.01014 .21184 L
0 .20684 L
F
0 .1985 m
.02027 .20851 L
.02027 .20851 L
0 .19266 L
F
0 .1839 m
.01995 .1954 L
.03991 .20698 L
.05986 .21861 L
.07982 .23022 L
.09977 .24193 L
.11973 .25366 L
.13968 .26539 L
.15964 .27721 L
.17959 .28912 L
.19955 .30108 L
.2195 .31301 L
.23946 .32527 L
.23946 .32527 L
.24584 .30509 L
.253 .2849 L
.26054 .26472 L
.26908 .24454 L
.2784 .22435 L
.28913 .20417 L
.3013 .18399 L
.31507 .1638 L
.33109 .14362 L
.34973 .12344 L
.34973 .12344 L
.32916 .1115 L
.30859 .10069 L
.28801 .09087 L
.26744 .08196 L
.24687 .07391 L
.2263 .06664 L
.20572 .06006 L
.18515 .05414 L
.16458 .0488 L
.14401 .04397 L
.12343 .03962 L
.10286 .03571 L
.08229 .03218 L
.06172 .02888 L
.04114 .0259 L
.02057 .02321 L
0 .02081 L
F
0 .01975 m
.01973 .02191 L
.03946 .02432 L
.05919 .027 L
.07892 .02996 L
.09865 .0332 L
.11838 .03667 L
.13811 .04052 L
.15784 .04478 L
.17757 .04948 L
.1973 .05462 L
.21703 .06031 L
.23676 .06661 L
.25649 .07357 L
.27622 .08124 L
.29595 .08963 L
.31568 .09885 L
.33541 .10899 L
.35514 .1201 L
.35514 .1201 L
.37481 .10575 L
.39448 .09375 L
.41416 .08343 L
.43383 .07446 L
.4535 .06651 L
.47318 .05926 L
.49285 .05268 L
.51252 .0467 L
.5322 .04122 L
.55187 .03609 L
.57154 .03135 L
.59122 .027 L
.61089 .02298 L
.63056 .01924 L
.65024 .01581 L
.66991 .01267 L
.68958 .00985 L
.70926 .00734 L
.72893 .00514 L
.7486 .00328 L
.76828 .00174 L
.78795 .00054 L
.79936 0 L
0 0 L
F
.58703 .30776 m
.56669 .30337 L
.54635 .29831 L
.52601 .29418 L
.50568 .29027 L
.48534 .28582 L
.465 .2814 L
.44466 .27724 L
.42432 .27356 L
.42432 .27356 L
.41661 .25427 L
.40854 .23499 L
.40041 .2157 L
.39226 .19641 L
.38373 .17713 L
.37498 .15784 L
.36604 .13855 L
.35703 .11927 L
.35703 .11927 L
.37507 .10616 L
.39311 .09507 L
.41115 .08548 L
.42919 .07673 L
.42919 .07673 L
.44355 .09598 L
.45786 .11523 L
.47192 .13449 L
.48583 .15374 L
.49922 .17299 L
.51266 .19224 L
.52567 .2115 L
.53845 .23075 L
.55094 .25 L
.56311 .26925 L
.57519 .2885 L
.58703 .30776 L
F
.35108 .1226 m
.36113 .14359 L
.37098 .16458 L
.38048 .18557 L
.38966 .20656 L
.39865 .22755 L
.40757 .24854 L
.40757 .24854 L
.39761 .26903 L
.38752 .28953 L
.37766 .31002 L
.36808 .33051 L
.35851 .35101 L
.34916 .3715 L
.34027 .39199 L
.34027 .39199 L
.32005 .37833 L
.29984 .36526 L
.27962 .35222 L
.25941 .33885 L
.23919 .32527 L
.23919 .32527 L
.24604 .305 L
.25304 .28474 L
.26089 .26447 L
.2693 .2442 L
.27875 .22394 L
.2894 .20367 L
.30167 .1834 L
.31584 .16314 L
.33198 .14287 L
.35108 .1226 L
F
.22865 .42285 m
.23742 .44352 L
.24657 .46418 L
.25561 .48485 L
.26444 .50551 L
.2732 .52618 L
.28183 .54684 L
.29061 .56751 L
.29927 .58818 L
.30811 .60884 L
.30811 .60884 L
.31986 .61238 L
.33162 .61627 L
.34338 .61999 L
.35514 .62302 L
.35514 .62302 L
.343 .603 L
.33054 .58299 L
.31783 .56297 L
.30536 .54295 L
.29268 .52294 L
.27996 .50292 L
.26726 .4829 L
.25433 .46289 L
.24132 .44287 L
.22865 .42285 L
F
.22865 .42285 m
.24116 .44262 L
.25401 .46239 L
.26678 .48215 L
.27932 .50192 L
.29188 .52168 L
.30443 .54145 L
.31699 .56122 L
.3293 .58098 L
.34162 .60075 L
.35351 .62052 L
.35351 .62052 L
.35747 .60004 L
.3611 .57956 L
.36424 .55908 L
.36712 .5386 L
.36975 .51812 L
.37209 .49764 L
.37392 .47716 L
.37549 .45668 L
.37676 .4362 L
.37676 .4362 L
.35676 .42303 L
.33676 .41049 L
.31676 .39798 L
.29676 .38497 L
.27676 .37201 L
.25676 .35907 L
.23676 .34612 L
.23676 .34612 L
.23442 .3653 L
.23226 .38449 L
.23041 .40367 L
.22865 .42285 L
F
.23676 .34612 m
.23442 .3653 L
.23226 .38449 L
.23041 .40367 L
.22865 .42285 L
.22865 .42285 L
.20896 .40182 L
.18917 .38078 L
.16941 .35974 L
.14947 .33871 L
.12935 .31767 L
.10893 .29664 L
.08827 .2756 L
.06711 .25456 L
.04595 .23353 L
.04595 .23353 L
.06503 .2447 L
.08411 .25592 L
.10319 .26714 L
.12227 .27835 L
.14135 .28956 L
.16043 .30079 L
.17951 .31211 L
.19859 .32344 L
.21768 .33477 L
.23676 .34612 L
F
.65 g
.86486 0 m
.8442 .0015 L
.82354 .0046 L
.80288 .00841 L
.78222 .01378 L
.76156 .02008 L
.7409 .02725 L
.72024 .03607 L
.69958 .04673 L
.67892 .05838 L
.67892 .05838 L
.69899 .05769 L
.71905 .05658 L
.73912 .0553 L
.75919 .05405 L
.77926 .05279 L
.79932 .05207 L
.81939 .05127 L
.83946 .0499 L
.85953 .04802 L
.87959 .04658 L
.89966 .04539 L
.91973 .04415 L
.9398 .04291 L
.95986 .04173 L
.97993 .04024 L
1 .03837 L
1 0 L
F
1 .4779 m
.98033 .46694 L
.96067 .45595 L
.941 .44536 L
.92134 .4357 L
.90167 .42596 L
.88201 .41651 L
.86234 .40756 L
.84268 .39906 L
.82301 .39054 L
.80335 .38224 L
.78368 .37444 L
.76402 .36712 L
.74435 .35988 L
.72468 .35257 L
.70502 .34529 L
.68535 .33847 L
.66569 .33214 L
.64602 .32613 L
.62636 .32006 L
.60669 .31389 L
.58703 .30776 L
.58703 .30776 L
.57519 .2885 L
.56311 .26925 L
.55094 .25 L
.53845 .23075 L
.52567 .2115 L
.51266 .19224 L
.49922 .17299 L
.48583 .15374 L
.47192 .13449 L
.45786 .11523 L
.44355 .09598 L
.42919 .07673 L
.42919 .07673 L
.45 .07551 L
.47081 .07477 L
.49162 .07381 L
.51243 .07183 L
.53324 .07047 L
.55405 .06928 L
.57486 .06776 L
.59568 .06579 L
.61649 .06386 L
.6373 .06192 L
.65811 .06005 L
.67892 .05838 L
.67892 .05838 L
.6929 .0786 L
.70699 .09881 L
.72144 .11903 L
.73616 .13924 L
.75123 .15946 L
.76663 .17967 L
.78261 .19989 L
.79903 .2201 L
.81583 .24032 L
.83322 .26053 L
.85141 .28075 L
.8704 .30097 L
.89024 .32118 L
.91128 .3414 L
.93348 .36161 L
.95743 .38183 L
.98313 .40204 L
1 .41413 L
F
.83297 1 m
.82662 .98038 L
.82003 .96076 L
.81319 .94114 L
.80632 .92152 L
.79947 .9019 L
.79242 .88228 L
.78531 .86266 L
.77806 .84304 L
.77053 .82342 L
.76302 .8038 L
.75546 .78419 L
.74765 .76457 L
.7399 .74495 L
.73179 .72533 L
.72386 .70571 L
.71547 .68609 L
.70733 .66647 L
.69869 .64685 L
.69004 .62723 L
.68142 .60761 L
.67243 .58799 L
.67243 .58799 L
.69291 .5897 L
.71338 .59118 L
.73385 .59239 L
.75432 .59366 L
.7748 .59551 L
.79527 .59709 L
.81574 .59828 L
.83622 .59955 L
.85669 .60142 L
.87716 .60298 L
.89764 .60416 L
.91811 .60545 L
.93858 .60729 L
.95905 .60927 L
.97953 .61093 L
1 .61218 L
1 1 L
F
1 .59967 m
.98 .59346 L
.96 .58727 L
.94 .58129 L
.92 .57577 L
.9 .57023 L
.88 .56462 L
.86 .55923 L
.84 .55432 L
.82 .54939 L
.8 .54445 L
.78 .5395 L
.76 .53455 L
.74 .53011 L
.72 .52585 L
.7 .52151 L
.68 .5171 L
.68 .5171 L
.6717 .49639 L
.66309 .47567 L
.65401 .45496 L
.6447 .43425 L
.63468 .41354 L
.62459 .39283 L
.62459 .39283 L
.64435 .3969 L
.66411 .40121 L
.68387 .4052 L
.70363 .40886 L
.72339 .41307 L
.74314 .41777 L
.7629 .4227 L
.78266 .42758 L
.80242 .43236 L
.82218 .43793 L
.84193 .44413 L
.86169 .45023 L
.88145 .45622 L
.90121 .46281 L
.92097 .47041 L
.94073 .47893 L
.96048 .48736 L
.98024 .49655 L
1 .50709 L
F
.35 g
1 .41413 m
.98313 .40204 L
.95743 .38183 L
.93348 .36161 L
.91128 .3414 L
.89024 .32118 L
.8704 .30097 L
.85141 .28075 L
.83322 .26053 L
.81583 .24032 L
.79903 .2201 L
.78261 .19989 L
.76663 .17967 L
.75123 .15946 L
.73616 .13924 L
.72144 .11903 L
.70699 .09881 L
.6929 .0786 L
.67892 .05838 L
.67892 .05838 L
.69899 .05769 L
.71905 .05658 L
.73912 .0553 L
.75919 .05405 L
.77926 .05279 L
.79932 .05207 L
.81939 .05127 L
.83946 .0499 L
.85953 .04802 L
.87959 .04658 L
.89966 .04539 L
.91973 .04415 L
.9398 .04291 L
.95986 .04173 L
.97993 .04024 L
1 .03837 L
F
.15 g
0 g
.3 Mabswid
s
0 .54138 m
.02624 .55887 L
.05633 .57897 L
.08637 .59906 L
.11635 .61915 L
.14627 .63924 L
.17612 .65934 L
.20591 .67943 L
.23565 .69952 L
.26534 .71961 L
.29499 .73971 L
.32459 .7598 L
s
.50216 .88073 m
.52208 .89435 L
.54199 .90797 L
.5619 .92162 L
.58182 .93529 L
.60173 .94897 L
.62164 .96268 L
.64156 .97642 L
.66147 .99017 L
.67568 1 L
s
.37027 .76731 m
.37352 .7867 L
.37678 .80609 L
.38005 .82548 L
.38332 .84487 L
.38659 .86426 L
.38984 .88365 L
.39321 .90304 L
.39666 .92244 L
.39997 .94183 L
.4035 .96122 L
.40702 .98061 L
.41054 1 L
s
.37216 .77231 m
.37566 .79301 L
.37915 .81371 L
.38264 .83441 L
.38612 .85511 L
.38961 .87581 L
.39311 .8965 L
.39686 .9172 L
.40035 .9379 L
.40411 .9586 L
.40787 .9793 L
.41162 1 L
s
0 .8799 m
.02029 .86785 L
.04057 .85679 L
.06086 .8464 L
.08115 .8365 L
.10144 .82763 L
.12172 .81929 L
.14201 .81139 L
.1623 .80396 L
.18258 .79699 L
.20287 .7905 L
.22316 .78448 L
.24345 .77893 L
.26373 .77389 L
.28402 .76886 L
.30431 .76409 L
.32459 .7598 L
s
.32459 .7598 m
.33601 .76158 L
.34743 .76335 L
.35885 .76528 L
.37027 .76731 L
s
0 .51682 m
.03935 .529 L
.1054 .54917 L
.17244 .56934 L
.24099 .58951 L
.30811 .60967 L
s
.22865 .42285 m
.23746 .44361 L
.24666 .46437 L
.25572 .48513 L
.2646 .50588 L
.27339 .52664 L
.28207 .5474 L
.29089 .56816 L
.29949 .58892 L
.30811 .60967 L
s
.22865 .42285 m
.23742 .44352 L
.24657 .46418 L
.25561 .48485 L
.26444 .50551 L
.2732 .52618 L
.28183 .54684 L
.29061 .56751 L
.29927 .58818 L
.30811 .60884 L
s
.37216 .77231 m
.39216 .77622 L
.41216 .78053 L
.43216 .78558 L
.45216 .79149 L
s
.45216 .79149 m
.45676 .81234 L
.46135 .83319 L
.46622 .85405 L
.47108 .8749 L
.47595 .89575 L
.48081 .9166 L
.48568 .93745 L
.49081 .9583 L
.49595 .97915 L
.50108 1 L
s
.52243 .92577 m
.52585 .94433 L
.52921 .96289 L
.53258 .98144 L
.53595 1 L
s
.52243 .92577 m
.53091 .94433 L
.53906 .96289 L
.5472 .98144 L
.55514 1 L
s
.52568 .93244 m
.5331 .94933 L
.54052 .96622 L
.54797 .98311 L
s
.55541 1 m
.54797 .98311 L
s
s
.52568 .89658 m
.52568 .90555 L
.52568 .91451 L
.52568 .92348 L
.52568 .93244 L
s
.54324 .6055 m
.54324 .62491 L
.54325 .64431 L
.54278 .66372 L
.54227 .68312 L
.5418 .70253 L
.54093 .72193 L
.53993 .74134 L
.53862 .76075 L
.53724 .78015 L
.53579 .79956 L
.53402 .81896 L
.53212 .83837 L
.52988 .85777 L
.52786 .87718 L
.52568 .89658 L
s
.30811 .60884 m
.31986 .61238 L
.33162 .61627 L
.34338 .61999 L
.35514 .62302 L
s
.22865 .42285 m
.24132 .44287 L
.25433 .46289 L
.26726 .4829 L
.27996 .50292 L
.29268 .52294 L
.30536 .54295 L
.31783 .56297 L
.33054 .58299 L
.343 .603 L
.35514 .62302 L
s
.22865 .42285 m
.24116 .44262 L
.25401 .46239 L
.26678 .48215 L
.27932 .50192 L
.29188 .52168 L
.30443 .54145 L
.31699 .56122 L
.3293 .58098 L
.34162 .60075 L
.35351 .62052 L
s
.37676 .4362 m
.37549 .45668 L
.37392 .47716 L
.37209 .49764 L
.36975 .51812 L
.36712 .5386 L
.36424 .55908 L
.3611 .57956 L
.35747 .60004 L
.35351 .62052 L
s
.54324 .6055 m
.56477 .60255 L
.58631 .59984 L
.60784 .59725 L
.62937 .59433 L
.6509 .59098 L
.67243 .58799 L
s
.44243 .50709 m
.46223 .50802 L
.48203 .50861 L
.50182 .50971 L
.52162 .51073 L
.54142 .51128 L
.56122 .51185 L
.58101 .51292 L
.60081 .514 L
.62061 .51457 L
.64041 .51514 L
.6602 .51592 L
.68 .5171 L
s
.49432 .38115 m
.48735 .40214 L
.47953 .42313 L
.4711 .44412 L
.4619 .46511 L
.45226 .4861 L
.44243 .50709 L
s
.40757 .24854 m
.39761 .26903 L
.38752 .28953 L
.37766 .31002 L
.36808 .33051 L
.35851 .35101 L
.34916 .3715 L
.34027 .39199 L
s
.23676 .34612 m
.25676 .35907 L
.27676 .37201 L
.29676 .38497 L
.31676 .39798 L
.33676 .41049 L
.35676 .42303 L
.37676 .4362 L
s
.23919 .32527 m
.25941 .33885 L
.27962 .35222 L
.29984 .36526 L
.32005 .37833 L
.34027 .39199 L
s
.49432 .38115 m
.51293 .38196 L
.53154 .38357 L
.55015 .38538 L
.56876 .3871 L
.58737 .3888 L
.60598 .39066 L
.62459 .39283 L
s
.42432 .27356 m
.44466 .27724 L
.465 .2814 L
.48534 .28582 L
.50568 .29027 L
.52601 .29418 L
.54635 .29831 L
.56669 .30337 L
.58703 .30776 L
s
.35703 .11927 m
.36604 .13855 L
.37498 .15784 L
.38373 .17713 L
.39226 .19641 L
.40041 .2157 L
.40854 .23499 L
.41661 .25427 L
.42432 .27356 L
s
.35108 .1226 m
.36113 .14359 L
.37098 .16458 L
.38048 .18557 L
.38966 .20656 L
.39865 .22755 L
.40757 .24854 L
s
.67243 .58799 m
.68142 .60761 L
.69004 .62723 L
.69869 .64685 L
.70733 .66647 L
.71547 .68609 L
.72386 .70571 L
.73179 .72533 L
.7399 .74495 L
.74765 .76457 L
.75546 .78419 L
.76302 .8038 L
.77053 .82342 L
.77806 .84304 L
.78531 .86266 L
.79242 .88228 L
.79947 .9019 L
.80632 .92152 L
.81319 .94114 L
.82003 .96076 L
.82662 .98038 L
s
.83297 1 m
.82662 .98038 L
s
s
.68 .5171 m
.67942 .53482 L
.67811 .55254 L
.67588 .57027 L
.67243 .58799 L
s
.62459 .39283 m
.63468 .41354 L
.6447 .43425 L
.65401 .45496 L
.66309 .47567 L
.6717 .49639 L
.68 .5171 L
s
.67243 .58799 m
.69291 .5897 L
.71338 .59118 L
.73385 .59239 L
.75432 .59366 L
.7748 .59551 L
.79527 .59709 L
.81574 .59828 L
.83622 .59955 L
.85669 .60142 L
.87716 .60298 L
.89764 .60416 L
.91811 .60545 L
.93858 .60729 L
.95905 .60927 L
.97953 .61093 L
s
1 .61218 m
.97953 .61093 L
s
s
.68 .5171 m
.7 .52151 L
.72 .52585 L
.74 .53011 L
.76 .53455 L
.78 .5395 L
.8 .54445 L
.82 .54939 L
.84 .55432 L
.86 .55923 L
.88 .56462 L
.9 .57023 L
.92 .57577 L
.94 .58129 L
.96 .58727 L
.98 .59346 L
1 .59967 L
s
.62459 .39283 m
.64435 .3969 L
.66411 .40121 L
.68387 .4052 L
.70363 .40886 L
.72339 .41307 L
.74314 .41777 L
.7629 .4227 L
.78266 .42758 L
.80242 .43236 L
.82218 .43793 L
.84193 .44413 L
.86169 .45023 L
.88145 .45622 L
.90121 .46281 L
.92097 .47041 L
.94073 .47893 L
.96048 .48736 L
.98024 .49655 L
s
1 .50709 m
.98024 .49655 L
s
s
.58703 .30776 m
.59672 .32902 L
.60604 .35029 L
.61535 .37156 L
.62459 .39283 L
s
.42919 .07673 m
.44355 .09598 L
.45786 .11523 L
.47192 .13449 L
.48583 .15374 L
.49922 .17299 L
.51266 .19224 L
.52567 .2115 L
.53845 .23075 L
.55094 .25 L
.56311 .26925 L
.57519 .2885 L
.58703 .30776 L
s
.58703 .30776 m
.60669 .31389 L
.62636 .32006 L
.64602 .32613 L
.66569 .33214 L
.68535 .33847 L
.70502 .34529 L
.72468 .35257 L
.74435 .35988 L
.76402 .36712 L
.78368 .37444 L
.80335 .38224 L
.82301 .39054 L
.84268 .39906 L
.86234 .40756 L
.88201 .41651 L
.90167 .42596 L
.92134 .4357 L
.941 .44536 L
.96067 .45595 L
.98033 .46694 L
1 .4779 L
s
.23676 .34612 m
.23442 .3653 L
.23226 .38449 L
.23041 .40367 L
.22865 .42285 L
s
.23676 .34612 m
.23442 .3653 L
.23226 .38449 L
.23041 .40367 L
.22865 .42285 L
s
.04595 .23353 m
.06711 .25456 L
.08827 .2756 L
.10893 .29664 L
.12935 .31767 L
.14947 .33871 L
.16941 .35974 L
.18917 .38078 L
.20896 .40182 L
.22865 .42285 L
s
.04757 .2352 m
.06862 .25605 L
.08938 .2769 L
.10998 .29775 L
.13024 .3186 L
.15018 .33945 L
.16993 .3603 L
.18951 .38115 L
.20913 .402 L
.22865 .42285 L
s
.35108 .1226 m
.33198 .14287 L
.31584 .16314 L
.30167 .1834 L
.2894 .20367 L
.27875 .22394 L
.2693 .2442 L
.26089 .26447 L
.25304 .28474 L
.24604 .305 L
.23919 .32527 L
s
.34973 .12344 m
.33109 .14362 L
.31507 .1638 L
.3013 .18399 L
.28913 .20417 L
.2784 .22435 L
.26908 .24454 L
.26054 .26472 L
.253 .2849 L
.24584 .30509 L
.23946 .32527 L
s
0 .1839 m
.01995 .1954 L
.03991 .20698 L
.05986 .21861 L
.07982 .23022 L
.09977 .24193 L
.11973 .25366 L
.13968 .26539 L
.15964 .27721 L
.17959 .28912 L
.19955 .30108 L
.2195 .31301 L
.23946 .32527 L
s
.04595 .23353 m
.06503 .2447 L
.08411 .25592 L
.10319 .26714 L
.12227 .27835 L
.14135 .28956 L
.16043 .30079 L
.17951 .31211 L
.19859 .32344 L
.21768 .33477 L
.23676 .34612 L
s
0 .22435 m
.01189 .22729 L
.02378 .23027 L
.03568 .23259 L
.04757 .2352 L
s
0 .21768 m
.0098 .2201 L
.01959 .22255 L
.02939 .22486 L
.03919 .22686 L
s
0 .20684 m
.01014 .21184 L
.03919 .22686 L
s
0 .1985 m
.02027 .20851 L
s
0 .19266 m
.02027 .20851 L
s
s
0 .02081 m
.02057 .02321 L
.04114 .0259 L
.06172 .02888 L
.08229 .03218 L
.10286 .03571 L
.12343 .03962 L
.14401 .04397 L
.16458 .0488 L
.18515 .05414 L
.20572 .06006 L
.2263 .06664 L
.24687 .07391 L
.26744 .08196 L
.28801 .09087 L
.30859 .10069 L
.32916 .1115 L
.34973 .12344 L
s
0 .01975 m
.01973 .02191 L
.03946 .02432 L
.05919 .027 L
.07892 .02996 L
.09865 .0332 L
.11838 .03667 L
.13811 .04052 L
.15784 .04478 L
.17757 .04948 L
.1973 .05462 L
.21703 .06031 L
.23676 .06661 L
.25649 .07357 L
.27622 .08124 L
.29595 .08963 L
.31568 .09885 L
.33541 .10899 L
.35514 .1201 L
s
.35514 .1201 m
.37481 .10575 L
.39448 .09375 L
.41416 .08343 L
.43383 .07446 L
.4535 .06651 L
.47318 .05926 L
.49285 .05268 L
.51252 .0467 L
.5322 .04122 L
.55187 .03609 L
.57154 .03135 L
.59122 .027 L
.61089 .02298 L
.63056 .01924 L
.65024 .01581 L
.66991 .01267 L
.68958 .00985 L
.70926 .00734 L
.72893 .00514 L
.7486 .00328 L
.76828 .00174 L
.78795 .00054 L
.79936 0 L
s
.35703 .11927 m
.37507 .10616 L
.39311 .09507 L
.41115 .08548 L
.42919 .07673 L
s
.42919 .07673 m
.44951 .06846 L
.46984 .06089 L
.49016 .05402 L
.51049 .04777 L
.53081 .04203 L
.55114 .03674 L
.57146 .03188 L
.59178 .02738 L
.61211 .02324 L
.63243 .01947 L
.65276 .01601 L
.67308 .01281 L
.69341 .00991 L
.71373 .00732 L
.73405 .00506 L
.75438 .00313 L
.7747 .00157 L
.79503 .00038 L
.80337 0 L
s
.42919 .07673 m
.45 .07551 L
.47081 .07477 L
.49162 .07381 L
.51243 .07183 L
.53324 .07047 L
.55405 .06928 L
.57486 .06776 L
.59568 .06579 L
.61649 .06386 L
.6373 .06192 L
.65811 .06005 L
.67892 .05838 L
s
.67892 .05838 m
.6929 .0786 L
.70699 .09881 L
.72144 .11903 L
.73616 .13924 L
.75123 .15946 L
.76663 .17967 L
.78261 .19989 L
.79903 .2201 L
.81583 .24032 L
.83322 .26053 L
.85141 .28075 L
.8704 .30097 L
.89024 .32118 L
.91128 .3414 L
.93348 .36161 L
.95743 .38183 L
.98313 .40204 L
1 .41413 L
s
.67892 .05838 m
.69899 .05769 L
.71905 .05658 L
.73912 .0553 L
.75919 .05405 L
.77926 .05279 L
.79932 .05207 L
.81939 .05127 L
.83946 .0499 L
.85953 .04802 L
.87959 .04658 L
.89966 .04539 L
.91973 .04415 L
.9398 .04291 L
.95986 .04173 L
.97993 .04024 L
1 .03837 L
s
.67892 .05838 m
.69958 .04673 L
.72024 .03607 L
.7409 .02725 L
.76156 .02008 L
.78222 .01378 L
.80288 .00841 L
.82354 .0046 L
.8442 .0015 L
.86486 0 L
s
.6 Mabswid
.30811 .60884 m
.31612 .62927 L
.32405 .64971 L
.33206 .67014 L
.34023 .69058 L
.34816 .71101 L
.3561 .73144 L
.36432 .75188 L
.37216 .77231 L
s
.35351 .62052 m
.36546 .64053 L
.37714 .66055 L
.38881 .68057 L
.40046 .70058 L
.41191 .7206 L
.42329 .74062 L
.4347 .76063 L
.44611 .78065 L
.45749 .80067 L
.46865 .82068 L
.47981 .8407 L
.49112 .86072 L
.50216 .88073 L
s
.50216 .88073 m
.50724 .89199 L
.51233 .90325 L
.51744 .91451 L
.52243 .92577 L
s
.52261 .92577 m
.52568 .93244 L
s
.34027 .39199 m
.35579 .4114 L
.37203 .43081 L
.38899 .45022 L
.40668 .46963 L
.42501 .48904 L
.44387 .50845 L
.46305 .52786 L
.48271 .54727 L
.50283 .56668 L
.52293 .58609 L
.54324 .6055 L
s
.40757 .24854 m
.42014 .26748 L
.43272 .28643 L
.44531 .30537 L
.45791 .32432 L
.47034 .34326 L
.48239 .36221 L
.49432 .38115 L
s
.23946 .32527 m
.23676 .34612 L
s
0 .18891 m
.00194 .19078 L
.01757 .20559 L
.03265 .22039 L
.04757 .2352 L
s
.34973 .12344 m
.35703 .11927 L
s
0 1 0 r
1 0 0 r
0 0 1 r
p
0 g
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{483, 483},
  ImageMargins->{{33, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007S0001ha000`40O003h00Oogooi7oo003oOooT
Ool00?moonAoo`00ogooi7oo003oOooTOol00?moonAoo`00ogooi7oo000ROol30003Ool30004Ool2
000_Ool00`00Oomoo`03Ool20004Ool2000_Ool00`00Oomoo`02Ool30004Ool2000^Ool30004Ool2
0004Ool2000^Ool30003Ool30004Ool2000^Ool20005Ool20004Ool2000^Ool20004Ool30004Ool2
000[Ool30004Ool20004Ool20004Ool20004Ool0025oo`07001oogooOol007oo00000goo00@007oo
Ool0009oo`03001oogoo02aoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00;Woo00D0
07ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`0ZOol01@00Oomoogoo00000Woo00@007oo
Ool0009oo`04001oogoo000/Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0002Ool00`00Oomo
o`0]Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo02eoo`04001oogoo0003Ool0
1000Oomoo`000Woo00<007ooOol0:Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000goo000QOol01@00Oomoogoo00001Goo00@007ooOol0009oo`03001oogoo02eo
o`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol0;Goo00<007ooOol017oo00@007oo
Ool0009oo`03001oogoo02Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol002ao
o`05001oogooOol00005Ool01000Oomoo`000Woo00<007ooOol0;Woo00@007ooOol0009oo`04001o
ogoo0002Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<007ooOol0:Goo00<0
07ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo000QOol40006Ool0
1000Oomoo`000Woo00<007ooOol0;Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`0]Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol0:goo0`000goo00@007ooOol0009o
o`04001oogoo000]Ool30006Ool01000Oomoo`000Woo00<007ooOol0:goo10000Woo00@007ooOol0
009oo`04001oogoo000]Ool40005Ool01000Oomoo`000Woo00<007ooOol0:Goo00<007ooOol00Woo
00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo000QOol00`00Oomoo`03Ool40003
Ool01000Oomoo`00<7oo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0^Ool00`00Ool0
00030003Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`00
;7oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`00;7oo00H007ooOomoo`00Ool40003Ool01000Oomoo`00:goo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo000ROol00`00Oomoo`02Ool0
0`00Oomoo`04Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`00;7oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00;7oo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`00;7oo00L007ooOomoo`00Ool00006Ool01000Oomoo`00;7oo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`00;7oo00L007ooOomoo`00Ool00006Ool01000
Oomoo`00:Woo0P0017oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo000SOol2
0002Ool50003Ool2000]Ool50003Ool20004Ool2000]Ool500000goo000000030003Ool2000^Ool3
0004Ool20004Ool2000^Ool30002Ool50003Ool2000^Ool30004Ool20004Ool2000^Ool30002Ool5
0003Ool2000/Ool00`00Oomoo`03Ool20004Ool20004Ool20004Ool00?moonAoo`00ogooi7oo003o
OooTOol00?moonAoo`00ogooi7oo003oOooTOol00?moonAoo`004Gooo`00aP003Goo000AOol00`00
Kg]_N`3oKg]=Kg/E000FKg/90011DY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0?m_NdA_N`/0029_
N`L004YBU003001oogoo00]oo`004Goo00<006mkKg/0ofmk>fmk2`009Vmk1@00DE:D00<007ooOol0
2goo000AOol00`00Kg]_N`3oKg/dKg/9000ZKg/5001FDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk
0?m_Nbm_N`L002a_N`D005]BU003001oogoo00]oo`004Goo00<006mkKg/0ofmk:Fmk2000;Vmk0`00
H5:D00<007ooOol02goo000AOol00`00Kg]_N`3oKg/RKg/8000bKg/3001SDY@00`00Oomoo`0;Ool0
015oo`03001_Nfmk0?m_Nae_N`H003I_N`<006IBU003001oogoo00]oo`004Goo1P00ofmk56mk1`00
=fmk1000JE:D00<007ooOol02goo000AOol00`00Kg]_N`03Kg/9003oKg/4Kg/8000jKg/3001]DY@0
0`00Oomoo`0;Ool0015oo`03001_Nfmk00Y_N`/00?I_N`D003i_N`<0071BU003001oogoo00]oo`00
4Goo00<006mkKg/03fmk3`00jFmk1000@6mk0`00Le:D00<007ooOol02goo000AOol00`00Kg]_N`0F
Kg/>003NKg/50012Kg/2001fDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk01m_N`X00=E_N`@004A_
N`<007QBU003001oogoo00]oo`004Goo00<006mkKg/09Vmk2P00bFmk1@00AVmk0P00Ne:D00<007oo
Ool02goo000AOol00`00Kg]_N`0[Kg/400000goo00000004002oKg/40019Kg/2001mDY@00`00Oomo
o`0;Ool0015oo`03001_Nfmk02m_N`D0009oo`D00;E_N`D004]_N`8007]BU0D000eoo`004Goo00<0
06mkKg/0=6mk10000goo1000[Vmk1@00C6mk0P00M5:D2@0012e[00<007ooOol02goo000AOol00`00
Kg]_N`0hKg/50002Ool5002VKg/5001>Kg/00`00DYABU01RDY@B000=;F/00`00Oomoo`0;Ool0015o
o`03001_Nfmk03e_N`D0009oo`@009i_N`D0051_N`8005=BU18001l]J`03001oogoo00]oo`004Goo
00<006mkKg/0@Vmk1@0000=oo`0000000P00Ufmk1000DVmk0P00C5:D2@00<Be[00<007ooOol02goo
000AOol00`00Kg]_N`17Kg/400000goo00000002002@Kg/4001CKg/2000lDY@B000j;F/00`00Oomo
o`0;Ool0015oo`03001_Nfmk04]_N`P008Y_N`@005A_N`8002aBU18004`]J`03001oogoo00]oo`00
4Goo00<006mkKg/0D6mk1P00Q6mk1000EFmk0P006e:D4`00GRe[00<007ooOol02goo000AOol00`00
Kg]_N`1DKg/5001nKg/4001FKg/2000;DY@B001a;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk05M_
N`L007I_N`@005A_Na8008<]J`03001oogoo00]oo`004Goo00<006mkKg/0FVmk0`0000=oo`000000
0P00Kfmk1000CFmk2P0015:D00<002e[;F/0SRe[00<007ooOol02goo000AOol00`00Kg]_N`1MKg/3
0002Ool3001YKg/40017Kg/9000?DY@00`00;F/]J`2=;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk
061_N`<0009oo`<006A_N`<0045_N`T001UBU003000]Jbe[08`]J`03001oogoo00]oo`004Goo00<0
06mkKg/0Hfmk100000Aoo`00000005i_N`<0035_Na<002=BU003000]Jbe[08/]J`03001oogoo00]o
o`004Goo00<006mkKg/0Ifmk0`0000Aoo`00000005U_N`8002Y_N`X003MBU003000]Jbe[08X]J`03
001oogoo00]oo`004Goo00<006mkKg/0JVmk0`0000Aoo`00000005=_N`<001Y_Na80045BU003000]
Jbe[08X]J`03001oogoo00]oo`004Goo00<006mkKg/0KFmk0P000Woo0P00Cfmk0`004Vmk2P00E5:D
00<002e[;F/0RBe[00<007ooOol02goo000AOol00`00Kg]_N`1_Kg/20002Ool2001;Kg/20002Kg/C
001ODY@00`00;F/]J`28;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk075_N`<00004Ool000000016
Kg/6001cDY@00`00;F/]J`27;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk07A_N`80009oo`80045_
N`<00003Kg/005:D07IBU003000]Jbe[08L]J`03001oogoo00]oo`004Goo00<006mkKg/0MVmk0P00
0Woo0`00>fmk100016mk00<005:DDY@0ME:D00<002e[;F/0QRe[00<007ooOol02goo000AOol00`00
Kg]_N`1hKg/20003Ool3000fKg/40007Kg/00`00DYABU01eDY@00`00;F/]J`25;F/00`00Oomoo`0;
Ool0015oo`03001_Nfmk07Y_N`<000=oo`<0039_N`<000Y_N`03001BU5:D07ABU003000]Jbe[08D]
J`03001oogoo00]oo`004Goo00<006mkKg/0OFmk0P0017oo0P00;Vmk0`003Fmk00<005:DDY@0M5:D
00<002e[;F/0Q2e[00<007ooOol02goo000AOol00`00Kg]_N`1oKg/20004Ool2000ZKg/2000AKg/0
0`00DYABU01cDY@00`00;F/]J`24;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk085_N`<000=oo`80
02I_N`8001A_N`03001BU5:D07=BU003000]Jbe[08<]J`03001oogoo00]oo`004Goo00<006mkKg/0
Q6mk0P000goo00<006mkKg/08Vmk0P005Vmk00<005:DDY@0Le:D00<002e[;F/0PRe[00<007ooOol0
2goo000AOol00`00Kg]_N`26Kg/300000goo0000000PKg/2000HKg/00`00DYABU01cDY@00`00;F/]
J`22;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk08U_N`800003Ool0000001e_N`8001Y_N`03001B
U5:D07=BU003000]Jbe[084]J`03001oogoo00]oo`004Goo00<006mkKg/0Rfmk0P0000=oo`000000
6Fmk0P007Fmk00<005:DDY@0LU:D00<002e[;F/0PBe[00<007ooOol02goo000AOol00`00Kg]_N`2=
Kg/2000017oo000000005Fmk00<006mkKg/07Fmk00<005:DDY@0Le:D00<002e[;F/0P2e[00<007oo
Ool02goo000AOol00`00Kg]_N`2?Kg/01000Oomoogoo0P004Fmk0P008Fmk00<005:DDY@0Le:D00<0
02e[;F/0Obe[00<007ooOol02goo000AOol00`00Kg]_N`2@Kg/20003Ool2000>Kg/00`00Kg]_N`0R
Kg/00`00DYABU01bDY@00`00;F/]J`1o;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk099_N`8000=o
o`8000Y_N`8002E_N`03001BU5:D07=BU003000]Jbe[07h]J`03001oogoo00]oo`004Goo00<006mk
Kg/0U6mk00<007ooOol00Woo0P001fmk0P009fmk00<005:DDY@0Le:D00<002e[;F/0OBe[00<007oo
Ool02goo000AOol00`00Kg]_N`2EKg/20004Ool00`00Kg]_N`02Kg/2000ZKg/00`00DYABU01bDY@0
0`00;F/]J`1m;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk09M_N`03001oogoo009oo`800003Kg/0
000002]_N`03001BU5:D07=BU003000]Jbe[07`]J`03001oogoo00]oo`004Goo00<006mkKg/0V6mk
0P0017oo0P00;Fmk00<005:DDY@0Le:D00<002e[;F/0Nbe[00<007ooOol02goo000AOol00`00Kg]_
N`2JKg/01P00Ool00000Ool002i_N`03001BU5:D079BU003000]Jbe[07/]J`03001oogoo00]oo`00
4Goo00<006mkKg/0Vfmk0P000goo00<006mkKg/0;6mk00<005:DDY@0LU:D00<002e[;F/0NRe[00<0
07ooOol02goo000AOol00`00Kg]_N`2JKg/200001Fmk001oogoo0000;fmk00<005:DDY@0LU:D00<0
02e[;F/0NBe[00<007ooOol02goo000AOol00`00Kg]_N`2IKg/20002Kg/01@00Oomoogoo0000;Vmk
00<005:DDY@0Le:D00<002e[;F/0N2e[00<007ooOol02goo000AOol00`00Kg]_N`2HKg/20004Kg/0
1000Oomoo`00;fmk00<005:DDY@0Le:D00<002e[;F/0Mbe[00<007ooOol02goo000AOol00`00Kg]_
N`2GKg/20005Kg/01@00Oomoogoo0000;fmk00<005:DDY@0LU:D00<002e[;F/0Mbe[00<007ooOol0
2goo000AOol00`00Kg]_N`2FKg/20007Kg/01000Oomoo`00<6mk00<005:DDY@0LU:D00<002e[;F/0
MRe[00<007ooOol02goo000AOol00`00Kg]_N`2EKg/20008Kg/01@00Oomoogoo0000;fmk00<005:D
DY@0Le:D00<002e[;F/0MBe[00<007ooOol02goo000AOol00`00Kg]_N`2DKg/2000:Kg/01000Oomo
o`00<6mk00<005:DDY@0Le:D00<002e[;F/0M2e[00<007ooOol02goo000AOol00`00Kg]_N`2CKg/2
000;Kg/01@00Oomoogoo0000<6mk00<005:DDY@0LU:D00<002e[;F/0M2e[00<007ooOol02goo000A
Ool00`00Kg]_N`2CKg/00`00Kg]_N`0;Kg/01000Oomoo`00<Fmk00<005:DDY@0LU:D00<002e[;F/0
Lbe[00<007ooOol02goo000AOol00`00Kg]_N`2BKg/2000=Kg/01@00Oomoogoo0000<6mk00<005:D
DY@0Le:D00<002e[;F/0LRe[00<007ooOol02goo000AOol00`00Kg]_N`2AKg/2000?Kg/01000Oomo
o`00<Fmk00<005:DDY@0Le:D00<002e[;F/0LBe[00<007ooOol02goo000AOol00`00Kg]_N`2AKg/0
0`00Kg]_N`0>Kg/01000Oomoo`00<Vmk00<005:DDY@0Le:D00<002e[;F/0L2e[00<007ooOol02goo
000AOol00`00Kg]_N`2@Kg/00`00Kg]_N`0@Kg/01000Oomoo`00<Vmk00<005:DDY@0LU:D00<002e[
;F/0L2e[00<007ooOol02goo000AOol00`00Kg]_N`2?Kg/00`00Kg]_N`0AKg/01000Oomoo`00<Vmk
00<005:DDY@0Le:D00<002e[;F/0Kbe[00<007ooOol02goo000AOol00`00Kg]_N`2>Kg/2000CKg/0
1@00Oomoogoo0000<Vmk00<005:DDY@0Le:D00<002e[;F/0KRe[00<007ooOol02goo0006Ool50006
Ool00`00Kg]_N`2>Kg/00`00Kg]_N`0CKg/01000Oomoo`00<fmk00<005:DDY@0Le:D00<002e[;F/0
KBe[00<007ooOol02goo0007Ool01000Oomoo`001Woo00<006mkKg/0SFmk00<006mkKg/056mk00D0
07ooOomoo`00039_N`03001BU5:D07=BU003000]Jbe[06d]J`03001oogoo00]oo`0027oo00<007oo
Ool01Woo00<006mkKg/0S6mk00<006mkKg/05Vmk00@007ooOol003=_N`03001BU5:D07=BU003000]
Jbe[06`]J`03001oogoo00]oo`002Goo00<007ooOol01Goo00<006mkKg/0S6mk00<006mkKg/05Vmk
00D007ooOomoo`0003=_N`03001BU5:D07=BU003000]Jbe[06/]J`03001oogoo00]oo`001Woo00D0
07ooOomoo`0000Ioo`03001_Nfmk08]_N`03001_Nfmk01Q_N`04001oogoo000cKg/00`00DYABU01d
DY@00`00;F/]J`1Z;F/00`00Oomoo`0;Ool000Ioo`05001oogooOol00006Ool00`00Kg]_N`2:Kg/0
0`00Kg]_N`0IKg/01000Oomoo`00=6mk00<005:DDY@0M5:D00<002e[;F/0JBe[00<007ooOol02goo
0007Ool30007Ool00`00Kg]_N`29Kg/2000KKg/01@00Oomoogoo0000=6mk00<005:DDY@0Le:D00<0
02e[;F/0JBe[00<007ooOol02goo000AOol00`00Kg]_N`28Kg/2000MKg/01000Oomoo`00=6mk00<0
05:DDY@0M5:D00<002e[;F/0J2e[00<007ooOol02goo000AOol00`00Kg]_N`28Kg/00`00Kg]_N`0L
Kg/01@00Oomoogoo0000=6mk00<005:DDY@0M5:D00<002e[;F/0Ibe[00<007ooOol02goo000AOol0
0`00Kg]_N`27Kg/2000OKg/01000Oomoo`00=Fmk00<005:DDY@0M5:D00<002e[;F/0IRe[00<007oo
Ool02goo000AOol00`00Kg]_N`26Kg/2000PKg/01@00Oomoogoo0000=6mk00<005:DDY@0M5:D00<0
02e[;F/0IRe[00<007ooOol02goo000AOol20026Kg/2000QKg/01@00Oomoogoo0000=Fmk00<005:D
DY@0M5:D00<002e[;F/0IBe[00<007ooOol02goo000AOol01000Ool00000Q6mk0P008Vmk00D007oo
Oomoo`0003E_N`03001BU5:D07ABU003000]Jbe[06@]J`03001oogoo00]oo`004Goo00@007ooOomo
o`80085_N`8002=_N`05001oogooOol0000eKg/00`00DYABU01eDY@00`00;F/]J`1S;F/00`00Oomo
o`0;Ool0015oo`8000Aoo`03001_Nfmk07i_N`03001_Nfmk02=_N`04001oogoo000fKg/00`00DYAB
U01eDY@00`00;F/]J`1R;F/00`00Oomoo`0;Ool0015oo`<000Aoo`8007e_N`8002E_N`05001oogoo
Ool0000fKg/00`00DYABU01dDY@00`00;F/]J`1R;F/00`00Oomoo`0;Ool0015oo`04001_N`000005
Ool2001jKg/2000WKg/01000Oomoo`00=Vmk00<005:DDY@0ME:D00<002e[;F/0HBe[00<007ooOol0
2goo000AOol00`00Kg]_N`020006Ool2001hKg/00`00Kg]_N`0VKg/01@00Oomoogoo0000=Vmk00<0
05:DDY@0ME:D00<002e[;F/0H2e[00<007ooOol02goo000AOol20002Kg/20007Ool2001eKg/2000X
Kg/01@00Oomoogoo0000=fmk00<005:DDY@0ME:D00<002e[;F/0Gbe[00<007ooOol02goo000AOol0
1000Ool000000Vmk00<007ooOol01Woo00<006mkKg/0LVmk00<006mkKg/0:6mk00D007ooOomoo`00
03M_N`03001BU5:D07ABU003000]Jbe[05l]J`03001oogoo00]oo`004Goo00@007ooOomoo`@000Qo
o`80075_N`03001_Nfmk02U_N`05001oogooOol0000gKg/00`00DYABU01eDY@00`00;F/]J`1N;F/0
0`00Oomoo`0;Ool0015oo`8000Eoo`8000Uoo`8006m_N`03001_Nfmk02Y_N`04001oogoo000hKg/0
0`00DYABU01eDY@00`00;F/]J`1M;F/00`00Oomoo`0;Ool0015oo`04001_N`000005Ool00`00Oomo
o`08Ool00`00Kg]_N`1[Kg/00`00Kg]_N`0[Kg/01@00Oomoogoo0000>6mk00<005:DDY@0ME:D00<0
02e[;F/0G2e[00<007ooOol02goo000AOol01@00Kg]_Nfmk00001Goo00<007ooOol027oo0P00Jfmk
00<006mkKg/0;6mk00@007ooOol003U_N`03001BU5:D07EBU003000]Jbe[05/]J`03001oogoo00]o
o`004Goo00<006mkKg/00Vmk0P0017oo00<007ooOol02Goo00<006mkKg/0Ifmk00<006mkKg/0;Fmk
00@007ooOol003U_N`03001BU5:D07IBU003000]Jbe[05X]J`03001oogoo00]oo`004Goo00<006mk
Kg/016mk0P000goo00<007ooOol02Goo0P00IVmk00<006mkKg/0;Vmk00D007ooOomoo`0003U_N`03
001BU5:D07IBU003000]Jbe[05T]J`03001oogoo00]oo`004Goo10001Fmk0P000Woo00<007ooOol0
2Woo00<006mkKg/0Hfmk00<006mkKg/0;fmk00@007ooOol003Y_N`03001BU5:D07IBU003000]Jbe[
05P]J`03001oogoo00]oo`004Goo00@007ooOomoo`@000=_N`@000aoo`80069_N`03001_Nfmk031_
N`05001oogooOol0000iKg/00`00DYABU01gDY@00`00;F/]J`1G;F/00`00Oomoo`0;Ool0015oo`03
001oogoo00Eoo`<000=_N`<000aoo`80061_N`03001_Nfmk035_N`04001oogoo000jKg/00`00DYAB
U01fDY@00`00;F/]J`1G;F/00`00Oomoo`0;Ool0015oo`<000Qoo`8000=_N`8000eoo`8005e_N`03
001_Nfmk039_N`05001oogooOol0000jKg/00`00DYABU01fDY@00`00;F/]J`1F;F/00`00Oomoo`0;
Ool0015oo`03001_Nfmk00<000Moo`H000ioo`03001_Nfmk05Y_N`03001_Nfmk039_N`05001oogoo
Ool0000jKg/00`00DYABU01gDY@00`00;F/]J`1E;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk00=_
N`@000Uoo`03001oogoo00aoo`8005U_N`03001_Nfmk03A_N`04001oogoo000kKg/00`00DYABU01f
DY@00`00;F/]J`1E;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk00M_N`D000Eoo`03001oogoo00eo
o`8005M_N`03001_Nfmk03A_N`05001oogooOol0000kKg/00`00DYABU01fDY@00`00;F/]J`1D;F/0
0`00Oomoo`0;Ool0015oo`03001_Nfmk00a_N`D00003Ool0000000moo`8005A_N`03001_Nfmk03I_
N`04001oogoo000kKg/00`00DYABU01gDY@00`00;F/]J`1C;F/00`00Oomoo`0;Ool0015oo`03001_
Nfmk015_N`@0011oo`80059_N`03001_Nfmk03I_N`05001oogooOol0000kKg/00`00DYABU01gDY@0
0`00;F/]J`1B;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk01=_N`@0011oo`03001_Nfmk04m_N`03
001_Nfmk03M_N`04001oogoo000kKg/00`00DYABU01gDY@00`00;F/]J`1B;F/00`00Oomoo`0;Ool0
015oo`03001_Nfmk01A_N`800003Kg/007oo00moo`8004i_N`03001_Nfmk03U_N`04001oogoo000k
Kg/00`00DYABU01gDY@00`00;F/]J`1A;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk01E_N`800003
Kg/00000011oo`8004a_N`03001_Nfmk03U_N`04001oogoo000lKg/00`00DYABU01gDY@00`00;F/]
J`1@;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk01I_N`80009_N`03001oogoo00moo`03001_Nfmk
04Q_N`03001_Nfmk03]_N`04001oogoo000kKg/00`00DYABU01gDY@00`00;F/]J`1@;F/00`00Oomo
o`0;Ool0015oo`03001_Nfmk01M_N`80009_N`80011oo`8004Q_N`03001_Nfmk03]_N`04001oogoo
000lKg/00`00DYABU01gDY@00`00;F/]J`1?;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk01Q_N`80
00=_N`03001oogoo00moo`03001_Nfmk04A_N`03001_Nfmk03e_N`03001oo`0003a_N`03001BU5:D
07QBU003000]Jbe[04h]J`03001oogoo00]oo`004Goo00<006mkKg/06Fmk0P000fmk0P0047oo0P00
A6mk00<006mkKg/0?Fmk00@007ooOol003a_N`03001BU5:D07QBU003000]Jbe[04d]J`03001oogoo
00]oo`004Goo00<006mkKg/06Vmk0P0016mk0P0047oo00<006mkKg/0@6mk0P00?Vmk00D007oo001o
o`0003a_N`03001BU5:D07UBU003000]Jbe[04`]J`03001oogoo00]oo`004Goo00<006mkKg/06fmk
0P001Fmk00<007ooOol03Woo0P00@6mk00<006mkKg/0?Fmk00<007oo00000Woo00<006mkKg/0>Vmk
00<005:DDY@0NE:D00<002e[;F/0Bbe[00<007ooOol02goo000AOol00`00Kg]_N`0LKg/20005Kg/2
000@Ool2000nKg/00`00Kg]_N`0lKg/01`00Oomoogoo001oo`0003e_N`03001BU5:D07UBU003000]
Jbe[04X]J`03001oogoo00]oo`004Goo00<006mkKg/07Vmk00<006mkKg/016mk0P0047oo0P00>fmk
00<006mkKg/0?Fmk00<007ooOol00Woo00<007oo0000?6mk00<005:DDY@0NU:D00<002e[;F/0BBe[
00<007ooOol02goo000AOol00`00Kg]_N`0OKg/00`00Kg]_N`05Kg/2000@Ool00`00Kg]_N`0hKg/0
0`00Kg]_N`0lKg/00`00Oomoo`03Ool00`00Ool0000mKg/00`00DYABU01jDY@00`00;F/]J`18;F/0
0`00Oomoo`0;Ool0015oo`03001_Nfmk021_N`03001_Nfmk00I_N`03001oogoo00ioo`8003M_N`80
03i_N`03001oogoo00Aoo`8003i_N`03001BU5:D07UBU003000]Jbe[04P]J`03001oogoo00]oo`00
4Goo00<006mkKg/08Fmk00<006mkKg/01Vmk0P0047oo0P00=Fmk00<006mkKg/0?6mk00<007ooOol0
1Goo00<007oo0000?Fmk00<005:DDY@0NU:D00<002e[;F/0Abe[00<007ooOol02goo000AOol00`00
Kg]_N`0RKg/00`00Kg]_N`07Kg/2000@Ool2000cKg/00`00Kg]_N`0lKg/00`00Oomoo`06Ool2000n
Kg/00`00DYABU01jDY@00`00;F/]J`16;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk02=_N`03001_
Nfmk00Q_N`03001oogoo00moo`80031_N`03001_Nfmk03a_N`03001oogoo00Moo`8003m_N`03001B
U5:D07YBU003000]Jbe[04D]J`03001oogoo00]oo`004Goo00<006mkKg/096mk00<006mkKg/026mk
0P004Goo00<006mkKg/0;Fmk00<006mkKg/0?6mk00<007ooOol027oo0P00?Vmk00<005:DDY@0Ne:D
00<002e[;F/0A2e[00<007ooOol02goo000AOol00`00Kg]_N`0UKg/00`00Kg]_N`09Kg/2000@Ool2
000]Kg/00`00Kg]_N`0kKg/00`00Oomoo`0:Ool6000jKg/00`00DYABU01kDY@00`00;F/]J`13;F/0
0`00Oomoo`0;Ool0015oo`03001_Nfmk02E_N`8000a_N`03001oogoo00moo`8002Y_N`03001_Nfmk
03a_N`03001oogoo00]oo`03001oogoo009oo`H003E_N`03001BU5:D07]BU003000]Jbe[048]J`03
001oogoo00]oo`004Goo00<006mkKg/09Vmk00<006mkKg/02fmk0P004Goo00<006mkKg/09fmk00<0
06mkKg/0>fmk00<007ooOol037oo00<007ooOol027oo1@00<6mk00<005:DDY@0O5:D00<002e[;F/0
@Be[00<007ooOol02goo000AOol00`00Kg]_N`0WKg/00`00Kg]_N`0<Kg/2000@Ool2000WKg/00`00
Kg]_N`0jKg/00`00Oomoo`0>Ool00`00Oomoo`0<Ool5000/Kg/00`00DYABU01lDY@00`00;F/]J`10
;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk02Q_N`03001_Nfmk00e_N`80011oo`03001_Nfmk02=_
N`03001_Nfmk03]_N`03001oogoo00moo`03001oogoo011oo`D002M_N`03001BU5:D07eBU003000]
Jbe[03l]J`03001oogoo00]oo`004Goo00<006mkKg/0:Fmk00<006mkKg/03Vmk00<007ooOol03Woo
0P008fmk00<006mkKg/0>Vmk00<007ooOol04Goo00<007ooOol057oo100096mk00<005:DDY@0OE:D
00<002e[;F/0?Re[00<007ooOol02goo000AOol00`00Kg]_N`0ZKg/00`00Kg]_N`0>Kg/2000@Ool0
0`00Kg]_N`0PKg/00`00Kg]_N`0jKg/00`00Oomoo`0AOol00`00Oomoo`0HOol5000PKg/00`00DYAB
U01mDY@00`00;F/]J`0m;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk02]_N`03001_Nfmk00m_N`80
00moo`8001m_N`03001_Nfmk03Y_N`03001oogoo01=oo`03001oogoo01aoo`@001a_N`03001BU5:D
07iBU003000]Jbe[03`]J`03001oogoo00]oo`004Goo00<006mkKg/0;6mk00<006mkKg/046mk0P00
3goo0P007Fmk00<006mkKg/0>Vmk00<007ooOol057oo00<007ooOol07goo1@0066mk00<005:DDY@0
OU:D00<002e[;F/0>be[00<007ooOol02goo000AOol00`00Kg]_N`0]Kg/00`00Kg]_N`0AKg/2000?
Ool2000JKg/00`00Kg]_N`0jKg/00`00Oomoo`0EOol00`00Oomoo`0TOol4000EKg/00`00DYABU01n
DY@00`00;F/]J`0j;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk02i_N`03001_Nfmk019_N`03001o
ogoo00ioo`03001_Nfmk01M_N`03001_Nfmk03Y_N`03001oogoo01Ioo`03001oogoo02Moo`D0011_
N`03001BU5:D07mBU003000]Jbe[03T]J`03001oogoo00]oo`004Goo00<006mkKg/0;fmk00<006mk
Kg/04Vmk0P003goo0P005fmk00<006mkKg/0>Fmk00<007ooOol067oo00<007ooOol0:goo10003Fmk
00<005:DDY@0Oe:D00<002e[;F/0>2e[00<007ooOol02goo000AOol00`00Kg]_N`0`Kg/00`00Kg]_
N`0CKg/2000?Ool2000DKg/00`00Kg]_N`0jKg/00`00Oomoo`0HOol00`00Oomoo`0_Ool50009Kg/0
0`00DYABU01oDY@00`00;F/]J`0g;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk035_N`03001_Nfmk
01A_N`03001oogoo00ioo`80019_N`03001_Nfmk03Y_N`03001oogoo01Uoo`03001oogoo03=oo`D0
00A_N`03001BU5:D081BU003000]Jbe[03H]J`03001oogoo00]oo`004Goo00<006mkKg/0<Vmk00<0
06mkKg/056mk0P0047oo0P003fmk00<006mkKg/0>Vmk00<007ooOol06goo00<007ooOol0=goo1P00
PU:D00<002e[;F/0=Be[00<007ooOol02goo000AOol00`00Kg]_N`0cKg/00`00Kg]_N`0EKg/2000@
Ool00`00Kg]_N`0<Kg/00`00Kg]_N`0jKg/00`00Oomoo`0KOol00`00Oomoo`0lOol40020DY@00`00
;F/]J`0d;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk03A_N`03001_Nfmk01I_N`03001oogoo00io
o`8000]_N`03001_Nfmk03Y_N`03001oogoo01eoo`03001oogoo03aoo`03001_Nfmk00<007iBU003
000]Jbe[03<]J`03001oogoo00]oo`004Goo00<006mkKg/0=Fmk00<006mkKg/05Vmk0P0047oo0P00
2Fmk00<006mkKg/0>Vmk00<007ooOol07Goo00<007ooOol0?Goo00<006mkKg/00Vmk0`00O5:D00<0
02e[;F/0<Re[00<007ooOol02goo000AOol00`00Kg]_N`0fKg/00`00Kg]_N`0GKg/2000@Ool00`00
Kg]_N`06Kg/00`00Kg]_N`0iKg/00`00Oomoo`0OOol00`00Oomoo`0lOol00`00Kg]_N`05Kg/2001k
DY@00`00;F/]J`0a;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk03M_N`03001_Nfmk01Q_N`8000mo
o`8000E_N`03001_Nfmk03Y_N`03001oogoo021oo`03001oogoo03]oo`03001_Nfmk00M_N`<007UB
U003000]Jbe[030]J`03001oogoo00]oo`004Goo00<006mkKg/0>6mk00<006mkKg/06Fmk00<007oo
Ool03Woo00<006mkKg/00Vmk00<006mkKg/0>Fmk00<007ooOol08Goo00<007ooOol0?7oo00<006mk
Kg/02Fmk0`00Me:D00<002e[;F/0;be[00<007ooOol02goo000AOol00`00Kg]_N`0iKg/00`00Kg]_
N`0IKg/2000?Ool20002Kg/00`00Kg]_N`0iKg/00`00Oomoo`0ROol00`00Oomoo`0kOol00`00Kg]_
N`0<Kg/3001eDY@00`00;F/]J`0^;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk03Y_N`03001_Nfmk
01Y_N`8000moo`8003a_N`03001oogoo029oo`03001oogoo03aoo`03001_Nfmk00i_N`D0075BU003
000]Jbe[02d]J`03001oogoo00]oo`004Goo00<006mkKg/0>fmk00<006mkKg/06fmk0P003Woo0P00
>Vmk00<007ooOol097oo00<007ooOol0>goo00<006mkKg/04fmk1000KU:D00<002e[;F/0;2e[00<0
07ooOol02goo0008Ool30006Ool00`00Kg]_N`0lKg/00`00Kg]_N`0LKg/2000<Ool01000Ool00000
>6mk00<007ooOol097oo00<007ooOol0>goo00<006mkKg/05fmk0`00K5:D00<002e[;F/0:be[00<0
07ooOol02goo0009Ool00`00Oomoo`05Ool00`00Kg]_N`0mKg/00`00Kg]_N`0MKg/00`00Oomoo`09
Ool01@00Oomoogoo0000=Vmk00<007ooOol09Woo00<007ooOol0>goo00<006mkKg/06Fmk0`00JU:D
00<002e[;F/0:Re[00<007ooOol02goo0006Ool50006Ool00`00Kg]_N`0nKg/00`00Kg]_N`0MKg/2
0009Ool00`00Oomoo`02Ool2000dKg/00`00Oomoo`0WOol00`00Oomoo`0jOol00`00Kg]_N`0LKg/3
001XDY@00`00;F/]J`0Y;F/00`00Oomoo`0;Ool000Ioo`04001oogoo0007Ool00`00Kg]_N`0oKg/0
0`00Kg]_N`0NKg/20007Ool00`00Oomoo`04Ool2000aKg/00`00Oomoo`0YOol00`00Oomoo`0jOol0
0`00Kg]_N`0NKg/3001VDY@00`00;F/]J`0X;F/00`00Oomoo`0;Ool000Moo`03001oo`0000Moo`03
001_Nfmk041_N`03001_Nfmk01m_N`03001oogoo00=oo`03001oogoo00Moo`03001_Nfmk02i_N`03
001oogoo02Uoo`03001oogoo03Yoo`03001_Nfmk025_N`<006ABU003000]Jbe[02L]J`03001oogoo
00]oo`0027oo0P001goo00<006mkKg/0@Fmk00<006mkKg/07fmk0P000goo00<007ooOol027oo0P00
;Fmk00<007ooOol0:goo00<007ooOol0>Woo00<006mkKg/08fmk0`00HU:D00<002e[;F/09Re[00<0
07ooOol02goo0009Ool00`00Oomoo`05Ool00`00Kg]_N`11Kg/00`00Kg]_N`0QKg/200000goo001o
o`0;Ool00`00Kg]_N`0ZKg/00`00Oomoo`0/Ool00`00Oomoo`0iOol00`00Kg]_N`0VKg/3001PDY@2
000V;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk049_N`03001_Nfmk029_N`8000eoo`8002U_N`03
001oogoo02ioo`03001oogoo03Qoo`03001_Nfmk02U_N`<005mBU003000]Jbe[02<]J`03001oogoo
00]oo`004Goo00<006mkKg/0@fmk00<006mkKg/08Vmk0P003Woo00<006mkKg/09Vmk00<007ooOol0
;Woo00<007ooOol0>Goo00<006mkKg/0:fmk0`00GE:D00<002e[;F/08Re[00<007ooOol02goo000A
Ool00`00Kg]_N`14Kg/00`00Kg]_N`0QKg/00`00Kg/0000>Ool2000UKg/00`00Oomoo`0`Ool00`00
Oomoo`0hOol00`00Kg]_N`0^Kg/3001KDY@00`00;F/]J`0Q;F/00`00Oomoo`0;Ool0015oo`03001_
Nfmk04E_N`03001_Nfmk021_N`03001_Nfmk008000ioo`03001_Nfmk029_N`03001oogoo031oo`03
001oogoo03Uoo`03001_Nfmk031_N`<005UBU003000]Jbe[020]J`03001oogoo00]oo`004Goo00<0
06mkKg/0AVmk00<006mkKg/07fmk00<006mkKg/00Vmk00<007ooOol037oo0P008Fmk00<007ooOol0
<Woo00<007ooOol0>7oo00<006mkKg/0<fmk0P00F5:D00<002e[;F/07be[00<007ooOol02goo000A
Ool00`00Kg]_N`17Kg/00`00Kg]_N`0NKg/00`00Kg]_N`03Kg/2000>Ool00`00Kg]_N`0NKg/00`00
Oomoo`0cOol00`00Oomoo`0hOol00`00Kg]_N`0dKg/2001GDY@00`00;F/]J`0N;F/00`00Oomoo`0;
Ool0015oo`03001_Nfmk04Q_N`03001_Nfmk01a_N`03001_Nfmk00I_N`03001oogoo00aoo`8001e_
N`03001oogoo03Aoo`03001oogoo03Qoo`03001_Nfmk03I_N`<005EBU003000]Jbe[01d]J`03001o
ogoo00]oo`004Goo00<006mkKg/0BFmk00<006mkKg/06fmk00<006mkKg/01fmk0P003Woo00<006mk
Kg/06Vmk00<007ooOol0=Goo00<007ooOol0>7oo00<006mkKg/0>6mk0P00E5:D00<002e[;F/072e[
00<007ooOol02goo000AOol00`00Kg]_N`1:Kg/00`00Kg]_N`0JKg/00`00Kg]_N`09Kg/00`00Oomo
o`0<Ool2000IKg/00`00Oomoo`0fOol00`00Oomoo`0hOol00`00Kg]_N`0jKg/3001BDY@2000L;F/0
0`00Oomoo`0;Ool0015oo`03001_Nfmk04]_N`03001_Nfmk01U_N`03001_Nfmk00Y_N`8000ioo`03
001_Nfmk01I_N`03001oogoo03Moo`03001oogoo03Qoo`03001_Nfmk03a_N`<0055BU003000]Jbe[
01T]J`03001oogoo00]oo`004Goo00<006mkKg/0C6mk00<006mkKg/066mk00<006mkKg/036mk00<0
07ooOol037oo0P005Vmk00<007ooOol0=goo00<007ooOol0>7oo00<006mkKg/0?fmk0`00Ce:D00<0
02e[;F/062e[00<007ooOol02goo000AOol00`00Kg]_N`1=Kg/00`00Kg]_N`0GKg/00`00Kg]_N`0=
Kg/2000>Ool00`00Kg]_N`0BKg/00`00Oomoo`0iOol00`00Oomoo`0hOol00`00Kg]_N`11Kg/3001=
DY@00`00;F/]J`0G;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk04i_N`03001_Nfmk01I_N`03001_
Nfmk00m_N`03001oogoo00aoo`80019_N`03001oogoo03Yoo`03001oogoo03Moo`03001_Nfmk04A_
N`<004]BU003000]Jbe[01H]J`03001oogoo00]oo`004Goo00<006mkKg/0Cfmk00<006mkKg/05Fmk
00<006mkKg/046mk0P003Woo00<006mkKg/03Vmk00<007ooOol0?7oo00<007ooOol0=goo00<006mk
Kg/0AVmk0`00BE:D00<002e[;F/05Be[00<007ooOol02goo000AOol00`00Kg]_N`1@Kg/00`00Kg]_
N`0DKg/00`00Kg]_N`0BKg/00`00Oomoo`0<Ool2000>Kg/00`00Oomoo`0lOol00`00Oomoo`0gOol0
0`00Kg]_N`19Kg/20018DY@00`00;F/]J`0D;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk055_N`03
001_Nfmk019_N`03001_Nfmk01A_N`8000ioo`03001_Nfmk00Y_N`03001oogoo03ioo`03001oogoo
03Moo`03001_Nfmk04Y_N`8004MBU003000]Jbe[01<]J`03001oogoo00]oo`004Goo00<006mkKg/0
DVmk00<006mkKg/04Fmk00<006mkKg/05Vmk00<007ooOol037oo0P002Vmk00<007ooOol0?goo00<0
07ooOol0=Woo00<006mkKg/0C6mk0`00AE:D00<002e[;F/04Re[00<007ooOol02goo000AOol00`00
Kg]_N`1CKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0GKg/2000>Ool00`00Kg]_N`06Kg/00`00Oomoo`11
Ool5000cOol00`00Kg]_N`1?Kg/20014DY@00`00;F/]J`0A;F/00`00Oomoo`0;Ool0015oo`03001_
Nfmk05=_N`03001_Nfmk011_N`03001_Nfmk01U_N`03001oogoo00aoo`8000I_N`03001oogoo045o
o`03001_Nfmk009_Na4002=oo`03001_Nfmk051_N`8004=BU080014]J`03001oogoo00]oo`004Goo
00<006mkKg/0E6mk00<006mkKg/03fmk00<006mkKg/06Vmk0P003Woo00<006mkKg/00fmk00<007oo
Ool0@Goo00<006mkKg/04fmk20006goo00<006mkKg/0DVmk0`00@U:D00<002e[;F/03Re[00<007oo
Ool02goo000AOol00`00Kg]_N`1EKg/00`00Kg]_N`0>Kg/00`00Kg]_N`0LKg/00`00Oomoo`0<Ool2
0002Kg/00`00Oomoo`11Ool00`00Kg]_N`0LKg/9000COol00`00Kg]_N`1DKg/30010DY@00`00;F/]
J`0=;F/00`00Oomoo`0;Ool0015oo`03001_Nfmk05I_N`03001_Nfmk00e_N`03001_Nfmk01e_N`80
00ioo`03001_N`0004=oo`03001_Nfmk02E_N`P000]oo`03001_Nfmk05M_N`8003mBU08000d]J`03
001oogoo00]oo`004Goo00<006mkKg/0Efmk00<006mkKg/036mk00<006mkKg/07fmk00<007ooOol0
37oo00<007ooOol0@Woo00<006mkKg/0;Fmk2@000Woo00<006mkKg/0FFmk0P00?e:D00<002e[;F/0
2Re[00<007ooOol02goo000AOol00`00Kg]_N`1HKg/00`00Kg]_N`0;Kg/00`00Kg]_N`0PKg/2000<
Ool00`00Oomoo`11Ool00`00Kg]_N`0gKg/9001GKg/3000mDY@00`00;F/]J`09;F/00`00Oomoo`0;
Ool0015oo`03001_Nfmk05U_N`03001_Nfmk00U_N`03001_Nfmk02=_N`03001oogoo00Yoo`03001o
ogoo041oo`03001_Nfmk03Y_N`03001BU5:D00=BU0H005A_N`8003aBU08000T]J`03001oogoo00]o
o`004Goo00<006mkKg/0FVmk00<006mkKg/026mk00<006mkKg/096mk0P002goo00<007ooOol0?goo
00<006mkKg/0>fmk00<005:DDY@025:D1@00DFmk0P00?5:D00<002e[;F/01Re[00<007ooOol02goo
000AOol00`00Kg]_N`1KKg/00`00Kg]_N`07Kg/00`00Kg]_N`0VKg/00`00Oomoo`09Ool00`00Oomo
o`0mOol00`00Kg]_N`0lKg/00`00DYABU00=DY@4001?Kg/2000kDY@00`00;F/]J`05;F/00`00Oomo
o`0;Ool0015oo`03001_Nfmk05a_N`03001_Nfmk00I_N`03001_Nfmk02M_N`8000Yoo`03001oogoo
03aoo`03001_Nfmk03e_N`03001BU5:D011BU0D004a_N`<003UBU08000D]J`03001oogoo00]oo`00
4Goo00<006mkKg/0GFmk00<006mkKg/01Fmk00<006mkKg/0:Fmk00<007ooOol01goo00<007ooOol0
?7oo00<006mkKg/0?Fmk00<005:DDY@05E:D1000Bfmk0P00>E:D00<002e[;F/00Re[00<007ooOol0
2goo000AOol00`00Kg]_N`1NKg/00`00Kg]_N`04Kg/00`00Kg]_N`0ZKg/20008Ool00`00Oomoo`0j
Ool00`00Kg]_N`0nKg/00`00DYABU00IDY@40019Kg/2000hDY@20002;F/00`00Oomoo`0;Ool0015o
o`03001_Nfmk05m_N`03001_Nfmk00=_N`03001_Nfmk02a_N`03001oogoo00Ioo`03001oogoo03Uo
o`03001_Nfmk03m_N`03001BU5:D01aBU0@004M_N`8003QBU003000]J`0000eoo`004Goo00<006mk
Kg/0H6mk00<006mkKg/00Vmk00<006mkKg/0;Fmk0P001goo00<007ooOol0=goo00<006mkKg/0@6mk
00<005:DDY@085:D1@00A6mk0`00=U:D0P003Goo000AOol00`00Kg]_N`1QKg/01@00Kg]_Nfmk0000
<Fmk0P001Goo00<007ooOol0=goo00<006mkKg/0@Fmk00<005:DDY@095:D1000@fmk0P00=E:D00<0
07ooOol02goo000AOol00`00Kg]_N`1RKg/01000Kg]_N`00<fmk0P0017oo00<007ooOol0=Woo00<0
06mkKg/0@Fmk00<005:DDY@0:5:D1@00@6mk0P00<e:D00<007ooOol02goo000AOol00`00Kg]_N`1S
Kg/00`00Kg/0000eKg/20003Ool00`00Oomoo`0dOol00`00Kg]_N`13Kg/00`00DYABU00/DY@4000n
Kg/2000aDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk06A_N`8003M_N`80009oo`03001oogoo03=o
o`03001_Nfmk04=_N`03001BU5:D031BU0D003]_N`8002mBU003001oogoo00]oo`004Goo00<006mk
Kg/0IFmk00<006mkKg/0=fmk0P0000=oo`00Ool0<Woo00<006mkKg/0AFmk00<005:DDY@0=5:D1000
>Fmk00<005:DDY@0;5:D00<007ooOol02goo000AOol00`00Kg]_N`1UKg/00`00Kg]_N`0iKg/2000c
Ool00`00Kg]_N`16Kg/00`00DYABU00gDY@5000eKg/2000/DY@00`00Oomoo`0;Ool0015oo`03001_
Nfmk06I_N`03001_Nfmk03U_N`80035oo`03001_Nfmk04M_N`03001BU5:D03aBU0@003=_N`8002YB
U003001oogoo00]oo`004Goo00<006mkKg/0IVmk00<006mkKg/0>fmk00<007ooOol0;Woo00<006mk
Kg/0B6mk00<005:DDY@0?e:D1@00<6mk0P00:5:D00<007ooOol02goo000AOol00`00Kg]_N`1WKg/0
0`00Kg]_N`0kKg/2000^Ool00`00Kg]_N`18Kg/00`00DYABU014DY@4000^Kg/3000UDY@00`00Oomo
o`0;Ool0015oo`03001_Nfmk06M_N`8003e_N`8002aoo`03001_Nfmk04Y_N`03001BU5:D04MBU0<0
02i_N`8002=BU003001oogoo00]oo`004Goo00<006mkKg/0Ifmk0P00?Vmk0P00:goo00<006mkKg/0
BVmk00<005:DDY@0BU:D0`00;Fmk0P008E:D00<007ooOol02goo000AOol00`00Kg]_N`1XKg/2000n
Kg/00`00Oomoo`0XOol00`00Kg]_N`1<Kg/00`00DYABU01<DY@3000/Kg/2000ODY@00`00Oomoo`0;
Ool0015oo`03001_Nfmk06Q_N`8003i_N`8002Uoo`03001_Nfmk04a_N`03001BU5:D04mBU0<002]_
N`<001aBU003001oogoo00]oo`004Goo00<006mkKg/0JFmk0P00?Fmk00<007oo0000:7oo00<006mk
Kg/0C6mk00<005:DDY@0DU:D0`00:fmk0P006U:D00<007ooOol02goo000AOol00`00Kg]_N`1YKg/2
000mKg/01000Oomoo`009Woo00<006mkKg/0CVmk00<005:DDY@0E5:D0`00:Vmk0P0065:D00<007oo
Ool02goo000AOol00`00Kg]_N`1ZKg/2000kKg/00`00Oomoo`02Ool00`00Oomoo`0SOol00`00Kg]_
N`1>Kg/00`00DYABU01GDY@5000WKg/2000FDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk06Y_N`03
001_N`0003Y_N`03001oogoo00=oo`03001oogoo025oo`03001_Nfmk051_N`03001BU5:D05]BU0@0
02E_N`8001ABU003001oogoo00]oo`004Goo00<006mkKg/0JVmk00<006mk0000>Vmk00<007ooOol0
0goo00<007ooOol08Goo00<006mkKg/0D6mk00<005:DDY@0Ge:D0`0096mk00<005:DDY@04E:D00<0
07ooOol02goo000AOol00`00Kg]_N`1[Kg/00`00Kg/0000iKg/00`00Oomoo`04Ool00`00Oomoo`0O
Ool00`00Kg]_N`1AKg/00`00DYABU01RDY@3000RKg/2000ADY@00`00Oomoo`0;Ool0015oo`03001_
Nfmk06]_N`04001_Nfmk000hKg/00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Kg]_N`1BKg/00`00
DYABU01TDY@3000QKg/2000?DY@00`00Oomoo`0;Ool0015oo`03001_Nfmk06a_N`03001_N`0003Q_
N`03001oogoo00Ioo`03001oogoo01eoo`03001_Nfmk059_N`03001BU5:D06MBU0<0021_N`8000eB
U003001oogoo00]oo`004Goo00<006mkKg/0K6mk00@006mkKg/003M_N`03001oogoo00Moo`03001o
ogoo01]oo`03001_Nfmk05A_N`03001BU5:D06UBU0<001m_N`8000]BU003001oogoo00]oo`004Goo
00<006mkKg/0K6mk00D006mkKg]_N`0003I_N`03001oogoo00Qoo`03001oogoo01Yoo`03001_Nfmk
05A_N`03001BU5:D06aBU08001m_N`03001BU5:D00QBU003001oogoo00]oo`004Goo00<006mkKg/0
KFmk00@006mkKg/003I_N`03001oogoo00Uoo`03001oogoo01Qoo`03001_Nfmk05I_N`03001BU5:D
06eBU08001i_N`8000QBU003001oogoo00]oo`004Goo00<006mkKg/0KFmk00D006mkKg]_N`0003E_
N`03001oogoo00Yoo`03001oogoo01Moo`03001_Nfmk05I_N`03001BU5:D06mBU0<001e_N`8000IB
U003001oogoo00]oo`004Goo00<006mkKg/0KVmk00D006mkKg]_N`0003=_N`03001oogoo00aoo`03
001oogoo01Eoo`03001_Nfmk05M_N`03001BU5:D079BU08001e_N`03001BU5:D00=BU003001oogoo
00]oo`004Goo00<006mkKg/0KVmk00D006mkKg]_N`0003=_N`03001oogoo00aoo`03001oogoo01Eo
o`03001_Nfmk05Q_N`03001BU5:D07=BU0<001]_N`8000=BU003001oogoo00]oo`004Goo00<006mk
Kg/0Kfmk00D006mkKg]_N`00039_N`03001oogoo00eoo`03001oogoo01Aoo`03001_Nfmk05Q_N`03
001BU5:D07IBU0<001Y_N`800003DY@007oo00aoo`004Goo00<006mkKg/0Kfmk00<006mkKg/00Vmk
00<006mkKg/0;fmk00<007ooOol03Woo00<007ooOol04Woo00<006mkKg/0FVmk00<005:DDY@0N5:D
0`006Fmk0P003Goo000AOol00`00Kg]_N`1_Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0_Kg/00`00Oomo
o`0?Ool00`00Oomoo`0AOol00`00Kg]_N`1JKg/00`00DYABU01kDY@2000HKg/00`00Oomoo`0;Ool0
015oo`03001_Nfmk071_N`03001_Nfmk009_N`03001_Nfmk02i_N`03001oogoo011oo`03001oogoo
00moo`03001_Nfmk05a_N`03001BU5:D07aBU08001I_N`03001oogoo00]oo`004Goo00<006mkKg/0
L6mk00<006mkKg/00fmk00<006mkKg/0;Fmk00<007ooOol04Goo00<007ooOol03Woo00<006mkKg/0
G6mk00<005:DDY@0OU:D0`004fmk00<007ooOol02goo000AOol00`00Kg]_N`1aKg/00`00Kg]_N`02
Kg/00`00Kg]_N`0]Kg/00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Kg]_N`1MKg/00`00DYABU020
DY@2000AKg/00`00Oomoo`0;Ool0015oo`03001_Nfmk075_N`03001_Nfmk00=_N`03001_Nfmk02a_
N`03001oogoo01=oo`03001oogoo00]oo`03001_Nfmk05i_N`03001BU5:D089BU08000m_N`03001o
ogoo00]oo`004Goo00<006mkKg/0LVmk00<006mkKg/00fmk00<006mkKg/0:Vmk00<007ooOol05Goo
00<007ooOol02Woo00<006mkKg/0GVmk00<005:DDY@0Q5:D0P003Fmk00<007ooOol02goo000AOol0
0`00Kg]_N`1bKg/00`00Kg]_N`03Kg/00`00Kg]_N`0ZKg/00`00Oomoo`0FOol00`00Oomoo`08Ool0
0`00Kg]_N`1PKg/00`00DYABU025DY@3000:Kg/00`00Oomoo`0;Ool000Moo`<000Moo`03001_Nfmk
079_N`8000E_N`03001_Nfmk02U_N`03001oogoo01Moo`03001oogoo00Moo`03001_Nfmk061_N`03
001BU5:D08QBU08000Q_N`03001oogoo00]oo`001Woo00D007ooOomoo`0000Ioo`03001_Nfmk07=_
N`03001_Nfmk00A_N`03001_Nfmk02Q_N`03001oogoo01Qoo`03001oogoo00Eoo`03001_Nfmk069_
N`03001BU5:D08UBU08000I_N`03001oogoo00]oo`001Woo00D007ooOomoo`0000Ioo`03001_Nfmk
07=_N`03001_Nfmk00A_N`03001_Nfmk02Q_N`03001oogoo01Uoo`03001oogoo00=oo`03001_Nfmk
06=_N`03001BU5:D08]BU003001_Nfmk00=_N`03001oogoo00]oo`001Woo10001goo00<006mkKg/0
M6mk00<006mkKg/016mk00<006mkKg/09fmk00<007ooOol06Woo00<007ooOol00Woo00<006mkKg/0
I6mk00<005:DDY@0Re:D0P000fmk00<007ooOol02goo0006Ool00`00Oomoo`08Ool00`00Kg]_N`1d
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0VKg/00`00Oomoo`0KOol01000Oomoo`00Ifmk00<005:DDY@0
SE:D0P0000=_N`00Ool037oo0007Ool00`00Oomoo`07Ool00`00Kg]_N`1dKg/20006Kg/00`00Kg]_
N`0VKg/00`00Oomoo`0LOol00`00Ool0001WKg/00`00DYABU02?DY@2000=Ool000Qoo`8000Moo`03
001_Nfmk07E_N`03001_Nfmk00E_N`03001_Nfmk02E_N`03001oogoo01eoo`H006A_N`03001BU5:D
08mBU003001oogoo00]oo`004Goo00<006mkKg/0MFmk0P001Vmk0P009Fmk00<007ooOol07goo00<0
07ooOol00Woo6`00BFmk00<005:DDY@0Se:D00<007ooOol02goo000AOol00`00Kg]_N`1fKg/00`00
Kg]_N`05Kg/00`00Kg]_N`0SKg/00`00Oomoo`0POol00`00Oomoo`0LOolK000_Kg/00`00DYABU02>
DY@00`00Oomoo`0;Ool0015oo`03001_Nfmk07I_N`03001_Nfmk00I_N`03001_Nfmk029_N`03001o
ogoo025oo`03001oogoo03Iooa8001e_N`03001BU5:D08iBU003001oogoo00]oo`004Goo00<006mk
Kg/0Mfmk00<006mkKg/01Fmk0P008fmk00<007ooOol08Woo00<007ooOol0Agoo6`000Vmk00<005:D
DY@0SU:D00<007ooOol02goo000AOol3001gKg/00`00Kg]_N`06Kg/00`00Kg]_N`0QKg/00`00Oomo
o`0SOol00`00Oomoo`1QOol6002=DY@00`00Oomoo`0;Ool0015oo`03001oogoo00<007A_N`8000M_
N`80029_N`03001oogoo02Aoo`03001oogoo06=oo`03001_Nfmk00D008QBU003001oogoo00]oo`00
4Goo00<007ooOol00goo1000LFmk00<006mkKg/01Vmk0P008Fmk00<007ooOol09Goo00<007ooOol0
HWoo00<006mkKg/01Fmk1000Q5:D00<007ooOol02goo000AOol00`00Oomoo`07Ool4001]Kg/00`00
Kg]_N`06Kg/2000QKg/00`00Oomoo`0VOol00`00Oomoo`1QOol00`00Kg]_N`09Kg/5001oDY@00`00
Oomoo`0;Ool0015oo`03001oogoo00]oo`<006]_N`03001_Nfmk00I_N`80021_N`03001oogoo02Mo
o`03001oogoo061oo`03001_Nfmk00i_N`@007]BU003001oogoo00]oo`004Goo00<007ooOol03Woo
1000Ifmk00<006mkKg/01fmk00<006mkKg/07Fmk00<007ooOol0:Goo0P00Ggoo00<006mkKg/04fmk
1@00MU:D00<007ooOol02goo000AOol00`00Oomoo`0BOol3001UKg/00`00Kg]_N`06Kg/2000NKg/0
0`00Oomoo`0[Ool00`00Oomoo`1LOol00`00Kg]_N`0HKg/4001bDY@00`00Oomoo`0;Ool0015oo`<0
01Eoo`<0069_N`03001_Nfmk00M_N`8001e_N`03001oogoo02aoo`03001oogoo05]oo`03001_Nfmk
01a_N`D006eBU003001oogoo00]oo`004Goo00<007ooOol067oo1000Gfmk00<006mkKg/01fmk00<0
06mkKg/06fmk00<007ooOol0;Goo00<007ooOol0FWoo00<006mkKg/08Fmk1000JE:D00<007ooOol0
2goo000AOol00`00Oomoo`0LOol3001LKg/00`00Kg]_N`07Kg/2000LKg/00`00Oomoo`0^Ool00`00
Oomoo`1IOol00`00Kg]_N`0UKg/5001TDY@00`00Oomoo`0;Ool0015oo`03001oogoo01moo`<005U_
N`03001_Nfmk00Q_N`03001_Nfmk01Y_N`03001oogoo02moo`03001oogoo05Qoo`03001_Nfmk02Y_
N`@0061BU003001oogoo00]oo`004Goo0P008goo1000EVmk00<006mkKg/026mk00<006mkKg/06Fmk
00<007ooOol0<7oo00<007ooOol0Egoo00<006mkKg/0;Vmk1@00Fe:D00<007ooOol02goo000AOol0
0`00Ool0000VOol3001CKg/00`00Kg]_N`08Kg/00`00Kg]_N`0IKg/00`00Oomoo`0aOol00`00Oomo
o`1FOol00`00Kg]_N`0cKg/4001GDY@00`00Oomoo`0;Ool0015oo`03001oogoo008002Moo`<0055_
N`03001_Nfmk00Q_N`03001_Nfmk01Q_N`03001oogoo039oo`03001oogoo05Eoo`03001_Nfmk03M_
N`D0059BU003001oogoo00]oo`004Goo00<007ooOol00Woo00<007ooOol09goo1000CFmk00<006mk
Kg/02Fmk00<006mkKg/05fmk00<007ooOol0<goo00<007ooOol0E7oo00<006mkKg/0?6mk1000CU:D
00<007ooOol02goo000AOol00`00Oomoo`03Ool2000[Ool3001;Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`0FKg/00`00Oomoo`0eOol00`00Oomoo`1COol00`00Kg]_N`10Kg/3001;DY@00`00Oomoo`0;Ool0
015oo`03001oogoo00Eoo`03001oogoo02]oo`<004Q_N`03001_Nfmk00U_N`03001_Nfmk01E_N`03
001oogoo03Ioo`03001oogoo059oo`03001_Nfmk04=_N`<004QBU003001oogoo00]oo`004Goo00<0
07ooOol01Woo0P00;Woo1000A6mk00<006mkKg/02Vmk00<006mkKg/056mk00<007ooOol0=goo00<0
07ooOol0DGoo00<006mkKg/0AVmk0`00AE:D00<007ooOol02goo000AOol00`00Oomoo`08Ool00`00
Oomoo`0_Ool30012Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0DKg/00`00Oomoo`0hOol00`00Oomoo`1@
Ool00`00Kg]_N`19Kg/50010DY@00`00Oomoo`0;Ool0015oo`03001oogoo00Uoo`80039oo`<003m_
N`03001_Nfmk00Y_N`03001_Nfmk01=_N`03001oogoo03Uoo`03001oogoo04moo`03001_Nfmk04i_
N`@003aBU003001oogoo00]oo`004Goo00<007ooOol02goo00<007ooOol0<Woo1000?6mk00<006mk
Kg/02Vmk00<006mkKg/04Vmk00<007ooOol0>Woo00<007ooOol0CWoo00<006mkKg/0DVmk1@00=e:D
00<007ooOol02goo000AOol00`00Oomoo`0<Ool2000fOol3000iKg/00`00Kg]_N`0:Kg/00`00Kg]_
N`0BKg/00`00Oomoo`0kOol00`00Oomoo`1<Ool00`00Kg]_N`1HKg/4000cDY@00`00Oomoo`0;Ool0
015oo`<000ioo`03001oogoo03Ioo`<003I_N`03001_Nfmk00]_N`03001_Nfmk011_N`03001oogoo
03eoo`03001oogoo04]oo`03001_Nfmk05a_N`<0031BU003001oogoo00]oo`004Goo00<007ooOol0
3goo0P00>Goo1000<fmk00<006mkKg/02Vmk0P004Fmk00<007ooOol0?Woo00<007ooOol0BWoo00<0
06mkKg/0Gfmk0`00;E:D00<007ooOol02goo000AOol00`00Oomoo`0AOol2000kOol3000`Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0?Kg/00`00Oomoo`0oOol00`00Oomoo`19Ool00`00Kg]_N`1RKg/3000Z
DY@00`00Oomoo`0;Ool0015oo`03001oogoo01=oo`03001oogoo03]oo`@002e_N`03001_Nfmk00]_
N`03001_Nfmk00i_N`03001oogoo041oo`03001oogoo04Qoo`03001_Nfmk06E_N`D002EBU003001o
ogoo00]oo`004Goo00<007ooOol057oo0P00?goo0`00:Vmk00<006mkKg/02fmk00<006mkKg/03Vmk
00<007ooOol0@Goo00<007ooOol0Agoo00<006mkKg/0JVmk10008E:D00<007ooOol02goo000AOol0
0`00Oomoo`0FOol00`00Oomoo`0oOol4000WKg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/00`00Oomo
o`13Ool00`00Oomoo`15Ool00`00Kg]_N`1_Kg/3000NDY@00`00Oomoo`0;Ool0015oo`03001oogoo
01Moo`8004=oo`<002A_N`03001_Nfmk00]_N`8000e_N`03001oogoo04Aoo`03001oogoo04Aoo`03
001_Nfmk079_N`<001]BU003001oogoo00]oo`004Goo00<007ooOol06Goo00<007ooOol0@goo0`00
8Fmk00<006mkKg/036mk00<006mkKg/02fmk00<007ooOol0AGoo00<007ooOol0@goo00<006mkKg/0
MFmk0`0065:D00<007ooOol02goo000AOol00`00Oomoo`0JOol20016Ool4000NKg/00`00Kg]_N`0;
Kg/2000<Kg/00`00Oomoo`16Ool00`00Oomoo`12Ool00`00Kg]_N`1hKg/5000CDY@00`00Oomoo`0;
Ool0015oo`03001oogoo01aoo`03001oogoo04Moo`<001]_N`03001_Nfmk00a_N`03001_Nfmk00Y_
N`03001oogoo04Moo`03001oogoo041oo`03001_Nfmk07i_N`@000mBU003001oogoo00]oo`004Goo
00<007ooOol07Goo0P00BWoo100066mk00<006mkKg/036mk00<006mkKg/02Fmk00<007ooOol0B7oo
00<007ooOol0>goo2P00Ofmk0`0035:D00<007ooOol02goo000AOol00`00Oomoo`0OOol00`00Oomo
o`1;Ool3000EKg/00`00Kg]_N`0<Kg/00`00Kg]_N`08Kg/00`00Oomoo`1:Ool00`00Oomoo`0cOol7
0004Kg/00`00DYABU003DY@C001_Kg/30009DY@00`00Oomoo`0;Ool0015oo`03001oogoo021oo`03
001oogoo04eoo`<001=_N`03001_Nfmk00a_N`03001_Nfmk00M_N`03001oogoo04]oo`03001oogoo
02eoo`D000a_N`03001BU5:D01EBU180061_N`<000IBU003001oogoo00]oo`004Goo00<007ooOol0
8Goo0P00D7oo0`0046mk00<006mkKg/03Fmk00<006mkKg/01Vmk00<007ooOol0C7oo00<007ooOol0
97oo20004Fmk00<005:DDY@09e:D2P00FFmk0`000e:D00<007ooOol02goo000AOol00`00Oomoo`0S
Ool00`00Oomoo`1@Ool3000=Kg/2000>Kg/00`00Kg]_N`06Kg/00`00Oomoo`1=Ool00`00Oomoo`0I
Ool:000JKg/00`00DYABU00`DY@B001:Kg/4000=Ool0015oo`<002Aoo`8005=oo`<000]_N`03001_
Nfmk00e_N`03001_Nfmk00E_N`03001oogoo04ioo`03001oogoo00moo`T002A_N`03001BU5:D049B
U0T004A_N`03001oogoo00]oo`004Goo00<007ooOol09Woo00<007ooOol0Dgoo0`0026mk00<006mk
Kg/03Fmk0P001Vmk00<007ooOol0Cgoo00<007ooOol01goo1`00;Fmk00<005:DDY@0Be:D2P00>Vmk
00<007ooOol02goo000AOol00`00Oomoo`0WOol2001FOol30006Kg/00`00Kg]_N`0=Kg/00`00Kg]_
N`04Kg/00`00Oomoo`1@Ool01000Oomoogoo1@00=Fmk00<005:DDY@0E5:D4P00:6mk00<007ooOol0
2goo000AOol00`00Oomoo`0YOol00`00Oomoo`1FOol30003Kg/00`00Kg]_N`0=Kg/20004Kg/00`00
Oomoo`1BOol3000jKg/00`00DYABU01VDY@9000OKg/00`00Oomoo`0;Ool0015oo`03001oogoo02Yo
o`8005Uoo`H000i_N`03001_Nfmk009_N`03001oogoo059oo`03001_Nfmk03]_N`03001BU5:D06iB
U1<000a_N`03001oogoo00]oo`004Goo00<007ooOol0;7oo0P00FWoo0P0000Aoo`00000000a_N`05
001_NfmkKg/0001DOol00`00Kg]_N`0kKg/00`00DYABU021DY@90003Kg/00`00Oomoo`0;Ool0015o
o`03001oogoo02ioo`03001oogoo05Uoo`04001oogooOol2000:Kg/20002Kg/00`00Oomoo`1BOol0
0`00Kg]_N`0lKg/00`00DYABU029DY@4000=Ool0015oo`03001oogoo02moo`8005Uoo`03001oogoo
00=oo`<000Q_N`04001_Nfmk001DOol00`00Kg]_N`0lKg/00`00DYABU02<DY@00`00Oomoo`0;Ool0
015oo`03001oogoo035oo`03001oogoo05Ioo`03001oogoo00Ioo`@000E_N`8005Eoo`03001_Nfmk
03e_N`03001BU5:D08]BU003001oogoo00]oo`004Goo00<007ooOol0<Woo0P00Egoo00<007ooOol0
2Goo100000=_N`000000EGoo00<006mkKg/0?Fmk00<005:DDY@0Re:D00<007ooOol02goo000AOol0
0`00Oomoo`0dOol00`00Oomoo`1DOol00`00Oomoo`0=Ool3001EOol00`00Kg]_N`0mKg/00`00DYAB
U02;DY@00`00Oomoo`0;Ool0015oo`03001oogoo03Eoo`8005Aoo`03001oogoo00moo`8005Aoo`03
001_Nfmk03i_N`03001BU5:D08YBU003001oogoo00]oo`004Goo00<007ooOol0=goo00<007ooOol0
DWoo00<007ooOol03goo00<007ooOol0DWoo00<006mkKg/0?Vmk00<005:DDY@0RU:D00<007ooOol0
2goo000AOol00`00Oomoo`0hOol2001BOol00`00Oomoo`0?Ool00`00Oomoo`1BOol00`00Kg]_N`0o
Kg/00`00DYABU029DY@00`00Oomoo`0;Ool0015oo`03001oogoo03Yoo`03001oogoo04moo`03001o
ogoo011oo`03001oogoo055oo`03001_Nfmk03m_N`03001BU5:D08UBU003001oogoo00]oo`004Goo
0`00>goo00<007ooOol0Cgoo00<007ooOol047oo00<007ooOol0D7oo00<006mkKg/0@6mk00<005:D
DY@0R5:D00<007ooOol02goo000AOol00`00Oomoo`0lOol2001?Ool00`00Oomoo`0@Ool00`00Oomo
o`1@Ool00`00Kg]_N`10Kg/00`00DYABU028DY@00`00Oomoo`0;Ool0015oo`03001oogoo03ioo`03
001oogoo04aoo`03001oogoo015oo`03001oogoo04moo`03001_Nfmk045_N`03001BU5:D08MBU003
001oogoo00]oo`004Goo00<007ooOol0?goo0P00CGoo00<007ooOol047oo00<007ooOol0Cgoo00<0
06mkKg/0@Fmk00<005:DDY@0Qe:D00<007ooOol02goo000AOol00`00Oomoo`11Ool00`00Oomoo`1:
Ool00`00Oomoo`0AOol00`00Oomoo`1>Ool00`00Kg]_N`12Kg/00`00DYABU026DY@00`00Oomoo`0;
Ool0015oo`03001oogoo049oo`8004]oo`03001oogoo011oo`03001oogoo04ioo`03001_Nfmk049_
N`03001BU5:D08IBU003001oogoo00]oo`004Goo00<007ooOol0A7oo00<007ooOol0B7oo00<007oo
Ool04Goo00<007ooOol0CGoo00<006mkKg/0@fmk00<005:DDY@0QE:D00<007ooOol02goo000AOol0
0`00Oomoo`15Ool20018Ool00`00Oomoo`0BOol00`00Oomoo`1<Ool00`00Kg]_N`13Kg/00`00DYAB
U025DY@00`00Oomoo`0;Ool0015oo`03001oogoo04Moo`8004Moo`03001oogoo015oo`03001oogoo
04aoo`03001_Nfmk04A_N`03001BU5:D08ABU003001oogoo00]oo`004Goo00<007ooOol0BGoo00<0
07ooOol0A7oo00<007ooOol04Woo00<007ooOol0Bgoo00<006mkKg/0A6mk00<005:DDY@0Q5:D00<0
07ooOol02goo000AOol00`00Oomoo`1:Ool20015Ool00`00Oomoo`0BOol00`00Oomoo`1:Ool00`00
Kg]_N`15Kg/00`00DYABU023DY@00`00Oomoo`0;Ool0015oo`03001oogoo04aoo`03001oogoo049o
o`03001oogoo019oo`03001oogoo04Yoo`03001_Nfmk04E_N`03001BU5:D08=BU003001oogoo00]o
o`004Goo00<007ooOol0CGoo0P00@Woo00<007ooOol04goo00<007ooOol0BGoo00<006mkKg/0AFmk
00<005:DDY@0Pe:D00<007ooOol02goo0007Ool30007Ool00`00Oomoo`1?Ool00`00Oomoo`10Ool0
0`00Oomoo`0COol00`00Oomoo`18Ool00`00Kg]_N`16Kg/00`00DYABU022DY@00`00Oomoo`0;Ool0
00Ioo`05001oogooOol00006Ool00`00Oomoo`1@Ool20010Ool00`00Oomoo`0COol00`00Oomoo`18
Ool00`00Kg]_N`16Kg/00`00DYABU022DY@00`00Oomoo`0;Ool000Ioo`05001oogooOol00006Ool4
001AOol00`00Oomoo`0mOol00`00Oomoo`0DOol00`00Oomoo`17Ool00`00Kg]_N`17Kg/00`00DYAB
U021DY@00`00Oomoo`0;Ool000Moo`<000Moo`03001oogoo05=oo`8003ioo`03001oogoo01=oo`03
001oogoo04Moo`03001_Nfmk04M_N`03001BU5:D085BU003001oogoo00]oo`001Woo00D007ooOomo
o`0000Ioo`03001oogoo05Eoo`03001oogoo03]oo`03001oogoo01Aoo`03001oogoo04Ioo`03001_
Nfmk04Q_N`03001BU5:D081BU003001oogoo00]oo`001Woo00D007ooOomoo`0000Ioo`03001oogoo
05Ioo`03001oogoo03Yoo`03001oogoo01Eoo`03001oogoo04Eoo`03001_Nfmk04Q_N`03001BU5:D
081BU003001oogoo00]oo`001goo0`001goo00<007ooOol0Egoo0P00>goo00<007ooOol057oo00<0
07ooOol0A7oo00<006mkKg/0BVmk00<005:DDY@0Oe:D00<007ooOol02goo000AOol00`00Oomoo`1I
Ool00`00Oomoo`0hOol00`00Oomoo`0EOol00`00Oomoo`13Ool00`00Kg]_N`1:Kg/00`00DYABU01o
DY@00`00Oomoo`0;Ool0015oo`03001oogoo05Yoo`8003Uoo`03001oogoo01Aoo`03001oogoo04=o
o`03001_Nfmk04Y_N`03001BU5:D07mBU003001oogoo00]oo`004Goo00<007ooOol0G7oo00<007oo
Ool0=Woo00<007ooOol05Goo00<007ooOol0@Woo00<006mkKg/0Bfmk00<005:DDY@0OU:D00<007oo
Ool02goo000AOol00`00Oomoo`1MOol2000fOol00`00Oomoo`0EOol00`00Oomoo`12Ool00`00Kg]_
N`1;Kg/00`00DYABU01nDY@00`00Oomoo`0;Ool0015oo`03001oogoo05moo`03001oogoo03Aoo`03
001oogoo01Eoo`03001oogoo045oo`03001_Nfmk04a_N`03001BU5:D07eBU003001oogoo00]oo`00
4Goo00<007ooOol0H7oo0P00=7oo00<007ooOol05Goo00<007ooOol0@Goo00<006mkKg/0C6mk00<0
05:DDY@0OE:D00<007ooOol02goo000AOol00`00Oomoo`1ROol2000cOol00`00Oomoo`0EOol00`00
Oomoo`10Ool00`00Kg]_N`1=Kg/00`00DYABU01lDY@00`00Oomoo`0;Ool0015oo`03001oogoo06Ao
o`03001oogoo031oo`03001oogoo01Ioo`03001oogoo03moo`03001_Nfmk04e_N`03001BU5:D07aB
U003001oogoo00]oo`004Goo00<007ooOol0IGoo0P00<Goo00<007ooOol05Goo00<007ooOol0?goo
00<006mkKg/0CVmk00<005:DDY@0Ne:D00<007ooOol02goo000AOol00`00Oomoo`1WOol00`00Oomo
o`0^Ool00`00Oomoo`0FOol00`00Oomoo`0nOol00`00Kg]_N`1>Kg/00`00DYABU01kDY@00`00Oomo
o`0;Ool0015oo`<006Qoo`8002moo`03001oogoo01Eoo`03001oogoo03ioo`03001_Nfmk04i_N`03
001BU5:D07]BU003001oogoo00]oo`004Goo00<007ooOol0JWoo00<007ooOol0;7oo00<007ooOol0
5Woo00<007ooOol0?Goo00<006mkKg/0Cfmk00<005:DDY@0NU:D00<007ooOol02goo000AOol00`00
Oomoo`1[Ool2000/Ool00`00Oomoo`0FOol00`00Oomoo`0mOol00`00Kg]_N`1?Kg/00`00DYABU01j
DY@00`00Oomoo`0;Ool0015oo`03001oogoo06eoo`03001oogoo02Yoo`03001oogoo01Ioo`03001o
ogoo03aoo`03001_Nfmk051_N`03001BU5:D07UBU003001oogoo00]oo`004Goo00<007ooOol0KWoo
0P00:Woo00<007ooOol05Woo00<007ooOol0?7oo00<006mkKg/0D6mk00<005:DDY@0NE:D00<007oo
Ool02goo000AOol00`00Oomoo`1`Ool00`00Oomoo`0XOol00`00Oomoo`0FOol00`00Oomoo`0kOol0
0`00Kg]_N`1AKg/00`00DYABU01hDY@00`00Oomoo`0;Ool0015oo`03001oogoo075oo`03001oogoo
02Moo`03001oogoo01Moo`03001oogoo03Yoo`03001_Nfmk055_N`03001BU5:D07QBU003001oogoo
00]oo`004Goo00<007ooOol0LWoo0P009goo00<007ooOol05goo00<007ooOol0>Woo00<006mkKg/0
DFmk00<005:DDY@0N5:D00<007ooOol02goo000AOol00`00Oomoo`1dOol00`00Oomoo`0UOol00`00
Oomoo`0GOol00`00Oomoo`0iOol00`00Kg]_N`1BKg/00`00DYABU01gDY@00`00Oomoo`0;Ool0015o
o`03001oogoo07Eoo`8002Eoo`03001oogoo01Moo`03001oogoo03Uoo`03001_Nfmk059_N`03001B
U5:D07MBU003001oogoo00]oo`004Goo00<007ooOol0Mgoo00<007ooOol08Woo00<007ooOol067oo
00<007ooOol0>7oo00<006mkKg/0DVmk00<005:DDY@0Me:D00<007ooOol02goo000AOol00`00Oomo
o`1hOol2000SOol00`00Oomoo`0GOol00`00Oomoo`0hOol00`00Kg]_N`1CKg/00`00DYABU01fDY@0
0`00Oomoo`0;Ool0015oo`03001oogoo07Yoo`03001oogoo021oo`03001oogoo01Qoo`03001oogoo
03Moo`03001_Nfmk05=_N`03001BU5:D07IBU003001oogoo00]oo`004Goo00<007ooOol0Ngoo0P00
87oo00<007ooOol06Goo00<007ooOol0=Woo00<006mkKg/0Dfmk00<005:DDY@0MU:D00<007ooOol0
2goo000AOol00`00Oomoo`1mOol2000OOol00`00Oomoo`0HOol00`00Oomoo`0fOol00`00Kg]_N`1D
Kg/00`00DYABU01eDY@00`00Oomoo`0;Ool0015oo`<007moo`03001oogoo01aoo`03001oogoo01Uo
o`03001oogoo03Aoo`03001_Nfmk05E_N`03001BU5:D07EBU003001oogoo00]oo`004Goo00<007oo
Ool0P7oo0P0077oo00<007ooOol06Woo00<007ooOol0<goo00<006mkKg/0EVmk00<005:DDY@0M5:D
00<007ooOol02goo000AOol00`00Oomoo`22Ool00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomo
o`0cOol00`00Kg]_N`1FKg/00`00DYABU01dDY@00`00Oomoo`0;Ool0015oo`03001oogoo08=oo`80
01Yoo`03001oogoo01Yoo`03001oogoo039oo`03001_Nfmk05I_N`03001BU5:D07ABU003001oogoo
00]oo`004Goo00<007ooOol0QGoo00<007ooOol067oo00<007ooOol06Woo00<007ooOol0<Goo00<0
06mkKg/0Efmk00<005:DDY@0Le:D00<007ooOol02goo000AOol00`00Oomoo`26Ool00`00Oomoo`0G
Ool00`00Oomoo`0JOol00`00Oomoo`0aOol00`00Kg]_N`1GKg/00`00DYABU01cDY@00`00Oomoo`0;
Ool0015oo`03001oogoo08Moo`8001Moo`03001oogoo01]oo`03001oogoo031oo`03001_Nfmk05Q_
N`03001BU5:D079BU003001oogoo00]oo`004Goo00<007ooOol0RGoo00<007ooOol05Goo00<007oo
Ool06Woo00<007ooOol0<7oo00<006mkKg/0F6mk00<005:DDY@0LU:D00<007ooOol02goo000AOol0
0`00Oomoo`2:Ool00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0_Ool00`00Kg]_N`1IKg/0
0`00DYABU01aDY@00`00Oomoo`0;Ool0015oo`03001oogoo08]oo`03001oogoo01Aoo`03001oogoo
01]oo`03001oogoo02ioo`03001_Nfmk05U_N`03001BU5:D075BU003001oogoo00]oo`004Goo00<0
07ooOol0S7oo0P0057oo00<007ooOol06goo00<007ooOol0;Woo00<006mkKg/0FFmk00<005:DDY@0
LE:D00<007ooOol02goo000AOol00`00Oomoo`2>Ool00`00Oomoo`0BOol00`00Oomoo`0KOol00`00
Oomoo`0]Ool00`00Kg]_N`1JKg/00`00DYABU01`DY@00`00Oomoo`0;Ool0015oo`03001oogoo08mo
o`03001oogoo015oo`03001oogoo01]oo`03001oogoo02eoo`03001_Nfmk05Y_N`03001BU5:D071B
U003001oogoo00]oo`004Goo00<007ooOol0S7oo3@002goo00<007ooOol06goo00<007ooOol0;7oo
00<006mkKg/0FVmk00<005:DDY@0L5:D00<007ooOol02goo000AOol00`00Oomoo`26Ool6000=Kg/5
0006Ool00`00Oomoo`0KOol00`00Oomoo`0/Ool00`00Kg]_N`1KKg/00`00DYABU01_DY@00`00Oomo
o`0;Ool0015oo`03001oogoo08=oo`<001Q_N`D00003Ool007oo01eoo`03001oogoo02]oo`03001_
Nfmk05]_N`03001BU5:D06mBU003001oogoo00]oo`004Goo0`00P7oo0`0086mk0`007Goo00<007oo
Ool0:goo00<006mkKg/0Ffmk00<005:DDY@0Ke:D00<007ooOol02goo000AOol00`00Oomoo`1lOol4
000UKg/00`00Oomoo`0LOol00`00Oomoo`0ZOol00`00Kg]_N`1LKg/00`00DYABU01^DY@00`00Oomo
o`0;Ool0015oo`03001oogoo07Moo`D002U_N`@001aoo`03001oogoo02Qoo`03001_Nfmk05e_N`03
001BU5:D06iBU003001oogoo00]oo`004Goo00<007ooOol0LWoo1@00;Vmk0P000Vmk1@005goo00<0
07ooOol0:7oo00<006mkKg/0GVmk00<005:DDY@0KE:D00<007ooOol02goo000AOol00`00Oomoo`1]
Ool5000cKg/20007Kg/4000DOol00`00Oomoo`0WOol00`00Kg]_N`1NKg/00`00DYABU01]DY@00`00
Oomoo`0;Ool0015oo`03001oogoo06Yoo`<003U_N`03001_Nfmk00U_N`D000moo`03001oogoo02Mo
o`03001_Nfmk05i_N`03001BU5:D06eBU003001oogoo00]oo`004Goo00<007ooOol0Igoo0`00?6mk
00<006mkKg/03Vmk100037oo00<007ooOol09Woo00<006mkKg/0Gfmk00<005:DDY@0K5:D00<007oo
Ool02goo000AOol00`00Oomoo`1TOol3000oKg/00`00Kg]_N`0BKg/50007Ool00`00Oomoo`0VOol0
0`00Kg]_N`1OKg/00`00DYABU01/DY@00`00Oomoo`0;Ool0015oo`03001oogoo061oo`@0049_N`80
01Q_N`@000Aoo`03001oogoo02Eoo`03001_Nfmk061_N`03001BU5:D06]BU003001oogoo00]oo`00
4Goo00<007ooOol0Fgoo1@00AVmk0P0076mk0`0000=oo`00Ool09Woo00<006mkKg/0H6mk00<005:D
DY@0Je:D00<007ooOol02goo000AOol00`00Oomoo`1HOol3001;Kg/2000OKg/3000VOol00`00Kg]_
N`1QKg/00`00DYABU01ZDY@00`00Oomoo`0;Ool0015oo`03001oogoo05Eoo`<004i_N`80029_N`03
001oogoo02=oo`03001_Nfmk065_N`03001BU5:D06YBU003001oogoo00]oo`004Goo00<007ooOol0
DWoo0`00DVmk00<006mkKg/086mk00<007ooOol08goo00<006mkKg/0HFmk00<005:DDY@0JU:D00<0
07ooOol02goo000AOol00`00Oomoo`1?Ool3001EKg/00`00Kg]_N`0PKg/2000TOol00`00Kg]_N`1R
Kg/00`00DYABU01YDY@00`00Oomoo`0;Ool0015oo`03001oogoo04aoo`<005Q_N`03001_Nfmk025_
N`03001oogoo029oo`03001_Nfmk069_N`03001BU5:D06UBU003001oogoo00]oo`004Goo0`00BGoo
0`00Ffmk0P008Vmk0P008goo00<006mkKg/0HVmk00<005:DDY@0JE:D00<007ooOol02goo000AOol0
0`00Oomoo`16Ool3001OKg/00`00Kg]_N`0PKg/2000SOol00`00Kg]_N`1SKg/00`00DYABU01XDY@0
0`00Oomoo`0;Ool0015oo`03001oogoo04=oo`<0069_N`03001_Nfmk021_N`03001oo`00029oo`03
001_Nfmk06=_N`03001BU5:D06QBU003001oogoo00]oo`004Goo00<007ooOol0@Goo0P00IFmk00<0
06mkKg/086mk00<007oo00008Woo00<006mkKg/0I6mk00<005:DDY@0Ie:D00<007ooOol02goo000A
Ool00`00Oomoo`0nOol3001WKg/00`00Kg]_N`0QKg/00`00Ool0000QOol00`00Kg]_N`1TKg/00`00
DYABU01WDY@00`00Oomoo`0;Ool0015oo`03001oogoo03aoo`8006Y_N`80029_N`04001oogoo000O
Ool00`00Kg]_N`1VKg/00`00DYABU01VDY@00`00Oomoo`0;Ool0015oo`03001oogoo03Uoo`<006a_
N`80029_N`04001oogoo000OOol00`00Kg]_N`1VKg/00`00DYABU01VDY@00`00Oomoo`0;Ool0015o
o`03001oogoo03Ioo`<0071_N`03001_Nfmk021_N`05001oogooOol0000NOol00`00Kg]_N`1VKg/0
0`00DYABU01VDY@00`00Oomoo`0;Ool0015oo`03001oogoo03=oo`<007=_N`03001_Nfmk025_N`04
001oogoo000NOol00`00Kg]_N`1WKg/00`00DYABU01UDY@00`00Oomoo`0;Ool0015oo`03001oogoo
035oo`8007I_N`03001_Nfmk025_N`05001oogooOol0000MOol00`00Kg]_N`1WKg/00`00DYABU01U
DY@00`00Oomoo`0;Ool0015oo`03001oogoo02ioo`<007Q_N`03001_Nfmk025_N`05001oogooOol0
000MOol00`00Kg]_N`1XKg/00`00DYABU01TDY@00`00Oomoo`0;Ool0015oo`03001oogoo02aoo`80
07]_N`80029_N`03001oogoo009oo`03001oogoo01Yoo`03001_Nfmk06Q_N`03001BU5:D06ABU003
001oogoo00]oo`0000Aoo`00000000Aoo`8000Moo`03001oogoo02Yoo`8007e_N`80029_N`03001o
ogoo009oo`03001oogoo01Yoo`03001_Nfmk06U_N`03001BU5:D06=BU003001oogoo00]oo`000Woo
00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo02Qoo`8007m_N`8002=_N`03001oogoo009o
o`03001oogoo01Qoo`03001_Nfmk06Y_N`03001BU5:D06=BU003001oogoo00]oo`000Woo00<007oo
Ool00Woo00@007ooOol000Ioo`03001oogoo02Eoo`<0089_N`03001_Nfmk025_N`03001oogoo00=o
o`03001oogoo01Moo`03001_Nfmk06Y_N`03001BU5:D06=BU003001oogoo00]oo`000Woo00<007oo
Ool00Woo00@007ooOol000Ioo`@0029oo`8008E_N`03001_Nfmk025_N`03001oogoo00=oo`03001o
ogoo01Moo`03001_Nfmk06]_N`03001BU5:D069BU003001oogoo00]oo`000Woo00<007ooOol00Woo
00@007ooOol000Ioo`03001oogoo025oo`8008M_N`03001_Nfmk025_N`03001oogoo00Aoo`03001o
ogoo01Ioo`03001_Nfmk06]_N`03001BU5:D069BU003001oogoo00]oo`0000=oo`00000017oo00@0
07ooOol000Ioo`03001oogoo01moo`8008U_N`03001_Nfmk025_N`03001oogoo00Aoo`03001oogoo
01Ioo`03001_Nfmk06]_N`03001BU5:D069BU003001oogoo00]oo`000Woo00<007ooOol00goo0P00
1goo00<007ooOol07Goo0P00Rfmk0P008fmk00<007ooOol017oo00<007ooOol05Goo00<006mkKg/0
K6mk00<005:DDY@0HE:D00<007ooOol02goo000AOol00`00Oomoo`0LOol00`00Kg]_N`2<Kg/00`00
Kg]_N`0QKg/00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Kg]_N`1/Kg/00`00DYABU01QDY@00`00
Oomoo`0;Ool0015oo`03001oogoo01Yoo`8008m_N`03001_Nfmk025_N`03001oogoo00Eoo`03001o
ogoo01Aoo`03001_Nfmk06a_N`03001BU5:D065BU003001oogoo00]oo`004Goo00<007ooOol067oo
0P00TFmk00<006mkKg/08Fmk00<007ooOol01Goo00<007ooOol057oo00<006mkKg/0KFmk00<005:D
DY@0H5:D00<007ooOol02goo000AOol00`00Oomoo`0FOol2002CKg/00`00Kg]_N`0QKg/00`00Oomo
o`06Ool00`00Oomoo`0BOol00`00Kg]_N`1^Kg/00`00DYABU01PDY@00`00Oomoo`0;Ool0015oo`03
001oogoo01=oo`<009E_N`8002=_N`03001oogoo00Ioo`03001oogoo015oo`03001_Nfmk06i_N`03
001BU5:D061BU003001oogoo00]oo`004Goo00<007ooOol04Goo0P00V6mk0P008fmk00<007ooOol0
1Woo00<007ooOol04Goo00<006mkKg/0Kfmk00<005:DDY@0Ge:D00<007ooOol02goo000AOol00`00
Oomoo`0?Ool2002KKg/00`00Kg]_N`0QKg/00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Kg]_N`1_
Kg/00`00DYABU01ODY@00`00Oomoo`0;Ool0015oo`03001oogoo00eoo`8009e_N`03001_Nfmk025_
N`03001oogoo00Moo`03001oogoo011oo`03001_Nfmk06m_N`03001BU5:D05mBU003001oogoo00]o
o`004Goo00<007ooOol02goo0P00Wfmk00<006mkKg/08Vmk00<007ooOol01goo00<007ooOol03goo
00<006mkKg/0L6mk00<005:DDY@0GU:D00<007ooOol02goo000AOol00`00Oomoo`09Ool2002QKg/0
0`00Kg]_N`0RKg/00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Kg]_N`1`Kg/00`00DYABU01NDY@0
0`00Oomoo`0;Ool0015oo`03001oogoo00Moo`800:=_N`03001_Nfmk029_N`03001oogoo00Qoo`03
001oogoo00ioo`03001_Nfmk071_N`03001BU5:D05iBU003001oogoo00]oo`004Goo0`001Goo0P00
YFmk0P008fmk00<007ooOol027oo00<007ooOol03Woo00<006mkKg/0LFmk00<005:DDY@0GE:D00<0
07ooOol02goo000AOol00`00Oomoo`04Ool00`00Kg]_N`2UKg/2000SKg/00`00Oomoo`09Ool00`00
Oomoo`0<Ool00`00Kg]_N`1bKg/00`00DYABU01MDY@00`00Oomoo`0;Ool0015oo`03001oogoo009o
o`800:Q_N`8002A_N`03001oogoo00Uoo`03001oogoo00]oo`03001_Nfmk07=_N`03001BU5:D05aB
U003001oogoo00]oo`004Goo00D007ooOomoo`000:Y_N`8002A_N`03001oogoo00Uoo`03001oogoo
00]oo`03001_Nfmk07=_N`03001BU5:D05aBU003001oogoo00]oo`004Goo00@007oo00000:a_N`03
001_Nfmk029_N`03001oogoo00Yoo`03001oogoo00Yoo`03001_Nfmk07=_N`03001BU5:D05aBU003
001oogoo00]oo`004Goo0P00[Vmk00<006mkKg/08Vmk00<007ooOol02Woo00<007ooOol02Woo00<0
06mkKg/0M6mk00<005:DDY@0Fe:D00<007ooOol02goo000AOol00`00Kg]_N`2]Kg/00`00Kg]_N`0R
Kg/00`00Oomoo`0;Ool2000:Ool00`00Kg]_N`1dKg/00`00DYABU01KDY@00`00Oomoo`0;Ool0015o
o`03001_Nfmk0:e_N`8002A_N`03001oogoo00Yoo`03001oo`0000Uoo`03001_Nfmk07E_N`03001B
U5:D05YBU003001oogoo00]oo`004Goo00<006mkKg/0[Fmk0P0096mk00<007ooOol02goo00@007oo
000000Moo`03001_Nfmk07E_N`03001BU5:D05YBU003001oogoo00]oo`004Goo00<006mkKg/0[Fmk
0P0096mk00<007ooOol037oo00@007ooOol000Ioo`03001_Nfmk07I_N`03001BU5:D05UBU003001o
ogoo00]oo`004Goo00<006mkKg/0[Fmk0P0096mk00<007ooOol037oo00@007ooOomoo`8000=oo`03
001_Nfmk07M_N`03001BU5:D05UBU003001oogoo00]oo`004Goo00<006mkKg/0[Vmk00<006mkKg/0
8Vmk00<007ooOol03Goo00<007ooOol00Woo00@007ooOol007U_N`03001BU5:D05UBU003001oogoo
00]oo`004Goo00<006mkKg/0[Vmk0P0096mk00<007ooOol037oo00<007ooOol00goo0`00NVmk00<0
05:DDY@0F5:D00<007ooOol02goo000AOol00`00Kg]_N`2^Kg/2000TKg/00`00Oomoo`0=Ool00`00
Oomoo`04Ool00`00Kg]_N`1hKg/00`00DYABU01HDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0:i_
N`8002A_N`03001oogoo00eoo`03001oogoo00Aoo`8007U_N`03001BU5:D05QBU003001oogoo00]o
o`004Goo00<006mkKg/0[fmk00<006mkKg/08fmk00<007ooOol037oo00<007ooOol017oo00@006mk
000007Q_N`03001BU5:D05MBU003001oogoo00]oo`004Goo00<006mkKg/0[fmk0P0096mk00<007oo
Ool03Goo00<007ooOol00goo00D006mkKg]_N`0007M_N`03001BU5:D05MBU003001oogoo00]oo`00
4Goo00<006mkKg/0[fmk0P0096mk00<007ooOol03Goo00<007ooOol00goo00<006mkKg/00Vmk00<0
06mkKg/0M6mk00<005:DDY@0Ee:D00<007ooOol02goo000AOol00`00Kg]_N`2_Kg/2000UKg/00`00
Oomoo`0=Ool00`00Oomoo`02Ool00`00Kg]_N`03Kg/00`00Kg]_N`1dKg/00`00DYABU01FDY@00`00
Oomoo`0;Ool0015oo`03001_Nfmk0;1_N`03001_Nfmk02=_N`03001oogoo00eoo`03001oogoo009o
o`03001_Nfmk00A_N`8007A_N`03001BU5:D05IBU003001oogoo00]oo`004Goo00<006mkKg/0/6mk
00<006mkKg/08fmk00<007ooOol03Goo00<007ooOol00Woo00<006mkKg/01Vmk00<006mkKg/0LFmk
00<005:DDY@0EU:D00<007ooOol02goo000AOol00`00Kg]_N`2`Kg/2000UKg/00`00Oomoo`0=Ool0
1@00Oomoogoo00002Fmk0P00LVmk00<005:DDY@0EE:D00<007ooOol02goo000AOol00`00Kg]_N`2`
Kg/2000UKg/00`00Oomoo`0=Ool01@00Oomoogoo00002fmk00<006mkKg/0Kfmk00<005:DDY@0EE:D
00<007ooOol02goo000AOol00`00Kg]_N`2`Kg/2000UKg/00`00Oomoo`0>Ool01000Oomoo`0036mk
0P00Kfmk00<005:DDY@0EE:D00<007ooOol02goo000AOol00`00Kg]_N`2aKg/00`00Kg]_N`0SKg/0
0`00Oomoo`0>Ool01000Oomoo`003Vmk00<006mkKg/0KFmk00<005:DDY@0E5:D00<007ooOol02goo
000AOol00`00Kg]_N`2aKg/00`00Kg]_N`0TKg/00`00Oomoo`0=Ool01000Oomoo`003fmk0P00KFmk
00<005:DDY@0E5:D00<007ooOol02goo000AOol00`00Kg]_N`2aKg/00`00Kg]_N`0TKg/00`00Oomo
o`0>Ool00`00Ool0000AKg/00`00Kg]_N`1ZKg/00`00DYABU01DDY@00`00Oomoo`0;Ool0015oo`03
001_Nfmk0;5_N`03001_Nfmk02A_N`03001oogoo00ioo`<0019_N`8006]_N`03001BU5:D05=BU003
001oogoo00]oo`004Goo00<006mkKg/0/Fmk0P009Fmk00<007ooOol03Woo0`0056mk00<006mkKg/0
J6mk00<005:DDY@0De:D00<007ooOol02goo000AOol00`00Kg]_N`2aKg/2000UKg/00`00Oomoo`0>
Ool3000EKg/2001XKg/00`00DYABU01CDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0;9_N`03001_
Nfmk02A_N`03001oogoo00ioo`8001M_N`03001_Nfmk06I_N`03001BU5:D059BU003001oogoo00]o
o`004Goo00<006mkKg/0/Vmk00<006mkKg/096mk00<007ooOol03Woo0P0066mk0P00IVmk00<005:D
DY@0DU:D00<007ooOol02goo000AOol00`00Kg]_N`2bKg/00`00Kg]_N`0TKg/00`00Oomoo`0>Ool3
000IKg/00`00Kg]_N`1SKg/00`00DYABU01BDY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0;9_N`03
001_Nfmk02A_N`03001oogoo00ioo`03001_N`0001Y_N`8006A_N`03001BU5:D055BU003001oogoo
00]oo`004Goo00<006mkKg/0/Vmk00<006mkKg/096mk00<007ooOol03goo0`006fmk00<006mkKg/0
HFmk00<005:DDY@0DE:D00<007ooOol02goo000AOol00`00Kg]_N`2bKg/2000VKg/00`00Oomoo`0>
Ool00`00Kg/0000LKg/2001QKg/00`00DYABU01ADY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0;9_
N`8002I_N`03001oogoo00ioo`03001_N`0001i_N`03001_Nfmk05m_N`03001BU5:D051BU003001o
ogoo00]oo`004Goo00<006mkKg/0/fmk00<006mkKg/096mk00<007ooOol03Woo00@006mkKg/001i_
N`8005m_N`03001BU5:D051BU003001oogoo00]oo`004Goo00<006mkKg/0/fmk00<006mkKg/096mk
00<007ooOol03goo00<006mk000086mk00<006mkKg/0G6mk00<005:DDY@0D5:D00<007ooOol02goo
000AOol00`00Kg]_N`2cKg/00`00Kg]_N`0TKg/00`00Oomoo`0?Ool01000Kg]_N`0086mk0P00GFmk
00<005:DDY@0Ce:D00<007ooOol02goo000AOol00`00Kg]_N`2cKg/2000VKg/00`00Oomoo`0>Ool0
1000Kg]_N`008Vmk00<006mkKg/0FVmk00<005:DDY@0Ce:D00<007ooOol02goo000AOol00`00Kg]_
N`2cKg/2000VKg/00`00Oomoo`0>Ool01@00Kg]_Nfmk00008Vmk0P00FVmk00<005:DDY@0Ce:D00<0
07ooOol02goo000AOol00`00Kg]_N`2dKg/00`00Kg]_N`0TKg/00`00Oomoo`0?Ool01000Kg]_N`00
96mk00<006mkKg/0F6mk00<005:DDY@0CU:D00<007ooOol02goo000AOol00`00Kg]_N`2dKg/00`00
Kg]_N`0TKg/00`00Oomoo`0?Ool01@00Kg]_Nfmk000096mk0P00F6mk00<005:DDY@0CU:D00<007oo
Ool02goo000AOol00`00Kg]_N`2dKg/2000VKg/00`00Oomoo`0>Ool01@00Kg]_Nfmk00009Vmk00<0
06mkKg/0EVmk00<005:DDY@0CE:D00<007ooOol02goo000AOol00`00Kg]_N`2dKg/2000VKg/00`00
Oomoo`0>Ool00`00Kg]_N`02Kg/00`00Kg]_N`0TKg/00`00Kg]_N`1EKg/00`00DYABU01=DY@00`00
Oomoo`0;Ool0015oo`03001_Nfmk0;A_N`8002I_N`03001oogoo00ioo`03001_Nfmk009_N`03001_
Nfmk02E_N`8005E_N`03001BU5:D04eBU003001oogoo00]oo`004Goo00<006mkKg/0]6mk0P009Vmk
00<007ooOol03Woo00<006mkKg/00fmk00<006mkKg/09Vmk00<006mkKg/0Dfmk00<005:DDY@0C5:D
00<007ooOol02goo000AOol00`00Kg]_N`2eKg/00`00Kg]_N`0TKg/00`00Oomoo`0?Ool00`00Kg]_
N`02Kg/00`00Kg]_N`0WKg/00`00Kg]_N`1BKg/00`00DYABU01<DY@00`00Oomoo`0;Ool0015oo`03
001_Nfmk0;E_N`8002I_N`03001oogoo00ioo`03001_Nfmk009_N`03001_Nfmk02Q_N`03001_Nfmk
055_N`03001BU5:D04aBU003001oogoo00]oo`004Goo00<006mkKg/0]Fmk0P009Vmk00<007ooOol0
3Woo00<006mkKg/00fmk00<006mkKg/0:6mk0P00DVmk00<005:DDY@0Be:D00<007ooOol02goo000A
Ool00`00Kg]_N`2eKg/2000VKg/00`00Oomoo`0>Ool00`00Kg]_N`03Kg/00`00Kg]_N`0ZKg/00`00
Kg]_N`1?Kg/00`00DYABU01;DY@00`00Oomoo`0;Ool0015oo`03001_Nfmk0;E_N`8002I_N`03001o
ogoo00ioo`03001_Nfmk00=_N`8002a_N`8004m_N`03001BU5:D04]BU003001oogoo00]oo`004Goo
00<006mkKg/0]Fmk0P009fmk00<007ooOol03Goo00<006mkKg/016mk00<006mkKg/0;6mk00<006mk
Kg/0CFmk00<005:DDY@0BU:D00<007ooOol02goo000AOol00`00Kg]_N`2fKg/00`00Kg]_N`0UKg/0
0`00Oomoo`0=Ool00`00Kg]_N`04Kg/2000^Kg/2001=Kg/00`00DYABU01:DY@00`00Oomoo`0;Ool0
015oo`03001_Nfmk0;I_N`03001_Nfmk02E_N`03001oogoo00ioo`03001_Nfmk00A_N`03001_Nfmk
02i_N`03001_Nfmk04Y_N`03001BU5:D04YBU003001oogoo00]oo`004Goo00<006mkKg/0]Vmk0P00
9fmk00<007ooOol03Goo00<006mkKg/016mk00<006mkKg/0;fmk0P00Bfmk00<005:DDY@0BE:D00<0
07ooOol02goo000AOol00`00Kg]_N`2fKg/2000WKg/00`00Oomoo`0=Ool00`00Kg]_N`05Kg/00`00
Kg]_N`0`Kg/20019Kg/00`00DYABU019DY@00`00Oomoo`0;Ool00004Ool000000002Ool50006Ool0
0`00Kg]_N`2fKg/2000WKg/00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Kg]_N`05Kg/00`00Kg]_
N`0bKg/00`00Kg]_N`16Kg/00`00DYABU019DY@00`00Oomoo`0;Ool0009oo`03001oogoo009oo`04
001oogoo0006Ool00`00Kg]_N`2gKg/00`00Kg]_N`0VKg/00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Kg]_N`04Kg/00`00Kg]_N`0cKg/20017Kg/00`00DYABU018DY@00`00Oomoo`0;Ool0009oo`03
001oogoo00=oo`03001oogoo00Ioool00<H000eoo`000Woo00<007ooOol017oo00<007ooOol0ogoo
f7oo0002Ool01@00Oomoogoo00000goo00<007ooOol0ogooegoo00000goo00000003Ool01@00Oomo
ogoo0000ogoofGoo0002Ool00`00Oomoo`02Ool3003oOooJOol00?moonAoo`00ogooi7oo003oOooT
Ool00?moonAoo`00ogooi7oo0000\
\>"],
  ImageRangeCache->{{{0, 482}, {482, 0}} -> {615.557, -0.528863, 0.817968, \
0.0265066}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["T - x (residue-melt)", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["(*------------------------------*)\n(*  liq ksp cd g (bi)   *)\n\n\
u1 = {{0, 5.00, 804.8},\n{0.0500, 5.00, 803.1},\n{0.1000, 5.00, 801.7},\n\
{0.1500, 5.00, 800.5},\n{0.2000, 5.00, 799.4},\n{0.2500, 5.00, 798.4},\n\
{0.3000, 5.00, 797.5},\n{0.3500, 5.00, 796.5},\n{0.4000, 5.00, 795.6},\n\
{0.4500, 5.00, 794.6},\n{0.5000, 5.00, 793.5},\n{0.5500, 5.00, 792.3},\n\
{0.6000, 5.00, 791.0},\n{0.6500, 5.00, 789.5},\n{0.7000, 5.00, 787.8}};\n\n\
(*------------------------------*)\n(*  liq ksp cd g (opx) *)\n\nu2 = {{0, \
5.00, 917.3},\n{0.0500, 5.00, 906.7},\n{0.1000, 5.00, 898.2},\n{0.1500, 5.00, \
891.3}};\n\n(*------------------------------*)\n(*  liq cd g opx (ksp) *)\n\n\
u3 = {{0, 5.00, 954.6},\n{0.0500, 5.00, 933.9},\n{0.1000, 5.00, 915.5},\n\
{0.1500, 5.00, 899.1}};\n\n(*------------------------------*)\n(*  liq cd g \
(ksp) *)\n\nu4 = {{0, 5.00, 954.6},\n{0.0500, 5.00, 933.8},\n{0.1000, 5.00, \
915.4},\n{0.1500, 5.00, 899.0},\n{0.2000, 5.00, 884.3},\n{0.2500, 5.00, \
871.0},\n{0.3000, 5.00, 858.9},\n{0.3500, 5.00, 847.9},\n{0.4000, 5.00, \
837.9},\n{0.4500, 5.00, 828.6},\n{0.5000, 5.00, 820.1},\n{0.5500, 5.00, \
812.2},\n{0.6000, 5.00, 804.9},\n{0.6500, 5.00, 798.1},\n{0.7000, 5.00, \
791.7},\n{0.7500, 5.00, 785.7},\n{0.8000, 5.00, 780.0},\n{0.8500, 5.00, \
774.7},\n{0.9000, 5.00, 769.6},\n{0.9500, 5.00, 764.7},\n{1.0000, 5.00, \
760.0}};\n\n(*------------------------------*)\n(*  liq cd g (opx) *)\n\nu5 = \
{{0, 5.00, 926.2},\n{0.0500, 5.00, 913.6},\n{0.1000, 5.00, 902.5},\n{0.1500, \
5.00, 893.1},\n{0.2000, 5.00, 885.3},\n{0.2500, 5.00, 878.9},\n{0.3000, 5.00, \
874.0},\n{0.3500, 5.00, 870.3},\n{0.4000, 5.00, 867.8},\n{0.4500, 5.00, \
866.5},\n{0.5000, 5.00, 866.2},\n{0.5500, 5.00, 866.9},\n{0.6000, 5.00, \
868.7},\n{0.6500, 5.00, 871.5},\n{0.7000, 5.00, 875.4},\n",
    FontWeight->"Plain"],
  StyleBox["{0.7500, 5.00, 880}",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["};\n\n(*------------------------------*)\n(*  liq cd opx (g) *)\n\
\nu6 = {{0, 5.00, 1007.1},\n{0.0500, 5.00, 996.6},\n{0.1000, 5.00, 986.5},\n\
{0.1500, 5.00, 976.8},\n{0.2000, 5.00, 967.4},\n{0.2500, 5.00, 958.2},\n\
{0.3000, 5.00, 949.2},\n{0.3500, 5.00, 940.4},\n{0.4000, 5.00, 931.6},\n\
{0.4500, 5.00, 922.8},\n{0.5000, 5.00, 914.0},\n{0.5500, 5.00, 904.9},\n\
{0.6000, 5.00, 895.7},\n{0.6500, 5.00, 886.0},\n{0.7000, 5.00, 875.9}};\n\n\n\
(*------------------------------*)\n(*  liq cd g (bi)  *) \n\nu7 = {{0, 5.00, \
757.2},\n{0.0500, 5.00, 775.1},\n{0.1000, 5.00, 785.7},\n{0.1500, 5.00, \
792.1},\n{0.2000, 5.00, 796.0},\n{0.2500, 5.00, 798.1},\n{0.3000, 5.00, \
799.1},\n{0.3500, 5.00, 799.3},\n{0.4000, 5.00, 798.9},\n{0.4500, 5.00, \
798.0},\n{0.5000, 5.00, 796.8},\n{0.5500, 5.00, 795.2},\n{0.6000, 5.00, \
793.3},\n{0.6500, 5.00, 791.1},\n{0.7000, 5.00, 788.6},\n{0.7500, 5.00, \
785.7},\n{0.8000, 5.00, 782.4},\n{0.8500, 5.00, 778.4},\n{0.9000, 5.00, \
773.7},\n{0.9500, 5.00, 767.8}};\n\n(*------------------------------*)\n(*  \
liq bi cd g (ksp)  *) \n\nu8 = {{0.7500, 5.00, 785.7},\n{0.8000, 5.00, \
779.7},\n{0.8500, 5.00, 774.2},\n{0.9000, 5.00, 769.1},\n{0.9500, 5.00, \
764.4}};\n\n(*------------------------------*)\n(*  liq cd (g)  *) \n\nu9 = \
{{0.7000, 5.00, 876.0},\n{0.7500, 5.00, 862.7},\n{0.8000, 5.00, 848.2},\n\
{0.8500, 5.00, 832.2},\n{0.9000, 5.00, 813.6},\n{0.9500, 5.00, 790.9},\n\
{1.0000, 5.00, 760.1}};",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
xycols = {1,3};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i0 = {1,760};", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
i1 = crossover[u4,u5]
i2 = crossover[u4,u7]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.1927364427553792, 886.341458353099}\
\>", \
"\<\
{0.192736, 886.341}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.7499999957960713, 785.7000004904583}\
\>", \
"\<\
{0.75, 785.7}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  liq ksp bi cd g (pl)  *) 

u10 = {{0.0500, 5.00, 738.2},
{0.1000, 5.00, 737.6},
{0.1500, 5.00, 737.0},
{0.2000, 5.00, 736.5},
{0.2500, 5.00, 736.0},
{0.3000, 5.00, 735.4},
{0.3500, 5.00, 734.9},
{0.4000, 5.00, 734.4},
{0.4500, 5.00, 733.8},
{0.5000, 5.00, 733.2},
{0.5500, 5.00, 732.6},
{0.6000, 5.00, 731.9},
{0.6500, 5.00, 731.1},
{0.7000, 5.00, 730.3},
{0.7500, 5.00, 729.4},
{0.8000, 5.00, 728.4},
{0.8500, 5.00, 727.2},
{0.9000, 5.00, 725.8},
{0.9500, 5.00, 724.1}};

(*------------------------------*)
(*  ksp bi cd g (liq)  *) 

u11 = {{0, 5.00, 760.0},
{0.0250, 5.00, 745.6},
{0.0500, 5.00, 731.8},
{0.0750, 5.00, 718.8},
{0.1000, 5.00, 706.3},
{0.1250, 5.00, 694.1},
{0.1500, 5.00, 683.2},
{0.1750, 5.00, 681.1}};

(*------------------------------*)
(*  ksp pl bi cd g (liq)  *) 

u12 = {{0.0500, 5.00, 734.6},
{0.0750, 5.00, 727.6},
{0.1000, 5.00, 721.6},
{0.1250, 5.00, 716.3},
{0.1500, 5.00, 711.8}};

(*------------------------------*)
(*  ksp bi cd g (pl)  *) 

u13 = {{0, 5.00, 602.0},
{0.0250, 5.00, 684.6},
{0.0500, 5.00, 795.5},
{0.0750, 5.00, 941.3},
{0.1000, 5.00, 1097.9},
{0.1250, 5.00, 1233.2}};

(*------------------------------*)
(*  cd liq (opx)  *) 

u14 = {{0.35,5,1000},
{0.5,5,950}};

(*------------------------------*)
(*  liq (cd)  *) 

u15 = {{0.4000, 5.00, 1057.8},
{0.4500, 5.00, 1044.1},
{0.5000, 5.00, 1029.9},
{0.5500, 5.00, 1015.1},
{0.6000, 5.00, 999.6},
{0.6500, 5.00, 983.1},
{0.7000, 5.00, 965.3},
{0.7500, 5.00, 945.9},
{0.8000, 5.00, 924.1},
{0.8500, 5.00, 899.0},
{0.9000, 5.00, 868.7},
{0.9500, 5.00, 828.5},
{1.0000, 5.00, 760.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i3 = crossover[u11,u13]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.03800352741410311, 738.3345272796139}\
\>", \
"\<\
{0.0380035, 738.335}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["i4 = crossover[u5,u9]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.7017498176774991, 875.551493396051}\
\>", \
"\<\
{0.70175, 875.551}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  pl bi mu sill (H2O)  *) 

u16 = {{0.2450, 5.00, 623.5},
{0.2455, 5.00, 612.1},
{0.2460, 5.00, 598.1},
{0.2465, 5.00, 580.4},
{0.2470, 5.00, 556.2},
{0.2475, 5.00, 517.1}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi sill (g)  *) 

u17 = {{0.2000, 5.00, 724.8},
{0.2500, 5.00, 725.2},
{0.3000, 5.00, 725.7},
{0.3500, 5.00, 726.1},
{0.4000, 5.00, 726.4},
{0.4500, 5.00, 726.7},
{0.5000, 5.00, 726.9},
{0.5500, 5.00, 727.1},
{0.6000, 5.00, 727.3},
{0.6500, 5.00, 727.3},
{0.7000, 5.00, 727.3},
{0.7500, 5.00, 727.2},
{0.8000, 5.00, 727.0},
{0.8500, 5.00, 726.6},
{0.9000, 5.00, 725.7},
{0.9500, 5.00, 723.5},
{1.0000, 5.00, 712.5}};

(*------------------------------*)
(*  liq ksp pl bi g sill (cd)  *) 

u18 = {{0.1500, 5.00, 736.1},
{0.2000, 5.00, 736.6},
{0.2500, 5.00, 737.2},
{0.3000, 5.00, 737.6},
{0.3500, 5.00, 738.0},
{0.4000, 5.00, 738.3},
{0.4500, 5.00, 738.6},
{0.5000, 5.00, 738.9},
{0.5500, 5.00, 739.1},
{0.6000, 5.00, 739.3},
{0.6500, 5.00, 739.4},
{0.7000, 5.00, 739.6}};

(*------------------------------*)
(*  liq ksp bi cd g (sill)  *) 

u19 = {{0.0400, 5.00, 738.6},
{0.0500, 5.00, 738.7},
{0.0600, 5.00, 738.8},
{0.0700, 5.00, 738.9},
{0.0800, 5.00, 739.0},
{0.0900, 5.00, 739.1},
{0.1000, 5.00, 739.2},
{0.1100, 5.00, 739.2},
{0.1200, 5.00, 739.3},
{0.1300, 5.00, 739.4},
{0.1400, 5.00, 739.5},
{0.1500, 5.00, 739.5},
{0.1600, 5.00, 739.6},
{0.1700, 5.00, 739.6},
{0.1800, 5.00, 739.7},
{0.1900, 5.00, 739.7},
{0.2000, 5.00, 739.8},
{0.2500, 5.00, 740.0},
{0.3000, 5.00, 740.2},
{0.3500, 5.00, 740.4},
{0.4000, 5.00, 740.6},
{0.4500, 5.00, 740.7},
{0.5000, 5.00, 740.8},
{0.5500, 5.00, 740.9},
{0.6000, 5.00, 741.1},
{0.6500, 5.00, 741.2},
{0.7000, 5.00, 741.3},
{0.7500, 5.00, 741.3},
{0.8000, 5.00, 741.4},
{0.8500, 5.00, 741.5},
{0.9000, 5.00, 741.6},
{0.9500, 5.00, 741.7}};

(*------------------------------*)
(*  liq ksp bi cd g sill (pl)  *) 

u20 = {{0.0500, 5.00, 738.6},
{0.1000, 5.00, 738.7},
{0.1500, 5.00, 738.9},
{0.2000, 5.00, 739.0},
{0.2500, 5.00, 739.1},
{0.3000, 5.00, 739.2},
{0.3500, 5.00, 739.3},
{0.4000, 5.00, 739.3},
{0.4500, 5.00, 739.4},
{0.5000, 5.00, 739.5},
{0.5500, 5.00, 739.5},
{0.6000, 5.00, 739.6},
{0.6500, 5.00, 739.6},
{0.7000, 5.00, 739.7}};


(*------------------------------*)
(*  ksp pl bi cd g sill (liq)  *) 

u21 = {{0.0400, 5.00, 738.4},
{0.0450, 5.00, 738.2},
{0.0500, 5.00, 738.0},
{0.0550, 5.00, 737.8},
{0.0600, 5.00, 737.7},
{0.0650, 5.00, 737.5},
{0.0700, 5.00, 737.3},
{0.0750, 5.00, 737.1},
{0.0800, 5.00, 736.9},
{0.0850, 5.00, 736.7},
{0.0900, 5.00, 736.6},
{0.0950, 5.00, 736.4},
{0.1000, 5.00, 736.2},
{0.1050, 5.00, 736.1},
{0.1100, 5.00, 735.9},
{0.1150, 5.00, 735.8}};

(*------------------------------*)
(*  ksp bi cd g sill (liq)  *) 

u22 = {{0.0400, 5.00, 738.2},
{0.0500, 5.00, 736.3},
{0.0600, 5.00, 734.4},
{0.0700, 5.00, 732.6},
{0.0800, 5.00, 730.9},
{0.0900, 5.00, 729.5}};

(*------------------------------*)
(*  ksp bi cd g (sill)  *) 

u23 = {{0,5.00, 730.9},
{0.0100, 5.00, 733.1},
{0.0200, 5.00, 735.2},
{0.0300, 5.00, 737.2},
{0.0400, 5.00, 739.1},
{0.0500, 5.00, 740.9},
{0.0600, 5.00, 742.7},
{0.0700, 5.00, 744.4},
{0.0800, 5.00, 746.1},
{0.0900, 5.00, 747.7},
{0.1000, 5.00, 749.4}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i3 = crossover[u23,u11]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.03747043380604849, 738.6288309015543}\
\>", \
"\<\
{0.0374704, 738.629}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  ksp pl bi g sill (liq)  *) 

u24 = {{0.0250, 5.00, 757.9},
{0.0500, 5.00, 751.5},
{0.0750, 5.00, 745.3},
{0.1000, 5.00, 739.5},
{0.1250, 5.00, 734.1},
{0.1500, 5.00, 729.1}};

(*------------------------------*)
(*  ksp pl bi g sill (cd)  *) 

u25 = {{0.0250, 5.00, 714.3},
{0.0500, 5.00, 720.9},
{0.0750, 5.00, 726.9},
{0.1000, 5.00, 732.3},
{0.1250, 5.00, 737.2},
{0.1500, 5.00, 741.7}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i5 = crossover[u24,u25]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.1172568317231118, 735.7297651311814}\
\>", \
"\<\
{0.117257, 735.73}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  ksp bi cd g sill (pl)  *) 

u26 = {{0.0200, 5.00, 713.3},
{0.0225, 5.00, 717.2},
{0.0250, 5.00, 720.9},
{0.0275, 5.00, 724.4},
{0.0300, 5.00, 727.8},
{0.0325, 5.00, 731.2},
{0.0350, 5.00, 734.5},
{0.0375, 5.00, 737.8},
{0.0400, 5.00, 741.2},
{0.0425, 5.00, 744.5}};

(*------------------------------*)
(*  ksp bi g sill (cd)  *) 

u27 = {{0, 5.00, 707.6},
{0.0100, 5.00, 710.3},
{0.0200, 5.00, 712.9},
{0.0300, 5.00, 715.4},
{0.0400, 5.00, 717.7},
{0.0500, 5.00, 719.9},
{0.0600, 5.00, 722.1},
{0.0700, 5.00, 724.2},
{0.0800, 5.00, 726.3},
{0.0900, 5.00, 728.4},
{0.1000, 5.00, 730.6},
{0.1100, 5.00, 733.1},
{0.1200, 5.00, 735.8},
{0.1300, 5.00, 739.1},
{0.1400, 5.00, 743.2},
{0.1500, 5.00, 748.0},
{0.1600, 5.00, 753.6},
{0.1700, 5.00, 759.3}};

(*------------------------------*)
(*  ksp bi g sill (pl)  *) 

u28 = {{0.0100, 5.00, 587.9},
{0.0120, 5.00, 601.9},
{0.0200, 5.00, 801.4},
{0.0240, 5.00, 1092.1},
{0.0260, 5.00, 1116.1}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i6 = crossover[u27,u28]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.01792410576198289, 712.368492300862}\
\>", \
"\<\
{0.0179241, 712.368}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
i7 = {0.038, 738.5}; 
i8 = {0.04, 738.63};  \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
(*------------------------------*)
(*  ksp pl bi sill (liq)  *) 

u31 = {{0.1600, 5.00, 838.8},
{0.1625, 5.00, 829.4},
{0.1650, 5.00, 812.3},
{0.1675, 5.00, 791.3},
{0.1700, 5.00, 768.6},
{0.1725, 5.00, 745.4},
{0.1750, 5.00, 722.4},
{0.1775, 5.00, 699.8},
{0.1800, 5.00, 678.3},
{0.1825, 5.00, 658.1},
{0.1850, 5.00, 638.7},
{0.1875, 5.00, 620.0},
{0.1900, 5.00, 601.7},
{0.1925, 5.00, 583.8}};

(*------------------------------*)
(*  ksp pl bi sill (g)  *) 

u32 = {{0.1725, 5.00, 947.8},
{0.1730, 5.00, 884.4},
{0.1735, 5.00, 830.4},
{0.1740, 5.00, 783.9},
{0.1745, 5.00, 743.6},
{0.1750, 5.00, 708.4},
{0.1755, 5.00, 679.0},
{0.1760, 5.00, 655.8},
{0.1765, 5.00, 635.7},
{0.177,5.00,610}};

i9 = crossover[u31,u32]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.174760351033361, 724.5906023453889}\
\>", \
"\<\
{0.17476, 724.591}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi sill (mu)  *) 

u33 = {{0.2000, 5.00, 685.7},
{0.2500, 5.00, 686.3},
{0.3000, 5.00, 686.9},
{0.3500, 5.00, 687.4},
{0.4000, 5.00, 687.9},
{0.4500, 5.00, 688.4},
{0.5000, 5.00, 688.8},
{0.5500, 5.00, 689.2},
{0.6000, 5.00, 689.5},
{0.6500, 5.00, 689.8},
{0.7000, 5.00, 690.1},
{0.7500, 5.00, 690.4},
{0.8000, 5.00, 690.6},
{0.8500, 5.00, 690.8},
{0.9000, 5.00, 691.1},
{0.9500, 5.00, 691.3},
{1.0000, 5.00, 691.9}};

(*------------------------------*)
(*  liq pl bi mu sill (ksp)  *) 

u34 = {{0.2500, 5.00, 683.7},
{0.3000, 5.00, 683.9},
{0.3500, 5.00, 684.0},
{0.4000, 5.00, 684.1},
{0.4500, 5.00, 684.2},
{0.5000, 5.00, 684.3}};

(*------------------------------*)
(*  ksp pl bi mu sill (liq)  *) 

u35 = {{0.1800, 5.00, 685.4},
{0.1900, 5.00, 685.1},
{0.2000, 5.00, 684.8},
{0.2100, 5.00, 684.5},
{0.2200, 5.00, 684.2},
{0.2300, 5.00, 683.9}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i10 = {0.1785, 685.5};", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(*------------------------------*)
(*  liq pl bi mu sill (H2O)  *) 

u37 = {{0.2500, 5.00, 662.2},
{0.3000, 5.00, 662.3},
{0.3500, 5.00, 662.4},
{0.4000, 5.00, 662.6},
{0.4500, 5.00, 662.7}};

(*------------------------------*)
(*  pl bi mu sill H2O (liq)  *) 

u38 = {{0.2500, 5.00, 662.0},
{0.3000, 5.00, 660.8},
{0.3500, 5.00, 659.8},
{0.4000, 5.00, 659.0}};

(*------------------------------*)
(*  pl bi mu sill (ksp)  *) 

u39 = {{0.2200, 5.00, 993.7},
{0.2225, 5.00, 963.1},
{0.2250, 5.00, 929.8},
{0.2275, 5.00, 893.3},
{0.2300, 5.00, 853.2},
{0.2325, 5.00, 808.7},
{0.2350, 5.00, 758.5},
{0.2375, 5.00, 701.0},
{0.2400, 5.00, 633.4},
{0.2425, 5.00, 550.2},
{0.2450, 5.00, 437.7}};

(*------------------------------*)
(*  pl bi mu sill (H2O)  *) 

u40 = {{0.2150, 5.00, 731.0},
{0.2175, 5.00, 730.5},
{0.2200, 5.00, 729.6},
{0.2225, 5.00, 728.2},
{0.2250, 5.00, 726.2},
{0.2275, 5.00, 723.5},
{0.2300, 5.00, 719.6},
{0.2325, 5.00, 714.4},
{0.2350, 5.00, 707.2},
{0.2375, 5.00, 697.2},
{0.2400, 5.00, 682.8},
{0.2425, 5.00, 661.1},
{0.2450, 5.00, 623.5},
{0.2475, 5.00, 517.1}};

(*------------------------------*)
(*  pl bi mu sill (liq)  *) 

u41 = {{0.2150, 5.00, 704.3},
{0.2175, 5.00, 704.0},
{0.2200, 5.00, 703.5},
{0.2225, 5.00, 702.8},
{0.2250, 5.00, 701.8},
{0.2275, 5.00, 700.4},
{0.2300, 5.00, 698.5},
{0.2325, 5.00, 695.7},
{0.2350, 5.00, 691.7},
{0.2375, 5.00, 685.8},
{0.2400, 5.00, 676.7},
{0.2425, 5.00, 661.4},
{0.2450, 5.00, 631.7},
{0.2475, 5.00, 532.5}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
i11 = crossover[u39,u41]
i12 = crossover[u40,u41]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.2381833610059637, 683.7568299645561}\
\>", \
"\<\
{0.238183, 683.757}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.2423936403380865, 662.2861670781587}\
\>", \
"\<\
{0.242394, 662.286}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  liq pl bi mu (sill)  *) 

u42 = {{0.4500, 5.00, 579.0},
{0.4750, 5.00, 651.0},
{0.5000, 5.00, 670.4},
{0.5250, 5.00, 680.1},
{0.5500, 5.00, 686.0},
{0.5750, 5.00, 690.0},
{0.6000, 5.00, 692.8}};

(*------------------------------*)
(*  liq pl bi mu H2O (sill)  *) 

u43 = {{0.4600, 5.00, 658.9},
{0.4625, 5.00, 659.3},
{0.4650, 5.00, 659.6},
{0.4675, 5.00, 659.9},
{0.4700, 5.00, 660.3},
{0.4725, 5.00, 660.6},
{0.4750, 5.00, 660.9},
{0.4775, 5.00, 661.3},
{0.4800, 5.00, 661.7},
{0.4825, 5.00, 662.0},
{0.4850, 5.00, 662.4},
{0.4875, 5.00, 662.8}};

(*------------------------------*)
(*  liq pl bi mu (ksp)  *) 

u44 = {{0.4000, 5.00, 744.4},
{0.4125, 5.00, 742.4},
{0.4250, 5.00, 740.1},
{0.4375, 5.00, 737.6},
{0.4500, 5.00, 734.8},
{0.4625, 5.00, 731.5},
{0.4750, 5.00, 727.8},
{0.4875, 5.00, 723.3},
{0.5000, 5.00, 717.8},
{0.5125, 5.00, 710.8},
{0.5250, 5.00, 701.7},
{0.5375, 5.00, 689.8},
{0.5500, 5.00, 675.0},
{0.5625, 5.00, 658.4},
{0.5750, 5.00, 641.2},
{0.5875, 5.00, 623.6},
{0.6000, 5.00, 605.2}};

(*------------------------------*)
(*  liq ksp pl bi mu (H2O)  *) 

u45 = {{0.6000, 5.00, 647.3},
{0.6500, 5.00, 648.6},
{0.7000, 5.00, 650.0},
{0.7500, 5.00, 651.4},
{0.8000, 5.00, 652.9},
{0.8500, 5.00, 654.2},
{0.9000, 5.00, 655.5},
{0.9500, 5.00, 656.7},
{1.0000, 5.00, 657.7}};

(*------------------------------*)
(*  ksp pl bi mu H2O (liq)  *) 

u46 = {{0.5500, 5.00, 642.5},
{0.6000, 5.00, 642.4},
{0.6500, 5.00, 642.4},
{0.7000, 5.00, 642.3},
{0.7500, 5.00, 642.3},
{0.8000, 5.00, 642.3},
{0.8500, 5.00, 642.2},
{0.9000, 5.00, 642.2},
{0.9500, 5.00, 642.2},
{1.0000, 5.00, 642.1}};

(*------------------------------*)
(*  liq ksp pl bi mu (sill)  *) 

u47 = {{0.5500, 5.00, 684.6},
{0.6000, 5.00, 685.4},
{0.6500, 5.00, 686.3},
{0.7000, 5.00, 687.1},
{0.7500, 5.00, 687.9},
{0.8000, 5.00, 688.6},
{0.8500, 5.00, 689.3},
{0.9000, 5.00, 689.9},
{0.9500, 5.00, 690.5},
{1.0000, 5.00, 691.4}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i13 = crossover[u42,u44]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.5422464236314932, 684.4621776832118}\
\>", \
"\<\
{0.542246, 684.462}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  liq pl bi mu (H2O)  *) 

u48 = {{0.4000, 5.00, 672.5},
{0.4125, 5.00, 672.1},
{0.4250, 5.00, 671.2},
{0.4375, 5.00, 670.0},
{0.4500, 5.00, 668.5},
{0.4625, 5.00, 666.8},
{0.4750, 5.00, 664.9},
{0.4875, 5.00, 662.8},
{0.5000, 5.00, 660.6},
{0.5125, 5.00, 658.3},
{0.5250, 5.00, 655.9},
{0.5375, 5.00, 653.4},
{0.5500, 5.00, 650.9},
{0.5625, 5.00, 648.3},
{0.5750, 5.00, 645.7},
{0.5875, 5.00, 643.1},
{0.6000, 5.00, 640.5}};

(*------------------------------*)
(*  pl bi mu H2O (liq)  *) 

u49 = {{0.4000, 5.00, 667.4},
{0.4125, 5.00, 666.3},
{0.4250, 5.00, 664.5},
{0.4375, 5.00, 662.0},
{0.4500, 5.00, 659.2},
{0.4625, 5.00, 655.9},
{0.4750, 5.00, 652.4},
{0.4875, 5.00, 648.8},
{0.5000, 5.00, 645.0},
{0.5125, 5.00, 641.1},
{0.5250, 5.00, 637.3},
{0.5375, 5.00, 633.8},
{0.5500, 5.00, 631.0},
{0.5625, 5.00, 629.3} };\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
i14 = crossover[u42,u48]
i15 = crossover[u44,u48]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.4855652238648554, 663.1341015187889}\
\>", \
"\<\
{0.485565, 663.134}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.5711914245341, 646.4921836969799}\
\>", \
"\<\
{0.571191, 646.492}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
(*------------------------------*)
(*  liq pl bi mu H2O (ksp)  *) 

u50 = {{0.5125, 5.00, 642.7},
{0.5250, 5.00, 643.4},
{0.5375, 5.00, 644.1},
{0.5500, 5.00, 644.9},
{0.5625, 5.00, 645.9}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 u51 = {{0.448, 5, 620},
        {0.448, 5, 630},
        {0.45, 5, 640},
        {0.451, 5, 650}};
        
u52 = {{0.528, 5, 620},
        {0.519, 5, 630},
        {0.51, 5, 640}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
i16 = {0.454, 658};
i17 = {0.508, 642.5};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\

(*------------------------------*)
(*  liq ksp bi g sill (cd)  *) 

u53 = {{0.7000, 5.00, 739.2},
{0.7250, 5.00, 739.5},
{0.7500, 5.00, 739.7},
{0.7750, 5.00, 739.9},
{0.8000, 5.00, 740.2},
{0.8250, 5.00, 740.4},
{0.8500, 5.00, 740.6},
{0.8750, 5.00, 740.8},
{0.9000, 5.00, 741.0},
{0.9250, 5.00, 741.2},
{0.9500, 5.00, 741.4},
{0.9750, 5.00, 741.6}};

(*------------------------------*)
(*  liq ksp bi g sill (pl)  *) 

u54 = {{0.7000, 5.00, 741.6},
{0.7250, 5.00, 740.7},
{0.7500, 5.00, 739.7},
{0.7750, 5.00, 738.6},
{0.8000, 5.00, 737.4},
{0.8250, 5.00, 736.2},
{0.8500, 5.00, 734.8},
{0.8750, 5.00, 733.2},
{0.9000, 5.00, 731.5},
{0.9250, 5.00, 729.6},
{0.9500, 5.00, 727.3},
{0.9750, 5.00, 724.6},
{1, 5, 719}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["i18 = crossover[u53,u54]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.7499999978044275, 739.6999999838992}\
\>", \
"\<\
{0.75, 739.7}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["i19 = {1,741.8}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{1, 741.8}\
\>", "\<\
{1, 741.8}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["function", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
          lu1 = makeline[u1, ul, i2],
          lu2 = makeline[u2, ul, i1],
          lu3 = makeline[u3, ul, i1],
          lu4 = makeline[u4, i1, i2],
          lu5 = makeline[u5, i1, i4],
          lu6 = makeline[u6, ul, i4],
          lu7 = makeline[u7, i2, i0],
          lu8 = makeline[u8, i2, i0],
          lu9 = makeline[u9, i4, lr],
          lu14 = makeline[u14, ul, i4],
          lu15 = makeline[u15, ul, lr],
                    
      (*    lu10 = makeline[u10, i3, lr], *)
      (*    lu12 = makeline[u12, i3, lr], *)
      (*    lu13 = makeline[u13, ll, i3], *)\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{1,3};\n\n   lu = {\n          lu17 = makeline[u17, i9, ur],\n          lu18 \
= makeline[u18, i5, i18],\n          lu19 = makeline[u19, i8, i19],\n         \
 lu20 = makeline[u20, i8, i18],\n          lu21 = makeline[u21, i7, i5],\n    \
      \n          lu22 = makeline[u22, i3, i7], \n       \n          lu11 = \
makeline[u11, i3, ul],\n          lu23 = makeline[u23, ll, i3],\n          \n \
         lu24 = makeline[u24, i9, i5],\n          \n          lu25 = \
makeline[u25, i5, i6],\n          lu26 = makeline[u26, i6, i7],          \n   \
       lu27 = makeline[u27, ll, i6],\n          lu28 = makeline[u28, ll, i6],\
\n          lu29 = connect[i7,i8],\n          lu30 = connect[i3,i8],\n\n      \
    lu31 = makeline[u31, i9, i10],\n          lu32 = makeline[u32, i9, lr],\n \
         \n          lu33 = makeline[u33, i10, ur],\n          lu34 = \
makeline[u34, i11, i13],\n          lu35 = makeline[u35, i10, i11],\n         \
 lu36 = connect[i10,i10 - {0,200}],\n          \n          lu37 = \
makeline[u37, i12, i14],\n          lu38 = makeline[u38, i12, i16],\n         \
 lu39 = makeline[u39, i11, lr],\n          lu40 = makeline[u40, i12, lr],\n   \
       lu41 = makeline[u41, i11, i12],\n          \n          lu42 = \
makeline[u42, i14, i13], \n          lu43 = makeline[u43, i16, i14],\n        \
  lu44 = makeline[u44, i13, i15],\n          lu45 = makeline[u45, i15, lr],\n \
         lu46 = makeline[u46, i17, lr],\n          lu47 = makeline[u47, i13, \
ur],\n          lu48 = makeline[u48, i14, i15],\n          lu49 = \
makeline[u49, i16, i17],\n          lu50 = makeline[u50, i17,i15],\n          \
lu51 = makeline[u51, ll,i16],\n          lu52 = makeline[u52, ll,i17],\n\n    \
      lu53 = makeline[u53, i18,i19],\n          lu54 = makeline[u54, i18,lr]  \
    };\n\n   Show[Graphics[\n   \n          {GrayLevel[1 - grade], (* \
trivariant *)\n          \n           area[{lu19,lu20,lu53}],\n           \
area[{lu26,lu25,lu21}],\n           area[{lu17,lu24,lu18,lu54}],\n           \
area[{lu33,lu35,lu34,lu47}],\n           area[{lu37,lu38,lu43}],\n           \
area[{lu45,lu50,lu46}],\n\n           GrayLevel[1 - 2 grade], (* \
quadrivariant *)\n           \n           area[{lu11,lu30,lu19}],\n           \
area[{lu23,lu22,lu26,lu27}],\n           area[{lu28,lu25,lu24,lu32}],\n       \
    area[{lu53,lu54}],\n           area[{lu17,lu31,lu33}],\n           \
area[{lu36,lu35,lu39}],\n           area[{lu40,lu38,lu51}],\n           \
area[{lu52,lu46}],\n           area[{lu45,lu44,lu47}],\n           \
area[{lu41,lu34,lu42,lu37}],\n           area[{lu49,lu43,lu48,lu50}],\n       \
    \n           GrayLevel[1 - 3 grade], (* quinivariant *)\n           \n    \
       area[{lu11,lu23}],\n           area[{lu27,lu28}],\n           \
area[{lu32,lu31,lu36}],\n           area[{lu39,lu41,lu40}],\n           \
area[{lu42,lu44,lu48}],\n           area[{lu51,lu49,lu52}],\n\n\n           \
GrayLevel[1 - 4 grade], (* sextivariant *)\n\n           \n           \
GrayLevel[1 - 5 grade], (* septivariant *)\n\n\n           GrayLevel[0], \
AbsoluteThickness[0.3], (* black lines *)\n                      \n           \
Map[drawline,lu],\n\n           outline,\n           \n           \
Dashing[{0.02,0.01}],\n           Line[{{0,760},{1,760}}]\n           \n      \
     }],\n         AspectRatio -> 1, Frame -> True,\n         PlotRange -> \
{{xlow, xhigh}, {ylow, yhigh}} ] );",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
nop = 100; grade = 0.1;
xlow = 0; xhigh = 1; ylow = 630; yhigh = 770;
drawing;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 -4.5 0.00714286 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(640)] -0.0125 .07143 1 0 Msboxa
[(660)] -0.0125 .21429 1 0 Msboxa
[(680)] -0.0125 .35714 1 0 Msboxa
[(700)] -0.0125 .5 1 0 Msboxa
[(720)] -0.0125 .64286 1 0 Msboxa
[(740)] -0.0125 .78571 1 0 Msboxa
[(760)] -0.0125 .92857 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .07143 m
.00625 .07143 L
s
P
[(640)] -0.0125 .07143 1 0 Mshowa
p
.002 w
0 .21429 m
.00625 .21429 L
s
P
[(660)] -0.0125 .21429 1 0 Mshowa
p
.002 w
0 .35714 m
.00625 .35714 L
s
P
[(680)] -0.0125 .35714 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(700)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .64286 m
.00625 .64286 L
s
P
[(720)] -0.0125 .64286 1 0 Mshowa
p
.002 w
0 .78571 m
.00625 .78571 L
s
P
[(740)] -0.0125 .78571 1 0 Mshowa
p
.002 w
0 .92857 m
.00625 .92857 L
s
P
[(760)] -0.0125 .92857 1 0 Mshowa
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .12857 m
.00375 .12857 L
s
P
p
.001 w
0 .15714 m
.00375 .15714 L
s
P
p
.001 w
0 .18571 m
.00375 .18571 L
s
P
p
.001 w
0 .24286 m
.00375 .24286 L
s
P
p
.001 w
0 .27143 m
.00375 .27143 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .32857 m
.00375 .32857 L
s
P
p
.001 w
0 .38571 m
.00375 .38571 L
s
P
p
.001 w
0 .41429 m
.00375 .41429 L
s
P
p
.001 w
0 .44286 m
.00375 .44286 L
s
P
p
.001 w
0 .47143 m
.00375 .47143 L
s
P
p
.001 w
0 .52857 m
.00375 .52857 L
s
P
p
.001 w
0 .55714 m
.00375 .55714 L
s
P
p
.001 w
0 .58571 m
.00375 .58571 L
s
P
p
.001 w
0 .61429 m
.00375 .61429 L
s
P
p
.001 w
0 .67143 m
.00375 .67143 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .72857 m
.00375 .72857 L
s
P
p
.001 w
0 .75714 m
.00375 .75714 L
s
P
p
.001 w
0 .81429 m
.00375 .81429 L
s
P
p
.001 w
0 .84286 m
.00375 .84286 L
s
P
p
.001 w
0 .87143 m
.00375 .87143 L
s
P
p
.001 w
0 .9 m
.00375 .9 L
s
P
p
.001 w
0 .04286 m
.00375 .04286 L
s
P
p
.001 w
0 .01429 m
.00375 .01429 L
s
P
p
.001 w
0 .95714 m
.00375 .95714 L
s
P
p
.001 w
0 .98571 m
.00375 .98571 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .07143 m
1 .07143 L
s
P
p
.002 w
.99375 .21429 m
1 .21429 L
s
P
p
.002 w
.99375 .35714 m
1 .35714 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .64286 m
1 .64286 L
s
P
p
.002 w
.99375 .78571 m
1 .78571 L
s
P
p
.002 w
.99375 .92857 m
1 .92857 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .12857 m
1 .12857 L
s
P
p
.001 w
.99625 .15714 m
1 .15714 L
s
P
p
.001 w
.99625 .18571 m
1 .18571 L
s
P
p
.001 w
.99625 .24286 m
1 .24286 L
s
P
p
.001 w
.99625 .27143 m
1 .27143 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .32857 m
1 .32857 L
s
P
p
.001 w
.99625 .38571 m
1 .38571 L
s
P
p
.001 w
.99625 .41429 m
1 .41429 L
s
P
p
.001 w
.99625 .44286 m
1 .44286 L
s
P
p
.001 w
.99625 .47143 m
1 .47143 L
s
P
p
.001 w
.99625 .52857 m
1 .52857 L
s
P
p
.001 w
.99625 .55714 m
1 .55714 L
s
P
p
.001 w
.99625 .58571 m
1 .58571 L
s
P
p
.001 w
.99625 .61429 m
1 .61429 L
s
P
p
.001 w
.99625 .67143 m
1 .67143 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .72857 m
1 .72857 L
s
P
p
.001 w
.99625 .75714 m
1 .75714 L
s
P
p
.001 w
.99625 .81429 m
1 .81429 L
s
P
p
.001 w
.99625 .84286 m
1 .84286 L
s
P
p
.001 w
.99625 .87143 m
1 .87143 L
s
P
p
.001 w
.99625 .9 m
1 .9 L
s
P
p
.001 w
.99625 .04286 m
1 .04286 L
s
P
p
.001 w
.99625 .01429 m
1 .01429 L
s
P
p
.001 w
.99625 .95714 m
1 .95714 L
s
P
p
.001 w
.99625 .98571 m
1 .98571 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.9 g
1 .79857 m
.99 .79843 L
.98 .79829 L
.97 .79814 L
.96 .798 L
.95 .79786 L
.94 .79771 L
.93 .79757 L
.92 .79743 L
.91 .79729 L
.9 .79714 L
.89 .797 L
.88 .79686 L
.87 .79671 L
.86 .79657 L
.85 .79643 L
.84 .79629 L
.83 .79614 L
.82 .796 L
.81 .79586 L
.8 .79571 L
.79 .79555 L
.78 .79539 L
.77 .79524 L
.76 .79511 L
.75 .795 L
.74 .79499 L
.73 .79499 L
.72 .79501 L
.71 .79501 L
.7 .795 L
.69 .79489 L
.68 .79476 L
.67 .79461 L
.66 .79445 L
.65 .79429 L
.64 .79417 L
.63 .79404 L
.62 .7939 L
.61 .79375 L
.6 .79357 L
.59 .7933 L
.58 .79301 L
.57 .79271 L
.56 .79242 L
.55 .79214 L
.54 .79197 L
.53 .79181 L
.52 .79167 L
.51 .79155 L
.5 .79143 L
.49 .79129 L
.48 .79114 L
.47 .791 L
.46 .79086 L
.45 .79071 L
.44 .79059 L
.43 .79047 L
.42 .79033 L
.41 .79018 L
.4 .79 L
.39 .78975 L
.38 .78947 L
.37 .78918 L
.36 .78888 L
.35 .78857 L
.34 .78829 L
.33 .788 L
.32 .78771 L
.31 .78743 L
.3 .78714 L
.29 .78686 L
.28 .78657 L
.27 .78629 L
.26 .786 L
.25 .78571 L
.24 .78558 L
.23 .78542 L
.22 .78517 L
.21 .78481 L
.2 .78429 L
.19 .78357 L
.18 .78357 L
.17 .78286 L
.16 .78286 L
.15 .78214 L
.14 .78214 L
.13 .78143 L
.12 .78071 L
.11 .78 L
.1 .78 L
.09 .77929 L
.08 .77857 L
.07 .77786 L
.06 .77714 L
.05 .77643 L
.04 .77593 L
.04 .77593 L
.05 .77571 L
.06 .77565 L
.07 .77572 L
.08 .77588 L
.09 .77613 L
.1 .77643 L
.11 .7767 L
.12 .77699 L
.13 .77729 L
.14 .77758 L
.15 .77786 L
.16 .77803 L
.17 .77819 L
.18 .77833 L
.19 .77845 L
.2 .77857 L
.21 .77871 L
.22 .77886 L
.23 .779 L
.24 .77914 L
.25 .77929 L
.26 .77943 L
.27 .77957 L
.28 .77971 L
.29 .77986 L
.3 .78 L
.31 .78017 L
.32 .78033 L
.33 .78047 L
.34 .78061 L
.35 .78071 L
.36 .78073 L
.37 .78072 L
.38 .78071 L
.39 .7807 L
.4 .78071 L
.41 .78082 L
.42 .78095 L
.43 .7811 L
.44 .78126 L
.45 .78143 L
.46 .78159 L
.47 .78175 L
.48 .7819 L
.49 .78203 L
.5 .78214 L
.51 .78215 L
.52 .78215 L
.53 .78214 L
.54 .78213 L
.55 .78214 L
.56 .78227 L
.57 .78242 L
.58 .78258 L
.59 .78273 L
.6 .78286 L
.61 .78287 L
.62 .78286 L
.63 .78285 L
.64 .78285 L
.65 .78286 L
.66 .78299 L
.67 .78314 L
.68 .78329 L
.69 .78344 L
.7 .78357 L
.71 .78367 L
.72 .78374 L
.73 .78375 L
.74 .7837 L
.75 .78357 L
.75 .78357 L
.76 .7841 L
.77 .78468 L
.78 .78542 L
.79 .78629 L
.8 .78714 L
.81 .78776 L
.82 .78831 L
.83 .78886 L
.84 .78943 L
.85 .79 L
.86 .79057 L
.87 .79114 L
.88 .79171 L
.89 .79229 L
.9 .79286 L
.91 .79343 L
.92 .794 L
.93 .79457 L
.94 .79514 L
.95 .79571 L
.96 .79629 L
.97 .79686 L
.98 .79743 L
.99 .798 L
1 .79857 L
F
.038 .775 m
.037 .76518 L
.03596 .75535 L
.0349 .74553 L
.03386 .7357 L
.03282 .72588 L
.0318 .71606 L
.03079 .70623 L
.02978 .69641 L
.02876 .68659 L
.02775 .67676 L
.02675 .66694 L
.02577 .65711 L
.02481 .64729 L
.02387 .63747 L
.02294 .62764 L
.02243 .61782 L
.022 .60799 L
.02071 .59817 L
.01792 .58835 L
.01792 .58835 L
.02295 .59816 L
.02801 .60798 L
.03312 .61779 L
.03828 .62761 L
.04353 .63742 L
.04887 .64724 L
.05435 .65706 L
.05995 .66687 L
.06568 .67669 L
.07156 .6865 L
.07759 .69632 L
.08378 .70613 L
.09013 .71595 L
.09665 .72577 L
.10334 .73558 L
.11021 .7454 L
.11726 .75521 L
.038 .775 L
.04791 .77202 L
.05781 .7696 L
.06772 .76708 L
.07763 .76425 L
.08754 .76178 L
.09744 .75926 L
.10735 .75721 L
.11726 .75521 L
F
1 .58929 m
.99006 .61248 L
.98011 .63149 L
.97017 .64674 L
.96023 .65865 L
.95029 .66764 L
.94034 .67413 L
.9304 .67855 L
.92046 .68131 L
.91052 .68283 L
.90057 .68355 L
.89063 .68531 L
.88069 .68684 L
.87075 .68809 L
.8608 .68911 L
.85086 .68994 L
.84092 .69072 L
.83098 .69139 L
.82103 .69195 L
.81109 .69242 L
.80115 .69282 L
.7912 .69319 L
.78126 .69352 L
.77132 .69381 L
.76138 .69405 L
.75143 .69426 L
.74149 .69446 L
.73155 .69463 L
.72161 .69478 L
.71166 .6949 L
.70172 .69499 L
.69178 .69503 L
.68184 .69505 L
.67189 .69504 L
.66195 .69503 L
.65201 .695 L
.64206 .69504 L
.63212 .69507 L
.62218 .69509 L
.61224 .69508 L
.60229 .69502 L
.59235 .69484 L
.58241 .69459 L
.57247 .6943 L
.56252 .69399 L
.55258 .69366 L
.54264 .69336 L
.5327 .69308 L
.52275 .69279 L
.51281 .69251 L
.50287 .69222 L
.49293 .69196 L
.48298 .69169 L
.47304 .69142 L
.4631 .69113 L
.45315 .69082 L
.44321 .69045 L
.43327 .69004 L
.42333 .68961 L
.41338 .68917 L
.40344 .68873 L
.3935 .68831 L
.38356 .6879 L
.37361 .68749 L
.36367 .68706 L
.35373 .6866 L
.34379 .68611 L
.33384 .68558 L
.3239 .68503 L
.31396 .68444 L
.30401 .68383 L
.29407 .68316 L
.28413 .68245 L
.27419 .68173 L
.26424 .68101 L
.2543 .6803 L
.24436 .67966 L
.23442 .67908 L
.22447 .67852 L
.21453 .67796 L
.20459 .6774 L
.19465 .67684 L
.1847 .67625 L
.17476 .67565 L
.17476 .67565 L
.16685 .68559 L
.15918 .69554 L
.15174 .70548 L
.14451 .71543 L
.13747 .72538 L
.13059 .73532 L
.12386 .74527 L
.11726 .75521 L
.11726 .75521 L
.1273 .75608 L
.13734 .75689 L
.14739 .75766 L
.15743 .7584 L
.16747 .75911 L
.17752 .75982 L
.18756 .76053 L
.19761 .76125 L
.20765 .76209 L
.21769 .76297 L
.22774 .76385 L
.23778 .76472 L
.24782 .76554 L
.25787 .76622 L
.26791 .76683 L
.27795 .7674 L
.288 .76794 L
.29804 .76847 L
.30808 .76905 L
.31813 .76964 L
.32817 .77023 L
.33821 .77079 L
.34826 .77134 L
.3583 .77181 L
.36835 .77226 L
.37839 .77269 L
.38843 .7731 L
.39848 .77351 L
.40852 .77394 L
.41856 .77437 L
.42861 .7748 L
.43865 .77523 L
.44869 .77566 L
.45874 .77611 L
.46878 .77656 L
.47882 .777 L
.48887 .77742 L
.49891 .77782 L
.50895 .77814 L
.519 .77845 L
.52904 .77873 L
.53909 .779 L
.54913 .77926 L
.55917 .77957 L
.56922 .77987 L
.57926 .78017 L
.5893 .78044 L
.59935 .7807 L
.60939 .78086 L
.61943 .781 L
.62948 .78113 L
.63952 .78127 L
.64956 .78142 L
.65961 .78169 L
.66965 .78198 L
.6797 .78228 L
.68974 .78258 L
.69978 .78285 L
.70983 .7831 L
.71987 .78331 L
.72991 .78346 L
.73996 .78355 L
.75 .78357 L
.75 .78357 L
.76 .78051 L
.77 .77734 L
.78 .77403 L
.79 .77061 L
.8 .76714 L
.81 .76379 L
.82 .76035 L
.83 .75669 L
.84 .75274 L
.85 .74857 L
.86 .74413 L
.87 .73951 L
.88 .73479 L
.89 .72999 L
.9 .725 L
.91 .71982 L
.92 .71433 L
.93 .70837 L
.94 .70191 L
.95 .695 L
.96 .68863 L
.97 .68066 L
.98 .66994 L
.99 .65534 L
1 .63571 L
F
1 .44214 m
.98998 .44088 L
.97996 .43985 L
.96995 .43902 L
.95993 .43837 L
.94991 .43785 L
.93989 .43745 L
.92987 .43714 L
.91985 .43688 L
.90984 .43665 L
.89982 .43642 L
.8898 .436 L
.87978 .43557 L
.86976 .43513 L
.85974 .43469 L
.84973 .43428 L
.83971 .43396 L
.82969 .43366 L
.81967 .43338 L
.80965 .43311 L
.79963 .43285 L
.78962 .43258 L
.7796 .43231 L
.76958 .43203 L
.75956 .43174 L
.74954 .43141 L
.73952 .43101 L
.72951 .4306 L
.71949 .43016 L
.70947 .42971 L
.69945 .42926 L
.68943 .42883 L
.67941 .4284 L
.6694 .42797 L
.65938 .42754 L
.64936 .42712 L
.63934 .42669 L
.62932 .42626 L
.6193 .42583 L
.60929 .4254 L
.59927 .42497 L
.58925 .42456 L
.57923 .42415 L
.56921 .42373 L
.5592 .42328 L
.54918 .42281 L
.53916 .42227 L
.52914 .42171 L
.51912 .42113 L
.5091 .42054 L
.49909 .41995 L
.48907 .4194 L
.47905 .41884 L
.46903 .41828 L
.45901 .41769 L
.44899 .41708 L
.43898 .41639 L
.42896 .41569 L
.41894 .41496 L
.40892 .41423 L
.3989 .41349 L
.38888 .41278 L
.37887 .41206 L
.36885 .41135 L
.35883 .41063 L
.34881 .40992 L
.33879 .40922 L
.32877 .40853 L
.31876 .40781 L
.30874 .40708 L
.29872 .40632 L
.2887 .4055 L
.27868 .40465 L
.26866 .40378 L
.25865 .4029 L
.24863 .40202 L
.23861 .40111 L
.22859 .40021 L
.21857 .39934 L
.20855 .39852 L
.19854 .39775 L
.18852 .39705 L
.1785 .39643 L
.1785 .39643 L
.18845 .39392 L
.19839 .39176 L
.20834 .38964 L
.21829 .38751 L
.22824 .38533 L
.23818 .38398 L
.23818 .38398 L
.24832 .3836 L
.25845 .38353 L
.26859 .38369 L
.27873 .38403 L
.28886 .38447 L
.299 .38495 L
.30913 .38516 L
.31927 .38532 L
.3294 .38546 L
.33954 .38559 L
.34967 .38571 L
.35981 .38585 L
.36994 .386 L
.38008 .38614 L
.39021 .38629 L
.40035 .38643 L
.41049 .38658 L
.42062 .38672 L
.43076 .38687 L
.44089 .38701 L
.45103 .38715 L
.46116 .38728 L
.4713 .3874 L
.48143 .38754 L
.49157 .3877 L
.5017 .38789 L
.51184 .38811 L
.52198 .38836 L
.53211 .38866 L
.54225 .38902 L
.54225 .38902 L
.5522 .39027 L
.56215 .39146 L
.5721 .3926 L
.58205 .39371 L
.592 .39482 L
.60195 .39596 L
.6119 .39723 L
.62186 .39852 L
.63181 .39981 L
.64176 .40109 L
.65171 .40235 L
.66166 .40351 L
.67161 .40466 L
.68156 .40579 L
.69151 .40691 L
.70147 .40803 L
.71142 .40919 L
.72137 .41034 L
.73132 .41148 L
.74127 .41261 L
.75122 .4137 L
.76117 .41473 L
.77112 .41573 L
.78107 .41672 L
.79103 .41769 L
.80098 .41867 L
.81093 .41969 L
.82088 .4207 L
.83083 .4217 L
.84078 .42268 L
.85073 .42364 L
.86068 .42452 L
.87063 .42539 L
.88059 .42623 L
.89054 .42707 L
.90049 .4279 L
.91044 .42868 L
.92039 .42948 L
.93034 .43032 L
.94029 .43121 L
.95024 .43217 L
.9602 .43321 L
.97015 .43435 L
.9801 .43562 L
.99005 .43702 L
1 .43857 L
F
.48557 .23667 m
.47543 .23543 L
.4653 .23449 L
.45517 .23382 L
.44504 .23338 L
.4349 .2331 L
.42477 .23296 L
.41464 .23289 L
.40451 .23287 L
.39438 .23271 L
.38424 .23242 L
.37411 .23212 L
.36398 .23182 L
.35385 .23153 L
.34372 .23131 L
.33358 .23115 L
.32345 .23101 L
.31332 .23088 L
.30319 .23075 L
.29305 .23035 L
.28292 .22989 L
.27279 .22959 L
.26266 .22955 L
.25253 .22986 L
.24239 .23062 L
.24239 .23062 L
.25247 .22797 L
.26255 .22575 L
.27262 .22389 L
.2827 .22231 L
.29278 .22092 L
.30285 .21955 L
.31293 .21802 L
.32301 .21654 L
.33308 .21511 L
.34316 .21375 L
.35324 .21247 L
.36331 .21129 L
.37339 .21014 L
.38346 .20901 L
.39354 .20788 L
.40362 .20672 L
.41369 .20553 L
.42377 .20428 L
.43385 .20295 L
.44392 .20153 L
.454 .2 L
.454 .2 L
.46238 .20917 L
.47222 .21834 L
.48125 .2275 L
.48557 .23667 L
F
1 .19786 m
.99003 .19658 L
.98006 .19522 L
.97008 .1938 L
.96011 .1923 L
.95014 .19074 L
.94017 .18912 L
.93019 .18745 L
.92022 .18574 L
.91025 .18398 L
.90028 .18219 L
.8903 .18038 L
.88033 .17854 L
.87036 .17668 L
.86039 .17481 L
.85042 .17294 L
.84044 .17113 L
.83047 .16931 L
.8205 .16747 L
.81053 .1656 L
.80055 .16368 L
.79058 .1616 L
.78061 .15947 L
.77064 .15732 L
.76066 .15516 L
.75069 .15301 L
.74072 .15097 L
.73075 .14896 L
.72078 .14697 L
.7108 .14499 L
.70083 .14302 L
.69086 .14101 L
.68089 .139 L
.67091 .13699 L
.66094 .13501 L
.65097 .13305 L
.641 .13119 L
.63103 .12935 L
.62105 .12752 L
.61108 .12567 L
.60111 .12378 L
.59114 .12186 L
.58116 .11987 L
.57119 .1178 L
.57119 .1178 L
.56066 .11255 L
.55013 .1065 L
.5396 .1016 L
.52906 .09729 L
.51853 .09327 L
.508 .08929 L
.508 .08929 L
.51804 .08939 L
.52808 .08942 L
.53812 .08939 L
.54816 .08931 L
.5582 .08919 L
.56824 .08904 L
.57829 .08889 L
.58833 .08873 L
.59837 .08859 L
.60841 .08856 L
.61845 .08856 L
.62849 .08858 L
.63853 .08858 L
.64857 .08857 L
.65861 .08846 L
.66865 .08831 L
.67869 .08816 L
.68873 .08801 L
.69878 .08787 L
.70882 .08783 L
.71886 .08781 L
.7289 .08782 L
.73894 .08783 L
.74898 .08785 L
.75902 .08788 L
.76906 .0879 L
.7791 .0879 L
.78914 .08789 L
.79918 .08786 L
.80922 .08774 L
.81927 .08759 L
.82931 .08743 L
.83935 .08728 L
.84939 .08715 L
.85943 .08711 L
.86947 .0871 L
.87951 .0871 L
.88955 .08712 L
.89959 .08714 L
.90963 .08716 L
.91967 .08718 L
.92971 .08719 L
.93976 .08718 L
.9498 .08714 L
.95984 .08708 L
.96988 .08698 L
.97992 .08685 L
.98996 .08666 L
1 .08643 L
F
.8 g
0 .92857 m
.00244 .91839 L
.00488 .90822 L
.00734 .89804 L
.0098 .88786 L
.01226 .87769 L
.01474 .86751 L
.01722 .85733 L
.01971 .84716 L
.02222 .83698 L
.02473 .8268 L
.02725 .81663 L
.02979 .80645 L
.03234 .79627 L
.0349 .7861 L
.03747 .77592 L
.03747 .77592 L
.04 .77593 L
.04 .77593 L
.05 .77643 L
.06 .77714 L
.07 .77786 L
.08 .77857 L
.09 .77929 L
.1 .78 L
.11 .78 L
.12 .78071 L
.13 .78143 L
.14 .78214 L
.15 .78214 L
.16 .78286 L
.17 .78286 L
.18 .78357 L
.19 .78357 L
.2 .78429 L
.21 .78481 L
.22 .78517 L
.23 .78542 L
.24 .78558 L
.25 .78571 L
.26 .786 L
.27 .78629 L
.28 .78657 L
.29 .78686 L
.3 .78714 L
.31 .78743 L
.32 .78771 L
.33 .788 L
.34 .78829 L
.35 .78857 L
.36 .78888 L
.37 .78918 L
.38 .78947 L
.39 .78975 L
.4 .79 L
.41 .79018 L
.42 .79033 L
.43 .79047 L
.44 .79059 L
.45 .79071 L
.46 .79086 L
.47 .791 L
.48 .79114 L
.49 .79129 L
.5 .79143 L
.51 .79155 L
.52 .79167 L
.53 .79181 L
.54 .79197 L
.55 .79214 L
.56 .79242 L
.57 .79271 L
.58 .79301 L
.59 .7933 L
.6 .79357 L
.61 .79375 L
.62 .7939 L
.63 .79404 L
.64 .79417 L
.65 .79429 L
.66 .79445 L
.67 .79461 L
.68 .79476 L
.69 .79489 L
.7 .795 L
.71 .79501 L
.72 .79501 L
.73 .79499 L
.74 .79499 L
.75 .795 L
.76 .79511 L
.77 .79524 L
.78 .79539 L
.79 .79555 L
.8 .79571 L
.81 .79586 L
.82 .796 L
.83 .79614 L
.84 .79629 L
.85 .79643 L
.86 .79657 L
.87 .79671 L
.88 .79686 L
.89 .797 L
.9 .79714 L
.91 .79729 L
.92 .79743 L
.93 .79757 L
.94 .79771 L
.95 .79786 L
.96 .798 L
.97 .79814 L
.98 .79829 L
.99 .79843 L
1 .79857 L
1 1 L
0 1 L
F
0 .72071 m
.0058 .72992 L
.01176 .73912 L
.01789 .74832 L
.0242 .75752 L
.03072 .76672 L
.03747 .77592 L
.038 .775 L
.037 .76518 L
.03596 .75535 L
.0349 .74553 L
.03386 .7357 L
.03282 .72588 L
.0318 .71606 L
.03079 .70623 L
.02978 .69641 L
.02876 .68659 L
.02775 .67676 L
.02675 .66694 L
.02577 .65711 L
.02481 .64729 L
.02387 .63747 L
.02294 .62764 L
.02243 .61782 L
.022 .60799 L
.02071 .59817 L
.01792 .58835 L
.01792 .58835 L
.01333 .57983 L
.00881 .57132 L
.00437 .5628 L
0 .55429 L
F
.01491 0 m
.01502 .00997 L
.01513 .01994 L
.01523 .02992 L
.01533 .03989 L
.01543 .04986 L
.01553 .05983 L
.01562 .0698 L
.01572 .07978 L
.01581 .08975 L
.01589 .09972 L
.01598 .10969 L
.01606 .11966 L
.01614 .12964 L
.01621 .13961 L
.01629 .14958 L
.01636 .15955 L
.01643 .16952 L
.0165 .1795 L
.01656 .18947 L
.01663 .19944 L
.01669 .20941 L
.01675 .21938 L
.0168 .22936 L
.01686 .23933 L
.01691 .2493 L
.01696 .25927 L
.01701 .26924 L
.01706 .27922 L
.01711 .28919 L
.01715 .29916 L
.0172 .30913 L
.01724 .3191 L
.01728 .32908 L
.01732 .33905 L
.01736 .34902 L
.01739 .35899 L
.01743 .36896 L
.01746 .37893 L
.01749 .38891 L
.01752 .39888 L
.01755 .40885 L
.01758 .41882 L
.01761 .42879 L
.01763 .43877 L
.01766 .44874 L
.01768 .45871 L
.0177 .46868 L
.01773 .47865 L
.01775 .48863 L
.01777 .4986 L
.01779 .50857 L
.01781 .51854 L
.01783 .52851 L
.01784 .53849 L
.01786 .54846 L
.01788 .55843 L
.01789 .5684 L
.01791 .57837 L
.01792 .58835 L
.01792 .58835 L
.02295 .59816 L
.02801 .60798 L
.03312 .61779 L
.03828 .62761 L
.04353 .63742 L
.04887 .64724 L
.05435 .65706 L
.05995 .66687 L
.06568 .67669 L
.07156 .6865 L
.07759 .69632 L
.08378 .70613 L
.09013 .71595 L
.09665 .72577 L
.10334 .73558 L
.11021 .7454 L
.11726 .75521 L
.11726 .75521 L
.12386 .74527 L
.13059 .73532 L
.13747 .72538 L
.14451 .71543 L
.15174 .70548 L
.15918 .69554 L
.16685 .68559 L
.17476 .67565 L
.17476 .67565 L
.17478 .66571 L
.1748 .65578 L
.17482 .64584 L
.17484 .6359 L
.17486 .62597 L
.17488 .61603 L
.1749 .6061 L
.17492 .59616 L
.17494 .58622 L
.17496 .57629 L
.17499 .56635 L
.17501 .55642 L
.17503 .54648 L
.17505 .53654 L
.17507 .52661 L
.17509 .51667 L
.17512 .50674 L
.17514 .4968 L
.17516 .48686 L
.17518 .47693 L
.17521 .46699 L
.17523 .45706 L
.17525 .44712 L
.17528 .43718 L
.1753 .42725 L
.17533 .41731 L
.17535 .40738 L
.17538 .39744 L
.1754 .3875 L
.17543 .37757 L
.17545 .36763 L
.17548 .3577 L
.17551 .34776 L
.17553 .33782 L
.17556 .32789 L
.17559 .31795 L
.17562 .30802 L
.17565 .29808 L
.17568 .28814 L
.17571 .27821 L
.17574 .26827 L
.17577 .25834 L
.1758 .2484 L
.17583 .23846 L
.17586 .22853 L
.17589 .21859 L
.17592 .20866 L
.17595 .19872 L
.17599 .18878 L
.17602 .17885 L
.17605 .16891 L
.17609 .15898 L
.17612 .14904 L
.17616 .1391 L
.17619 .12917 L
.17623 .11923 L
.17626 .1093 L
.1763 .09936 L
.17633 .08942 L
.17637 .07949 L
.1764 .06955 L
.17644 .05962 L
.17647 .04968 L
.1765 .03974 L
.17654 .02981 L
.17657 .01987 L
.1766 .00994 L
.17663 0 L
F
1 .79857 m
.99 .798 L
.98 .79743 L
.97 .79686 L
.96 .79629 L
.95 .79571 L
.94 .79514 L
.93 .79457 L
.92 .794 L
.91 .79343 L
.9 .79286 L
.89 .79229 L
.88 .79171 L
.87 .79114 L
.86 .79057 L
.85 .79 L
.84 .78943 L
.83 .78886 L
.82 .78831 L
.81 .78776 L
.8 .78714 L
.79 .78629 L
.78 .78542 L
.77 .78468 L
.76 .7841 L
.75 .78357 L
.75 .78357 L
.76 .78051 L
.77 .77734 L
.78 .77403 L
.79 .77061 L
.8 .76714 L
.81 .76379 L
.82 .76035 L
.83 .75669 L
.84 .75274 L
.85 .74857 L
.86 .74413 L
.87 .73951 L
.88 .73479 L
.89 .72999 L
.9 .725 L
.91 .71982 L
.92 .71433 L
.93 .70837 L
.94 .70191 L
.95 .695 L
.96 .68863 L
.97 .68066 L
.98 .66994 L
.99 .65534 L
1 .63571 L
F
1 .58929 m
.99006 .61248 L
.98011 .63149 L
.97017 .64674 L
.96023 .65865 L
.95029 .66764 L
.94034 .67413 L
.9304 .67855 L
.92046 .68131 L
.91052 .68283 L
.90057 .68355 L
.89063 .68531 L
.88069 .68684 L
.87075 .68809 L
.8608 .68911 L
.85086 .68994 L
.84092 .69072 L
.83098 .69139 L
.82103 .69195 L
.81109 .69242 L
.80115 .69282 L
.7912 .69319 L
.78126 .69352 L
.77132 .69381 L
.76138 .69405 L
.75143 .69426 L
.74149 .69446 L
.73155 .69463 L
.72161 .69478 L
.71166 .6949 L
.70172 .69499 L
.69178 .69503 L
.68184 .69505 L
.67189 .69504 L
.66195 .69503 L
.65201 .695 L
.64206 .69504 L
.63212 .69507 L
.62218 .69509 L
.61224 .69508 L
.60229 .69502 L
.59235 .69484 L
.58241 .69459 L
.57247 .6943 L
.56252 .69399 L
.55258 .69366 L
.54264 .69336 L
.5327 .69308 L
.52275 .69279 L
.51281 .69251 L
.50287 .69222 L
.49293 .69196 L
.48298 .69169 L
.47304 .69142 L
.4631 .69113 L
.45315 .69082 L
.44321 .69045 L
.43327 .69004 L
.42333 .68961 L
.41338 .68917 L
.40344 .68873 L
.3935 .68831 L
.38356 .6879 L
.37361 .68749 L
.36367 .68706 L
.35373 .6866 L
.34379 .68611 L
.33384 .68558 L
.3239 .68503 L
.31396 .68444 L
.30401 .68383 L
.29407 .68316 L
.28413 .68245 L
.27419 .68173 L
.26424 .68101 L
.2543 .6803 L
.24436 .67966 L
.23442 .67908 L
.22447 .67852 L
.21453 .67796 L
.20459 .6774 L
.19465 .67684 L
.1847 .67625 L
.17476 .67565 L
.17476 .67565 L
.17491 .66568 L
.17507 .6557 L
.17522 .64573 L
.17538 .63576 L
.17554 .62579 L
.1757 .61581 L
.17587 .60584 L
.17603 .59587 L
.17619 .5859 L
.17635 .57593 L
.17651 .56595 L
.17666 .55598 L
.17682 .54601 L
.17697 .53604 L
.17712 .52607 L
.17726 .51609 L
.1774 .50612 L
.17751 .49615 L
.17755 .48618 L
.1776 .47621 L
.17766 .46623 L
.17773 .45626 L
.17781 .44629 L
.1779 .43632 L
.17802 .42634 L
.17815 .41637 L
.17831 .4064 L
.1785 .39643 L
.1785 .39643 L
.18852 .39705 L
.19854 .39775 L
.20855 .39852 L
.21857 .39934 L
.22859 .40021 L
.23861 .40111 L
.24863 .40202 L
.25865 .4029 L
.26866 .40378 L
.27868 .40465 L
.2887 .4055 L
.29872 .40632 L
.30874 .40708 L
.31876 .40781 L
.32877 .40853 L
.33879 .40922 L
.34881 .40992 L
.35883 .41063 L
.36885 .41135 L
.37887 .41206 L
.38888 .41278 L
.3989 .41349 L
.40892 .41423 L
.41894 .41496 L
.42896 .41569 L
.43898 .41639 L
.44899 .41708 L
.45901 .41769 L
.46903 .41828 L
.47905 .41884 L
.48907 .4194 L
.49909 .41995 L
.5091 .42054 L
.51912 .42113 L
.52914 .42171 L
.53916 .42227 L
.54918 .42281 L
.5592 .42328 L
.56921 .42373 L
.57923 .42415 L
.58925 .42456 L
.59927 .42497 L
.60929 .4254 L
.6193 .42583 L
.62932 .42626 L
.63934 .42669 L
.64936 .42712 L
.65938 .42754 L
.6694 .42797 L
.67941 .4284 L
.68943 .42883 L
.69945 .42926 L
.70947 .42971 L
.71949 .43016 L
.72951 .4306 L
.73952 .43101 L
.74954 .43141 L
.75956 .43174 L
.76958 .43203 L
.7796 .43231 L
.78962 .43258 L
.79963 .43285 L
.80965 .43311 L
.81967 .43338 L
.82969 .43366 L
.83971 .43396 L
.84973 .43428 L
.85974 .43469 L
.86976 .43513 L
.87978 .43557 L
.8898 .436 L
.89982 .43642 L
.90984 .43665 L
.91985 .43688 L
.92987 .43714 L
.93989 .43745 L
.94991 .43785 L
.95993 .43837 L
.96995 .43902 L
.97996 .43985 L
.98998 .44088 L
1 .44214 L
F
.1785 0 m
.1785 .39643 L
.1785 .39643 L
.18845 .39392 L
.19839 .39176 L
.20834 .38964 L
.21829 .38751 L
.22824 .38533 L
.23818 .38398 L
.23818 .38398 L
.23824 .37387 L
.23829 .36377 L
.23835 .35366 L
.2384 .34356 L
.23845 .33345 L
.23851 .32335 L
.23856 .31324 L
.23861 .30314 L
.23867 .29304 L
.23872 .28293 L
.23877 .27283 L
.23882 .26272 L
.23888 .25262 L
.23893 .24251 L
.23898 .23241 L
.23903 .2223 L
.23908 .2122 L
.23913 .20209 L
.23918 .19199 L
.23924 .18188 L
.23929 .17178 L
.23934 .16167 L
.23939 .15157 L
.23944 .14147 L
.23949 .13136 L
.23954 .12126 L
.23958 .11115 L
.23963 .10105 L
.23968 .09094 L
.23973 .08084 L
.23978 .07073 L
.23983 .06063 L
.23988 .05052 L
.23992 .04042 L
.23997 .03031 L
.24002 .02021 L
.24007 .0101 L
.24011 0 L
F
.24468 0 m
.2446 .01003 L
.24452 .02005 L
.24444 .03008 L
.24436 .04011 L
.24428 .05013 L
.24419 .06016 L
.24411 .07019 L
.24402 .08021 L
.24392 .09024 L
.24383 .10027 L
.24373 .11029 L
.24364 .12032 L
.24354 .13035 L
.24343 .14037 L
.24333 .1504 L
.24322 .16043 L
.24311 .17045 L
.243 .18048 L
.24288 .19051 L
.24276 .20054 L
.24264 .21056 L
.24252 .22059 L
.24239 .23062 L
.24239 .23062 L
.25247 .22797 L
.26255 .22575 L
.27262 .22389 L
.2827 .22231 L
.29278 .22092 L
.30285 .21955 L
.31293 .21802 L
.32301 .21654 L
.33308 .21511 L
.34316 .21375 L
.35324 .21247 L
.36331 .21129 L
.37339 .21014 L
.38346 .20901 L
.39354 .20788 L
.40362 .20672 L
.41369 .20553 L
.42377 .20428 L
.43385 .20295 L
.44392 .20153 L
.454 .2 L
.454 .2 L
.45322 .19 L
.45257 .18 L
.45202 .17 L
.45157 .16 L
.45121 .15 L
.45092 .14 L
.4507 .13 L
.45052 .12 L
.45039 .11 L
.45028 .1 L
.45018 .09 L
.45009 .08 L
.44996 .07 L
.44967 .06 L
.44937 .05 L
.44907 .04 L
.44877 .03 L
.44849 .02 L
.44823 .01 L
.448 0 L
F
.519 0 m
.5177 .00992 L
.51641 .01984 L
.51513 .02976 L
.51386 .03968 L
.51262 .0496 L
.51141 .05952 L
.51023 .06944 L
.50909 .07937 L
.508 .08929 L
.508 .08929 L
.51804 .08939 L
.52808 .08942 L
.53812 .08939 L
.54816 .08931 L
.5582 .08919 L
.56824 .08904 L
.57829 .08889 L
.58833 .08873 L
.59837 .08859 L
.60841 .08856 L
.61845 .08856 L
.62849 .08858 L
.63853 .08858 L
.64857 .08857 L
.65861 .08846 L
.66865 .08831 L
.67869 .08816 L
.68873 .08801 L
.69878 .08787 L
.70882 .08783 L
.71886 .08781 L
.7289 .08782 L
.73894 .08783 L
.74898 .08785 L
.75902 .08788 L
.76906 .0879 L
.7791 .0879 L
.78914 .08789 L
.79918 .08786 L
.80922 .08774 L
.81927 .08759 L
.82931 .08743 L
.83935 .08728 L
.84939 .08715 L
.85943 .08711 L
.86947 .0871 L
.87951 .0871 L
.88955 .08712 L
.89959 .08714 L
.90963 .08716 L
.91967 .08718 L
.92971 .08719 L
.93976 .08718 L
.9498 .08714 L
.95984 .08708 L
.96988 .08698 L
.97992 .08685 L
.98996 .08666 L
1 .08643 L
1 0 L
F
1 .19786 m
.99003 .19658 L
.98006 .19522 L
.97008 .1938 L
.96011 .1923 L
.95014 .19074 L
.94017 .18912 L
.93019 .18745 L
.92022 .18574 L
.91025 .18398 L
.90028 .18219 L
.8903 .18038 L
.88033 .17854 L
.87036 .17668 L
.86039 .17481 L
.85042 .17294 L
.84044 .17113 L
.83047 .16931 L
.8205 .16747 L
.81053 .1656 L
.80055 .16368 L
.79058 .1616 L
.78061 .15947 L
.77064 .15732 L
.76066 .15516 L
.75069 .15301 L
.74072 .15097 L
.73075 .14896 L
.72078 .14697 L
.7108 .14499 L
.70083 .14302 L
.69086 .14101 L
.68089 .139 L
.67091 .13699 L
.66094 .13501 L
.65097 .13305 L
.641 .13119 L
.63103 .12935 L
.62105 .12752 L
.61108 .12567 L
.60111 .12378 L
.59114 .12186 L
.58116 .11987 L
.57119 .1178 L
.57119 .1178 L
.57017 .12785 L
.56916 .13789 L
.56813 .14794 L
.56711 .15798 L
.56608 .16803 L
.56505 .17807 L
.56402 .18812 L
.56299 .19816 L
.56195 .20821 L
.56092 .21825 L
.55989 .2283 L
.55885 .23834 L
.55781 .24839 L
.55676 .25843 L
.5557 .26848 L
.55464 .27852 L
.55357 .28857 L
.55249 .29861 L
.5514 .30866 L
.5503 .3187 L
.54919 .32875 L
.54807 .33879 L
.54694 .34884 L
.54579 .35888 L
.54463 .36893 L
.54345 .37897 L
.54225 .38902 L
.54225 .38902 L
.5522 .39027 L
.56215 .39146 L
.5721 .3926 L
.58205 .39371 L
.592 .39482 L
.60195 .39596 L
.6119 .39723 L
.62186 .39852 L
.63181 .39981 L
.64176 .40109 L
.65171 .40235 L
.66166 .40351 L
.67161 .40466 L
.68156 .40579 L
.69151 .40691 L
.70147 .40803 L
.71142 .40919 L
.72137 .41034 L
.73132 .41148 L
.74127 .41261 L
.75122 .4137 L
.76117 .41473 L
.77112 .41573 L
.78107 .41672 L
.79103 .41769 L
.80098 .41867 L
.81093 .41969 L
.82088 .4207 L
.83083 .4217 L
.84078 .42268 L
.85073 .42364 L
.86068 .42452 L
.87063 .42539 L
.88059 .42623 L
.89054 .42707 L
.90049 .4279 L
.91044 .42868 L
.92039 .42948 L
.93034 .43032 L
.94029 .43121 L
.95024 .43217 L
.9602 .43321 L
.97015 .43435 L
.9801 .43562 L
.99005 .43702 L
1 .43857 L
F
.24239 .23062 m
.24221 .24084 L
.24202 .25106 L
.24182 .26129 L
.24161 .27151 L
.24138 .28174 L
.24114 .29196 L
.24089 .30218 L
.24062 .31241 L
.24033 .32263 L
.24002 .33286 L
.23971 .34308 L
.23938 .3533 L
.23901 .36353 L
.23861 .37375 L
.23818 .38398 L
.23818 .38398 L
.24832 .3836 L
.25845 .38353 L
.26859 .38369 L
.27873 .38403 L
.28886 .38447 L
.299 .38495 L
.30913 .38516 L
.31927 .38532 L
.3294 .38546 L
.33954 .38559 L
.34967 .38571 L
.35981 .38585 L
.36994 .386 L
.38008 .38614 L
.39021 .38629 L
.40035 .38643 L
.41049 .38658 L
.42062 .38672 L
.43076 .38687 L
.44089 .38701 L
.45103 .38715 L
.46116 .38728 L
.4713 .3874 L
.48143 .38754 L
.49157 .3877 L
.5017 .38789 L
.51184 .38811 L
.52198 .38836 L
.53211 .38866 L
.54225 .38902 L
.54225 .38902 L
.53592 .37886 L
.53031 .3687 L
.52532 .35855 L
.52068 .34839 L
.51645 .33823 L
.51258 .32808 L
.50902 .31792 L
.50572 .30777 L
.50262 .29761 L
.49964 .28745 L
.49647 .2773 L
.49347 .26714 L
.49064 .25698 L
.488 .24683 L
.48557 .23667 L
.48557 .23667 L
.47543 .23543 L
.4653 .23449 L
.45517 .23382 L
.44504 .23338 L
.4349 .2331 L
.42477 .23296 L
.41464 .23289 L
.40451 .23287 L
.39438 .23271 L
.38424 .23242 L
.37411 .23212 L
.36398 .23182 L
.35385 .23153 L
.34372 .23131 L
.33358 .23115 L
.32345 .23101 L
.31332 .23088 L
.30319 .23075 L
.29305 .23035 L
.28292 .22989 L
.27279 .22959 L
.26266 .22955 L
.25253 .22986 L
.24239 .23062 L
F
.508 .08929 m
.5035 .09935 L
.49897 .10942 L
.49439 .11948 L
.48973 .12955 L
.48495 .13961 L
.48008 .14968 L
.47513 .15974 L
.47025 .16981 L
.46519 .17987 L
.45961 .18994 L
.454 .2 L
.454 .2 L
.46238 .20917 L
.47222 .21834 L
.48125 .2275 L
.48557 .23667 L
.48557 .23667 L
.49356 .22677 L
.50133 .21686 L
.50889 .20695 L
.51627 .19705 L
.52347 .18714 L
.53047 .17724 L
.53737 .16733 L
.54433 .15742 L
.5512 .14752 L
.55788 .13761 L
.56452 .12771 L
.57119 .1178 L
.57119 .1178 L
.56066 .11255 L
.55013 .1065 L
.5396 .1016 L
.52906 .09729 L
.51853 .09327 L
.508 .08929 L
F
.7 g
.03747 .77592 m
.0349 .7861 L
.03234 .79627 L
.02979 .80645 L
.02725 .81663 L
.02473 .8268 L
.02222 .83698 L
.01971 .84716 L
.01722 .85733 L
.01474 .86751 L
.01226 .87769 L
.0098 .88786 L
.00734 .89804 L
.00488 .90822 L
.00244 .91839 L
0 .92857 L
0 .72071 L
.0058 .72992 L
.01176 .73912 L
.01789 .74832 L
.0242 .75752 L
.03072 .76672 L
.03747 .77592 L
F
0 .55429 m
.00437 .5628 L
.00881 .57132 L
.01333 .57983 L
.01792 .58835 L
.01792 .58835 L
.01791 .57837 L
.01789 .5684 L
.01788 .55843 L
.01786 .54846 L
.01784 .53849 L
.01783 .52851 L
.01781 .51854 L
.01779 .50857 L
.01777 .4986 L
.01775 .48863 L
.01773 .47865 L
.0177 .46868 L
.01768 .45871 L
.01766 .44874 L
.01763 .43877 L
.01761 .42879 L
.01758 .41882 L
.01755 .40885 L
.01752 .39888 L
.01749 .38891 L
.01746 .37893 L
.01743 .36896 L
.01739 .35899 L
.01736 .34902 L
.01732 .33905 L
.01728 .32908 L
.01724 .3191 L
.0172 .30913 L
.01715 .29916 L
.01711 .28919 L
.01706 .27922 L
.01701 .26924 L
.01696 .25927 L
.01691 .2493 L
.01686 .23933 L
.0168 .22936 L
.01675 .21938 L
.01669 .20941 L
.01663 .19944 L
.01656 .18947 L
.0165 .1795 L
.01643 .16952 L
.01636 .15955 L
.01629 .14958 L
.01621 .13961 L
.01614 .12964 L
.01606 .11966 L
.01598 .10969 L
.01589 .09972 L
.01581 .08975 L
.01572 .07978 L
.01562 .0698 L
.01553 .05983 L
.01543 .04986 L
.01533 .03989 L
.01523 .02992 L
.01513 .01994 L
.01502 .00997 L
.01491 0 L
0 0 L
F
.17663 0 m
.1766 .00994 L
.17657 .01987 L
.17654 .02981 L
.1765 .03974 L
.17647 .04968 L
.17644 .05962 L
.1764 .06955 L
.17637 .07949 L
.17633 .08942 L
.1763 .09936 L
.17626 .1093 L
.17623 .11923 L
.17619 .12917 L
.17616 .1391 L
.17612 .14904 L
.17609 .15898 L
.17605 .16891 L
.17602 .17885 L
.17599 .18878 L
.17595 .19872 L
.17592 .20866 L
.17589 .21859 L
.17586 .22853 L
.17583 .23846 L
.1758 .2484 L
.17577 .25834 L
.17574 .26827 L
.17571 .27821 L
.17568 .28814 L
.17565 .29808 L
.17562 .30802 L
.17559 .31795 L
.17556 .32789 L
.17553 .33782 L
.17551 .34776 L
.17548 .3577 L
.17545 .36763 L
.17543 .37757 L
.1754 .3875 L
.17538 .39744 L
.17535 .40738 L
.17533 .41731 L
.1753 .42725 L
.17528 .43718 L
.17525 .44712 L
.17523 .45706 L
.17521 .46699 L
.17518 .47693 L
.17516 .48686 L
.17514 .4968 L
.17512 .50674 L
.17509 .51667 L
.17507 .52661 L
.17505 .53654 L
.17503 .54648 L
.17501 .55642 L
.17499 .56635 L
.17496 .57629 L
.17494 .58622 L
.17492 .59616 L
.1749 .6061 L
.17488 .61603 L
.17486 .62597 L
.17484 .6359 L
.17482 .64584 L
.1748 .65578 L
.17478 .66571 L
.17476 .67565 L
.17476 .67565 L
.17491 .66568 L
.17507 .6557 L
.17522 .64573 L
.17538 .63576 L
.17554 .62579 L
.1757 .61581 L
.17587 .60584 L
.17603 .59587 L
.17619 .5859 L
.17635 .57593 L
.17651 .56595 L
.17666 .55598 L
.17682 .54601 L
.17697 .53604 L
.17712 .52607 L
.17726 .51609 L
.1774 .50612 L
.17751 .49615 L
.17755 .48618 L
.1776 .47621 L
.17766 .46623 L
.17773 .45626 L
.17781 .44629 L
.1779 .43632 L
.17802 .42634 L
.17815 .41637 L
.17831 .4064 L
.1785 .39643 L
.1785 .39643 L
.1785 0 L
F
.24011 0 m
.24007 .0101 L
.24002 .02021 L
.23997 .03031 L
.23992 .04042 L
.23988 .05052 L
.23983 .06063 L
.23978 .07073 L
.23973 .08084 L
.23968 .09094 L
.23963 .10105 L
.23958 .11115 L
.23954 .12126 L
.23949 .13136 L
.23944 .14147 L
.23939 .15157 L
.23934 .16167 L
.23929 .17178 L
.23924 .18188 L
.23918 .19199 L
.23913 .20209 L
.23908 .2122 L
.23903 .2223 L
.23898 .23241 L
.23893 .24251 L
.23888 .25262 L
.23882 .26272 L
.23877 .27283 L
.23872 .28293 L
.23867 .29304 L
.23861 .30314 L
.23856 .31324 L
.23851 .32335 L
.23845 .33345 L
.2384 .34356 L
.23835 .35366 L
.23829 .36377 L
.23824 .37387 L
.23818 .38398 L
.23818 .38398 L
.23861 .37375 L
.23901 .36353 L
.23938 .3533 L
.23971 .34308 L
.24002 .33286 L
.24033 .32263 L
.24062 .31241 L
.24089 .30218 L
.24114 .29196 L
.24138 .28174 L
.24161 .27151 L
.24182 .26129 L
.24202 .25106 L
.24221 .24084 L
.24239 .23062 L
.24239 .23062 L
.24252 .22059 L
.24264 .21056 L
.24276 .20054 L
.24288 .19051 L
.243 .18048 L
.24311 .17045 L
.24322 .16043 L
.24333 .1504 L
.24343 .14037 L
.24354 .13035 L
.24364 .12032 L
.24373 .11029 L
.24383 .10027 L
.24392 .09024 L
.24402 .08021 L
.24411 .07019 L
.24419 .06016 L
.24428 .05013 L
.24436 .04011 L
.24444 .03008 L
.24452 .02005 L
.2446 .01003 L
.24468 0 L
F
.48557 .23667 m
.488 .24683 L
.49064 .25698 L
.49347 .26714 L
.49647 .2773 L
.49964 .28745 L
.50262 .29761 L
.50572 .30777 L
.50902 .31792 L
.51258 .32808 L
.51645 .33823 L
.52068 .34839 L
.52532 .35855 L
.53031 .3687 L
.53592 .37886 L
.54225 .38902 L
.54225 .38902 L
.54345 .37897 L
.54463 .36893 L
.54579 .35888 L
.54694 .34884 L
.54807 .33879 L
.54919 .32875 L
.5503 .3187 L
.5514 .30866 L
.55249 .29861 L
.55357 .28857 L
.55464 .27852 L
.5557 .26848 L
.55676 .25843 L
.55781 .24839 L
.55885 .23834 L
.55989 .2283 L
.56092 .21825 L
.56195 .20821 L
.56299 .19816 L
.56402 .18812 L
.56505 .17807 L
.56608 .16803 L
.56711 .15798 L
.56813 .14794 L
.56916 .13789 L
.57017 .12785 L
.57119 .1178 L
.57119 .1178 L
.56452 .12771 L
.55788 .13761 L
.5512 .14752 L
.54433 .15742 L
.53737 .16733 L
.53047 .17724 L
.52347 .18714 L
.51627 .19705 L
.50889 .20695 L
.50133 .21686 L
.49356 .22677 L
.48557 .23667 L
F
.448 0 m
.44823 .01 L
.44849 .02 L
.44877 .03 L
.44907 .04 L
.44937 .05 L
.44967 .06 L
.44996 .07 L
.45009 .08 L
.45018 .09 L
.45028 .1 L
.45039 .11 L
.45052 .12 L
.4507 .13 L
.45092 .14 L
.45121 .15 L
.45157 .16 L
.45202 .17 L
.45257 .18 L
.45322 .19 L
.454 .2 L
.454 .2 L
.45961 .18994 L
.46519 .17987 L
.47025 .16981 L
.47513 .15974 L
.48008 .14968 L
.48495 .13961 L
.48973 .12955 L
.49439 .11948 L
.49897 .10942 L
.5035 .09935 L
.508 .08929 L
.508 .08929 L
.50909 .07937 L
.51023 .06944 L
.51141 .05952 L
.51262 .0496 L
.51386 .03968 L
.51513 .02976 L
.51641 .01984 L
.5177 .00992 L
.519 0 L
F
.6 g
.5 g
0 g
p
.3 Mabswid
.17476 .67565 m
.1847 .67625 L
.19465 .67684 L
.20459 .6774 L
.21453 .67796 L
.22447 .67852 L
.23442 .67908 L
.24436 .67966 L
.2543 .6803 L
.26424 .68101 L
.27419 .68173 L
.28413 .68245 L
.29407 .68316 L
.30401 .68383 L
.31396 .68444 L
.3239 .68503 L
.33384 .68558 L
.34379 .68611 L
.35373 .6866 L
.36367 .68706 L
.37361 .68749 L
.38356 .6879 L
.3935 .68831 L
.40344 .68873 L
.41338 .68917 L
.42333 .68961 L
.43327 .69004 L
.44321 .69045 L
.45315 .69082 L
.4631 .69113 L
.47304 .69142 L
.48298 .69169 L
.49293 .69196 L
.50287 .69222 L
.51281 .69251 L
.52275 .69279 L
.5327 .69308 L
.54264 .69336 L
.55258 .69366 L
.56252 .69399 L
.57247 .6943 L
.58241 .69459 L
.59235 .69484 L
.60229 .69502 L
.61224 .69508 L
.62218 .69509 L
.63212 .69507 L
.64206 .69504 L
.65201 .695 L
.66195 .69503 L
Mistroke
.67189 .69504 L
.68184 .69505 L
.69178 .69503 L
.70172 .69499 L
.71166 .6949 L
.72161 .69478 L
.73155 .69463 L
.74149 .69446 L
.75143 .69426 L
.76138 .69405 L
.77132 .69381 L
.78126 .69352 L
.7912 .69319 L
.80115 .69282 L
.81109 .69242 L
.82103 .69195 L
.83098 .69139 L
.84092 .69072 L
.85086 .68994 L
.8608 .68911 L
.87075 .68809 L
.88069 .68684 L
.89063 .68531 L
.90057 .68355 L
.91052 .68283 L
.92046 .68131 L
.9304 .67855 L
.94034 .67413 L
.95029 .66764 L
.96023 .65865 L
.97017 .64674 L
.98011 .63149 L
.99006 .61248 L
Mfstroke
1 .58929 m
.99006 .61248 L
s
s
.11726 .75521 m
.1273 .75608 L
.13734 .75689 L
.14739 .75766 L
.15743 .7584 L
.16747 .75911 L
.17752 .75982 L
.18756 .76053 L
.19761 .76125 L
.20765 .76209 L
.21769 .76297 L
.22774 .76385 L
.23778 .76472 L
.24782 .76554 L
.25787 .76622 L
.26791 .76683 L
.27795 .7674 L
.288 .76794 L
.29804 .76847 L
.30808 .76905 L
.31813 .76964 L
.32817 .77023 L
.33821 .77079 L
.34826 .77134 L
.3583 .77181 L
.36835 .77226 L
.37839 .77269 L
.38843 .7731 L
.39848 .77351 L
.40852 .77394 L
.41856 .77437 L
.42861 .7748 L
.43865 .77523 L
.44869 .77566 L
.45874 .77611 L
.46878 .77656 L
.47882 .777 L
.48887 .77742 L
.49891 .77782 L
.50895 .77814 L
.519 .77845 L
.52904 .77873 L
.53909 .779 L
.54913 .77926 L
.55917 .77957 L
.56922 .77987 L
.57926 .78017 L
.5893 .78044 L
.59935 .7807 L
.60939 .78086 L
Mistroke
.61943 .781 L
.62948 .78113 L
.63952 .78127 L
.64956 .78142 L
.65961 .78169 L
.66965 .78198 L
.6797 .78228 L
.68974 .78258 L
.69978 .78285 L
.70983 .7831 L
.71987 .78331 L
.72991 .78346 L
.73996 .78355 L
.75 .78357 L
Mfstroke
.04 .77593 m
.05 .77643 L
.06 .77714 L
.07 .77786 L
.08 .77857 L
.09 .77929 L
.1 .78 L
.11 .78 L
.12 .78071 L
.13 .78143 L
.14 .78214 L
.15 .78214 L
.16 .78286 L
.17 .78286 L
.18 .78357 L
.19 .78357 L
.2 .78429 L
.21 .78481 L
.22 .78517 L
.23 .78542 L
.24 .78558 L
.25 .78571 L
.26 .786 L
.27 .78629 L
.28 .78657 L
.29 .78686 L
.3 .78714 L
.31 .78743 L
.32 .78771 L
.33 .788 L
.34 .78829 L
.35 .78857 L
.36 .78888 L
.37 .78918 L
.38 .78947 L
.39 .78975 L
.4 .79 L
.41 .79018 L
.42 .79033 L
.43 .79047 L
.44 .79059 L
.45 .79071 L
.46 .79086 L
.47 .791 L
.48 .79114 L
.49 .79129 L
.5 .79143 L
.51 .79155 L
.52 .79167 L
.53 .79181 L
Mistroke
.54 .79197 L
.55 .79214 L
.56 .79242 L
.57 .79271 L
.58 .79301 L
.59 .7933 L
.6 .79357 L
.61 .79375 L
.62 .7939 L
.63 .79404 L
.64 .79417 L
.65 .79429 L
.66 .79445 L
.67 .79461 L
.68 .79476 L
.69 .79489 L
.7 .795 L
.71 .79501 L
.72 .79501 L
.73 .79499 L
.74 .79499 L
.75 .795 L
.76 .79511 L
.77 .79524 L
.78 .79539 L
.79 .79555 L
.8 .79571 L
.81 .79586 L
.82 .796 L
.83 .79614 L
.84 .79629 L
.85 .79643 L
.86 .79657 L
.87 .79671 L
.88 .79686 L
.89 .797 L
.9 .79714 L
.91 .79729 L
.92 .79743 L
.93 .79757 L
.94 .79771 L
.95 .79786 L
.96 .798 L
.97 .79814 L
.98 .79829 L
.99 .79843 L
Mfstroke
1 .79857 m
.99 .79843 L
s
s
.04 .77593 m
.05 .77571 L
.06 .77565 L
.07 .77572 L
.08 .77588 L
.09 .77613 L
.1 .77643 L
.11 .7767 L
.12 .77699 L
.13 .77729 L
.14 .77758 L
.15 .77786 L
.16 .77803 L
.17 .77819 L
.18 .77833 L
.19 .77845 L
.2 .77857 L
.21 .77871 L
.22 .77886 L
.23 .779 L
.24 .77914 L
.25 .77929 L
.26 .77943 L
.27 .77957 L
.28 .77971 L
.29 .77986 L
.3 .78 L
.31 .78017 L
.32 .78033 L
.33 .78047 L
.34 .78061 L
.35 .78071 L
.36 .78073 L
.37 .78072 L
.38 .78071 L
.39 .7807 L
.4 .78071 L
.41 .78082 L
.42 .78095 L
.43 .7811 L
.44 .78126 L
.45 .78143 L
.46 .78159 L
.47 .78175 L
.48 .7819 L
.49 .78203 L
.5 .78214 L
.51 .78215 L
.52 .78215 L
.53 .78214 L
Mistroke
.54 .78213 L
.55 .78214 L
.56 .78227 L
.57 .78242 L
.58 .78258 L
.59 .78273 L
.6 .78286 L
.61 .78287 L
.62 .78286 L
.63 .78285 L
.64 .78285 L
.65 .78286 L
.66 .78299 L
.67 .78314 L
.68 .78329 L
.69 .78344 L
.7 .78357 L
.71 .78367 L
.72 .78374 L
.73 .78375 L
.74 .7837 L
.75 .78357 L
Mfstroke
.038 .775 m
.04791 .77202 L
.05781 .7696 L
.06772 .76708 L
.07763 .76425 L
.08754 .76178 L
.09744 .75926 L
.10735 .75721 L
.11726 .75521 L
s
s
.03747 .77592 m
.0349 .7861 L
.03234 .79627 L
.02979 .80645 L
.02725 .81663 L
.02473 .8268 L
.02222 .83698 L
.01971 .84716 L
.01722 .85733 L
.01474 .86751 L
.01226 .87769 L
.0098 .88786 L
.00734 .89804 L
.00488 .90822 L
.00244 .91839 L
0 .92857 L
s
0 .72071 m
.0058 .72992 L
.01176 .73912 L
.01789 .74832 L
.0242 .75752 L
.03072 .76672 L
.03747 .77592 L
s
.17476 .67565 m
.16685 .68559 L
.15918 .69554 L
.15174 .70548 L
.14451 .71543 L
.13747 .72538 L
.13059 .73532 L
.12386 .74527 L
.11726 .75521 L
s
.01792 .58835 m
.02295 .59816 L
.02801 .60798 L
.03312 .61779 L
.03828 .62761 L
.04353 .63742 L
.04887 .64724 L
.05435 .65706 L
.05995 .66687 L
.06568 .67669 L
.07156 .6865 L
.07759 .69632 L
.08378 .70613 L
.09013 .71595 L
.09665 .72577 L
.10334 .73558 L
.11021 .7454 L
.11726 .75521 L
s
.01792 .58835 m
.02071 .59817 L
.022 .60799 L
.02243 .61782 L
.02294 .62764 L
.02387 .63747 L
.02481 .64729 L
.02577 .65711 L
.02675 .66694 L
.02775 .67676 L
.02876 .68659 L
.02978 .69641 L
.03079 .70623 L
.0318 .71606 L
.03282 .72588 L
.03386 .7357 L
.0349 .74553 L
.03596 .75535 L
.037 .76518 L
.038 .775 L
s
0 .55429 m
.00437 .5628 L
.00881 .57132 L
.01333 .57983 L
.01792 .58835 L
s
.01491 0 m
.01502 .00997 L
.01513 .01994 L
.01523 .02992 L
.01533 .03989 L
.01543 .04986 L
.01553 .05983 L
.01562 .0698 L
.01572 .07978 L
.01581 .08975 L
.01589 .09972 L
.01598 .10969 L
.01606 .11966 L
.01614 .12964 L
.01621 .13961 L
.01629 .14958 L
.01636 .15955 L
.01643 .16952 L
.0165 .1795 L
.01656 .18947 L
.01663 .19944 L
.01669 .20941 L
.01675 .21938 L
.0168 .22936 L
.01686 .23933 L
.01691 .2493 L
.01696 .25927 L
.01701 .26924 L
.01706 .27922 L
.01711 .28919 L
.01715 .29916 L
.0172 .30913 L
.01724 .3191 L
.01728 .32908 L
.01732 .33905 L
.01736 .34902 L
.01739 .35899 L
.01743 .36896 L
.01746 .37893 L
.01749 .38891 L
.01752 .39888 L
.01755 .40885 L
.01758 .41882 L
.01761 .42879 L
.01763 .43877 L
.01766 .44874 L
.01768 .45871 L
.0177 .46868 L
.01773 .47865 L
.01775 .48863 L
Mistroke
.01777 .4986 L
.01779 .50857 L
.01781 .51854 L
.01783 .52851 L
.01784 .53849 L
.01786 .54846 L
.01788 .55843 L
.01789 .5684 L
.01791 .57837 L
.01792 .58835 L
Mfstroke
.038 .775 m
.04 .77593 L
s
.03747 .77592 m
.04 .77593 L
s
.1785 .39643 m
.17831 .4064 L
.17815 .41637 L
.17802 .42634 L
.1779 .43632 L
.17781 .44629 L
.17773 .45626 L
.17766 .46623 L
.1776 .47621 L
.17755 .48618 L
.17751 .49615 L
.1774 .50612 L
.17726 .51609 L
.17712 .52607 L
.17697 .53604 L
.17682 .54601 L
.17666 .55598 L
.17651 .56595 L
.17635 .57593 L
.17619 .5859 L
.17603 .59587 L
.17587 .60584 L
.1757 .61581 L
.17554 .62579 L
.17538 .63576 L
.17522 .64573 L
.17507 .6557 L
.17491 .66568 L
.17476 .67565 L
s
.17663 0 m
.1766 .00994 L
.17657 .01987 L
.17654 .02981 L
.1765 .03974 L
.17647 .04968 L
.17644 .05962 L
.1764 .06955 L
.17637 .07949 L
.17633 .08942 L
.1763 .09936 L
.17626 .1093 L
.17623 .11923 L
.17619 .12917 L
.17616 .1391 L
.17612 .14904 L
.17609 .15898 L
.17605 .16891 L
.17602 .17885 L
.17599 .18878 L
.17595 .19872 L
.17592 .20866 L
.17589 .21859 L
.17586 .22853 L
.17583 .23846 L
.1758 .2484 L
.17577 .25834 L
.17574 .26827 L
.17571 .27821 L
.17568 .28814 L
.17565 .29808 L
.17562 .30802 L
.17559 .31795 L
.17556 .32789 L
.17553 .33782 L
.17551 .34776 L
.17548 .3577 L
.17545 .36763 L
.17543 .37757 L
.1754 .3875 L
.17538 .39744 L
.17535 .40738 L
.17533 .41731 L
.1753 .42725 L
.17528 .43718 L
.17525 .44712 L
.17523 .45706 L
.17521 .46699 L
.17518 .47693 L
.17516 .48686 L
Mistroke
.17514 .4968 L
.17512 .50674 L
.17509 .51667 L
.17507 .52661 L
.17505 .53654 L
.17503 .54648 L
.17501 .55642 L
.17499 .56635 L
.17496 .57629 L
.17494 .58622 L
.17492 .59616 L
.1749 .6061 L
.17488 .61603 L
.17486 .62597 L
.17484 .6359 L
.17482 .64584 L
.1748 .65578 L
.17478 .66571 L
.17476 .67565 L
Mfstroke
.1785 .39643 m
.18852 .39705 L
.19854 .39775 L
.20855 .39852 L
.21857 .39934 L
.22859 .40021 L
.23861 .40111 L
.24863 .40202 L
.25865 .4029 L
.26866 .40378 L
.27868 .40465 L
.2887 .4055 L
.29872 .40632 L
.30874 .40708 L
.31876 .40781 L
.32877 .40853 L
.33879 .40922 L
.34881 .40992 L
.35883 .41063 L
.36885 .41135 L
.37887 .41206 L
.38888 .41278 L
.3989 .41349 L
.40892 .41423 L
.41894 .41496 L
.42896 .41569 L
.43898 .41639 L
.44899 .41708 L
.45901 .41769 L
.46903 .41828 L
.47905 .41884 L
.48907 .4194 L
.49909 .41995 L
.5091 .42054 L
.51912 .42113 L
.52914 .42171 L
.53916 .42227 L
.54918 .42281 L
.5592 .42328 L
.56921 .42373 L
.57923 .42415 L
.58925 .42456 L
.59927 .42497 L
.60929 .4254 L
.6193 .42583 L
.62932 .42626 L
.63934 .42669 L
.64936 .42712 L
.65938 .42754 L
.6694 .42797 L
Mistroke
.67941 .4284 L
.68943 .42883 L
.69945 .42926 L
.70947 .42971 L
.71949 .43016 L
.72951 .4306 L
.73952 .43101 L
.74954 .43141 L
.75956 .43174 L
.76958 .43203 L
.7796 .43231 L
.78962 .43258 L
.79963 .43285 L
.80965 .43311 L
.81967 .43338 L
.82969 .43366 L
.83971 .43396 L
.84973 .43428 L
.85974 .43469 L
.86976 .43513 L
.87978 .43557 L
.8898 .436 L
.89982 .43642 L
.90984 .43665 L
.91985 .43688 L
.92987 .43714 L
.93989 .43745 L
.94991 .43785 L
.95993 .43837 L
.96995 .43902 L
.97996 .43985 L
.98998 .44088 L
Mfstroke
1 .44214 m
.98998 .44088 L
s
s
.23818 .38398 m
.24832 .3836 L
.25845 .38353 L
.26859 .38369 L
.27873 .38403 L
.28886 .38447 L
.299 .38495 L
.30913 .38516 L
.31927 .38532 L
.3294 .38546 L
.33954 .38559 L
.34967 .38571 L
.35981 .38585 L
.36994 .386 L
.38008 .38614 L
.39021 .38629 L
.40035 .38643 L
.41049 .38658 L
.42062 .38672 L
.43076 .38687 L
.44089 .38701 L
.45103 .38715 L
.46116 .38728 L
.4713 .3874 L
.48143 .38754 L
.49157 .3877 L
.5017 .38789 L
.51184 .38811 L
.52198 .38836 L
.53211 .38866 L
.54225 .38902 L
s
.1785 .39643 m
.18845 .39392 L
.19839 .39176 L
.20834 .38964 L
.21829 .38751 L
.22824 .38533 L
.23818 .38398 L
s
.1785 0 m
.1785 .39643 L
s
.24239 .23062 m
.25253 .22986 L
.26266 .22955 L
.27279 .22959 L
.28292 .22989 L
.29305 .23035 L
.30319 .23075 L
.31332 .23088 L
.32345 .23101 L
.33358 .23115 L
.34372 .23131 L
.35385 .23153 L
.36398 .23182 L
.37411 .23212 L
.38424 .23242 L
.39438 .23271 L
.40451 .23287 L
.41464 .23289 L
.42477 .23296 L
.4349 .2331 L
.44504 .23338 L
.45517 .23382 L
.4653 .23449 L
.47543 .23543 L
.48557 .23667 L
s
.24239 .23062 m
.25247 .22797 L
.26255 .22575 L
.27262 .22389 L
.2827 .22231 L
.29278 .22092 L
.30285 .21955 L
.31293 .21802 L
.32301 .21654 L
.33308 .21511 L
.34316 .21375 L
.35324 .21247 L
.36331 .21129 L
.37339 .21014 L
.38346 .20901 L
.39354 .20788 L
.40362 .20672 L
.41369 .20553 L
.42377 .20428 L
.43385 .20295 L
.44392 .20153 L
.454 .2 L
s
.24011 0 m
.24007 .0101 L
.24002 .02021 L
.23997 .03031 L
.23992 .04042 L
.23988 .05052 L
.23983 .06063 L
.23978 .07073 L
.23973 .08084 L
.23968 .09094 L
.23963 .10105 L
.23958 .11115 L
.23954 .12126 L
.23949 .13136 L
.23944 .14147 L
.23939 .15157 L
.23934 .16167 L
.23929 .17178 L
.23924 .18188 L
.23918 .19199 L
.23913 .20209 L
.23908 .2122 L
.23903 .2223 L
.23898 .23241 L
.23893 .24251 L
.23888 .25262 L
.23882 .26272 L
.23877 .27283 L
.23872 .28293 L
.23867 .29304 L
.23861 .30314 L
.23856 .31324 L
.23851 .32335 L
.23845 .33345 L
.2384 .34356 L
.23835 .35366 L
.23829 .36377 L
.23824 .37387 L
.23818 .38398 L
s
.24468 0 m
.2446 .01003 L
.24452 .02005 L
.24444 .03008 L
.24436 .04011 L
.24428 .05013 L
.24419 .06016 L
.24411 .07019 L
.24402 .08021 L
.24392 .09024 L
.24383 .10027 L
.24373 .11029 L
.24364 .12032 L
.24354 .13035 L
.24343 .14037 L
.24333 .1504 L
.24322 .16043 L
.24311 .17045 L
.243 .18048 L
.24288 .19051 L
.24276 .20054 L
.24264 .21056 L
.24252 .22059 L
.24239 .23062 L
s
.24239 .23062 m
.24221 .24084 L
.24202 .25106 L
.24182 .26129 L
.24161 .27151 L
.24138 .28174 L
.24114 .29196 L
.24089 .30218 L
.24062 .31241 L
.24033 .32263 L
.24002 .33286 L
.23971 .34308 L
.23938 .3533 L
.23901 .36353 L
.23861 .37375 L
.23818 .38398 L
s
.48557 .23667 m
.488 .24683 L
.49064 .25698 L
.49347 .26714 L
.49647 .2773 L
.49964 .28745 L
.50262 .29761 L
.50572 .30777 L
.50902 .31792 L
.51258 .32808 L
.51645 .33823 L
.52068 .34839 L
.52532 .35855 L
.53031 .3687 L
.53592 .37886 L
.54225 .38902 L
s
.454 .2 m
.46238 .20917 L
.47222 .21834 L
.48125 .2275 L
.48557 .23667 L
s
.57119 .1178 m
.57017 .12785 L
.56916 .13789 L
.56813 .14794 L
.56711 .15798 L
.56608 .16803 L
.56505 .17807 L
.56402 .18812 L
.56299 .19816 L
.56195 .20821 L
.56092 .21825 L
.55989 .2283 L
.55885 .23834 L
.55781 .24839 L
.55676 .25843 L
.5557 .26848 L
.55464 .27852 L
.55357 .28857 L
.55249 .29861 L
.5514 .30866 L
.5503 .3187 L
.54919 .32875 L
.54807 .33879 L
.54694 .34884 L
.54579 .35888 L
.54463 .36893 L
.54345 .37897 L
.54225 .38902 L
s
.57119 .1178 m
.58116 .11987 L
.59114 .12186 L
.60111 .12378 L
.61108 .12567 L
.62105 .12752 L
.63103 .12935 L
.641 .13119 L
.65097 .13305 L
.66094 .13501 L
.67091 .13699 L
.68089 .139 L
.69086 .14101 L
.70083 .14302 L
.7108 .14499 L
.72078 .14697 L
.73075 .14896 L
.74072 .15097 L
.75069 .15301 L
.76066 .15516 L
.77064 .15732 L
.78061 .15947 L
.79058 .1616 L
.80055 .16368 L
.81053 .1656 L
.8205 .16747 L
.83047 .16931 L
.84044 .17113 L
.85042 .17294 L
.86039 .17481 L
.87036 .17668 L
.88033 .17854 L
.8903 .18038 L
.90028 .18219 L
.91025 .18398 L
.92022 .18574 L
.93019 .18745 L
.94017 .18912 L
.95014 .19074 L
.96011 .1923 L
.97008 .1938 L
.98006 .19522 L
.99003 .19658 L
s
1 .19786 m
.99003 .19658 L
s
s
.508 .08929 m
.51804 .08939 L
.52808 .08942 L
.53812 .08939 L
.54816 .08931 L
.5582 .08919 L
.56824 .08904 L
.57829 .08889 L
.58833 .08873 L
.59837 .08859 L
.60841 .08856 L
.61845 .08856 L
.62849 .08858 L
.63853 .08858 L
.64857 .08857 L
.65861 .08846 L
.66865 .08831 L
.67869 .08816 L
.68873 .08801 L
.69878 .08787 L
.70882 .08783 L
.71886 .08781 L
.7289 .08782 L
.73894 .08783 L
.74898 .08785 L
.75902 .08788 L
.76906 .0879 L
.7791 .0879 L
.78914 .08789 L
.79918 .08786 L
.80922 .08774 L
.81927 .08759 L
.82931 .08743 L
.83935 .08728 L
.84939 .08715 L
.85943 .08711 L
.86947 .0871 L
.87951 .0871 L
.88955 .08712 L
.89959 .08714 L
.90963 .08716 L
.91967 .08718 L
.92971 .08719 L
.93976 .08718 L
.9498 .08714 L
.95984 .08708 L
.96988 .08698 L
.97992 .08685 L
.98996 .08666 L
s
1 .08643 m
.98996 .08666 L
s
s
.54225 .38902 m
.5522 .39027 L
.56215 .39146 L
.5721 .3926 L
.58205 .39371 L
.592 .39482 L
.60195 .39596 L
.6119 .39723 L
.62186 .39852 L
.63181 .39981 L
.64176 .40109 L
.65171 .40235 L
.66166 .40351 L
.67161 .40466 L
.68156 .40579 L
.69151 .40691 L
.70147 .40803 L
.71142 .40919 L
.72137 .41034 L
.73132 .41148 L
.74127 .41261 L
.75122 .4137 L
.76117 .41473 L
.77112 .41573 L
.78107 .41672 L
.79103 .41769 L
.80098 .41867 L
.81093 .41969 L
.82088 .4207 L
.83083 .4217 L
.84078 .42268 L
.85073 .42364 L
.86068 .42452 L
.87063 .42539 L
.88059 .42623 L
.89054 .42707 L
.90049 .4279 L
.91044 .42868 L
.92039 .42948 L
.93034 .43032 L
.94029 .43121 L
.95024 .43217 L
.9602 .43321 L
.97015 .43435 L
.9801 .43562 L
.99005 .43702 L
s
1 .43857 m
.99005 .43702 L
s
s
.57119 .1178 m
.56452 .12771 L
.55788 .13761 L
.5512 .14752 L
.54433 .15742 L
.53737 .16733 L
.53047 .17724 L
.52347 .18714 L
.51627 .19705 L
.50889 .20695 L
.50133 .21686 L
.49356 .22677 L
.48557 .23667 L
s
.508 .08929 m
.5035 .09935 L
.49897 .10942 L
.49439 .11948 L
.48973 .12955 L
.48495 .13961 L
.48008 .14968 L
.47513 .15974 L
.47025 .16981 L
.46519 .17987 L
.45961 .18994 L
.454 .2 L
s
.508 .08929 m
.51853 .09327 L
.52906 .09729 L
.5396 .1016 L
.55013 .1065 L
.56066 .11255 L
.57119 .1178 L
s
.448 0 m
.44823 .01 L
.44849 .02 L
.44877 .03 L
.44907 .04 L
.44937 .05 L
.44967 .06 L
.44996 .07 L
.45009 .08 L
.45018 .09 L
.45028 .1 L
.45039 .11 L
.45052 .12 L
.4507 .13 L
.45092 .14 L
.45121 .15 L
.45157 .16 L
.45202 .17 L
.45257 .18 L
.45322 .19 L
.454 .2 L
s
.519 0 m
.5177 .00992 L
.51641 .01984 L
.51513 .02976 L
.51386 .03968 L
.51262 .0496 L
.51141 .05952 L
.51023 .06944 L
.50909 .07937 L
.508 .08929 L
s
.75 .78357 m
.76 .7841 L
.77 .78468 L
.78 .78542 L
.79 .78629 L
.8 .78714 L
.81 .78776 L
.82 .78831 L
.83 .78886 L
.84 .78943 L
.85 .79 L
.86 .79057 L
.87 .79114 L
.88 .79171 L
.89 .79229 L
.9 .79286 L
.91 .79343 L
.92 .794 L
.93 .79457 L
.94 .79514 L
.95 .79571 L
.96 .79629 L
.97 .79686 L
.98 .79743 L
.99 .798 L
1 .79857 L
s
.75 .78357 m
.76 .78051 L
.77 .77734 L
.78 .77403 L
.79 .77061 L
.8 .76714 L
.81 .76379 L
.82 .76035 L
.83 .75669 L
.84 .75274 L
.85 .74857 L
.86 .74413 L
.87 .73951 L
.88 .73479 L
.89 .72999 L
.9 .725 L
.91 .71982 L
.92 .71433 L
.93 .70837 L
.94 .70191 L
.95 .695 L
.96 .68863 L
.97 .68066 L
.98 .66994 L
.99 .65534 L
1 .63571 L
s
P
p
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
[ .02 .01 ] 0 setdash
.3 Mabswid
0 .92857 m
1 .92857 L
s
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{542, 542},
  ImageMargins->{{31, Inherited}, {Inherited, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008N00027Q000`40O003h00Oogooogoo87oo003o
OoooOolPOol00?mooomoob1oo`00ogooogoo87oo003oOoooOolPOol00?mooomoob1oo`00ogooogoo
87oo003oOoooOolPOol00?mooomoob1oo`00N7oo0P0017oo00@007ooOomoo`D005Moo`8000Aoo`03
001oogoo00=oo`<005Qoo`8000Aoo`03001oogoo009oo`<005Uoo`8000Aoo`03001oogoo009oo`<0
05eoo`<000Aoo`00Mgoo00@007ooOol000Qoo`04001oogoo001FOol01000Oomoo`002Woo00<007oo
Ool0EWoo00@007ooOol000Moo`05001oogooOol0001GOol01000Oomoo`001goo00D007ooOomoo`00
05eoo`03001oogoo00=oo`00Mgoo00@007ooOol000Uoo`03001oogoo05Ioo`04001oogoo0007Ool5
001GOol01000Oomoo`001goo00D007ooOomoo`0005Moo`04001oogoo0007Ool01@00Oomoogoo0000
GGoo00<007ooOol00goo001gOol01000Oomoo`002Woo00<007ooOol0EGoo00@007ooOol000Moo`04
001oogoo001HOol01000Oomoo`001goo1000F7oo00@007ooOol000Qoo`<005ioo`03001oogoo00=o
o`00Mgoo00@007ooOol000Moo`05001oogooOol0001FOol01000Oomoo`0027oo00<007oo0000F7oo
00@007ooOol000Moo`03001oogoo05Uoo`04001oogoo0007Ool01@00Oomoogoo0000GGoo00<007oo
Ool00goo001gOol01000Oomoo`001goo00D007ooOomoo`0005Ioo`04001oogoo0009Ool2001HOol0
1000Oomoo`0027oo00<007ooOol0F7oo00@007ooOol000Moo`05001oogooOol0001LOol20005Ool0
07Qoo`8000Uoo`<005Qoo`8000]oo`03001oogoo05Moo`8000Yoo`8005Uoo`8000Uoo`<005ioo`03
001oogoo00=oo`00ogooogoo87oo003oOoooOolPOol00?mooomoob1oo`00ogooogoo87oo003oOooo
OolPOol00?mooomoob1oo`0067ooo`00o`00100017oo000HOol00`00F]IJeP05F]H00`00IcUW>@1@
IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H08E[F00<006LiIcT0m6Li00<007ooOol00Woo000H
Ool00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H08E[F00<0
06LiIcT0m6Li00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000
F]IJeP00IfLi00<005[FF]H08E[F00<006LiIcT0m6Li00<007ooOol00Woo000HOol00`00F]IJeP05
F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H08E[F00<006LiIcT0m6Li00<0
07ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<0
05[FF]H08E[F00<006LiIcT0m6Li00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@
IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H08E[F00<006LiIcT0m6Li00<007ooOol00Woo000H
Ool00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H08E[F00<0
06LiIcT0m6Li00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000
F]IJeP00IfLi00<005[FF]H085[F00<006LiIcT0mFLi00<007ooOol00Woo000HOol00`00F]IJeP05
F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H085[F00<006LiIcT0mFLi00<0
07ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<0
05[FF]H085[F00<006LiIcT0mFLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@
IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H085[F00<006LiIcT0mFLi00<007ooOol00Woo000H
Ool00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000F]IJeP00IfLi00<005[FF]H085[F00<0
06LiIcT0mFLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT01000
F]IJeP00IfLi00<005[FF]H07e[F00<006LiIcT0mVLi00<007ooOol00Woo000HOol00`00F]IJeP05
F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001XIcT00`00F]IJeP0OF]H00`00IcUW>@3fIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001JeP0006QW>@03001J
eU[F01mJeP03001W>FLi0?IW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0D6Li
0P007VLi00<005[F0000J6Li00<005[FF]H07e[F00<006LiIcT0mVLi00<007ooOol00Woo000HOol0
0`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001XIcT00`00F]IJeP0OF]H00`00IcUW
>@3fIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001JeP00
06QW>@03001JeU[F01mJeP03001W>FLi0?IW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<0
06LiIcT0D6Li0P007VLi00<005[F0000JFLi00<005[FF]H07U[F00<006LiIcT0mVLi00<007ooOol0
0Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0N
F]H00`00IcUW>@3fIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW
>@03001JeP0006UW>@03001JeU[F01iJeP03001W>FLi0?IW>@03001oogoo009oo`0067oo00<005[F
F]H01E[F00<006LiIcT0D6Li0P007VLi00<005[F0000JFLi00<005[FF]H07U[F00<006LiIcT0mVLi
00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001YIcT0
0`00F]IJeP0NF]H00`00IcUW>@3fIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi
051W>@8001iW>@03001JeP0006UW>@03001JeU[F01eJeP03001W>FLi0?MW>@03001oogoo009oo`00
67oo00<005[FF]H01E[F00<006LiIcT0D6Li0P007VLi00<005[F0000JFLi00<005[FF]H07E[F00<0
06LiIcT0mfLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00
F]H0001YIcT00`00F]IJeP0MF]H00`00IcUW>@3gIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJ
eP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03001JeU[F01eJeP03001W>FLi0?MW>@03001o
ogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0D6Li0P007VLi00<005[F0000JFLi00<005[F
F]H07E[F00<006LiIcT0mfLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1@IcT2
000NIcT00`00F]H0001YIcT00`00F]IJeP0MF]H00`00IcUW>@3gIcT00`00Oomoo`02Ool001Qoo`03
001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03001JeU[F01eJeP03001W>FLi
0?MW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0D6Li0P007VLi00<005[F0000
JFLi00<005[FF]H07E[F00<006LiIcT0mfLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00
IcUW>@1@IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0MF]H00`00IcUW>@3gIcT00`00Oomoo`02
Ool001Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03001JeU[F01eJ
eP03001W>FLi0?MW>@03001oogoo009oo`0000Aoo`00000000Aoo`<000=oo`8000Qoo`03001JeU[F
00EJeP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03001JeU[F01aJeP03001W>FLi0?QW>@03
001oogoo009oo`0000D007ooOomoo`0000Aoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00
F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0LF]H00`00IcUW>@3h
IcT00`00Oomoo`02Ool00006001oogooOol007oo1@000Woo00@007ooOol000Moo`03001JeU[F00EJ
eP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03001JeU[F01aJeP03001W>FLi0?QW>@03001o
ogoo009oo`0010000Woo00@007ooOol000=oo`04001oogoo0007Ool00`00F]IJeP05F]H00`00IcUW
>@1@IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0LF]H00`00IcUW>@3hIcT00`00Oomoo`02Ool0
0003001oogoo00Aoo`03001oo`0000=oo`04001oogoo0007Ool00`00F]IJeP05F]H00`00IcUW>@1@
IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0LF]H00`00IcUW>@3hIcT00`00Oomoo`02Ool00003
Ool007oo00Eoo`8000=oo`04001oogoo0007Ool00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT0
0`00F]H0001YIcT00`00F]IJeP0KF]H00`00IcUW>@3iIcT00`00Oomoo`02Ool0009oo`8000Eoo`03
001oogoo009oo`8000Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001JeP0006UW>@03
001JeU[F01]JeP03001W>FLi0?UW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0
D6Li0P007VLi00<005[F0000JFLi00<005[FF]H06e[F00<006LiIcT0nFLi00<007ooOol00Woo000H
Ool00`00F]IJeP05F]H00`00IcUW>@1@IcT2000NIcT00`00F]H0001YIcT00`00F]IJeP0KF]H00`00
IcUW>@3iIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi051W>@8001iW>@03001J
eP0006UW>@03001JeU[F01]JeP03001W>FLi0?UW>@03001oogoo009oo`0067oo00<005[FF]H01E[F
00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H06e[F00<006LiIcT0nFLi
00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0
001YIcT00`00F]IJeP0KF]H00`00IcUW>@1BIcVX0004Ool001Qoo`03001JeU[F00EJeP03001W>FLi
04mW>@03001JeP0001iW>@03001JeP0006UW>@03001JeU[F01]JeUD00:McW003001oogoo009oo`00
67oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H0
6e[F00<006Li00000P00mg>L00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT0
0`00F]H0000NIcT00`00F]H0001YIcT00`00F]IJeP0JF]H00`00IcUW>@03IcT3003dLi`00`00Oomo
o`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006UW>@03
001JeU[F01YJeP03001W>FLi00IW>@<00?5cW003001oogoo009oo`0067oo00<005[FF]H01E[F00<0
06LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H06U[F00<006LiIcT02FLi0P00
kg>L00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00
F]H0001YIcT00`00F]IJeP0IF]H00`00IcUW>@0<IcT3003/Li`00`00Oomoo`02Ool001Qoo`03001J
eU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006UW>@03001JeU[F01UJeP03001W
>FLi00mW>@800>YcW003001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F
00007VLi00<005[F0000JFLi00<005[FF]H065[F00<006LiIcT04VLi0P00j7>L00<007ooOol00Woo
000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001YIcT00`00F]IJ
eP0GF]H00`00IcUW>@0EIcT00`00LiacW03ULi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03
001W>FLi04mW>@03001JeP0001iW>@03001JeP0006UW>@03001JeU[F01MJeP03001W>FLi01IW>@80
0>EcW003001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<0
05[F0000JFLi00<005[FF]H05U[F00<006LiIcT06FLi0P00hg>L00<007ooOol00Woo000HOol00`00
F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001YIcT00`00F]IJeP0FF]H00`00
IcUW>@0KIcT2003QLi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001J
eP0001iW>@03001JeP0006UW>@03001JeU[F01EJeP03001W>FLi01iW>@800=mcW003001oogoo009o
o`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[F
F]H05E[F00<006LiIcT086Li0P00gG>L00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW
>@1?IcT00`00F]H0000NIcT00`00F]H0001YIcT00`00F]IJeP0EF]H00`00IcUW>@0RIcT00`00Liac
W03JLi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03
001JeP0006UW>@03001JeU[F01AJeP03001W>FLi02AW>@@00=QcW003001oogoo009oo`0067oo00<0
05[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H055[F00<0
06LiIcT096Li00@006LiIcUW>@D00==cW003001oogoo009oo`0067oo00<005[FF]H01E[F00<006Li
IcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H055[F00<006LiIcT08fLi0P0026Li
1P00cG>L00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT0
0`00F]H0001YIcT00`00F]IJeP0CF]H00`00IcUW>@0SIcT00`00F]H0000>IcT50038Li`00`00Oomo
o`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006UW>@03
001JeU[F019JeP03001W>FLi02AW>@03001JeP0001=W>@D00<=cW003001oogoo009oo`0067oo00<0
05[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H04U[F00<0
06LiIcT08fLi00@005[FF]H001QW>@D00;icW003001oogoo009oo`0067oo00<005[FF]H01E[F00<0
06LiIcT0CfLi00<005[F00007VLi00<005[F0000JFLi00<005[FF]H04E[F00<006LiIcT096Li00@0
05[FF]H001eW>@D00;UcW003001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<0
05[F00007VLi00<005[F0000JFLi00<005[FF]H04E[F00<006LiIcT08fLi00D005[FF]IJeP00029W
>@D00;AcW003001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi
00<005[F0000JFLi00<005[FF]H045[F00<006LiIcT08fLi00D005[FF]IJeP0002QW>@D00:mcW003
001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000
JVLi00<005[FF]H03e[F00<006LiIcT08VLi00<005[FF]H00U[F00<006LiIcT0:fLi1@00ZW>L00<0
07ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001Z
IcT00`00F]IJeP0?F]H00`00IcUW>@0QIcT00`00F]IJeP03F]H00`00IcUW>@0`IcT5002ULi`00`00
Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW
>@03001JeU[F00iJeP03001W>FLi029W>@03001JeU[F00=JeP03001W>FLi03EW>@H009mcW003001o
ogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi
00<005[FF]H03U[F00<006LiIcT08FLi00<005[FF]H015[F00<006LiIcT0>fLi1@00VW>L00<007oo
Ool00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT0
0`00F]IJeP0=F]H00`00IcUW>@0QIcT00`00F]IJeP05F]H00`00IcUW>@10IcT5002ELi`00`00Oomo
o`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03
001JeU[F00aJeP03001W>FLi029W>@03001JeU[F00EJeP03001W>FLi04EW>@D0091cW003001oogoo
009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<0
05[FF]H035[F00<006LiIcT08FLi00<005[FF]H01U[F00<006LiIcT0BVLi1@00Rg>L00<007ooOol0
0Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00
F]IJeP0;F]H00`00IcUW>@0RIcT00`00F]IJeP06F]H00`00IcUW>@1?IcT50026Li`00`00Oomoo`02
Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001J
eU[F00]JeP03001W>FLi025W>@03001JeU[F00MJeP03001W>FLi05AW>@D0085cW003001oogoo009o
o`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[F
F]H02U[F00<006LiIcT08FLi00<005[FF]H01e[F00<006LiIcT0FVLi1@00O7>L00<007ooOol00Woo
000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJ
eP0:F]H00`00IcUW>@0PIcT00`00F]IJeP08F]H00`00IcUW>@1OIcT6001fLi`00`00Oomoo`02Ool0
01Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001JeU[F
00YJeP03001W>FLi01mW>@03001JeU[F00UJeP03001W>FLi06EW>@D0075cW003001oogoo009oo`00
67oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[FF]H0
2E[F00<006LiIcT086Li00<005[FF]H02E[F00<006LiIcT0JVLi1@00K7>L00<007ooOol00Woo000H
Ool00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJeP09
F]H00`00IcUW>@0OIcT00`00F]IJeP0:F]H00`00IcUW>@1_IcT5001WLi`00`00Oomoo`02Ool001Qo
o`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001JeU[F00QJ
eP03001W>FLi01mW>@03001JeU[F00]JeP03001W>FLi07AW>@D0069cW003001oogoo009oo`0067oo
00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[FF]H01e[F
00<006LiIcT086Li00<005[FF]H02e[F00<006LiIcT0NFLi1@00GG>L00<007ooOol00Woo000HOol0
0`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJeP07F]H0
0`00IcUW>@0OIcT00`00F]IJeP0<F]H00`00IcUW>@1nIcT5001HLi`00`00Oomoo`02Ool001Qoo`03
001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001JeU[F00IJeP03
001W>FLi021W>@03001JeU[F00aJeP03001W>FLi08=W>@D005=cW003001oogoo009oo`0067oo00<0
05[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[FF]H01U[F00<0
06LiIcT07fLi00<005[FF]H03E[F00<006LiIcT0R6Li1P00CG>L00<007ooOol00Woo000HOol00`00
F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJeP05F]H00`00
IcUW>@0OIcT00`00F]IJeP0>F]H00`00IcUW>@2>IcT50018Li`00`00Oomoo`02Ool001Qoo`03001J
eU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001JeU[F00EJeP03001W
>FLi01iW>@03001JeU[F00iJeP03001W>FLi09AW>@D004=cW003001oogoo009oo`0067oo00<005[F
F]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[FF]H01E[F00<006Li
IcT07FLi00<005[FF]H03e[F00<006LiIcT0VFLi1@00?W>L00<007ooOol00Woo000HOol00`00F]IJ
eP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJeP04F]H00`00IcUW
>@0NIcT00`00F]IJeP0?F]H00`00IcUW>@2NIcT5000iLi`00`00Oomoo`02Ool001Qoo`03001JeU[F
00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006YW>@03001JeU[F00AJeP03001W>FLi
01eW>@03001JeU[F011JeP03001W>FLi0:=W>@D003AcW003001oogoo009oo`0067oo00<005[FF]H0
1E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JVLi00<005[FF]H015[F00<006LiIcT0
76Li00<005[FF]H04E[F00<006LiIcT0Z6Li1@00;g>L00<007ooOol00Woo000HOol00`00F]IJeP05
F]H00`00IcUW>@1?IcT00`00F]H0000NIcT00`00F]H0001ZIcT00`00F]IJeP03F]H00`00IcUW>@0M
IcT00`00F]IJeP0AF]H00`00IcUW>@2]IcT5000ZLi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJ
eP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006]W>@05001JeU[FF]H0000OIcT00`00F]IJ
eP0BF]H00`00IcUW>@2bIcT;000OLi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi
04mW>@03001JeP0001iW>@03001JeP0006]W>@05001JeU[FF]H0000OIcT00`00F]IJeP0BF]H00`00
IcUW>@2mIcT5000JLi`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001J
eP0001iW>@03001JeP0006]W>@04001JeU[F000OIcT00`00F]IJeP0CF]H00`00IcUW>@32IcT5000E
Li`00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001J
eP0006]W>@04001JeU[F000NIcT00`00F]IJeP0DF]H00`00IcUW>@37IcT5000@Li`00`00Oomoo`02
Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006]W>@03001J
eP0001iW>@03001JeU[F01AJeP03001W>FLi0<eW>@X000IcW003001oogoo009oo`0067oo00<005[F
F]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000JfLi0P007VLi00<005[FF]H05E[F
00<006LiIcT0efLi1@0000=cW000Ool00goo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00
F]H0000NIcT00`00F]H0001[IcT2000NIcT00`00F]IJeP0EF]H00`00IcUW>@3LIcT20004Ool001Qo
o`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0006UW>@<001iW>@03001J
eU[F01IJeP03001W>FLi0=eW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0CfLi
00<005[F00007VLi00<005[F0000GfLi2P000W>L00<006LiIcT06fLi00<005[FF]H05e[F00<006Li
IcT0gFLi00<007ooOol00Woo000HOol00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0000NIcT0
0`00F]H0001IIcT6000=Li`00`00IcUW>@0IIcT00`00F]IJeP0HF]H00`00IcUW>@3MIcT00`00Oomo
o`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP0004mW>@X0
01AcW003001W>FLi01MW>@03001JeU[F01UJeP03001W>FLi0=eW>@03001oogoo009oo`0067oo00<0
05[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000BVLi1@007g>L00<006LiIcT0
5VLi00<005[FF]H06E[F00<006LiIcT0gFLi00<007ooOol00Woo000017oo000000000goo0`0017oo
0P0027oo00<005[FF]H01E[F00<006LiIcT0CfLi00<005[F00007VLi00<005[F0000@6Li2P009G>L
0P005FLi00<005[FF]H06U[F00<006LiIcT0gFLi00<007ooOol00Woo00001`00Oomoogoo001oo`00
00=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00F]IJeP05F]H00`00IcUW>@1?IcT00`00F]H0
000NIcT00`00F]H0000eIcT;000aLi`00`00IcUW>@0AIcT00`00F]IJeP0KF]H00`00IcUW>@3MIcT0
0`00Oomoo`02Ool00007001oogooOol007oo00000goo00@007ooOol0009oo`03001oogoo00Eoo`03
001JeU[F00EJeP03001W>FLi04mW>@03001JeP0001iW>@03001JeP00031W>@D003ecW003001W>FLi
011W>@03001JeU[F01YJeP03001W>FLi0=iW>@03001oogoo009oo`0010000Woo10000goo00@007oo
Ool000Moo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@8002MW>@X004=cW003001W
>FLi00iW>@03001JeU[F01]JeP03001W>FLi0=iW>@03001oogoo009oo`0000<007ooOol00goo00<0
07ooOol017oo00@007ooOol000Moo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@80
025W>@H004icW003001W>FLi00aW>@03001JeU[F01aJeP03001W>FLi0=iW>@03001oogoo009oo`00
00=oo`00Ool017oo00<007ooOol00goo00@007ooOol000Moo`03001JeU[F00IJeP03001W>FLi04iW
>@03001JeP0001iW>@8001aW>@D005EcW003001W>FLi00]W>@03001JeU[F01aJeP03001W>FLi0=iW
>@03001oogoo009oo`000Woo0P0017oo0P0017oo0P0027oo00<005[FF]H01U[F00<006LiIcT0CVLi
00<005[F00007VLi0P004VLi2P00Fg>L00<006LiIcT02FLi00<005[FF]H07E[F00<006LiIcT0gVLi
00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT2000=IcT5
001VLi`00`00IcUW>@07IcT00`00F]IJeP0MF]H00`00IcUW>@3OIcT00`00Oomoo`02Ool001Qoo`03
001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@8000QW>@D006acW003001W>FLi00EW>@03
001JeU[F01iJeP03001W>FLi0=mW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi00<005[F00007VLi0P0016Li1000LW>L00<006LiIcT00fLi00<005[FF]H07e[F00<006LiIcT0
gfLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT20000
0fLi0000000E001RLi`00`00IcUW>@03IcT00`00F]IJeP0OF]H00`00IcUW>@3OIcT00`00Oomoo`02
Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@@001IW>Bl003AcW005001W
>FLiIcT0000RF]H00`00IcUW>@3OIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi
04iW>@03001JeP0001iW>@8004MW>BX000YcW004001W>FLi000SF]H00`00IcUW>@3OIcT00`00Oomo
o`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@80075W>@/00003IcT0
05[F02=JeP03001W>FLi0=mW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi
00<005[F00007VLi0P00NfLi0P009E[F00<006LiIcT0gfLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT2001lIcT00`00F]IJeP0SF]H00`00IcUW>@3OIcT0
0`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@8007eW>@03
001JeU[F029JeP03001W>FLi0=mW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi00<005[F00007VLi0P00OFLi00<005[FF]H08U[F00<006LiIcT0gfLi00<007ooOol00Woo000H
Ool00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT2001mIcT00`00F]IJeP0QF]H00`00
IcUW>@3PIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW
>@8007iW>@03001JeU[F021JeP03001W>FLi0>1W>@03001oogoo009oo`0067oo00<005[FF]H01U[F
00<006LiIcT0CVLi00<005[F00007VLi0P00OVLi00<005[FF]H085[F00<006LiIcT0h6Li00<007oo
Ool00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT2001nIcT00`00F]IJ
eP0PF]H00`00IcUW>@3PIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03
001JeP0001iW>@8007mW>@03001JeU[F01mJeP03001W>FLi0>1W>@03001oogoo009oo`0067oo00<0
05[FF]H01U[F00<006LiIcT0CVLi00<005[F00007VLi0P00OfLi00<005[FF]H07e[F00<006LiIcT0
h6Li00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT2001o
IcT00`00F]IJeP0OF]H00`00IcUW>@3PIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@03001JeP0001iW>@8007mW>@03001JeU[F01mJeP03001W>FLi0>1W>@03001oogoo009o
o`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007VLi0P00OfLi00<005[FF]H07e[F
00<006LiIcT0h6Li00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0
000NIcT20020IcT00`00F]IJeP0NF]H00`00IcUW>@3PIcT00`00Oomoo`02Ool001Qoo`03001JeU[F
00IJeP03001W>FLi04iW>@03001JeP0001iW>@80081W>@03001JeU[F01eJeP03001W>FLi0>5W>@03
001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007VLi0P00P6Li00<0
05[FF]H07E[F00<006LiIcT0hFLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>
IcT00`00F]H0000NIcT20020IcT00`00F]IJeP0MF]H00`00IcUW>@3QIcT00`00Oomoo`02Ool001Qo
o`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@80085W>@03001JeU[F01aJeP03001W
>FLi0>5W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007VLi
0P00PFLi00<005[FF]H075[F00<006LiIcT0hFLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT00`00F]H0000NIcT20021IcT00`00F]IJeP0LF]H00`00IcUW>@3QIcT00`00Oomo
o`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@80089W>@03001JeU[F
01]JeP03001W>FLi0>5W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<0
05[F00007VLi0P00PVLi00<005[FF]H06e[F00<006LiIcT0hFLi00<007ooOol00Woo000HOol00`00
F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT20022IcT00`00F]IJeP0KF]H00`00IcUW>@3Q
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001iW>@8008=W
>@03001JeU[F01YJeP03001W>FLi0>5W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006Li
IcT0CVLi00<005[F00007VLi0P00PfLi00<005[FF]H06E[F00<006LiIcT0hVLi00<007ooOol00Woo
000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000NIcT20023IcT00`00F]IJeP0IF]H0
0`00IcUW>@3RIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP00
01iW>@8008AW>@03001JeU[F01QJeP03001W>FLi0>9W>@03001oogoo009oo`0067oo00<005[FF]H0
1U[F00<006LiIcT0CVLi00<005[F00007FLi00<005[F0000Q6Li00<005[FF]H065[F00<006LiIcT0
hVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT00`00
F]H00024IcT00`00F]IJeP0HF]H00`00IcUW>@3RIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@03001JeP0001eW>@03001JeP0008EW>@03001JeU[F01MJeP03001W>FLi0>9W
>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi00<005[F
0000QFLi00<005[FF]H05e[F00<006LiIcT0hVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT00`00F]H0000MIcT00`00F]H00025IcT00`00F]IJeP0GF]H00`00IcUW>@3RIcT0
0`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@03001JeP00
08EW>@03001JeU[F01MJeP03001W>FLi0>9W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<0
06LiIcT0CVLi00<005[F00007FLi00<005[F0000QVLi00<005[FF]H05U[F00<006LiIcT0hVLi00<0
07ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT00`00F]H00026
IcT00`00F]IJeP0FF]H00`00IcUW>@3RIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@03001JeP0001eW>@03001JeP0008IW>@03001JeU[F01EJeP03001W>FLi0>=W>@03001o
ogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi00<005[F0000QfLi
00<005[FF]H055[F00<006LiIcT0hfLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW
>@1>IcT00`00F]H0000MIcT00`00F]H00027IcT00`00F]IJeP0DF]H00`00IcUW>@3SIcT00`00Oomo
o`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@03001JeP0008MW>@03
001JeU[F01AJeP03001W>FLi0>=W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi00<005[F00007FLi00<005[F0000R6Li00<005[FF]H04e[F00<006LiIcT0hfLi00<007ooOol0
0Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT00`00F]H00028IcT00`00
F]IJeP0CF]H00`00IcUW>@3SIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW
>@03001JeP0001eW>@03001JeP0008QW>@03001JeU[F01=JeP03001W>FLi0>=W>@03001oogoo009o
o`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi0P00RFLi00<005[FF]H04e[F
00<006LiIcT0hfLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0
000MIcT2002:IcT00`00F]IJeP0BF]H00`00IcUW>@3SIcT00`00Oomoo`02Ool001Qoo`03001JeU[F
00IJeP03001W>FLi04iW>@03001JeP0001eW>@8008YW>@03001JeU[F019JeP03001W>FLi0>=W>@03
001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi0P00RVLi00<0
05[FF]H04E[F00<006LiIcT0i6Li00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>
IcT00`00F]H0000MIcT2002;IcT00`00F]IJeP0@F]H00`00IcUW>@3TIcT00`00Oomoo`02Ool001Qo
o`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@8008]W>@03001JeU[F011JeP03001W
>FLi0>AW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi
0P00RfLi00<005[FF]H045[F00<006LiIcT0i6Li00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT00`00F]H0000MIcT2002<IcT00`00F]IJeP0?F]H00`00IcUW>@3TIcT00`00Oomo
o`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@8008aW>@03001JeU[F
00iJeP03001W>FLi0>EW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<0
05[F00007FLi0P00S6Li00<005[FF]H03U[F00<006LiIcT0iFLi00<007ooOol00Woo000HOol00`00
F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2002=IcT00`00F]IJeP0=F]H00`00IcUW>@3U
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@8008eW
>@03001JeU[F00eJeP03001W>FLi0>EW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006Li
IcT0CVLi00<005[F00007FLi0P00SVLi00<005[FF]H035[F00<006LiIcT0iFLi00<007ooOol00Woo
000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2002>IcT00`00F]IJeP0<F]H0
0`00IcUW>@3UIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP00
01eW>@8008iW>@03001JeU[F00aJeP03001W>FLi0>EW>@03001oogoo009oo`0067oo00<005[FF]H0
1U[F00<006LiIcT0CVLi00<005[F00007FLi0P00SfLi00<005[FF]H02e[F00<006LiIcT0iFLi00<0
07ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2002?IcT00`00
F]IJeP0;F]H00`00IcUW>@3UIcT00`00Oomoo`02Ool00004Ool000000003Ool30004Ool20008Ool0
0`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2002@IcT00`00F]IJeP0:F]H00`00IcUW
>@3UIcT00`00Oomoo`02Ool00007001oogooOol007oo00000goo00@007ooOol0009oo`03001oogoo
00Eoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@80095W>@03001JeU[F00UJeP03
001W>FLi0>EW>@03001oogoo009oo`0000L007ooOomoo`00Ool00003Ool01000Oomoo`000Woo00<0
07ooOol01Goo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi0P00TFLi00<005[FF]H0
25[F00<006LiIcT0iVLi00<007ooOol00Woo00040003Ool30003Ool01000Oomoo`001goo00<005[F
F]H01U[F00<006LiIcT0CVLi00<005[F00007FLi0P00TVLi00<005[FF]H01e[F00<006LiIcT0iVLi
00<007ooOol00Woo00000`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol000Moo`03001J
eU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@80099W>@03001JeU[F00MJeP03001W>FLi0>IW
>@03001oogoo009oo`0000=oo`00Ool00goo00D007ooOomoo`00009oo`04001oogoo0007Ool00`00
F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2002CIcT00`00F]IJeP06F]H00`00IcUW>@3V
IcT00`00Oomoo`02Ool0009oo`8000=oo`<000Aoo`8000Qoo`03001JeU[F00IJeP03001W>FLi04iW
>@03001JeP0001eW>@8009=W>@03001JeU[F00IJeP03001W>FLi0>IW>@03001oogoo009oo`0067oo
00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi0P00TfLi00<005[FF]H01U[F00<006Li
IcT0iVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT2
002DIcT00`00F]IJeP05F]H00`00IcUW>@3VIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03
001W>FLi04iW>@03001JeP0001eW>@03001W>FLi09=W>@03001JeU[F00EJeP03001W>FLi0>IW>@03
001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F00007FLi00<006LiIcT0
TfLi00<005[FF]H01E[F00<006LiIcT0iVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00
IcUW>@1>IcT00`00F]H0000MIcT00`00IcUW>@2DIcT00`00F]IJeP04F]H00`00IcUW>@3VIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP0001eW>@03001W>FLi09EW
>@03001JeU[F009JeP03001W>FLi0>MW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006Li
IcT0CVLi00<005[F00007FLi00<006LiIcT0UFLi00<005[FF]H00U[F00<006LiIcT0ifLi00<007oo
Ool00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000MIcT00`00IcUW>@2FIcT0
1@00F]IJeU[F0000jFLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00
F]H0000MIcT00`00IcUW>@2FIcT01@00F]IJeU[F0000jFLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT00`00F]H0000KIcTK0021IcT01000F]IJeP00jFLi00<007ooOol00Woo
000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00F]H0000FIcT5000KLi`_001CIcT2003ZIcT0
0`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@03001JeP00015W>@D004mcW4@0
00mW>@800>YW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi00<005[F0000
36Li1@00V7>L5000ifLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT00`00
F]H00008IcT4002aLi`;003LIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW
>@03001JeP0000EW>@<00<1cW0X00=9W>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006Li
IcT0CVLi00<005[F00000VLi0`00cG>L1@00cFLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT00`00F]H0000=003:Li`:0033IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@03001JeP0000eW>@X00<YcW0D00;iW>@03001oogoo009oo`0067oo00<005[F
F]H01U[F00<006LiIcT0CVLi00<005[F00005fLi2P00aG>L2`00/fLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2000RIcT;0035Li`:002YIcT00`00Oomoo`02Ool001Qoo`03
001JeU[F00IJeP03001W>FLi04iW>@8002eW>@l00<1cW0D00:AW>@03001oogoo009oo`0067oo00<0
05[FF]H01U[F00<006LiIcT0CVLi0P00?6Li2P00^g>L2P00VVLi00<007ooOol00Woo000HOol00`00
F]IJeP06F]H00`00IcUW>@1>IcT20016IcT@002eLi`:002@IcT00`00Oomoo`02Ool001Qoo`03001J
eU[F00IJeP03001W>FLi04iW>@8005IW>@l00;1cW0D008]W>@03001oogoo009oo`0067oo00<005[F
F]H01U[F00<006LiIcT0CVLi0P00IFLi2`00ZW>L2`00P6Li00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2001`IcT?002VLi`:001fIcT00`00Oomoo`02Ool001Qoo`03001JeU[F
00IJeP03001W>FLi04iW>@8007mW>A000:1cW0X006aW>@03001oogoo009oo`0067oo00<005[FF]H0
1U[F00<006LiIcT0CVLi0P00SfLi3`00Vg>L2P00HVLi00<007ooOol00Woo000HOol00`00F]IJeP06
F]H00`00IcUW>@1>IcT2002NIcTE002@Li`;001GIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800;=W>@l008acW0X004eW>@03001oogoo009oo`0067oo00<005[FF]H01U[F
00<006LiIcT0CVLi0P00`VLi6P00O7>L2P00@fLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT2003LIcTD001bLi`:000iIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03
001W>FLi04iW>@800?1W>AX0069cW10002UW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<0
06LiIcT0CVLi0P00ofLi2fLi5@00GG>L2P007fLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H0
0`00IcUW>@1>IcT2003oIcTPIcTN0019Li`:000EIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>CiW>B@002mcW0X000]W>@03001oogoo009oo`0067oo00<005[FF]H0
1U[F00<006LiIcT0CVLi0P00ofLiHVLi6P007g>L1@001VLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2003oIcUlIcTJ000:Li`70004Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@800?mW>IIW>@X000IcW003001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiX6Li1`0017oo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`00
67oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00
ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`00
67oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00
ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`00
67oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00
ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`00
67oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJ
eP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W
>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00
ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`00
0Woo00<007ooOol00goo0P0017oo0P0027oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi
00<007ooOol00Woo0002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Moo`03001J
eU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`000goo00D007ooOomoo`00009o
o`04001oogoo0002Ool00`00Oomoo`05Ool00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT0
0`00Oomoo`02Ool000=oo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol01Goo00<0
05[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo0004Ool01000Oomoo`000Woo
00@007ooOol0009oo`03001oogoo00Eoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03
001oogoo009oo`0000D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001goo00<005[F
F]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo00050003Ool20004Ool20008Ool0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVV
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo
009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVV
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo
009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVV
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo
009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVV
IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo
009oo`0067oo00<005[FF]H01U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJ
eP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<005[FF]H01U[F00<006LiIcT0
CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol20007F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00
Oomoo`02Ool001Qoo`8000MJeP03001W>FLi04iW>@800?mW>JIW>@03001oogoo009oo`0067oo00<0
06Li00001U[F00<006LiIcT0CVLi0P00ofLiYVLi00<007ooOol00Woo000HOol00`00IcT00006F]H0
0`00IcUW>@1>IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`04001W>FLi0005F]H00`00IcUW>@1>
IcT2003oIcVVIcT00`00Oomoo`02Ool001Qoo`04001W>FLi0005F]H00`00IcUW>@1>IcT2003oIcVV
IcT00`00Oomoo`02Ool001Qoo`04001W>FLi0005F]H00`00IcUW>@1>IcT2003oIcVVIcT00`00Oomo
o`02Ool001Qoo`05001W>FLiIcT00004F]H00`00IcUW>@1>IcT00`00IcUW>@3oIcVUIcT00`00Oomo
o`02Ool001Qoo`05001W>FLiIcT00004F]H00`00IcUW>@1>IcT00`00IcUW>@3oIcVUIcT00`00Oomo
o`02Ool001Qoo`03001W>FLi009W>@05001JeU[FF]H0001@IcT00`00IcUW>@3oIcVUIcT00`00Oomo
o`02Ool001Qoo`03001W>FLi00=W>@04001JeU[F001@IcT00`00IcUW>@3oIcVUIcT00`00Oomoo`02
Ool001Qoo`03001W>FLi00AW>@03001JeP00051W>@03001W>FLi0?mW>JEW>@03001oogoo009oo`00
67oo00<006LiIcT016Li00<005[F0000D6Li00<006LiIcT0ofLiYFLi00<007ooOol00Woo000HOol0
0`00IcUW>@05IcT2001@IcT00`00IcUW>@3oIcVUIcT00`00Oomoo`02Ool001Qoo`03001W>FLi00EW
>@80051W>@03001W>FLi0?mW>JEW>@03001oogoo009oo`0067oo00<006LiIcT01VLi00<006LiIcT0
CVLi00<006LiIcT0ofLiYFLi00<007ooOol00Woo000HOol00`00IcUW>@06IcT00`00IcUW>@1>IcT0
0`00IcUW>@3oIcVUIcT00`00Oomoo`02Ool001Qoo`03001W>FLi00MW>@03001W>FLi04eW>@03001W
>FLi0?mW>JEW>@03001oogoo009oo`0067oo00<006LiIcT01fLi0P00CVLi00<006LiIcT0ofLiY6Li
0P0017oo000HOol00`00IcUW>@07IcT2001>IcT00`00IcUW>@3oIcVTIcT20004Ool001Qoo`03001W
>FLi00QW>@8004eW>@03001W>FLi0?mW>JAW>@8000Aoo`0067oo00<006LiIcT026Li0P00CFLi00<0
06LiIcT0ofLiXfLi00<007>L000017oo000HOol00`00IcUW>@08IcT00`00Li`0001<IcT00`00IcUW
>@3oIcVSIcT00`00Li`00004Ool001Qoo`03001W>FLi00QW>@03001cW00004aW>@03001W>FLi0?mW
>J9W>@04001cW7>L0004Ool001Qoo`03001W>FLi00QW>@03001cW00004aW>@03001W>FLi0?mW>J9W
>@04001cW7>L0004Ool001Qoo`03001W>FLi00QW>@04001cW7>L001;IcT00`00IcUW>@3oIcVQIcT0
1@00LiacW7>L000017oo000HOol00`00IcUW>@08IcT01000LiacW000BfLi00<006LiIcT0ofLiXFLi
00D007>LLiacW00000Aoo`0067oo00<006LiIcT026Li00D007>LLiacW00004YW>@03001W>FLi0?mW
>J5W>@05001cW7>LLi`00004Ool001Qoo`03001W>FLi00QW>@03001cW7>L009cW003001W>FLi04MW
>@03001W>FLi0?mW>J1W>@03001cW7>L009cW003001oogoo009oo`0067oo00<006LiIcT026Li00<0
07>LLi`00W>L00<006LiIcT0AfLi00<006LiIcT0ofLiX6Li00<007>LLi`00W>L00<007ooOol00Woo
000HOol00`00IcUW>@08IcT00`00LiacW003Li`00`00IcUW>@16IcT00`00IcUW>@3oIcVOIcT00`00
LiacW003Li`00`00Oomoo`02Ool001Qoo`03001W>FLi00QW>@03001cW7>L00=cW003001W>FLi04IW
>@03001W>FLi0?mW>ImW>@03001cW7>L00=cW003001oogoo009oo`0067oo00<006LiIcT026Li00<0
07>LLi`017>L00<006LiIcT0AFLi00<006LiIcT0ofLiWVLi00<007>LLi`017>L00<007ooOol00Woo
000HOol00`00IcUW>@08IcT00`00LiacW004Li`00`00IcUW>@15IcT00`00IcUW>@3oIcVNIcT00`00
LiacW004Li`00`00Oomoo`02Ool001Qoo`03001W>FLi00UW>@03001cW7>L00AcW003001W>FLi04AW
>@03001W>FLi0?mW>IeW>@03001cW7>L00EcW003001oogoo009oo`0067oo00<006LiIcT02FLi00<0
07>LLi`017>L00<006LiIcT0A6Li00<006LiIcT0ofLiWFLi00<007>LLi`01G>L00<007ooOol00Woo
000HOol00`00IcUW>@09IcT00`00LiacW005Li`00`00IcUW>@13IcT00`00IcUW>@3oIcVLIcT00`00
LiacW006Li`00`00Oomoo`02Ool001Qoo`03001W>FLi00UW>@03001cW7>L00EcW003001W>FLi04=W
>@03001W>FLi0?mW>IaW>@03001cW7>L00IcW003001oogoo009oo`0067oo00<006LiIcT02FLi00<0
07>LLi`01W>L00<006LiIcT0@VLi00<006LiIcT0ofLiVfLi00<007>LLi`01g>L00<007ooOol00Woo
000HOol00`00IcUW>@09IcT00`00LiacW006Li`00`00IcUW>@12IcT00`00IcUW>@3oIcVKIcT00`00
LiacW007Li`00`00Oomoo`02Ool001Qoo`03001W>FLi00UW>@03001cW7>L00IcW003001W>FLi049W
>@03001W>FLi0?mW>IYW>@03001cW7>L00QcW003001oogoo009oo`000Woo00@007ooOomoo`D000=o
o`8000Qoo`03001W>FLi00UW>@03001cW7>L00McW003001W>FLi045W>@03001W>FLi0?mW>IUW>@03
001cW7>L00UcW003001oogoo009oo`000Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0007Ool00`00IcUW>@09IcT00`00LiacW007Li`00`00IcUW>@11IcT00`00IcUW>@3oIcVHIcT00`00
LiacW009Li`20004Ool000=oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0007Ool00`00
IcUW>@09IcT00`00LiacW008Li`00`00IcUW>@10IcT00`00IcUW>@3oIcVHIcT00`00LiacW009Li`2
0004Ool000=oo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00IcUW>@0:
IcT00`00LiacW008Li`00`00IcUW>@0oIcT00`00IcUW>@3oIcVGIcT00`00LiacW009Li`00`00IcT0
0004Ool000Aoo`03001oo`0000=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00IcUW>@0:IcT0
0`00LiacW008Li`00`00IcUW>@0oIcT00`00IcUW>@3oIcVFIcT00`00LiacW00:Li`00`00IcT00004
Ool00007001oogooOol007oo00000goo00@007ooOol0009oo`03001oogoo00Eoo`03001W>FLi00YW
>@03001cW7>L00UcW003001W>FLi03iW>@03001W>FLi0?mW>IIW>@03001cW7>L00UcW004001W>FLi
0004Ool000D0009oo`<000Aoo`8000Qoo`03001W>FLi00YW>@03001cW7>L00UcW003001W>FLi03iW
>@03001W>FLi0?mW>IEW>@03001cW7>L00YcW004001W>FLi0004Ool001Qoo`03001W>FLi00YW>@03
001cW7>L00YcW003001W>FLi03eW>@03001W>FLi0?mW>IAW>@03001cW7>L00YcW005001W>FLiIcT0
0004Ool001Qoo`03001W>FLi00YW>@03001cW7>L00]cW003001W>FLi03aW>@03001W>FLi0?mW>I=W
>@03001cW7>L00]cW005001W>FLiIcT00004Ool001Qoo`03001W>FLi00YW>@03001cW7>L00]cW003
001W>FLi03aW>@03001W>FLi0?mW>I9W>@03001cW7>L00]cW003001W>FLi009W>@03001oogoo009o
o`0067oo00<006LiIcT02VLi00<007>LLi`037>L00<006LiIcT0>fLi00<006LiIcT0ofLiTFLi00<0
07>LLi`037>L00<006LiIcT00VLi00<007ooOol00Woo000HOol00`00IcUW>@0:IcT00`00LiacW00<
Li`00`00IcUW>@0kIcT00`00IcUW>@3oIcV@IcT00`00LiacW00<Li`00`00IcUW>@03IcT00`00Oomo
o`02Ool001Qoo`03001W>FLi00YW>@03001cW7>L00ecW003001W>FLi03YW>@03001W>FLi0?mW>HmW
>@03001cW7>L00acW003001W>FLi00AW>@03001oogoo009oo`0067oo00<006LiIcT02fLi00<007>L
Li`03G>L00<006LiIcT0>FLi00<006LiIcT0ofLiSVLi00<007>LLi`037>L00<006LiIcT01FLi00<0
07ooOol00Woo000HOol00`00IcUW>@0;IcT00`00LiacW00=Li`00`00IcUW>@0iIcT00`00IcUW>@3o
IcV=IcT00`00LiacW00=Li`00`00IcUW>@05IcT00`00Oomoo`02Ool001Qoo`03001W>FLi00]W>@03
001cW7>L00icW003001W>FLi03QW>@03001W>FLi0?mW>H]W>@8000mcW003001W>FLi00IW>@03001o
ogoo009oo`0067oo00<006LiIcT02fLi00<007>LLi`03W>L00<006LiIcT0>6Li00<006LiIcT0ofLi
RFLi0P0047>L00<006LiIcT01fLi00<007ooOol00Woo000HOol00`00IcUW>@0;IcT00`00LiacW00?
Li`00`00IcUW>@0gIcT00`00IcUW>@3oIcV8IcT00`00LiacW00@Li`00`00IcUW>@07IcT00`00Oomo
o`02Ool001Qoo`03001W>FLi00]W>@03001cW7>L011cW003001W>FLi03IW>@03001W>FLi0?mW>HIW
>@80019cW003001W>FLi00QW>@03001oogoo009oo`0067oo00<006LiIcT02fLi00<007>LLi`047>L
00<006LiIcT0=VLi1000ofLiPfLi0P004g>L00<006LiIcT02FLi00<007ooOol00Woo000HOol00`00
IcUW>@0;IcT00`00LiacW00ALi`00`00IcUW>@0eIcT01000LiacW7>L5000ofLiKVLi00<007>LLi`0
4W>L00<006LiIcT02VLi00<007ooOol00Woo000HOol00`00IcUW>@0;IcT00`00LiacW00ALi`00`00
IcUW>@0dIcT00`00LiacW00FLi`?003oIcULIcT3000DLi`00`00IcUW>@0;IcT00`00Oomoo`02Ool0
01Qoo`03001W>FLi00]W>@03001cW7>L019cW003001W>FLi039W>@03001cW7>L02IcW1000?mW>DMW
>@D001EcW08000iW>@03001oogoo009oo`0067oo00<006LiIcT036Li00<007>LLi`04W>L00<006Li
IcT0<6Li00<007>LLi`0=g>L3`00ofLi;FLi2`006G>L00<006LiIcT03VLi00<007ooOol00Woo000H
Ool00`00IcUW>@0<IcT00`00LiacW00BLi`00`00IcUW>@0_IcT00`00LiacW017Li`?003oIcTIIcT5
000SLi`00`00IcUW>@0?IcT00`00Oomoo`02Ool001Qoo`03001W>FLi00aW>@03001cW7>L01=cW003
001W>FLi02iW>@03001cW7>L05IcW1X00?UW>@D002McW003001W>FLi011W>@03001oogoo009oo`00
67oo00<006LiIcT036Li00<007>LLi`04g>L00<006LiIcT0;FLi00<007>LLi`0LG>L5000ffLi2P00
:W>L0P004fLi00<007ooOol00Woo000HOol00`00IcUW>@0<IcT00`00LiacW00DLi`00`00IcUW>@0[
IcT00`00LiacW026Li`O002]IcT?000bLi`2000EIcT00`00Oomoo`02Ool001Qoo`03001W>FLi00aW
>@03001cW7>L01EcW003001W>FLi02UW>@03001cW7>L0:IcW2@006mW>AX0041cW003001W>FLi01EW
>@03001oogoo009oo`0067oo00<006LiIcT036Li00<007>LLi`05G>L00<006LiIcT0:6Li00<007>L
Li`0bg>LK`00F7>L0P0066Li00<007ooOol00Woo000HOol00`00IcUW>@0<IcT00`00LiacW00FLi`0
0`00IcUW>@0WIcT00`00LiacW03oLibBLi`00`00IcUW>@0HIcT00`00Oomoo`02Ool001Qoo`03001W
>FLi00aW>@03001cW7>L01IcW003001W>FLi02IW>@03001cW7>L0?mcW99cW003001W>FLi01UW>@03
001oogoo009oo`0067oo00<006LiIcT036Li00<007>LLi`05g>L00<006LiIcT096Li00<007>LLi`0
og>LTW>L00<006LiIcT06VLi00<007ooOol00Woo000HOol00`00IcUW>@0=IcT00`00LiacW00GLi`0
0`00IcUW>@0SIcT00`00LiacW03oLib@Li`2000MIcT00`00Oomoo`02Ool001Qoo`03001W>FLi00eW
>@03001cW7>L01McW003001W>FLi029W>@03001cW7>L0?mcW8mcW08001mW>@03001oogoo009oo`00
67oo00<006LiIcT03FLi00<007>LLi`067>L00<006LiIcT086Li00<007>LLi`0og>LSg>L00<006Li
IcT07fLi00<007ooOol00Woo000HOol00`00IcUW>@0=IcT00`00LiacW00HLi`00`00IcUW>@0PIcT0
0`00LiacW03oLib=Li`2000RIcT00`00Oomoo`02Ool001Qoo`03001W>FLi00eW>@03001cW7>L01Uc
W003001W>FLi01iW>@03001cW7>L0?mcW8acW08002AW>@03001oogoo009oo`0067oo00<006LiIcT0
3FLi00<007>LLi`06W>L00<006LiIcT076Li00<007>LLi`0og>LRg>L0P009VLi00<007ooOol00Woo
000HOol00`00IcUW>@0=IcT00`00LiacW00JLi`00`00IcUW>@0KIcT00`00LiacW03oLib:Li`2000X
IcT00`00Oomoo`02Ool001Qoo`03001W>FLi00eW>@03001cW7>L01]cW003001W>FLi01UW>@03001c
W7>L0?mcW8UcW08002YW>@03001oogoo009oo`0067oo00<006LiIcT03FLi00<007>LLi`06g>L00<0
06LiIcT06FLi00<007>LLi`0og>LR7>L00<006LiIcT0:VLi00<007ooOol00Woo000HOol00`00IcUW
>@0=IcT00`00LiacW00LLi`00`00IcUW>@0GIcT00`00LiacW03oLib7Li`2000]IcT00`00Oomoo`02
Ool001Qoo`03001W>FLi00iW>@03001cW7>L01acW003001W>FLi01EW>@03001cW7>L0?mcW8IcW080
02mW>@03001oogoo009oo`0067oo0P003fLi00<007>LLi`07G>L00<006LiIcT056Li00<007>LLi`0
og>LQG>L00<006LiIcT0;fLi00<007ooOol00Woo000HOol00`00F]H0000>IcT00`00LiacW00NLi`0
0`00IcUW>@0BIcT00`00LiacW03oLib4Li`2000bIcT00`00Oomoo`02Ool001Qoo`03001JeP0000iW
>@03001cW7>L01icW003001W>FLi019W>@03001cW7>L0?mcW85cW0<003AW>@03001oogoo009oo`00
67oo00@005[FF]H000eW>@03001cW7>L01mcW003001W>FLi011W>@03001cW7>L0?mcW81cW08003MW
>@03001oogoo009oo`0067oo00@005[FF]H000eW>@03001cW7>L021cW003001W>FLi00iW>@03001c
W7>L0?mcW7mcW08003UW>@03001oogoo009oo`0067oo00D005[FF]IJeP0000aW>@03001cW7>L021c
W003001W>FLi00eW>@03001cW7>L0?mcW7mcW003001W>FLi03UW>@03001oogoo009oo`0067oo00<0
05[FF]H00U[F00<006LiIcT02FLi00<007>LLi`08G>L00<006LiIcT02fLi00<007>LLi`0og>LOW>L
0P00?6Li00<007ooOol00Woo000HOol00`00F]IJeP02F]H00`00IcUW>@09IcT00`00LiacW00QLi`0
0`00IcUW>@0;IcT00`00LiacW03oLiakLi`3000nIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00=J
eP03001W>FLi00QW>@03001cW7>L029cW003001W>FLi00UW>@03001cW7>L0?mcW7YcW080045W>@03
001oogoo009oo`0067oo00<005[FF]H00e[F00<006LiIcT02FLi00<007>LLi`08W>L00<006LiIcT0
1fLi00<007>LLi`0og>LN7>L0`00@fLi00<007ooOol00Woo000HOol00`00F]IJeP04F]H00`00IcUW
>@08IcT00`00LiacW00SLi`00`00IcUW>@06IcT00`00LiacW03oLiafLi`20016IcT00`00Oomoo`02
Ool001Qoo`03001JeU[F00EJeP03001W>FLi00MW>@03001cW7>L02AcW003001W>FLi00AW>@03001c
W7>L0?mcW7EcW08004QW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT01fLi00<0
07>LLi`097>L00<006LiIcT016Li00<007>LLi`0og>LLg>L0P00BVLi00<007ooOol00Woo000HOol0
0`00F]IJeP06F]H00`00IcUW>@06IcT00`00LiacW00ULi`00`00IcUW>@02IcT00`00LiacW03oLiab
Li`2001<IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi00IW>@03001cW7>L02Ic
W004001W>FLi003oLiabLi`3001>IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00MJeP03001W>FLi
00EW>@03001cW7>L02IcW003001W>@000?mcW75cW080055W>@03001oogoo009oo`0067oo00<005[F
F]H025[F00<006LiIcT016Li00<007>LLi`09G>L1P00og>LK7>L0`00DfLi00<007ooOol00Woo000H
Ool00`00F]IJeP09F]H00`00IcUW>@03IcT00`00LiacW00PLi`50006Ool@003oLiaJLi`2001FIcT0
0`00Oomoo`02Ool001Qoo`03001JeU[F00UJeP03001W>FLi00=W>@03001cW7>L01]cW0D001]oo`l0
0?mcW4QcW0<005QW>@03001oogoo009oo`0067oo00<005[FF]H02U[F00<006LiIcT00fLi00<007>L
Li`05W>L1000;goo2P00og>L>g>L0`00FfLi00<007ooOol00Woo000HOol00`00F]IJeP0;F]H00`00
IcUW>@02IcT00`00LiacW00CLi`3000mOol@003oLi`WLi`4001NIcT00`00Oomoo`02Ool001Qoo`03
001JeU[F00aJeP05001W>FLiIcT0000BLi`3001@Ool:003oLi`JLi`3001RIcT00`00Oomoo`02Ool0
01Qoo`03001JeU[F00eJeP04001W>FLi000=Li`5001MOol@003oLi`8Li`2001UIcT00`00Oomoo`02
Ool001Qoo`03001JeU[F00eJeP04001W>FLi0009Li`4001bOolD003`Li`3001WIcT00`00Oomoo`02
Ool001Qoo`03001JeU[F00iJeP03001W>@0000IcW0<008Yooa000=icW08006YW>@03001oogoo009o
o`0067oo00<005[FF]H03e[F0P000W>L1000WGoo6P00`G>L0`00K6Li00<007ooOol00Woo000HOol0
0`00F]IJeP0?F]H4002kOolD002YLi`4001_IcT00`00Oomoo`02Ool001Qoo`03001JeU[F011JeS@0
09iooaX008]cW0@007=W>@03001oogoo009oo`0067oo00<005[FF]H045[F00<006LiIcT03FLi3`00
5G>L@P00MWoo7`00JG>L0`00MfLi00<007ooOol00Woo0002Ool00`00Oomoo`03Ool30003Ool20008
Ool00`00F]IJeP0@F]H00`00IcUW>@0LIcT@0017LiaM000hOol^000iLi`2001jIcT00`00Oomoo`02
Ool0009oo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00F]IJeP0?F]H0
0`00IcUW>@0]IcTI002;Lib@000<Li`3001lIcT00`00Oomoo`02Ool000=oo`03001oogoo00D0009o
o`04001oogoo0007Ool00`00F]IJeP0?F]H00`00IcUW>@16IcTJ003/Li`^001bIcT00`00Oomoo`02
Ool000=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<005[FF]H03e[F
00<006LiIcT0H6Li:@00lG>L4000HVLi00<007ooOol00Woo0004Ool01P00Oomoo`00Ool000=oo`04
001oogoo0007Ool00`00F]IJeP0?F]H00`00IcUW>@29IcTO003RLi`?001CIcT00`00Oomoo`02Ool0
0005001oogooOol00003Ool20003Ool01000Oomoo`001goo00<005[FF]H03e[F00<006LiIcT0Z6Li
>000^G>L4000@fLi00<007ooOol00Woo00050004Ool00`00Oomoo`02Ool20008Ool00`00F]IJeP0>
F]H00`00IcUW>@3QIcTi002@Li`D000_IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00iJeP03001W
>FLi0?mW>A]W>Cd000YcW10004ecW10001mW>@03001oogoo009oo`0067oo00<005[FF]H03U[F00<0
06LiIcT0ofLiF6Li2P0046Li@`006W>L50002fLi00<007ooOol00Woo000HOol00`00F]IJeP0>F]H0
0`00IcUW>@3oIcVeIcTj0004Ool001Qoo`03001JeU[F00eJeP03001W>FLi0?mW>NmW>@03001oogoo
009oo`0067oo00<005[FF]H03E[F00<006LiIcT0ofLikfLi00<007ooOol00Woo000HOol00`00F]IJ
eP0=F]H00`00IcUW>@3oIcW_IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00aJeP03001W>FLi0?mW
>O1W>@03001oogoo009oo`0067oo00<005[FF]H035[F00<006LiIcT0ofLil6Li00<007ooOol00Woo
000HOol00`00F]IJeP0<F]H00`00IcUW>@3oIcW`IcT00`00Oomoo`02Ool001Qoo`03001JeU[F00aJ
eP03001W>FLi0?mW>O1W>@03001oogoo009oo`0067oo00<005[FF]H02e[F00<006LiIcT0ofLilFLi
00<007ooOol00Woo000HOol00`00F]IJeP0;F]H00`00IcUW>@3oIcWaIcT00`00Oomoo`02Ool001Qo
o`03001JeU[F00]JeP03001W>FLi0?mW>O5W>@03001oogoo009oo`0067oo00<005[FF]H02e[F00<0
06LiIcT0ofLilFLi00<007ooOol00Woo000HOol00`00F]IJeP0;F]H00`00IcUW>@3oIcWaIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00YJeP03001W>FLi0?mW>O9W>@03001oogoo009oo`0067oo00<0
05[FF]H02U[F00<006LiIcT0ofLilVLi00<007ooOol00Woo000HOol00`00F]IJeP0:F]H00`00IcUW
>@3oIcWbIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00YJeP03001W>FLi0?mW>O9W>@03001oogoo
009oo`0067oo00<005[FF]H02E[F00<006LiIcT0ofLilfLi00<007ooOol00Woo000HOol00`00F]IJ
eP09F]H00`00IcUW>@3oIcWcIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00UJeP03001W>FLi0?mW
>O=W>@03001oogoo009oo`0067oo00<005[FF]H025[F00<006LiIcT0ofLim6Li00<007ooOol00Woo
000HOol00`00F]IJeP08F]H00`00IcUW>@3oIcWdIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00QJ
eP03001W>FLi0?mW>OAW>@03001oogoo009oo`0067oo00<005[FF]H01e[F00<006LiIcT0ofLimFLi
00<007ooOol00Woo000HOol00`00F]IJeP07F]H00`00IcUW>@3oIcWeIcT00`00Oomoo`02Ool001Qo
o`03001JeU[F00MJeP03001W>FLi0?mW>OEW>@03001oogoo009oo`0067oo00<005[FF]H01e[F00<0
06LiIcT0ofLimFLi00<007ooOol00Woo000HOol00`00F]IJeP07F]H00`00IcUW>@3oIcWeIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00MJeP03001W>FLi0?mW>OEW>@03001oogoo009oo`0067oo00<0
05[FF]H01U[F00<006LiIcT0ofLimVLi00<007ooOol00Woo000HOol00`00F]IJeP06F]H00`00IcUW
>@3oIcWfIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00IJeP03001W>FLi0?mW>OIW>@03001oogoo
009oo`0067oo00<005[FF]H01U[F00<006LiIcT0ofLimVLi00<007ooOol00Woo000HOol00`00F]IJ
eP05F]H00`00IcUW>@3oIcWgIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00EJeP03001W>FLi0?mW
>OMW>@03001oogoo009oo`0067oo00<005[FF]H01E[F00<006LiIcT0ofLimfLi00<007ooOol00Woo
000HOol00`00F]IJeP04F]H00`00IcUW>@3oIcWhIcT00`00Oomoo`02Ool001Qoo`03001JeU[F00AJ
eP03001W>FLi0?mW>OQW>@03001oogoo009oo`0067oo00<005[FF]H015[F00<006LiIcT0ofLin6Li
00<007ooOol00Woo000HOol00`00F]IJeP03F]H00`00IcUW>@3oIcWiIcT00`00Oomoo`02Ool001Qo
o`03001JeU[F00=JeP03001W>FLi0?mW>OUW>@03001oogoo009oo`0067oo00<005[FF]H00e[F00<0
06LiIcT0ofLinFLi00<007ooOol00Woo000HOol00`00F]IJeP03F]H00`00IcUW>@3oIcWiIcT00`00
Oomoo`02Ool001Qoo`03001JeU[F00=JeP03001W>FLi0?mW>OUW>@03001oogoo009oo`0067oo00<0
05[FF]H00U[F00<006LiIcT0ofLinVLi00<007ooOol00Woo000HOol00`00F]IJeP02F]H00`00IcUW
>@3oIcWjIcT00`00Oomoo`02Ool001Qoo`03001JeU[F009JeP03001W>FLi0?mW>OYW>@03001oogoo
009oo`0067oo00<005[FF]H00U[F00<006LiIcT0ofLinVLi00<007ooOol00Woo000HOol00`00F]IJ
eP02F]H00`00IcUW>@3oIcWjIcT00`00Oomoo`02Ool001Qoo`05001JeU[FF]H0003oIcWmIcT00`00
Oomoo`02Ool001Qoo`05001JeU[FF]H0003oIcWmIcT00`00Oomoo`02Ool001Qoo`05001JeU[FF]H0
003oIcWmIcT00`00Oomoo`02Ool001Qoo`05001JeU[FF]H0003oIcWmIcT00`00Oomoo`02Ool001Qo
o`04001JeU[F003oIcWnIcT00`00Oomoo`02Ool001Qoo`04001JeU[F003oIcWnIcT00`00Oomoo`02
Ool001Qoo`04001JeU[F003oIcWnIcT00`00Oomoo`02Ool001Qoo`03001JeP000?mW>OmW>@03001o
ogoo009oo`0067oo00<005[F0000ofLiofLi00<007ooOol00Woo000HOol00`00F]H0003oIcWoIcT0
0`00Oomoo`02Ool001Qoo`03001JeP000?mW>OmW>@03001oogoo009oo`0067oo0P00ofLiofLi0FLi
00<007ooOol00Woo000HOol2003oIcWoIcT1IcT00`00Oomoo`02Ool001Qoo`800?mW>OmW>@5W>@03
001oogoo009oo`0067oo0P00ofLiofLi0FLi00<007ooOol00Woo000HOol2003oIcWoIcT1IcT00`00
Oomoo`02Ool0009oo`03001oogoo009oo`<000Aoo`8000Qoo`03001W>FLi0?mW>OmW>@03001oogoo
009oo`000Woo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`05Ool00`00IcUW>@3o
IcWoIcT00`00Oomoo`02Ool000=oo`04001oogoo0003Ool01000Oomoo`000Woo00<007ooOol01Goo
2`0016Li300016Li2`0016Li2`001FLi2`0016Li2`0016Li300016Li2`0016Li2`001FLi2`0016Li
2`0016Li300016Li2`0016Li2`001FLi2`0016Li2`0016Li300016Li2`0016Li2`001FLi2`0016Li
2`0016Li300016Li2`0016Li300016Li2`0016Li2`0016Li300016Li2`0016Li300016Li2`0016Li
2`001FLi2`0016Li2`0016Li1P0017oo0003Ool00`00Oomoo`040003Ool01000Oomoo`001goo00<0
06LiIcT0ofLiofLi00<007ooOol00Woo0004Ool00`00Ool00006Ool01000Oomoo`001goo00<006Li
IcT0ofLiofLi00<007ooOol00Woo00001@00Oomoogoo00000Woo00<007ooOol00goo00@007ooOol0
00Moo`03001W>FLi0?mW>OmW>@03001oogoo009oo`001@000goo0P0017oo0P0027oo00<006LiIcT0
ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W
>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol0
0`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`00
67oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02
Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007oo
Ool00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03
001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWo
IcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0
ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W
>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol0
0`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`00
67oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02
Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007oo
Ool00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03
001oogoo009oo`0067oo00<006LiIcT0ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWo
IcT00`00Oomoo`02Ool001Qoo`03001W>FLi0?mW>OmW>@03001oogoo009oo`0067oo00<006LiIcT0
ofLiofLi00<007ooOol00Woo000HOol00`00IcUW>@3oIcWoIcT00`00Oomoo`02Ool001Qoo`03001W
>FLi0?mW>OmW>@03001oogoo009oo`0067ooo`00o`00100017oo003oOoooOolPOol00?mooomoob1o
o`00ogooogoo87oo003oOoooOolPOol00?mooomoob1oo`00\
\>"],
  ImageRangeCache->{{{0, 541}, {541, 0}} -> {-0.0475535, 624.083, 0.00194713, \
0.272599}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
nop = 100; grade = 0.1;
xlow = 0.15; xhigh = 0.75; ylow = 620; yhigh = 700;
drawing;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["area problem: lines do not connect up?", "Print",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.25 1.66667 -7.75 0.0125 [
[(0.2)] .08333 0 0 2 Msboxa
[(0.3)] .25 0 0 2 Msboxa
[(0.4)] .41667 0 0 2 Msboxa
[(0.5)] .58333 0 0 2 Msboxa
[(0.6)] .75 0 0 2 Msboxa
[(0.7)] .91667 0 0 2 Msboxa
[(620)] -0.0125 0 1 0 Msboxa
[(630)] -0.0125 .125 1 0 Msboxa
[(640)] -0.0125 .25 1 0 Msboxa
[(650)] -0.0125 .375 1 0 Msboxa
[(660)] -0.0125 .5 1 0 Msboxa
[(670)] -0.0125 .625 1 0 Msboxa
[(680)] -0.0125 .75 1 0 Msboxa
[(690)] -0.0125 .875 1 0 Msboxa
[(700)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08333 0 m
.08333 .00625 L
s
P
[(0.2)] .08333 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(0.3)] .25 0 0 2 Mshowa
p
.002 w
.41667 0 m
.41667 .00625 L
s
P
[(0.4)] .41667 0 0 2 Mshowa
p
.002 w
.58333 0 m
.58333 .00625 L
s
P
[(0.5)] .58333 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(0.6)] .75 0 0 2 Mshowa
p
.002 w
.91667 0 m
.91667 .00625 L
s
P
[(0.7)] .91667 0 0 2 Mshowa
p
.001 w
.11667 0 m
.11667 .00375 L
s
P
p
.001 w
.15 0 m
.15 .00375 L
s
P
p
.001 w
.18333 0 m
.18333 .00375 L
s
P
p
.001 w
.21667 0 m
.21667 .00375 L
s
P
p
.001 w
.28333 0 m
.28333 .00375 L
s
P
p
.001 w
.31667 0 m
.31667 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.38333 0 m
.38333 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.48333 0 m
.48333 .00375 L
s
P
p
.001 w
.51667 0 m
.51667 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.61667 0 m
.61667 .00375 L
s
P
p
.001 w
.65 0 m
.65 .00375 L
s
P
p
.001 w
.68333 0 m
.68333 .00375 L
s
P
p
.001 w
.71667 0 m
.71667 .00375 L
s
P
p
.001 w
.78333 0 m
.78333 .00375 L
s
P
p
.001 w
.81667 0 m
.81667 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.88333 0 m
.88333 .00375 L
s
P
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.01667 0 m
.01667 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.98333 0 m
.98333 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(620)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .125 m
.00625 .125 L
s
P
[(630)] -0.0125 .125 1 0 Mshowa
p
.002 w
0 .25 m
.00625 .25 L
s
P
[(640)] -0.0125 .25 1 0 Mshowa
p
.002 w
0 .375 m
.00625 .375 L
s
P
[(650)] -0.0125 .375 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(660)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .625 m
.00625 .625 L
s
P
[(670)] -0.0125 .625 1 0 Mshowa
p
.002 w
0 .75 m
.00625 .75 L
s
P
[(680)] -0.0125 .75 1 0 Mshowa
p
.002 w
0 .875 m
.00625 .875 L
s
P
[(690)] -0.0125 .875 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(700)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .025 m
.00375 .025 L
s
P
p
.001 w
0 .05 m
.00375 .05 L
s
P
p
.001 w
0 .075 m
.00375 .075 L
s
P
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .15 m
.00375 .15 L
s
P
p
.001 w
0 .175 m
.00375 .175 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .225 m
.00375 .225 L
s
P
p
.001 w
0 .275 m
.00375 .275 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .325 m
.00375 .325 L
s
P
p
.001 w
0 .35 m
.00375 .35 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .425 m
.00375 .425 L
s
P
p
.001 w
0 .45 m
.00375 .45 L
s
P
p
.001 w
0 .475 m
.00375 .475 L
s
P
p
.001 w
0 .525 m
.00375 .525 L
s
P
p
.001 w
0 .55 m
.00375 .55 L
s
P
p
.001 w
0 .575 m
.00375 .575 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .65 m
.00375 .65 L
s
P
p
.001 w
0 .675 m
.00375 .675 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .725 m
.00375 .725 L
s
P
p
.001 w
0 .775 m
.00375 .775 L
s
P
p
.001 w
0 .8 m
.00375 .8 L
s
P
p
.001 w
0 .825 m
.00375 .825 L
s
P
p
.001 w
0 .85 m
.00375 .85 L
s
P
p
.001 w
0 .9 m
.00375 .9 L
s
P
p
.001 w
0 .925 m
.00375 .925 L
s
P
p
.001 w
0 .95 m
.00375 .95 L
s
P
p
.001 w
0 .975 m
.00375 .975 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.08333 .99375 m
.08333 1 L
s
P
p
.002 w
.25 .99375 m
.25 1 L
s
P
p
.002 w
.41667 .99375 m
.41667 1 L
s
P
p
.002 w
.58333 .99375 m
.58333 1 L
s
P
p
.002 w
.75 .99375 m
.75 1 L
s
P
p
.002 w
.91667 .99375 m
.91667 1 L
s
P
p
.001 w
.11667 .99625 m
.11667 1 L
s
P
p
.001 w
.15 .99625 m
.15 1 L
s
P
p
.001 w
.18333 .99625 m
.18333 1 L
s
P
p
.001 w
.21667 .99625 m
.21667 1 L
s
P
p
.001 w
.28333 .99625 m
.28333 1 L
s
P
p
.001 w
.31667 .99625 m
.31667 1 L
s
P
p
.001 w
.35 .99625 m
.35 1 L
s
P
p
.001 w
.38333 .99625 m
.38333 1 L
s
P
p
.001 w
.45 .99625 m
.45 1 L
s
P
p
.001 w
.48333 .99625 m
.48333 1 L
s
P
p
.001 w
.51667 .99625 m
.51667 1 L
s
P
p
.001 w
.55 .99625 m
.55 1 L
s
P
p
.001 w
.61667 .99625 m
.61667 1 L
s
P
p
.001 w
.65 .99625 m
.65 1 L
s
P
p
.001 w
.68333 .99625 m
.68333 1 L
s
P
p
.001 w
.71667 .99625 m
.71667 1 L
s
P
p
.001 w
.78333 .99625 m
.78333 1 L
s
P
p
.001 w
.81667 .99625 m
.81667 1 L
s
P
p
.001 w
.85 .99625 m
.85 1 L
s
P
p
.001 w
.88333 .99625 m
.88333 1 L
s
P
p
.001 w
.05 .99625 m
.05 1 L
s
P
p
.001 w
.01667 .99625 m
.01667 1 L
s
P
p
.001 w
.95 .99625 m
.95 1 L
s
P
p
.001 w
.98333 .99625 m
.98333 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .125 m
1 .125 L
s
P
p
.002 w
.99375 .25 m
1 .25 L
s
P
p
.002 w
.99375 .375 m
1 .375 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .625 m
1 .625 L
s
P
p
.002 w
.99375 .75 m
1 .75 L
s
P
p
.002 w
.99375 .875 m
1 .875 L
s
P
p
.001 w
.99625 .025 m
1 .025 L
s
P
p
.001 w
.99625 .05 m
1 .05 L
s
P
p
.001 w
.99625 .075 m
1 .075 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .15 m
1 .15 L
s
P
p
.001 w
.99625 .175 m
1 .175 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .225 m
1 .225 L
s
P
p
.001 w
.99625 .275 m
1 .275 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .325 m
1 .325 L
s
P
p
.001 w
.99625 .35 m
1 .35 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .425 m
1 .425 L
s
P
p
.001 w
.99625 .45 m
1 .45 L
s
P
p
.001 w
.99625 .475 m
1 .475 L
s
P
p
.001 w
.99625 .525 m
1 .525 L
s
P
p
.001 w
.99625 .55 m
1 .55 L
s
P
p
.001 w
.99625 .575 m
1 .575 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .65 m
1 .65 L
s
P
p
.001 w
.99625 .675 m
1 .675 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .725 m
1 .725 L
s
P
p
.001 w
.99625 .775 m
1 .775 L
s
P
p
.001 w
.99625 .8 m
1 .8 L
s
P
p
.001 w
.99625 .825 m
1 .825 L
s
P
p
.001 w
.99625 .85 m
1 .85 L
s
P
p
.001 w
.99625 .9 m
1 .9 L
s
P
p
.001 w
.99625 .925 m
1 .925 L
s
P
p
.001 w
.99625 .95 m
1 .95 L
s
P
p
.001 w
.99625 .975 m
1 .975 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.9 g
p
P
p
P
p
P
1 .88 m
.98997 .87959 L
.97995 .87916 L
.96992 .87873 L
.95989 .87827 L
.94987 .87781 L
.93984 .87735 L
.92982 .87687 L
.91979 .8764 L
.90976 .87594 L
.89974 .87549 L
.88971 .87504 L
.87968 .87459 L
.86966 .87413 L
.85963 .87368 L
.84961 .87323 L
.83958 .87278 L
.82955 .87233 L
.81953 .87188 L
.8095 .87143 L
.79947 .87098 L
.78945 .87053 L
.77942 .87007 L
.76939 .86962 L
.75937 .86917 L
.74934 .86872 L
.73932 .8683 L
.72929 .86787 L
.71926 .86743 L
.70924 .86699 L
.69921 .86654 L
.68918 .86608 L
.67916 .86561 L
.66913 .86512 L
.65911 .86458 L
.64908 .86401 L
.63905 .86342 L
.62903 .86282 L
.619 .86221 L
.60897 .8616 L
.59895 .86097 L
.58892 .86035 L
.57889 .85974 L
.56887 .85917 L
.55884 .85859 L
.54882 .858 L
.53879 .85741 L
.52876 .8568 L
.51874 .85619 L
.50871 .85556 L
.49868 .85491 L
.48866 .8542 L
.47863 .85347 L
.46861 .85272 L
.45858 .85197 L
.44855 .85121 L
.43853 .85044 L
.4285 .84967 L
.41847 .84889 L
.40845 .84813 L
.39842 .84738 L
.38839 .84663 L
.37837 .84588 L
.36834 .84513 L
.35832 .84437 L
.34829 .84362 L
.33826 .84287 L
.32824 .84213 L
.31821 .8414 L
.30818 .84067 L
.29816 .83993 L
.28813 .83919 L
.27811 .83844 L
.26808 .83767 L
.25805 .83689 L
.24803 .83608 L
.238 .83522 L
.22797 .83434 L
.21795 .83344 L
.20792 .83254 L
.19789 .83163 L
.18787 .83071 L
.17784 .82978 L
.16782 .82886 L
.15779 .8279 L
.14776 .82694 L
.13774 .826 L
.12771 .82507 L
.11768 .82415 L
.10766 .82327 L
.09763 .82241 L
.08761 .82159 L
.07758 .82081 L
.06755 .82007 L
.05753 .81938 L
.0475 .81875 L
.0475 .81875 L
.05745 .81602 L
.06739 .81358 L
.07734 .81132 L
.08729 .80911 L
.09724 .80687 L
.10718 .80463 L
.11713 .80239 L
.12708 .80004 L
.13703 .7981 L
.14697 .79696 L
.14697 .79696 L
.15691 .7965 L
.16685 .79625 L
.17678 .79617 L
.18672 .79624 L
.19666 .79644 L
.20659 .79674 L
.21653 .79713 L
.22647 .79758 L
.2364 .79807 L
.24634 .79857 L
.25628 .79887 L
.26621 .79905 L
.27615 .79922 L
.28609 .79937 L
.29602 .79951 L
.30596 .79965 L
.3159 .79978 L
.32583 .79991 L
.33577 .80004 L
.34571 .80019 L
.35564 .80033 L
.36558 .80048 L
.37552 .80063 L
.38545 .80078 L
.39539 .80093 L
.40533 .80108 L
.41526 .80123 L
.4252 .80138 L
.43514 .80153 L
.44507 .80168 L
.45501 .80183 L
.46495 .80197 L
.47488 .80212 L
.48482 .80227 L
.49476 .80242 L
.50469 .80256 L
.51463 .80268 L
.52457 .80281 L
.5345 .80294 L
.54444 .80308 L
.55438 .80323 L
.56431 .8034 L
.57425 .80357 L
.58419 .80377 L
.59412 .80398 L
.60406 .80421 L
.614 .80447 L
.62393 .80475 L
.63387 .80506 L
.64381 .8054 L
.65374 .80578 L
.65374 .80578 L
.66364 .8071 L
.67353 .80838 L
.68342 .80962 L
.69332 .81083 L
.70321 .81201 L
.7131 .81318 L
.723 .81434 L
.73289 .81549 L
.74278 .81665 L
.75267 .81785 L
.76257 .81918 L
.77246 .82051 L
.78235 .82186 L
.79225 .8232 L
.80214 .82455 L
.81203 .82589 L
.82193 .82723 L
.83182 .82855 L
.84171 .82979 L
.8516 .83101 L
.8615 .83221 L
.87139 .8334 L
.88128 .83458 L
.89118 .83575 L
.90107 .83692 L
.91096 .83808 L
.92086 .83926 L
.93075 .84047 L
.94064 .84168 L
.95053 .84288 L
.96043 .84408 L
.97032 .84527 L
.98021 .84644 L
.99011 .8476 L
1 .84875 L
F
.55928 .53918 m
.54939 .53783 L
.53951 .53668 L
.52962 .53571 L
.51974 .53491 L
.50985 .53426 L
.49997 .53375 L
.49008 .53335 L
.4802 .53305 L
.47031 .53284 L
.46043 .5327 L
.45054 .53261 L
.44066 .53256 L
.43077 .53254 L
.42089 .53251 L
.411 .53234 L
.40111 .53205 L
.39123 .53175 L
.38134 .53145 L
.37146 .53114 L
.36157 .53083 L
.35169 .53053 L
.3418 .53024 L
.33192 .52997 L
.32203 .52978 L
.31215 .52961 L
.30226 .52945 L
.29238 .52931 L
.28249 .52917 L
.27261 .52904 L
.26272 .52891 L
.25284 .52879 L
.24295 .52836 L
.23307 .52784 L
.22318 .52738 L
.2133 .52701 L
.20341 .52676 L
.19353 .52667 L
.18364 .52678 L
.17376 .52711 L
.16387 .52769 L
.15399 .52858 L
.15399 .52858 L
.16407 .52569 L
.17414 .52311 L
.18422 .52078 L
.1943 .51869 L
.20437 .51681 L
.21445 .5151 L
.22452 .51353 L
.2346 .51207 L
.24468 .5107 L
.25475 .50922 L
.26483 .50759 L
.27491 .506 L
.28498 .50445 L
.29506 .50293 L
.30514 .50145 L
.31521 .50001 L
.32529 .4986 L
.33537 .49724 L
.34544 .49598 L
.35552 .49475 L
.3656 .49355 L
.37567 .49235 L
.38575 .49117 L
.39583 .48998 L
.4059 .48879 L
.41598 .48758 L
.42605 .48636 L
.43613 .48511 L
.44621 .48382 L
.45628 .48249 L
.46636 .48112 L
.47644 .47969 L
.48651 .4782 L
.49659 .47664 L
.50667 .475 L
.50667 .475 L
.51625 .4857 L
.52659 .49639 L
.53703 .50709 L
.54703 .51778 L
.55715 .52848 L
.55928 .53918 L
F
1 .3925 m
.99007 .39037 L
.98013 .38826 L
.9702 .38616 L
.96026 .38408 L
.95033 .382 L
.9404 .37993 L
.93046 .37786 L
.92053 .3758 L
.9106 .37371 L
.90066 .3716 L
.89073 .36949 L
.88079 .36739 L
.87086 .3653 L
.86093 .36322 L
.85099 .36115 L
.84106 .35909 L
.83113 .35707 L
.82119 .35513 L
.81126 .35321 L
.80132 .35129 L
.79139 .34937 L
.78146 .34745 L
.77152 .34551 L
.76159 .34356 L
.75165 .34158 L
.74172 .33958 L
.73179 .33754 L
.72185 .33546 L
.71192 .33333 L
.70199 .33115 L
.70199 .33115 L
.69241 .32649 L
.68284 .321 L
.67326 .31518 L
.66369 .3097 L
.65411 .30501 L
.64454 .30068 L
.63496 .29661 L
.62539 .29266 L
.61582 .28844 L
.60624 .28453 L
.59667 .28125 L
.59667 .28125 L
.60675 .28138 L
.61683 .28145 L
.62692 .28149 L
.637 .28147 L
.64708 .28143 L
.65717 .28135 L
.66725 .28124 L
.67733 .28112 L
.68742 .28097 L
.6975 .28082 L
.70758 .28065 L
.71767 .28049 L
.72775 .28033 L
.73783 .28017 L
.74792 .28003 L
.758 .27999 L
.76808 .27998 L
.77817 .27998 L
.78825 .28 L
.79833 .28001 L
.80842 .28002 L
.8185 .28002 L
.82858 .28001 L
.83867 .27993 L
.84875 .27979 L
.85883 .27963 L
.86892 .27947 L
.879 .27931 L
.88908 .27915 L
.89917 .27899 L
.90925 .27885 L
.91933 .27874 L
.92942 .2787 L
.9395 .27868 L
.94958 .27867 L
.95967 .27867 L
.96975 .27868 L
.97983 .2787 L
.98992 .27873 L
1 .27875 L
F
.8 g
p
P
p
P
.04473 0 m
.04471 .01 L
.04468 .02 L
.04466 .03 L
.04463 .04 L
.0446 .05 L
.04458 .06 L
.04455 .07 L
.04452 .08 L
.04449 .09 L
.04446 .1 L
.04443 .11 L
.0444 .12 L
.04437 .13 L
.04434 .14 L
.04431 .15 L
.04428 .16 L
.04425 .17 L
.04422 .18 L
.04419 .19 L
.04415 .2 L
.04412 .21 L
.04409 .22 L
.04406 .23 L
.04403 .24 L
.04399 .25 L
.04396 .26 L
.04393 .27 L
.04389 .28 L
.04386 .29 L
.04383 .3 L
.04379 .31 L
.04376 .32 L
.04373 .33 L
.04369 .34 L
.04366 .35 L
.04362 .36 L
.04359 .37 L
.04356 .38 L
.04352 .39 L
.04349 .4 L
.04346 .41 L
.04342 .42 L
.04339 .43 L
.04336 .44 L
.04333 .45 L
.04329 .46 L
.04326 .47 L
.04323 .48 L
.0432 .49 L
.04317 .5 L
.04314 .51 L
.04311 .52 L
.04308 .53 L
.04305 .54 L
.04302 .55 L
.04299 .56 L
.04296 .57 L
.04293 .58 L
.04291 .59 L
.04288 .6 L
.04285 .61 L
.04282 .62 L
.04279 .63 L
.04276 .64 L
.04274 .65 L
.04271 .66 L
.04268 .67 L
.04265 .68 L
.04263 .69 L
.0426 .7 L
.04257 .71 L
.04255 .72 L
.04252 .73 L
.04249 .74 L
.04247 .75 L
.04244 .76 L
.04242 .77 L
.04239 .78 L
.04237 .79 L
.04234 .8 L
.04232 .81 L
.0423 .82 L
.04227 .83 L
.04225 .84 L
.04222 .85 L
.0422 .86 L
.04218 .87 L
.04215 .88 L
.04213 .89 L
.04211 .9 L
.04209 .91 L
.04206 .92 L
.04204 .93 L
.04202 .94 L
.042 .95 L
.04197 .96 L
.04195 .97 L
.04193 .98 L
.04191 .99 L
.04189 1 L
0 1 L
0 0 L
F
p
P
.0458 1 m
.04586 .98993 L
.04591 .97986 L
.04595 .96979 L
.046 .95972 L
.04605 .94965 L
.04611 .93958 L
.04617 .92951 L
.04624 .91944 L
.04632 .90937 L
.0464 .89931 L
.0465 .88924 L
.0466 .87917 L
.04672 .8691 L
.04685 .85903 L
.04699 .84896 L
.04714 .83889 L
.04731 .82882 L
.0475 .81875 L
.0475 .81875 L
.05753 .81938 L
.06755 .82007 L
.07758 .82081 L
.08761 .82159 L
.09763 .82241 L
.10766 .82327 L
.11768 .82415 L
.12771 .82507 L
.13774 .826 L
.14776 .82694 L
.15779 .8279 L
.16782 .82886 L
.17784 .82978 L
.18787 .83071 L
.19789 .83163 L
.20792 .83254 L
.21795 .83344 L
.22797 .83434 L
.238 .83522 L
.24803 .83608 L
.25805 .83689 L
.26808 .83767 L
.27811 .83844 L
.28813 .83919 L
.29816 .83993 L
.30818 .84067 L
.31821 .8414 L
.32824 .84213 L
.33826 .84287 L
.34829 .84362 L
.35832 .84437 L
.36834 .84513 L
.37837 .84588 L
.38839 .84663 L
.39842 .84738 L
.40845 .84813 L
.41847 .84889 L
.4285 .84967 L
.43853 .85044 L
.44855 .85121 L
.45858 .85197 L
.46861 .85272 L
.47863 .85347 L
.48866 .8542 L
.49868 .85491 L
.50871 .85556 L
.51874 .85619 L
.52876 .8568 L
.53879 .85741 L
.54882 .858 L
.55884 .85859 L
.56887 .85917 L
.57889 .85974 L
.58892 .86035 L
.59895 .86097 L
.60897 .8616 L
.619 .86221 L
.62903 .86282 L
.63905 .86342 L
.64908 .86401 L
.65911 .86458 L
.66913 .86512 L
.67916 .86561 L
.68918 .86608 L
.69921 .86654 L
.70924 .86699 L
.71926 .86743 L
.72929 .86787 L
.73932 .8683 L
.74934 .86872 L
.75937 .86917 L
.76939 .86962 L
.77942 .87007 L
.78945 .87053 L
.79947 .87098 L
.8095 .87143 L
.81953 .87188 L
.82955 .87233 L
.83958 .87278 L
.84961 .87323 L
.85963 .87368 L
.86966 .87413 L
.87968 .87459 L
.88971 .87504 L
.89974 .87549 L
.90976 .87594 L
.91979 .8764 L
.92982 .87687 L
.93984 .87735 L
.94987 .87781 L
.95989 .87827 L
.96992 .87873 L
.97995 .87916 L
.98997 .87959 L
1 .88 L
1 1 L
F
.0475 0 m
.0475 .81875 L
.0475 .81875 L
.05745 .81602 L
.06739 .81358 L
.07734 .81132 L
.08729 .80911 L
.09724 .80687 L
.10718 .80463 L
.11713 .80239 L
.12708 .80004 L
.13703 .7981 L
.14697 .79696 L
.14697 .79696 L
.14702 .787 L
.14707 .77704 L
.14713 .76707 L
.14718 .75711 L
.14723 .74715 L
.14728 .73719 L
.14733 .72723 L
.14738 .71726 L
.14743 .7073 L
.14748 .69734 L
.14753 .68738 L
.14758 .67742 L
.14763 .66745 L
.14768 .65749 L
.14773 .64753 L
.14778 .63757 L
.14783 .62761 L
.14788 .61764 L
.14793 .60768 L
.14798 .59772 L
.14803 .58776 L
.14808 .5778 L
.14812 .56783 L
.14817 .55787 L
.14822 .54791 L
.14827 .53795 L
.14832 .52799 L
.14837 .51802 L
.14841 .50806 L
.14846 .4981 L
.14851 .48814 L
.14856 .47818 L
.14861 .46821 L
.14865 .45825 L
.1487 .44829 L
.14875 .43833 L
.1488 .42837 L
.14884 .4184 L
.14889 .40844 L
.14894 .39848 L
.14899 .38852 L
.14903 .37856 L
.14908 .36859 L
.14913 .35863 L
.14917 .34867 L
.14922 .33871 L
.14926 .32875 L
.14931 .31878 L
.14936 .30882 L
.1494 .29886 L
.14945 .2889 L
.14949 .27894 L
.14954 .26897 L
.14959 .25901 L
.14963 .24905 L
.14968 .23909 L
.14972 .22913 L
.14977 .21916 L
.14981 .2092 L
.14986 .19924 L
.1499 .18928 L
.14995 .17932 L
.14999 .16935 L
.15004 .15939 L
.15008 .14943 L
.15013 .13947 L
.15017 .12951 L
.15021 .11954 L
.15026 .10958 L
.1503 .09962 L
.15035 .08966 L
.15039 .0797 L
.15043 .06973 L
.15048 .05977 L
.15052 .04981 L
.15057 .03985 L
.15061 .02989 L
.15065 .01992 L
.1507 .00996 L
.15074 0 L
F
.1586 0 m
.15854 .00997 L
.15848 .01995 L
.15842 .02992 L
.15836 .03989 L
.15829 .04987 L
.15823 .05984 L
.15817 .06981 L
.1581 .07979 L
.15803 .08976 L
.15797 .09973 L
.1579 .1097 L
.15783 .11968 L
.15776 .12965 L
.15769 .13962 L
.15761 .1496 L
.15754 .15957 L
.15747 .16954 L
.15739 .17952 L
.15731 .18949 L
.15724 .19946 L
.15716 .20944 L
.15708 .21941 L
.157 .22938 L
.15691 .23936 L
.15683 .24933 L
.15675 .2593 L
.15666 .26928 L
.15657 .27925 L
.15649 .28922 L
.1564 .29919 L
.15631 .30917 L
.15621 .31914 L
.15612 .32911 L
.15603 .33909 L
.15593 .34906 L
.15583 .35903 L
.15574 .36901 L
.15564 .37898 L
.15554 .38895 L
.15544 .39893 L
.15533 .4089 L
.15523 .41887 L
.15512 .42885 L
.15501 .43882 L
.15491 .44879 L
.1548 .45877 L
.15469 .46874 L
.15457 .47871 L
.15446 .48868 L
.15434 .49866 L
.15423 .50863 L
.15411 .5186 L
.15399 .52858 L
.15399 .52858 L
.16407 .52569 L
.17414 .52311 L
.18422 .52078 L
.1943 .51869 L
.20437 .51681 L
.21445 .5151 L
.22452 .51353 L
.2346 .51207 L
.24468 .5107 L
.25475 .50922 L
.26483 .50759 L
.27491 .506 L
.28498 .50445 L
.29506 .50293 L
.30514 .50145 L
.31521 .50001 L
.32529 .4986 L
.33537 .49724 L
.34544 .49598 L
.35552 .49475 L
.3656 .49355 L
.37567 .49235 L
.38575 .49117 L
.39583 .48998 L
.4059 .48879 L
.41598 .48758 L
.42605 .48636 L
.43613 .48511 L
.44621 .48382 L
.45628 .48249 L
.46636 .48112 L
.47644 .47969 L
.48651 .4782 L
.49659 .47664 L
.50667 .475 L
.50667 .475 L
.50591 .4651 L
.50522 .45521 L
.50459 .44531 L
.50402 .43542 L
.50351 .42552 L
.50306 .41563 L
.50265 .40573 L
.50229 .39583 L
.50197 .38594 L
.50169 .37604 L
.50145 .36615 L
.50124 .35625 L
.50105 .34635 L
.5009 .33646 L
.50076 .32656 L
.50064 .31667 L
.50053 .30677 L
.50043 .29688 L
.50034 .28698 L
.50025 .27708 L
.50017 .26719 L
.50007 .25729 L
.49993 .2474 L
.49966 .2375 L
.49938 .2276 L
.4991 .21771 L
.49881 .20781 L
.49853 .19792 L
.49824 .18802 L
.49797 .17813 L
.4977 .16823 L
.49744 .15833 L
.49719 .14844 L
.49696 .13854 L
.49674 .12865 L
.49655 .11875 L
.49637 .10885 L
.49623 .09896 L
.49611 .08906 L
.49602 .07917 L
.49596 .06927 L
.49593 .05938 L
.49595 .04948 L
.496 .03958 L
.4961 .02969 L
.49624 .01979 L
.49643 .0099 L
.49667 0 L
F
.63 0 m
.62888 .01004 L
.62774 .02009 L
.62657 .03013 L
.6254 .04018 L
.6242 .05022 L
.62299 .06027 L
.62177 .07031 L
.62054 .08036 L
.6193 .0904 L
.61806 .10045 L
.61681 .11049 L
.61556 .12054 L
.6143 .13058 L
.61305 .14063 L
.6118 .15067 L
.61056 .16071 L
.60932 .17076 L
.60809 .1808 L
.60687 .19085 L
.60567 .20089 L
.60447 .21094 L
.6033 .22098 L
.60214 .23103 L
.601 .24107 L
.59988 .25112 L
.59878 .26116 L
.59771 .27121 L
.59667 .28125 L
.59667 .28125 L
.60675 .28138 L
.61683 .28145 L
.62692 .28149 L
.637 .28147 L
.64708 .28143 L
.65717 .28135 L
.66725 .28124 L
.67733 .28112 L
.68742 .28097 L
.6975 .28082 L
.70758 .28065 L
.71767 .28049 L
.72775 .28033 L
.73783 .28017 L
.74792 .28003 L
.758 .27999 L
.76808 .27998 L
.77817 .27998 L
.78825 .28 L
.79833 .28001 L
.80842 .28002 L
.8185 .28002 L
.82858 .28001 L
.83867 .27993 L
.84875 .27979 L
.85883 .27963 L
.86892 .27947 L
.879 .27931 L
.88908 .27915 L
.89917 .27899 L
.90925 .27885 L
.91933 .27874 L
.92942 .2787 L
.9395 .27868 L
.94958 .27867 L
.95967 .27867 L
.96975 .27868 L
.97983 .2787 L
.98992 .27873 L
1 .27875 L
1 0 L
F
1 .3925 m
.99007 .39037 L
.98013 .38826 L
.9702 .38616 L
.96026 .38408 L
.95033 .382 L
.9404 .37993 L
.93046 .37786 L
.92053 .3758 L
.9106 .37371 L
.90066 .3716 L
.89073 .36949 L
.88079 .36739 L
.87086 .3653 L
.86093 .36322 L
.85099 .36115 L
.84106 .35909 L
.83113 .35707 L
.82119 .35513 L
.81126 .35321 L
.80132 .35129 L
.79139 .34937 L
.78146 .34745 L
.77152 .34551 L
.76159 .34356 L
.75165 .34158 L
.74172 .33958 L
.73179 .33754 L
.72185 .33546 L
.71192 .33333 L
.70199 .33115 L
.70199 .33115 L
.70101 .34125 L
.70004 .35135 L
.69906 .36145 L
.69808 .37155 L
.69711 .38164 L
.69613 .39174 L
.69515 .40184 L
.69416 .41194 L
.69318 .42204 L
.69219 .43214 L
.69121 .44223 L
.69022 .45233 L
.68923 .46243 L
.68823 .47253 L
.68724 .48263 L
.68626 .49273 L
.68527 .50283 L
.68428 .51292 L
.68329 .52302 L
.6823 .53312 L
.68131 .54322 L
.68031 .55332 L
.67931 .56342 L
.6783 .57351 L
.6773 .58361 L
.67628 .59371 L
.67527 .60381 L
.67425 .61391 L
.67323 .62401 L
.6722 .6341 L
.67116 .6442 L
.67012 .6543 L
.66908 .6644 L
.66803 .6745 L
.66697 .6846 L
.66591 .69469 L
.66485 .70479 L
.66378 .71489 L
.6627 .72499 L
.66161 .73509 L
.66051 .74519 L
.65941 .75529 L
.6583 .76538 L
.65717 .77548 L
.65604 .78558 L
.6549 .79568 L
.65374 .80578 L
.65374 .80578 L
.66364 .8071 L
.67353 .80838 L
.68342 .80962 L
.69332 .81083 L
.70321 .81201 L
.7131 .81318 L
.723 .81434 L
.73289 .81549 L
.74278 .81665 L
.75267 .81785 L
.76257 .81918 L
.77246 .82051 L
.78235 .82186 L
.79225 .8232 L
.80214 .82455 L
.81203 .82589 L
.82193 .82723 L
.83182 .82855 L
.84171 .82979 L
.8516 .83101 L
.8615 .83221 L
.87139 .8334 L
.88128 .83458 L
.89118 .83575 L
.90107 .83692 L
.91096 .83808 L
.92086 .83926 L
.93075 .84047 L
.94064 .84168 L
.95053 .84288 L
.96043 .84408 L
.97032 .84527 L
.98021 .84644 L
.99011 .8476 L
1 .84875 L
F
.15399 .52858 m
.15383 .53852 L
.15366 .54846 L
.15348 .5584 L
.1533 .56834 L
.15312 .57828 L
.15292 .58822 L
.15273 .59816 L
.15252 .6081 L
.15231 .61804 L
.15209 .62798 L
.15186 .63792 L
.15163 .64786 L
.15138 .6578 L
.15113 .66774 L
.15087 .67768 L
.1506 .68762 L
.15032 .69756 L
.15004 .7075 L
.14975 .71744 L
.14946 .72738 L
.14915 .73732 L
.14883 .74726 L
.14849 .7572 L
.14814 .76714 L
.14777 .77708 L
.14738 .78702 L
.14697 .79696 L
.14697 .79696 L
.15691 .7965 L
.16685 .79625 L
.17678 .79617 L
.18672 .79624 L
.19666 .79644 L
.20659 .79674 L
.21653 .79713 L
.22647 .79758 L
.2364 .79807 L
.24634 .79857 L
.25628 .79887 L
.26621 .79905 L
.27615 .79922 L
.28609 .79937 L
.29602 .79951 L
.30596 .79965 L
.3159 .79978 L
.32583 .79991 L
.33577 .80004 L
.34571 .80019 L
.35564 .80033 L
.36558 .80048 L
.37552 .80063 L
.38545 .80078 L
.39539 .80093 L
.40533 .80108 L
.41526 .80123 L
.4252 .80138 L
.43514 .80153 L
.44507 .80168 L
.45501 .80183 L
.46495 .80197 L
.47488 .80212 L
.48482 .80227 L
.49476 .80242 L
.50469 .80256 L
.51463 .80268 L
.52457 .80281 L
.5345 .80294 L
.54444 .80308 L
.55438 .80323 L
.56431 .8034 L
.57425 .80357 L
.58419 .80377 L
.59412 .80398 L
.60406 .80421 L
.614 .80447 L
.62393 .80475 L
.63387 .80506 L
.64381 .8054 L
.65374 .80578 L
.65374 .80578 L
.64773 .7959 L
.64211 .78603 L
.63685 .77615 L
.63192 .76628 L
.6273 .75641 L
.62289 .74653 L
.61863 .73666 L
.61459 .72678 L
.61075 .71691 L
.6071 .70704 L
.60362 .69716 L
.60029 .68729 L
.59711 .67741 L
.59405 .66754 L
.5911 .65767 L
.58826 .64779 L
.5855 .63792 L
.58274 .62804 L
.57977 .61817 L
.57688 .6083 L
.57408 .59842 L
.57137 .58855 L
.56875 .57867 L
.56623 .5688 L
.56381 .55892 L
.56149 .54905 L
.55928 .53918 L
.55928 .53918 L
.54939 .53783 L
.53951 .53668 L
.52962 .53571 L
.51974 .53491 L
.50985 .53426 L
.49997 .53375 L
.49008 .53335 L
.4802 .53305 L
.47031 .53284 L
.46043 .5327 L
.45054 .53261 L
.44066 .53256 L
.43077 .53254 L
.42089 .53251 L
.411 .53234 L
.40111 .53205 L
.39123 .53175 L
.38134 .53145 L
.37146 .53114 L
.36157 .53083 L
.35169 .53053 L
.3418 .53024 L
.33192 .52997 L
.32203 .52978 L
.31215 .52961 L
.30226 .52945 L
.29238 .52931 L
.28249 .52917 L
.27261 .52904 L
.26272 .52891 L
.25284 .52879 L
.24295 .52836 L
.23307 .52784 L
.22318 .52738 L
.2133 .52701 L
.20341 .52676 L
.19353 .52667 L
.18364 .52678 L
.17376 .52711 L
.16387 .52769 L
.15399 .52858 L
F
.59667 .28125 m
.59232 .29145 L
.58797 .30164 L
.58362 .31184 L
.57922 .32204 L
.57479 .33224 L
.57031 .34243 L
.5658 .35263 L
.56122 .36283 L
.55656 .37303 L
.55185 .38322 L
.5471 .39342 L
.54232 .40362 L
.53762 .41382 L
.53288 .42401 L
.52803 .43421 L
.52302 .44441 L
.51756 .45461 L
.51195 .4648 L
.50667 .475 L
.50667 .475 L
.51625 .4857 L
.52659 .49639 L
.53703 .50709 L
.54703 .51778 L
.55715 .52848 L
.55928 .53918 L
.55928 .53918 L
.5669 .52927 L
.57444 .51936 L
.58188 .50946 L
.58918 .49955 L
.59638 .48965 L
.60346 .47974 L
.61045 .46983 L
.61734 .45993 L
.62413 .45002 L
.63081 .44012 L
.63741 .43021 L
.64398 .42031 L
.65059 .4104 L
.65722 .40049 L
.6638 .39059 L
.67027 .38068 L
.67663 .37078 L
.68296 .36087 L
.68929 .35096 L
.69564 .34106 L
.70199 .33115 L
.70199 .33115 L
.69241 .32649 L
.68284 .321 L
.67326 .31518 L
.66369 .3097 L
.65411 .30501 L
.64454 .30068 L
.63496 .29661 L
.62539 .29266 L
.61582 .28844 L
.60624 .28453 L
.59667 .28125 L
F
.7 g
p
P
p
P
.04473 0 m
.04471 .01 L
.04468 .02 L
.04466 .03 L
.04463 .04 L
.0446 .05 L
.04458 .06 L
.04455 .07 L
.04452 .08 L
.04449 .09 L
.04446 .1 L
.04443 .11 L
.0444 .12 L
.04437 .13 L
.04434 .14 L
.04431 .15 L
.04428 .16 L
.04425 .17 L
.04422 .18 L
.04419 .19 L
.04415 .2 L
.04412 .21 L
.04409 .22 L
.04406 .23 L
.04403 .24 L
.04399 .25 L
.04396 .26 L
.04393 .27 L
.04389 .28 L
.04386 .29 L
.04383 .3 L
.04379 .31 L
.04376 .32 L
.04373 .33 L
.04369 .34 L
.04366 .35 L
.04362 .36 L
.04359 .37 L
.04356 .38 L
.04352 .39 L
.04349 .4 L
.04346 .41 L
.04342 .42 L
.04339 .43 L
.04336 .44 L
.04333 .45 L
.04329 .46 L
.04326 .47 L
.04323 .48 L
.0432 .49 L
.04317 .5 L
.04314 .51 L
.04311 .52 L
.04308 .53 L
.04305 .54 L
.04302 .55 L
.04299 .56 L
.04296 .57 L
.04293 .58 L
.04291 .59 L
.04288 .6 L
.04285 .61 L
.04282 .62 L
.04279 .63 L
.04276 .64 L
.04274 .65 L
.04271 .66 L
.04268 .67 L
.04265 .68 L
.04263 .69 L
.0426 .7 L
.04257 .71 L
.04255 .72 L
.04252 .73 L
.04249 .74 L
.04247 .75 L
.04244 .76 L
.04242 .77 L
.04239 .78 L
.04237 .79 L
.04234 .8 L
.04232 .81 L
.0423 .82 L
.04227 .83 L
.04225 .84 L
.04222 .85 L
.0422 .86 L
.04218 .87 L
.04215 .88 L
.04213 .89 L
.04211 .9 L
.04209 .91 L
.04206 .92 L
.04204 .93 L
.04202 .94 L
.042 .95 L
.04197 .96 L
.04195 .97 L
.04193 .98 L
.04191 .99 L
.04189 1 L
.0458 1 L
.04586 .98993 L
.04591 .97986 L
.04595 .96979 L
.046 .95972 L
.04605 .94965 L
.04611 .93958 L
.04617 .92951 L
.04624 .91944 L
.04632 .90937 L
.0464 .89931 L
.0465 .88924 L
.0466 .87917 L
.04672 .8691 L
.04685 .85903 L
.04699 .84896 L
.04714 .83889 L
.04731 .82882 L
.0475 .81875 L
.0475 .81875 L
.0475 0 L
F
.15074 0 m
.1507 .00996 L
.15065 .01992 L
.15061 .02989 L
.15057 .03985 L
.15052 .04981 L
.15048 .05977 L
.15043 .06973 L
.15039 .0797 L
.15035 .08966 L
.1503 .09962 L
.15026 .10958 L
.15021 .11954 L
.15017 .12951 L
.15013 .13947 L
.15008 .14943 L
.15004 .15939 L
.14999 .16935 L
.14995 .17932 L
.1499 .18928 L
.14986 .19924 L
.14981 .2092 L
.14977 .21916 L
.14972 .22913 L
.14968 .23909 L
.14963 .24905 L
.14959 .25901 L
.14954 .26897 L
.14949 .27894 L
.14945 .2889 L
.1494 .29886 L
.14936 .30882 L
.14931 .31878 L
.14926 .32875 L
.14922 .33871 L
.14917 .34867 L
.14913 .35863 L
.14908 .36859 L
.14903 .37856 L
.14899 .38852 L
.14894 .39848 L
.14889 .40844 L
.14884 .4184 L
.1488 .42837 L
.14875 .43833 L
.1487 .44829 L
.14865 .45825 L
.14861 .46821 L
.14856 .47818 L
.14851 .48814 L
.14846 .4981 L
.14841 .50806 L
.14837 .51802 L
.14832 .52799 L
.14827 .53795 L
.14822 .54791 L
.14817 .55787 L
.14812 .56783 L
.14808 .5778 L
.14803 .58776 L
.14798 .59772 L
.14793 .60768 L
.14788 .61764 L
.14783 .62761 L
.14778 .63757 L
.14773 .64753 L
.14768 .65749 L
.14763 .66745 L
.14758 .67742 L
.14753 .68738 L
.14748 .69734 L
.14743 .7073 L
.14738 .71726 L
.14733 .72723 L
.14728 .73719 L
.14723 .74715 L
.14718 .75711 L
.14713 .76707 L
.14707 .77704 L
.14702 .787 L
.14697 .79696 L
.14697 .79696 L
.14738 .78702 L
.14777 .77708 L
.14814 .76714 L
.14849 .7572 L
.14883 .74726 L
.14915 .73732 L
.14946 .72738 L
.14975 .71744 L
.15004 .7075 L
.15032 .69756 L
.1506 .68762 L
.15087 .67768 L
.15113 .66774 L
.15138 .6578 L
.15163 .64786 L
.15186 .63792 L
.15209 .62798 L
.15231 .61804 L
.15252 .6081 L
.15273 .59816 L
.15292 .58822 L
.15312 .57828 L
.1533 .56834 L
.15348 .5584 L
.15366 .54846 L
.15383 .53852 L
.15399 .52858 L
.15399 .52858 L
.15411 .5186 L
.15423 .50863 L
.15434 .49866 L
.15446 .48868 L
.15457 .47871 L
.15469 .46874 L
.1548 .45877 L
.15491 .44879 L
.15501 .43882 L
.15512 .42885 L
.15523 .41887 L
.15533 .4089 L
.15544 .39893 L
.15554 .38895 L
.15564 .37898 L
.15574 .36901 L
.15583 .35903 L
.15593 .34906 L
.15603 .33909 L
.15612 .32911 L
.15621 .31914 L
.15631 .30917 L
.1564 .29919 L
.15649 .28922 L
.15657 .27925 L
.15666 .26928 L
.15675 .2593 L
.15683 .24933 L
.15691 .23936 L
.157 .22938 L
.15708 .21941 L
.15716 .20944 L
.15724 .19946 L
.15731 .18949 L
.15739 .17952 L
.15747 .16954 L
.15754 .15957 L
.15761 .1496 L
.15769 .13962 L
.15776 .12965 L
.15783 .11968 L
.1579 .1097 L
.15797 .09973 L
.15803 .08976 L
.1581 .07979 L
.15817 .06981 L
.15823 .05984 L
.15829 .04987 L
.15836 .03989 L
.15842 .02992 L
.15848 .01995 L
.15854 .00997 L
.1586 0 L
F
.55928 .53918 m
.56149 .54905 L
.56381 .55892 L
.56623 .5688 L
.56875 .57867 L
.57137 .58855 L
.57408 .59842 L
.57688 .6083 L
.57977 .61817 L
.58274 .62804 L
.5855 .63792 L
.58826 .64779 L
.5911 .65767 L
.59405 .66754 L
.59711 .67741 L
.60029 .68729 L
.60362 .69716 L
.6071 .70704 L
.61075 .71691 L
.61459 .72678 L
.61863 .73666 L
.62289 .74653 L
.6273 .75641 L
.63192 .76628 L
.63685 .77615 L
.64211 .78603 L
.64773 .7959 L
.65374 .80578 L
.65374 .80578 L
.6549 .79568 L
.65604 .78558 L
.65717 .77548 L
.6583 .76538 L
.65941 .75529 L
.66051 .74519 L
.66161 .73509 L
.6627 .72499 L
.66378 .71489 L
.66485 .70479 L
.66591 .69469 L
.66697 .6846 L
.66803 .6745 L
.66908 .6644 L
.67012 .6543 L
.67116 .6442 L
.6722 .6341 L
.67323 .62401 L
.67425 .61391 L
.67527 .60381 L
.67628 .59371 L
.6773 .58361 L
.6783 .57351 L
.67931 .56342 L
.68031 .55332 L
.68131 .54322 L
.6823 .53312 L
.68329 .52302 L
.68428 .51292 L
.68527 .50283 L
.68626 .49273 L
.68724 .48263 L
.68823 .47253 L
.68923 .46243 L
.69022 .45233 L
.69121 .44223 L
.69219 .43214 L
.69318 .42204 L
.69416 .41194 L
.69515 .40184 L
.69613 .39174 L
.69711 .38164 L
.69808 .37155 L
.69906 .36145 L
.70004 .35135 L
.70101 .34125 L
.70199 .33115 L
.70199 .33115 L
.69564 .34106 L
.68929 .35096 L
.68296 .36087 L
.67663 .37078 L
.67027 .38068 L
.6638 .39059 L
.65722 .40049 L
.65059 .4104 L
.64398 .42031 L
.63741 .43021 L
.63081 .44012 L
.62413 .45002 L
.61734 .45993 L
.61045 .46983 L
.60346 .47974 L
.59638 .48965 L
.58918 .49955 L
.58188 .50946 L
.57444 .51936 L
.5669 .52927 L
.55928 .53918 L
F
.49667 0 m
.49643 .0099 L
.49624 .01979 L
.4961 .02969 L
.496 .03958 L
.49595 .04948 L
.49593 .05938 L
.49596 .06927 L
.49602 .07917 L
.49611 .08906 L
.49623 .09896 L
.49637 .10885 L
.49655 .11875 L
.49674 .12865 L
.49696 .13854 L
.49719 .14844 L
.49744 .15833 L
.4977 .16823 L
.49797 .17813 L
.49824 .18802 L
.49853 .19792 L
.49881 .20781 L
.4991 .21771 L
.49938 .2276 L
.49966 .2375 L
.49993 .2474 L
.50007 .25729 L
.50017 .26719 L
.50025 .27708 L
.50034 .28698 L
.50043 .29688 L
.50053 .30677 L
.50064 .31667 L
.50076 .32656 L
.5009 .33646 L
.50105 .34635 L
.50124 .35625 L
.50145 .36615 L
.50169 .37604 L
.50197 .38594 L
.50229 .39583 L
.50265 .40573 L
.50306 .41563 L
.50351 .42552 L
.50402 .43542 L
.50459 .44531 L
.50522 .45521 L
.50591 .4651 L
.50667 .475 L
.50667 .475 L
.51195 .4648 L
.51756 .45461 L
.52302 .44441 L
.52803 .43421 L
.53288 .42401 L
.53762 .41382 L
.54232 .40362 L
.5471 .39342 L
.55185 .38322 L
.55656 .37303 L
.56122 .36283 L
.5658 .35263 L
.57031 .34243 L
.57479 .33224 L
.57922 .32204 L
.58362 .31184 L
.58797 .30164 L
.59232 .29145 L
.59667 .28125 L
.59667 .28125 L
.59771 .27121 L
.59878 .26116 L
.59988 .25112 L
.601 .24107 L
.60214 .23103 L
.6033 .22098 L
.60447 .21094 L
.60567 .20089 L
.60687 .19085 L
.60809 .1808 L
.60932 .17076 L
.61056 .16071 L
.6118 .15067 L
.61305 .14063 L
.6143 .13058 L
.61556 .12054 L
.61681 .11049 L
.61806 .10045 L
.6193 .0904 L
.62054 .08036 L
.62177 .07031 L
.62299 .06027 L
.6242 .05022 L
.6254 .04018 L
.62657 .03013 L
.62774 .02009 L
.62888 .01004 L
.63 0 L
F
.6 g
.5 g
0 g
p
.3 Mabswid
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.0475 .81875 m
.04731 .82882 L
.04714 .83889 L
.04699 .84896 L
.04685 .85903 L
.04672 .8691 L
.0466 .87917 L
.0465 .88924 L
.0464 .89931 L
.04632 .90937 L
.04624 .91944 L
.04617 .92951 L
.04611 .93958 L
.04605 .94965 L
.046 .95972 L
.04595 .96979 L
.04591 .97986 L
.04586 .98993 L
.0458 1 L
s
.04473 0 m
.04471 .01 L
.04468 .02 L
.04466 .03 L
.04463 .04 L
.0446 .05 L
.04458 .06 L
.04455 .07 L
.04452 .08 L
.04449 .09 L
.04446 .1 L
.04443 .11 L
.0444 .12 L
.04437 .13 L
.04434 .14 L
.04431 .15 L
.04428 .16 L
.04425 .17 L
.04422 .18 L
.04419 .19 L
.04415 .2 L
.04412 .21 L
.04409 .22 L
.04406 .23 L
.04403 .24 L
.04399 .25 L
.04396 .26 L
.04393 .27 L
.04389 .28 L
.04386 .29 L
.04383 .3 L
.04379 .31 L
.04376 .32 L
.04373 .33 L
.04369 .34 L
.04366 .35 L
.04362 .36 L
.04359 .37 L
.04356 .38 L
.04352 .39 L
.04349 .4 L
.04346 .41 L
.04342 .42 L
.04339 .43 L
.04336 .44 L
.04333 .45 L
.04329 .46 L
.04326 .47 L
.04323 .48 L
.0432 .49 L
Mistroke
.04317 .5 L
.04314 .51 L
.04311 .52 L
.04308 .53 L
.04305 .54 L
.04302 .55 L
.04299 .56 L
.04296 .57 L
.04293 .58 L
.04291 .59 L
.04288 .6 L
.04285 .61 L
.04282 .62 L
.04279 .63 L
.04276 .64 L
.04274 .65 L
.04271 .66 L
.04268 .67 L
.04265 .68 L
.04263 .69 L
.0426 .7 L
.04257 .71 L
.04255 .72 L
.04252 .73 L
.04249 .74 L
.04247 .75 L
.04244 .76 L
.04242 .77 L
.04239 .78 L
.04237 .79 L
.04234 .8 L
.04232 .81 L
.0423 .82 L
.04227 .83 L
.04225 .84 L
.04222 .85 L
.0422 .86 L
.04218 .87 L
.04215 .88 L
.04213 .89 L
.04211 .9 L
.04209 .91 L
.04206 .92 L
.04204 .93 L
.04202 .94 L
.042 .95 L
.04197 .96 L
.04195 .97 L
.04193 .98 L
.04191 .99 L
Mistroke
.04189 1 L
Mfstroke
.0475 .81875 m
.05753 .81938 L
.06755 .82007 L
.07758 .82081 L
.08761 .82159 L
.09763 .82241 L
.10766 .82327 L
.11768 .82415 L
.12771 .82507 L
.13774 .826 L
.14776 .82694 L
.15779 .8279 L
.16782 .82886 L
.17784 .82978 L
.18787 .83071 L
.19789 .83163 L
.20792 .83254 L
.21795 .83344 L
.22797 .83434 L
.238 .83522 L
.24803 .83608 L
.25805 .83689 L
.26808 .83767 L
.27811 .83844 L
.28813 .83919 L
.29816 .83993 L
.30818 .84067 L
.31821 .8414 L
.32824 .84213 L
.33826 .84287 L
.34829 .84362 L
.35832 .84437 L
.36834 .84513 L
.37837 .84588 L
.38839 .84663 L
.39842 .84738 L
.40845 .84813 L
.41847 .84889 L
.4285 .84967 L
.43853 .85044 L
.44855 .85121 L
.45858 .85197 L
.46861 .85272 L
.47863 .85347 L
.48866 .8542 L
.49868 .85491 L
.50871 .85556 L
.51874 .85619 L
.52876 .8568 L
.53879 .85741 L
Mistroke
.54882 .858 L
.55884 .85859 L
.56887 .85917 L
.57889 .85974 L
.58892 .86035 L
.59895 .86097 L
.60897 .8616 L
.619 .86221 L
.62903 .86282 L
.63905 .86342 L
.64908 .86401 L
.65911 .86458 L
.66913 .86512 L
.67916 .86561 L
.68918 .86608 L
.69921 .86654 L
.70924 .86699 L
.71926 .86743 L
.72929 .86787 L
.73932 .8683 L
.74934 .86872 L
.75937 .86917 L
.76939 .86962 L
.77942 .87007 L
.78945 .87053 L
.79947 .87098 L
.8095 .87143 L
.81953 .87188 L
.82955 .87233 L
.83958 .87278 L
.84961 .87323 L
.85963 .87368 L
.86966 .87413 L
.87968 .87459 L
.88971 .87504 L
.89974 .87549 L
.90976 .87594 L
.91979 .8764 L
.92982 .87687 L
.93984 .87735 L
.94987 .87781 L
.95989 .87827 L
.96992 .87873 L
.97995 .87916 L
.98997 .87959 L
1 .88 L
Mfstroke
.14697 .79696 m
.15691 .7965 L
.16685 .79625 L
.17678 .79617 L
.18672 .79624 L
.19666 .79644 L
.20659 .79674 L
.21653 .79713 L
.22647 .79758 L
.2364 .79807 L
.24634 .79857 L
.25628 .79887 L
.26621 .79905 L
.27615 .79922 L
.28609 .79937 L
.29602 .79951 L
.30596 .79965 L
.3159 .79978 L
.32583 .79991 L
.33577 .80004 L
.34571 .80019 L
.35564 .80033 L
.36558 .80048 L
.37552 .80063 L
.38545 .80078 L
.39539 .80093 L
.40533 .80108 L
.41526 .80123 L
.4252 .80138 L
.43514 .80153 L
.44507 .80168 L
.45501 .80183 L
.46495 .80197 L
.47488 .80212 L
.48482 .80227 L
.49476 .80242 L
.50469 .80256 L
.51463 .80268 L
.52457 .80281 L
.5345 .80294 L
.54444 .80308 L
.55438 .80323 L
.56431 .8034 L
.57425 .80357 L
.58419 .80377 L
.59412 .80398 L
.60406 .80421 L
.614 .80447 L
.62393 .80475 L
.63387 .80506 L
Mistroke
.64381 .8054 L
.65374 .80578 L
Mfstroke
.0475 .81875 m
.05745 .81602 L
.06739 .81358 L
.07734 .81132 L
.08729 .80911 L
.09724 .80687 L
.10718 .80463 L
.11713 .80239 L
.12708 .80004 L
.13703 .7981 L
.14697 .79696 L
s
.0475 0 m
.0475 .81875 L
s
.15399 .52858 m
.16387 .52769 L
.17376 .52711 L
.18364 .52678 L
.19353 .52667 L
.20341 .52676 L
.2133 .52701 L
.22318 .52738 L
.23307 .52784 L
.24295 .52836 L
.25284 .52879 L
.26272 .52891 L
.27261 .52904 L
.28249 .52917 L
.29238 .52931 L
.30226 .52945 L
.31215 .52961 L
.32203 .52978 L
.33192 .52997 L
.3418 .53024 L
.35169 .53053 L
.36157 .53083 L
.37146 .53114 L
.38134 .53145 L
.39123 .53175 L
.40111 .53205 L
.411 .53234 L
.42089 .53251 L
.43077 .53254 L
.44066 .53256 L
.45054 .53261 L
.46043 .5327 L
.47031 .53284 L
.4802 .53305 L
.49008 .53335 L
.49997 .53375 L
.50985 .53426 L
.51974 .53491 L
.52962 .53571 L
.53951 .53668 L
.54939 .53783 L
.55928 .53918 L
s
.15399 .52858 m
.16407 .52569 L
.17414 .52311 L
.18422 .52078 L
.1943 .51869 L
.20437 .51681 L
.21445 .5151 L
.22452 .51353 L
.2346 .51207 L
.24468 .5107 L
.25475 .50922 L
.26483 .50759 L
.27491 .506 L
.28498 .50445 L
.29506 .50293 L
.30514 .50145 L
.31521 .50001 L
.32529 .4986 L
.33537 .49724 L
.34544 .49598 L
.35552 .49475 L
.3656 .49355 L
.37567 .49235 L
.38575 .49117 L
.39583 .48998 L
.4059 .48879 L
.41598 .48758 L
.42605 .48636 L
.43613 .48511 L
.44621 .48382 L
.45628 .48249 L
.46636 .48112 L
.47644 .47969 L
.48651 .4782 L
.49659 .47664 L
.50667 .475 L
s
.15074 0 m
.1507 .00996 L
.15065 .01992 L
.15061 .02989 L
.15057 .03985 L
.15052 .04981 L
.15048 .05977 L
.15043 .06973 L
.15039 .0797 L
.15035 .08966 L
.1503 .09962 L
.15026 .10958 L
.15021 .11954 L
.15017 .12951 L
.15013 .13947 L
.15008 .14943 L
.15004 .15939 L
.14999 .16935 L
.14995 .17932 L
.1499 .18928 L
.14986 .19924 L
.14981 .2092 L
.14977 .21916 L
.14972 .22913 L
.14968 .23909 L
.14963 .24905 L
.14959 .25901 L
.14954 .26897 L
.14949 .27894 L
.14945 .2889 L
.1494 .29886 L
.14936 .30882 L
.14931 .31878 L
.14926 .32875 L
.14922 .33871 L
.14917 .34867 L
.14913 .35863 L
.14908 .36859 L
.14903 .37856 L
.14899 .38852 L
.14894 .39848 L
.14889 .40844 L
.14884 .4184 L
.1488 .42837 L
.14875 .43833 L
.1487 .44829 L
.14865 .45825 L
.14861 .46821 L
.14856 .47818 L
.14851 .48814 L
Mistroke
.14846 .4981 L
.14841 .50806 L
.14837 .51802 L
.14832 .52799 L
.14827 .53795 L
.14822 .54791 L
.14817 .55787 L
.14812 .56783 L
.14808 .5778 L
.14803 .58776 L
.14798 .59772 L
.14793 .60768 L
.14788 .61764 L
.14783 .62761 L
.14778 .63757 L
.14773 .64753 L
.14768 .65749 L
.14763 .66745 L
.14758 .67742 L
.14753 .68738 L
.14748 .69734 L
.14743 .7073 L
.14738 .71726 L
.14733 .72723 L
.14728 .73719 L
.14723 .74715 L
.14718 .75711 L
.14713 .76707 L
.14707 .77704 L
.14702 .787 L
.14697 .79696 L
Mfstroke
.1586 0 m
.15854 .00997 L
.15848 .01995 L
.15842 .02992 L
.15836 .03989 L
.15829 .04987 L
.15823 .05984 L
.15817 .06981 L
.1581 .07979 L
.15803 .08976 L
.15797 .09973 L
.1579 .1097 L
.15783 .11968 L
.15776 .12965 L
.15769 .13962 L
.15761 .1496 L
.15754 .15957 L
.15747 .16954 L
.15739 .17952 L
.15731 .18949 L
.15724 .19946 L
.15716 .20944 L
.15708 .21941 L
.157 .22938 L
.15691 .23936 L
.15683 .24933 L
.15675 .2593 L
.15666 .26928 L
.15657 .27925 L
.15649 .28922 L
.1564 .29919 L
.15631 .30917 L
.15621 .31914 L
.15612 .32911 L
.15603 .33909 L
.15593 .34906 L
.15583 .35903 L
.15574 .36901 L
.15564 .37898 L
.15554 .38895 L
.15544 .39893 L
.15533 .4089 L
.15523 .41887 L
.15512 .42885 L
.15501 .43882 L
.15491 .44879 L
.1548 .45877 L
.15469 .46874 L
.15457 .47871 L
.15446 .48868 L
Mistroke
.15434 .49866 L
.15423 .50863 L
.15411 .5186 L
.15399 .52858 L
Mfstroke
.15399 .52858 m
.15383 .53852 L
.15366 .54846 L
.15348 .5584 L
.1533 .56834 L
.15312 .57828 L
.15292 .58822 L
.15273 .59816 L
.15252 .6081 L
.15231 .61804 L
.15209 .62798 L
.15186 .63792 L
.15163 .64786 L
.15138 .6578 L
.15113 .66774 L
.15087 .67768 L
.1506 .68762 L
.15032 .69756 L
.15004 .7075 L
.14975 .71744 L
.14946 .72738 L
.14915 .73732 L
.14883 .74726 L
.14849 .7572 L
.14814 .76714 L
.14777 .77708 L
.14738 .78702 L
.14697 .79696 L
s
.55928 .53918 m
.56149 .54905 L
.56381 .55892 L
.56623 .5688 L
.56875 .57867 L
.57137 .58855 L
.57408 .59842 L
.57688 .6083 L
.57977 .61817 L
.58274 .62804 L
.5855 .63792 L
.58826 .64779 L
.5911 .65767 L
.59405 .66754 L
.59711 .67741 L
.60029 .68729 L
.60362 .69716 L
.6071 .70704 L
.61075 .71691 L
.61459 .72678 L
.61863 .73666 L
.62289 .74653 L
.6273 .75641 L
.63192 .76628 L
.63685 .77615 L
.64211 .78603 L
.64773 .7959 L
.65374 .80578 L
s
.50667 .475 m
.51625 .4857 L
.52659 .49639 L
.53703 .50709 L
.54703 .51778 L
.55715 .52848 L
.55928 .53918 L
s
.70199 .33115 m
.70101 .34125 L
.70004 .35135 L
.69906 .36145 L
.69808 .37155 L
.69711 .38164 L
.69613 .39174 L
.69515 .40184 L
.69416 .41194 L
.69318 .42204 L
.69219 .43214 L
.69121 .44223 L
.69022 .45233 L
.68923 .46243 L
.68823 .47253 L
.68724 .48263 L
.68626 .49273 L
.68527 .50283 L
.68428 .51292 L
.68329 .52302 L
.6823 .53312 L
.68131 .54322 L
.68031 .55332 L
.67931 .56342 L
.6783 .57351 L
.6773 .58361 L
.67628 .59371 L
.67527 .60381 L
.67425 .61391 L
.67323 .62401 L
.6722 .6341 L
.67116 .6442 L
.67012 .6543 L
.66908 .6644 L
.66803 .6745 L
.66697 .6846 L
.66591 .69469 L
.66485 .70479 L
.66378 .71489 L
.6627 .72499 L
.66161 .73509 L
.66051 .74519 L
.65941 .75529 L
.6583 .76538 L
.65717 .77548 L
.65604 .78558 L
.6549 .79568 L
.65374 .80578 L
s
.70199 .33115 m
.71192 .33333 L
.72185 .33546 L
.73179 .33754 L
.74172 .33958 L
.75165 .34158 L
.76159 .34356 L
.77152 .34551 L
.78146 .34745 L
.79139 .34937 L
.80132 .35129 L
.81126 .35321 L
.82119 .35513 L
.83113 .35707 L
.84106 .35909 L
.85099 .36115 L
.86093 .36322 L
.87086 .3653 L
.88079 .36739 L
.89073 .36949 L
.90066 .3716 L
.9106 .37371 L
.92053 .3758 L
.93046 .37786 L
.9404 .37993 L
.95033 .382 L
.96026 .38408 L
.9702 .38616 L
.98013 .38826 L
.99007 .39037 L
1 .3925 L
s
.59667 .28125 m
.60675 .28138 L
.61683 .28145 L
.62692 .28149 L
.637 .28147 L
.64708 .28143 L
.65717 .28135 L
.66725 .28124 L
.67733 .28112 L
.68742 .28097 L
.6975 .28082 L
.70758 .28065 L
.71767 .28049 L
.72775 .28033 L
.73783 .28017 L
.74792 .28003 L
.758 .27999 L
.76808 .27998 L
.77817 .27998 L
.78825 .28 L
.79833 .28001 L
.80842 .28002 L
.8185 .28002 L
.82858 .28001 L
.83867 .27993 L
.84875 .27979 L
.85883 .27963 L
.86892 .27947 L
.879 .27931 L
.88908 .27915 L
.89917 .27899 L
.90925 .27885 L
.91933 .27874 L
.92942 .2787 L
.9395 .27868 L
.94958 .27867 L
.95967 .27867 L
.96975 .27868 L
.97983 .2787 L
.98992 .27873 L
1 .27875 L
s
.65374 .80578 m
.66364 .8071 L
.67353 .80838 L
.68342 .80962 L
.69332 .81083 L
.70321 .81201 L
.7131 .81318 L
.723 .81434 L
.73289 .81549 L
.74278 .81665 L
.75267 .81785 L
.76257 .81918 L
.77246 .82051 L
.78235 .82186 L
.79225 .8232 L
.80214 .82455 L
.81203 .82589 L
.82193 .82723 L
.83182 .82855 L
.84171 .82979 L
.8516 .83101 L
.8615 .83221 L
.87139 .8334 L
.88128 .83458 L
.89118 .83575 L
.90107 .83692 L
.91096 .83808 L
.92086 .83926 L
.93075 .84047 L
.94064 .84168 L
.95053 .84288 L
.96043 .84408 L
.97032 .84527 L
.98021 .84644 L
.99011 .8476 L
1 .84875 L
s
.70199 .33115 m
.69564 .34106 L
.68929 .35096 L
.68296 .36087 L
.67663 .37078 L
.67027 .38068 L
.6638 .39059 L
.65722 .40049 L
.65059 .4104 L
.64398 .42031 L
.63741 .43021 L
.63081 .44012 L
.62413 .45002 L
.61734 .45993 L
.61045 .46983 L
.60346 .47974 L
.59638 .48965 L
.58918 .49955 L
.58188 .50946 L
.57444 .51936 L
.5669 .52927 L
.55928 .53918 L
s
.59667 .28125 m
.59232 .29145 L
.58797 .30164 L
.58362 .31184 L
.57922 .32204 L
.57479 .33224 L
.57031 .34243 L
.5658 .35263 L
.56122 .36283 L
.55656 .37303 L
.55185 .38322 L
.5471 .39342 L
.54232 .40362 L
.53762 .41382 L
.53288 .42401 L
.52803 .43421 L
.52302 .44441 L
.51756 .45461 L
.51195 .4648 L
.50667 .475 L
s
.59667 .28125 m
.60624 .28453 L
.61582 .28844 L
.62539 .29266 L
.63496 .29661 L
.64454 .30068 L
.65411 .30501 L
.66369 .3097 L
.67326 .31518 L
.68284 .321 L
.69241 .32649 L
.70199 .33115 L
s
.49667 0 m
.49643 .0099 L
.49624 .01979 L
.4961 .02969 L
.496 .03958 L
.49595 .04948 L
.49593 .05938 L
.49596 .06927 L
.49602 .07917 L
.49611 .08906 L
.49623 .09896 L
.49637 .10885 L
.49655 .11875 L
.49674 .12865 L
.49696 .13854 L
.49719 .14844 L
.49744 .15833 L
.4977 .16823 L
.49797 .17813 L
.49824 .18802 L
.49853 .19792 L
.49881 .20781 L
.4991 .21771 L
.49938 .2276 L
.49966 .2375 L
.49993 .2474 L
.50007 .25729 L
.50017 .26719 L
.50025 .27708 L
.50034 .28698 L
.50043 .29688 L
.50053 .30677 L
.50064 .31667 L
.50076 .32656 L
.5009 .33646 L
.50105 .34635 L
.50124 .35625 L
.50145 .36615 L
.50169 .37604 L
.50197 .38594 L
.50229 .39583 L
.50265 .40573 L
.50306 .41563 L
.50351 .42552 L
.50402 .43542 L
.50459 .44531 L
.50522 .45521 L
.50591 .4651 L
.50667 .475 L
s
.63 0 m
.62888 .01004 L
.62774 .02009 L
.62657 .03013 L
.6254 .04018 L
.6242 .05022 L
.62299 .06027 L
.62177 .07031 L
.62054 .08036 L
.6193 .0904 L
.61806 .10045 L
.61681 .11049 L
.61556 .12054 L
.6143 .13058 L
.61305 .14063 L
.6118 .15067 L
.61056 .16071 L
.60932 .17076 L
.60809 .1808 L
.60687 .19085 L
.60567 .20089 L
.60447 .21094 L
.6033 .22098 L
.60214 .23103 L
.601 .24107 L
.59988 .25112 L
.59878 .26116 L
.59771 .27121 L
.59667 .28125 L
s
s
s
P
p
.3 Mabswid
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
[ .02 .01 ] 0 setdash
.3 Mabswid
s
s
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["T - x (H2O)  5 kbar", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ox and als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["points data ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
i1={0.7320, 661.6};
i2={0.7260, 683.4};
i3={0.5760, 684.7};
i4={0.5670, 723.9};
i5={0.4520, 734.8};
i6={0.3000, 735.7};
i7={0.1070, 705.3};
i8={0.6850, 738.7};
i9={0.1490, 766.0};
i10={0.1125, 741.6};
i11={0.1165, 775.0};
i12={0.0505, 816.3};
i13={0.6279, 894.2};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["crossover[u34, u35]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
crossover[u34, u35]\
\>", "\<\
crossover[u34, u35]\
\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{0.6279, 894.2}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.6279, 894.2}\
\>", "\<\
{0.6279, 894.2}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{0.0505, 816.3}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.0505, 816.3}\
\>", "\<\
{0.0505, 816.3}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (1-30)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  pl bi mu sill H2O (liq)  *) 

u1={{0.7400, 5.00, 661.6},
{0.7600, 5.00, 661.6},
{0.7800, 5.00, 661.6},
{0.8000, 5.00, 661.6},
{0.8200, 5.00, 661.6},
{0.8400, 5.00, 661.6},
{0.8600, 5.00, 661.6},
{0.8800, 5.00, 661.6},
{0.9000, 5.00, 661.6},
{0.9200, 5.00, 661.6},
{0.9400, 5.00, 661.6},
{0.9600, 5.00, 661.6},
{0.9800, 5.00, 661.6},
{1.0000, 5.00, 661.6}};

(*------------------------------*)
(*  liq pl bi mu sill (H2O)  *) 

u2={{0.7400, 5.00, 661.8},
{0.7600, 5.00, 662.2},
{0.7800, 5.00, 662.7},
{0.8000, 5.00, 663.2},
{0.8200, 5.00, 663.8},
{0.8400, 5.00, 664.4},
{0.8600, 5.00, 665.0},
{0.8800, 5.00, 665.8},
{0.9000, 5.00, 666.5},
{0.9200, 5.00, 667.4},
{0.9400, 5.00, 668.2},
{0.9600, 5.00, 669.2},
{0.9800, 5.00, 670.2},
{1.0000, 5.00, 671.3}};

(*------------------------------*)
(*  liq pl bi mu sill (ksp)  *) 

u3={{0.7400, 5.00, 683.5},
{0.7600, 5.00, 683.8},
{0.7800, 5.00, 684.0},
{0.8000, 5.00, 684.3},
{0.8200, 5.00, 684.6},
{0.8400, 5.00, 684.9},
{0.8600, 5.00, 685.3},
{0.8800, 5.00, 685.7},
{0.9000, 5.00, 686.1},
{0.9200, 5.00, 686.6},
{0.9400, 5.00, 687.1},
{0.9600, 5.00, 687.6},
{0.9800, 5.00, 688.2},
{1.0000, 5.00, 688.8}};

(*------------------------------*)
(*  liq ksp pl bi sill (mu)  *) 

u4={{0.5800, 5.00, 684.7},
{0.6000, 5.00, 684.9},
{0.6200, 5.00, 685.0},
{0.6400, 5.00, 685.2},
{0.6600, 5.00, 685.4},
{0.6800, 5.00, 685.6},
{0.7000, 5.00, 685.8},
{0.7200, 5.00, 686.0},
{0.7400, 5.00, 686.2},
{0.7600, 5.00, 686.5},
{0.7800, 5.00, 686.7},
{0.8000, 5.00, 687.0},
{0.8200, 5.00, 687.2},
{0.8400, 5.00, 687.5},
{0.8600, 5.00, 687.8},
{0.8800, 5.00, 688.1},
{0.9000, 5.00, 688.4},
{0.9200, 5.00, 688.7},
{0.9400, 5.00, 689.1},
{0.9600, 5.00, 689.4},
{0.9800, 5.00, 689.8},
{1.0000, 5.00, 690.1}};

(*------------------------------*)
(*  pl bi mu sill (H2O)  *) 

u5={{0.7100, 5.00, 720.4},
{0.7125, 5.00, 718.3},
{0.7150, 5.00, 715.5},
{0.7175, 5.00, 712.0},
{0.7200, 5.00, 707.6},
{0.7225, 5.00, 701.9},
{0.7250, 5.00, 694.6},
{0.7275, 5.00, 684.9},
{0.7300, 5.00, 671.8},
{0.7325, 5.00, 653.2},
{0.7350, 5.00, 624.0}};

(*------------------------------*)
(*  pl bi mu sill (liq)  *) 

u6={{0.7200, 5.00, 691.7},
{0.7210, 5.00, 690.5},
{0.7220, 5.00, 689.2},
{0.7230, 5.00, 687.6},
{0.7240, 5.00, 685.9},
{0.7250, 5.00, 684.0},
{0.7260, 5.00, 681.8},
{0.7270, 5.00, 679.3},
{0.7280, 5.00, 676.3},
{0.7290, 5.00, 672.9},
{0.7300, 5.00, 669.0},
{0.7310, 5.00, 664.2},
{0.7320, 5.00, 658.6},
{0.7330, 5.00, 651.7},
{0.7340, 5.00, 643.1},
{0.7350, 5.00, 632.0},
{0.7360, 5.00, 617.1},
{0.7370, 5.00, 595.5}};

(*------------------------------*)
(*  ksp pl bi mu sill (liq)  *) 

u7={{0.5800, 5.00, 684.6},
{0.6000, 5.00, 684.4},
{0.6200, 5.00, 684.3},
{0.6400, 5.00, 684.1},
{0.6600, 5.00, 683.9},
{0.6800, 5.00, 683.7},
{0.7000, 5.00, 683.6},
{0.7200, 5.00, 683.4}};

(*------------------------------*)
(*  pl bi mu sill (ksp)  *) 

u8={{0.7000, 5.00, 961.0},
{0.7020, 5.00, 946.4},
{0.7040, 5.00, 931.0},
{0.7060, 5.00, 914.8},
{0.7080, 5.00, 897.5},
{0.7100, 5.00, 879.0},
{0.7120, 5.00, 859.4},
{0.7140, 5.00, 838.4},
{0.7160, 5.00, 815.9},
{0.7180, 5.00, 791.6},
{0.7200, 5.00, 765.4},
{0.7220, 5.00, 736.8},
{0.7240, 5.00, 705.5},
{0.7260, 5.00, 670.8},
{0.7280, 5.00, 632.1},
{0.7300, 5.00, 588.0}};

(*------------------------------*)
(*  liq ksp pl bi sill (g)  *) 

u9={{0.5800, 5.00, 724.0},
{0.6000, 5.00, 724.1},
{0.6200, 5.00, 724.3},
{0.6400, 5.00, 724.4},
{0.6600, 5.00, 724.5},
{0.6800, 5.00, 724.7},
{0.7000, 5.00, 724.9},
{0.7200, 5.00, 725.0},
{0.7400, 5.00, 725.2},
{0.7600, 5.00, 725.4},
{0.7800, 5.00, 725.6},
{0.8000, 5.00, 725.8},
{0.8200, 5.00, 726.0},
{0.8400, 5.00, 726.2},
{0.8600, 5.00, 726.4},
{0.8800, 5.00, 726.6},
{0.9000, 5.00, 726.9},
{0.9200, 5.00, 727.1},
{0.9400, 5.00, 727.3},
{0.9600, 5.00, 727.6},
{0.9800, 5.00, 727.8},
{1.0000, 5.00, 728.1}};

(*------------------------------*)
(*  liq ksp pl bi g sill (cd)  *) 

u10={{0.4600, 5.00, 734.8},
{0.4800, 5.00, 734.9},
{0.5000, 5.00, 735.0},
{0.5200, 5.00, 735.2},
{0.5400, 5.00, 735.3},
{0.5600, 5.00, 735.5},
{0.5800, 5.00, 735.6},
{0.6000, 5.00, 735.8},
{0.6200, 5.00, 735.9},
{0.6400, 5.00, 736.1},
{0.6600, 5.00, 736.3},
{0.6800, 5.00, 736.5},
{0.7000, 5.00, 736.7},
{0.7200, 5.00, 736.9},
{0.7400, 5.00, 737.1},
{0.7600, 5.00, 737.3},
{0.7800, 5.00, 737.5},
{0.8000, 5.00, 737.7},
{0.8200, 5.00, 737.9},
{0.8400, 5.00, 738.2},
{0.8600, 5.00, 738.4},
{0.8800, 5.00, 738.6},
{0.9000, 5.00, 738.9},
{0.9200, 5.00, 739.1},
{0.9400, 5.00, 739.3},
{0.9600, 5.00, 739.6},
{0.9800, 5.00, 739.8},
{1.0000, 5.00, 740.0}};

(*------------------------------*)
(*  ksp pl bi sill (mu)  *) 

u11={{0.5762, 5.00, 600.0},
{0.5762, 5.00, 610.0},
{0.5762, 5.00, 620.0},
{0.5762, 5.00, 630.0},
{0.5762, 5.00, 640.0},
{0.5762, 5.00, 650.0},
{0.5762, 5.00, 660.0},
{0.5762, 5.00, 670.0},
{0.5762, 5.00, 680.0},
{0.5762, 5.00, 690.0},
{0.5762, 5.00, 700.0}};

(*------------------------------*)
(*  ksp pl bi sill (liq)  *) 

u12={{0.5550, 5.00, 774.9},
{0.5600, 5.00, 752.1},
{0.5650, 5.00, 729.4},
{0.5700, 5.00, 707.1},
{0.5750, 5.00, 685.6},
{0.5800, 5.00, 665.5},
{0.5850, 5.00, 646.4},
{0.5900, 5.00, 627.9},
{0.5950, 5.00, 610.1}};

(*------------------------------*)
(*  ksp pl bi g sill (liq)  *) 

u13={{0.4000, 5.00, 740.3},
{0.4100, 5.00, 739.1},
{0.4200, 5.00, 738.0},
{0.4300, 5.00, 736.9},
{0.4400, 5.00, 735.8},
{0.4500, 5.00, 734.8},
{0.4600, 5.00, 733.7},
{0.4700, 5.00, 732.7},
{0.4800, 5.00, 731.7},
{0.4900, 5.00, 730.7},
{0.5000, 5.00, 729.8},
{0.5100, 5.00, 728.8},
{0.5200, 5.00, 727.9},
{0.5300, 5.00, 727.0},
{0.5400, 5.00, 726.2},
{0.5500, 5.00, 725.3},
{0.5600, 5.00, 724.4}};

(*------------------------------*)
(*  ksp pl bi sill (g)  *) 

u14={{0.5600, 5.00, 1077.8},
{0.5620, 5.00, 925.2},
{0.5640, 5.00, 814.2},
{0.5660, 5.00, 731.5},
{0.5680, 5.00, 670.8},
{0.5700, 5.00, 629.5},
{0.5720, 5.00, 596.7}};

(*------------------------------*)
(*  ksp pl bi cd g sill (liq)  *) 

u15={{0.3000, 5.00, 735.7},
{0.3200, 5.00, 735.6},
{0.3400, 5.00, 735.5},
{0.3600, 5.00, 735.3},
{0.3800, 5.00, 735.2},
{0.4000, 5.00, 735.1},
{0.4200, 5.00, 734.9},
{0.4400, 5.00, 734.8}};

(*------------------------------*)
(*  ksp pl bi g sill (cd)  *) 

u16={{0.0000, 5.00, 644.3},
{0.0200, 5.00, 650.6},
{0.0400, 5.00, 656.8},
{0.0600, 5.00, 662.8},
{0.0800, 5.00, 668.5},
{0.1000, 5.00, 674.0},
{0.1200, 5.00, 679.2},
{0.1400, 5.00, 684.3},
{0.1600, 5.00, 689.0},
{0.1800, 5.00, 693.5},
{0.2000, 5.00, 697.8},
{0.2200, 5.00, 701.9},
{0.2400, 5.00, 705.7},
{0.2600, 5.00, 709.3},
{0.2800, 5.00, 712.6},
{0.3000, 5.00, 715.8},
{0.3200, 5.00, 718.8},
{0.3400, 5.00, 721.6},
{0.3600, 5.00, 724.3},
{0.3800, 5.00, 726.8},
{0.4000, 5.00, 729.2},
{0.4200, 5.00, 731.5},
{0.4400, 5.00, 733.7},
{0.4600, 5.00, 735.7},
{0.4800, 5.00, 737.7},
{0.5000, 5.00, 739.7}};

(*------------------------------*)
(*  ksp pl bi cd g (sill)  *) 

u17={{0.1200, 5.00, 707.9},
{0.1400, 5.00, 711.8},
{0.1600, 5.00, 715.5},
{0.1800, 5.00, 719.0},
{0.2000, 5.00, 722.3},
{0.2200, 5.00, 725.4},
{0.2400, 5.00, 728.4},
{0.2600, 5.00, 731.2},
{0.2800, 5.00, 733.9},
{0.3000, 5.00, 736.5},
{0.3200, 5.00, 738.9},
{0.3400, 5.00, 741.2},
{0.3600, 5.00, 743.4},
{0.3800, 5.00, 745.6},
{0.4000, 5.00, 747.6}};

(*------------------------------*)
(*  ksp pl cd g sill (bi)  *) 

u18={{0.0000, 5.00, 644.3},
{0.0200, 5.00, 663.1},
{0.0400, 5.00, 676.3},
{0.0600, 5.00, 686.6},
{0.0800, 5.00, 695.3},
{0.1000, 5.00, 703.0}};

(*------------------------------*)
(*  ksp pl cd g (sill)  *) 

u19={{0.0550, 5.00, 808.4},
{0.0600, 5.00, 799.3},
{0.0800, 5.00, 760.6},
{0.1000, 5.00, 717.9},
{0.1200, 5.00, 670.3},
{0.1400, 5.00, 617.2}};

(*------------------------------*)
(*  ksp pl cd g (bi)  *) 

u20={{0.0750, 5.00, 585.9},
{0.0800, 5.00, 601.9},
{0.0850, 5.00, 618.9},
{0.0900, 5.00, 637.1},
{0.0950, 5.00, 656.6},
{0.1000, 5.00, 678.0},
{0.1050, 5.00, 701.8},
{0.1100, 5.00, 728.3},
{0.1120, 5.00, 739.7}};

(*------------------------------*)
(*  liq ksp bi cd g sill (pl)  *) 

u21={{0.7000, 5.00, 738.8},
{0.7200, 5.00, 738.9},
{0.7400, 5.00, 739.0},
{0.7600, 5.00, 739.1},
{0.7800, 5.00, 739.2},
{0.8000, 5.00, 739.3},
{0.8200, 5.00, 739.4},
{0.8400, 5.00, 739.6},
{0.8600, 5.00, 739.7},
{0.8800, 5.00, 739.8},
{0.9000, 5.00, 739.9},
{0.9200, 5.00, 740.0},
{0.9400, 5.00, 740.2},
{0.9600, 5.00, 740.3},
{0.9800, 5.00, 740.4},
{1.0000, 5.00, 740.5}};

(*------------------------------*)
(*  liq ksp pl bi cd g (sill)  *) 

u22={{0.3000, 5.00, 735.8},
{0.3200, 5.00, 735.9},
{0.3400, 5.00, 736.0},
{0.3600, 5.00, 736.2},
{0.3800, 5.00, 736.3},
{0.4000, 5.00, 736.4},
{0.4200, 5.00, 736.6},
{0.4400, 5.00, 736.7},
{0.4600, 5.00, 736.8},
{0.4800, 5.00, 737.0},
{0.5000, 5.00, 737.1},
{0.5200, 5.00, 737.3},
{0.5400, 5.00, 737.5},
{0.5600, 5.00, 737.6},
{0.5800, 5.00, 737.8},
{0.6000, 5.00, 738.0},
{0.6200, 5.00, 738.1},
{0.6400, 5.00, 738.3},
{0.6600, 5.00, 738.5},
{0.6800, 5.00, 738.7}};

(*------------------------------*)
(*  ksp pl bi cd g (liq)  *) 

u23={{0.1600, 5.00, 763.5},
{0.1800, 5.00, 758.8},
{0.2000, 5.00, 754.3},
{0.2200, 5.00, 750.0},
{0.2400, 5.00, 745.8},
{0.2600, 5.00, 741.9},
{0.2800, 5.00, 738.2},
{0.3000, 5.00, 734.8},
{0.3200, 5.00, 731.6},
{0.3400, 5.00, 728.6},
{0.3600, 5.00, 725.8},
{0.3800, 5.00, 723.3},
{0.4000, 5.00, 720.9}};

(*------------------------------*)
(*  ksp bi cd g (pl)  *) 

u24={{0.1200, 5.00, 746.5},
{0.1300, 5.00, 753.1},
{0.1400, 5.00, 760.0},
{0.1500, 5.00, 767.1},
{0.1600, 5.00, 774.5},
{0.1700, 5.00, 782.2},
{0.1800, 5.00, 790.1},
{0.1900, 5.00, 798.3},
{0.2000, 5.00, 806.9}};

(*------------------------------*)
(*  ksp cd g (bi)  *) 

u25={{0.0800, 5.00, 585.4},
{0.0900, 5.00, 621.3},
{0.1000, 5.00, 665.4},
{0.1100, 5.00, 724.7},
{0.1200, 5.00, 809.6},
{0.1300, 5.00, 951.7}};

(*------------------------------*)
(*  ksp cd g (pl)  *) 

u26={{0.0000, 5.00, 860.0},
{0.0100, 5.00, 852.4},
{0.0200, 5.00, 844.3},
{0.0300, 5.00, 835.7},
{0.0400, 5.00, 826.6},
{0.0500, 5.00, 816.9},
{0.0600, 5.00, 806.5},
{0.0700, 5.00, 795.6},
{0.0800, 5.00, 783.9},
{0.0900, 5.00, 771.6},
{0.1000, 5.00, 758.5},
{0.1100, 5.00, 744.8},
{0.1200, 5.00, 730.3},
{0.1300, 5.00, 715.2},
{0.1400, 5.00, 699.6},
{0.1500, 5.00, 683.4},
{0.1600, 5.00, 666.8},
{0.1700, 5.00, 649.7},
{0.1800, 5.00, 632.1},
{0.1900, 5.00, 613.6},
{0.2000, 5.00, 593.6}};

(*------------------------------*)
(*  liq ksp bi cd g (pl)  *) 

u27={{0.1600, 5.00, 765.5},
{0.1800, 5.00, 764.4},
{0.2000, 5.00, 763.3},
{0.2200, 5.00, 762.1},
{0.2400, 5.00, 761.0},
{0.2600, 5.00, 759.9},
{0.2800, 5.00, 758.8},
{0.3000, 5.00, 757.7},
{0.3200, 5.00, 756.6},
{0.3400, 5.00, 755.5},
{0.3600, 5.00, 754.4},
{0.3800, 5.00, 753.3},
{0.4000, 5.00, 752.2},
{0.4200, 5.00, 751.2},
{0.4400, 5.00, 750.1},
{0.4600, 5.00, 749.1},
{0.4800, 5.00, 748.1},
{0.5000, 5.00, 747.1},
{0.5200, 5.00, 746.1},
{0.5400, 5.00, 745.1},
{0.5600, 5.00, 744.2},
{0.5800, 5.00, 743.3},
{0.6000, 5.00, 742.4},
{0.6200, 5.00, 741.5},
{0.6400, 5.00, 740.6},
{0.6600, 5.00, 739.8},
{0.6800, 5.00, 739.0},
{0.7000, 5.00, 738.2}};

(*------------------------------*)
(*  liq ksp bi cd g (sill)  *) 

u28={{0.6000, 5.00, 737.2},
{0.6200, 5.00, 737.6},
{0.6400, 5.00, 737.9},
{0.6600, 5.00, 738.3},
{0.6800, 5.00, 738.6},
{0.7000, 5.00, 739.0},
{0.7200, 5.00, 739.3},
{0.7400, 5.00, 739.7},
{0.7600, 5.00, 740.1},
{0.7800, 5.00, 740.4},
{0.8000, 5.00, 740.8},
{0.8200, 5.00, 741.1},
{0.8400, 5.00, 741.5},
{0.8600, 5.00, 741.8},
{0.8800, 5.00, 742.2},
{0.9000, 5.00, 742.5},
{0.9200, 5.00, 742.9},
{0.9400, 5.00, 743.2},
{0.9600, 5.00, 743.5},
{0.9800, 5.00, 743.9},
{1.0000, 5.00, 744.2}};

(*------------------------------*)
(*  ksp bi cd g (liq)  *) 

u29={{0.1200, 5.00, 774.0},
{0.1250, 5.00, 772.7},
{0.1300, 5.00, 771.3},
{0.1350, 5.00, 769.9},
{0.1400, 5.00, 768.5},
{0.1450, 5.00, 767.1},
{0.1500, 5.00, 765.8},
{0.1550, 5.00, 764.4},
{0.1600, 5.00, 763.0},
{0.1650, 5.00, 761.6},
{0.1700, 5.00, 760.2},
{0.1750, 5.00, 758.8},
{0.1800, 5.00, 757.5},
{0.1850, 5.00, 756.1},
{0.1900, 5.00, 754.7},
{0.1950, 5.00, 753.4},
{0.2000, 5.00, 752.0}};


(*------------------------------*)
(*  liq ksp cd g (bi)  *) 

u30={{0.1200, 5.00, 775.1},
{0.1400, 5.00, 775.7},
{0.1600, 5.00, 776.2},
{0.1800, 5.00, 776.8},
{0.2000, 5.00, 777.5},
{0.2200, 5.00, 778.1},
{0.2400, 5.00, 778.7},
{0.2600, 5.00, 779.4},
{0.2800, 5.00, 780.1},
{0.3000, 5.00, 780.8},
{0.3200, 5.00, 781.6},
{0.3400, 5.00, 782.3},
{0.3600, 5.00, 783.0},
{0.3800, 5.00, 783.8},
{0.4000, 5.00, 784.6},
{0.4200, 5.00, 785.4},
{0.4400, 5.00, 786.1},
{0.4600, 5.00, 786.9},
{0.4800, 5.00, 787.7},
{0.5000, 5.00, 788.5},
{0.5200, 5.00, 789.3},
{0.5400, 5.00, 790.0},
{0.5600, 5.00, 790.8},
{0.5800, 5.00, 791.6},
{0.6000, 5.00, 792.4},
{0.6200, 5.00, 793.1},
{0.6400, 5.00, 793.9},
{0.6600, 5.00, 794.6},
{0.6800, 5.00, 795.3},
{0.7000, 5.00, 796.0},
{0.7200, 5.00, 796.8},
{0.7400, 5.00, 797.5},
{0.7600, 5.00, 798.1},
{0.7800, 5.00, 798.8},
{0.8000, 5.00, 799.5},
{0.8200, 5.00, 800.1},
{0.8400, 5.00, 800.8},
{0.8600, 5.00, 801.4},
{0.8800, 5.00, 802.0},
{0.9000, 5.00, 802.7},
{0.9200, 5.00, 803.3},
{0.9400, 5.00, 803.9},
{0.9600, 5.00, 804.4},
{0.9800, 5.00, 805.0},
{1.0000, 5.00, 805.6}};







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (31-60)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  ksp cd g (liq)  *) 

u31={{0.0000, 5.00, 994.8},
{0.0100, 5.00, 973.7},
{0.0200, 5.00, 952.6},
{0.0300, 5.00, 934.8},
{0.0400, 5.00, 918.2},
{0.0500, 5.00, 902.0},
{0.0600, 5.00, 885.7},
{0.0700, 5.00, 868.9},
{0.0800, 5.00, 851.4},
{0.0900, 5.00, 832.7},
{0.1000, 5.00, 812.5},
{0.1100, 5.00, 790.4},
{0.1200, 5.00, 765.9},
{0.1300, 5.00, 738.1},
{0.1400, 5.00, 706.2},
{0.1500, 5.00, 668.9},
{0.1600, 5.00, 624.3}};

(*------------------------------*)
(*  ksp cd g sill (pl)  *) 

u32={{0.0000, 5.00, 713.0},
{0.0050, 5.00, 718.3},
{0.0100, 5.00, 723.8},
{0.0150, 5.00, 729.6},
{0.0200, 5.00, 735.8},
{0.0250, 5.00, 742.5},
{0.0300, 5.00, 749.8},
{0.0350, 5.00, 758.3},
{0.0400, 5.00, 768.6},
{0.0450, 5.00, 782.3}};

(*------------------------------*)
(*  ksp cd g (sill)  *) 

u33={{0.0000, 5.00, 897.4},
{0.0100, 5.00, 882.4},
{0.0200, 5.00, 866.9},
{0.0300, 5.00, 850.9},
{0.0400, 5.00, 834.4},
{0.0500, 5.00, 817.3},
{0.0600, 5.00, 799.6},
{0.0700, 5.00, 781.2},
{0.0800, 5.00, 762.0},
{0.0900, 5.00, 741.9},
{0.1000, 5.00, 720.8}};

(*------------------------------*)
(*  liq cd g (ksp)  *) 

u34={{0.0200, 5.00, 1024.2},
{0.0400, 5.00, 1019.7},
{0.0600, 5.00, 1015.3},
{0.0800, 5.00, 1010.8},
{0.1000, 5.00, 1006.4},
{0.1200, 5.00, 1002.0},
{0.1400, 5.00, 997.6},
{0.1600, 5.00, 993.2},
{0.1800, 5.00, 988.8},
{0.2000, 5.00, 984.4},
{0.2200, 5.00, 980.1},
{0.2400, 5.00, 975.8},
{0.2600, 5.00, 971.4},
{0.2800, 5.00, 967.1},
{0.3000, 5.00, 962.9},
{0.3200, 5.00, 958.6},
{0.3400, 5.00, 954.3},
{0.3600, 5.00, 950.1},
{0.3800, 5.00, 945.8},
{0.4000, 5.00, 941.6},
{0.4200, 5.00, 937.4},
{0.4400, 5.00, 933.2},
{0.4600, 5.00, 929.0},
{0.4800, 5.00, 924.8},
{0.5000, 5.00, 920.7},
{0.5200, 5.00, 916.5},
{0.5400, 5.00, 912.4},
{0.5600, 5.00, 908.2},
{0.5800, 5.00, 904.1},
{0.6000, 5.00, 900.0},
{0.6200, 5.00, 895.8},
{0.6400, 5.00, 891.7},
{0.6600, 5.00, 887.6},
{0.6800, 5.00, 883.5},
{0.7000, 5.00, 879.5},
{0.7200, 5.00, 875.4},
{0.7400, 5.00, 871.3},
{0.7600, 5.00, 867.2},
{0.7800, 5.00, 863.2},
{0.8000, 5.00, 859.1},
{0.8200, 5.00, 855.1},
{0.8400, 5.00, 851.0},
{0.8600, 5.00, 847.0},
{0.8800, 5.00, 842.9},
{0.9000, 5.00, 838.9},
{0.9200, 5.00, 834.9},
{0.9400, 5.00, 830.9},
{0.9600, 5.00, 826.9},
{0.9800, 5.00, 822.9},
{1.0000, 5.00, 818.9}};

(*------------------------------*)
(*  liq cd g (opx)  *) 

u35={{0.0200, 5.00, 962.5},
{0.0400, 5.00, 961.0},
{0.0600, 5.00, 959.3},
{0.0800, 5.00, 957.6},
{0.1000, 5.00, 955.8},
{0.1200, 5.00, 953.9},
{0.1400, 5.00, 951.9},
{0.1600, 5.00, 949.9},
{0.1800, 5.00, 947.8},
{0.2000, 5.00, 945.7},
{0.2200, 5.00, 943.5},
{0.2400, 5.00, 941.3},
{0.2600, 5.00, 939.1},
{0.2800, 5.00, 936.8},
{0.3000, 5.00, 934.5},
{0.3200, 5.00, 932.2},
{0.3400, 5.00, 929.8},
{0.3600, 5.00, 927.5},
{0.3800, 5.00, 925.1},
{0.4000, 5.00, 922.7},
{0.4200, 5.00, 920.2},
{0.4400, 5.00, 917.8},
{0.4600, 5.00, 915.3},
{0.4800, 5.00, 912.9},
{0.5000, 5.00, 910.4},
{0.5200, 5.00, 907.9},
{0.5400, 5.00, 905.4},
{0.5600, 5.00, 902.8},
{0.5800, 5.00, 900.3},
{0.6000, 5.00, 897.7},
{0.6200, 5.00, 895.2},
{0.6400, 5.00, 892.6},
{0.6600, 5.00, 890.1},
{0.6800, 5.00, 887.5},
{0.7000, 5.00, 884.9},
{0.7200, 5.00, 882.3},
{0.7400, 5.00, 879.7},
{0.7600, 5.00, 877.1},
{0.7800, 5.00, 874.5},
{0.8000, 5.00, 871.9},
{0.8200, 5.00, 869.3},
{0.8400, 5.00, 866.7},
{0.8600, 5.00, 864.1},
{0.8800, 5.00, 861.5},
{0.9000, 5.00, 858.9},
{0.9200, 5.00, 856.3},
{0.9400, 5.00, 853.7},
{0.9600, 5.00, 851.1},
{0.9800, 5.00, 848.5},
{1.0000, 5.00, 845.9}};

(*------------------------------*)
(*  liq cd opx (g)  *) 

u36={{0.0200, 5.00, 1018.0},
{0.0400, 5.00, 1016.5},
{0.0600, 5.00, 1014.9},
{0.0800, 5.00, 1013.3},
{0.1000, 5.00, 1011.7},
{0.1200, 5.00, 1010.1},
{0.1400, 5.00, 1008.5},
{0.1600, 5.00, 1006.9},
{0.1800, 5.00, 1005.2},
{0.2000, 5.00, 1003.6},
{0.2200, 5.00, 1001.9},
{0.2400, 5.00, 1000.2},
{0.2600, 5.00, 998.5},
{0.2800, 5.00, 996.9},
{0.3000, 5.00, 995.2},
{0.3200, 5.00, 993.5},
{0.3400, 5.00, 991.8},
{0.3600, 5.00, 990.0},
{0.3800, 5.00, 988.3},
{0.4000, 5.00, 986.6},
{0.4200, 5.00, 984.9},
{0.4400, 5.00, 983.2},
{0.4600, 5.00, 981.4},
{0.4800, 5.00, 979.7},
{0.5000, 5.00, 978.0},
{0.5200, 5.00, 976.2},
{0.5400, 5.00, 974.5},
{0.5600, 5.00, 972.8},
{0.5800, 5.00, 971.0},
{0.6000, 5.00, 969.3},
{0.6200, 5.00, 967.5},
{0.6400, 5.00, 965.8},
{0.6600, 5.00, 964.1},
{0.6800, 5.00, 962.3},
{0.7000, 5.00, 960.6},
{0.7200, 5.00, 958.8},
{0.7400, 5.00, 957.1},
{0.7600, 5.00, 955.4},
{0.7800, 5.00, 953.6},
{0.8000, 5.00, 951.9},
{0.8200, 5.00, 950.2},
{0.8400, 5.00, 948.5},
{0.8600, 5.00, 946.7},
{0.8800, 5.00, 945.0},
{0.9000, 5.00, 943.3},
{0.9200, 5.00, 941.6},
{0.9400, 5.00, 939.9},
{0.9600, 5.00, 938.1},
{0.9800, 5.00, 936.4},
{1.0000, 5.00, 934.7}};

(*------------------------------*)
(*  liq ksp cd g (opx)  *) 

u37={{0.0000, 5.00, 1005.3},
{0.0200, 5.00, 996.8},
{0.0400, 5.00, 988.9},
{0.0600, 5.00, 982.7},
{0.0800, 5.00, 977.4},
{0.1000, 5.00, 972.6},
{0.1200, 5.00, 968.2},
{0.1400, 5.00, 964.1},
{0.1600, 5.00, 960.2},
{0.1800, 5.00, 956.5},
{0.2000, 5.00, 953.0},
{0.2200, 5.00, 949.6},
{0.2400, 5.00, 946.3},
{0.2600, 5.00, 943.1},
{0.2800, 5.00, 940.0},
{0.3000, 5.00, 936.9},
{0.3200, 5.00, 934.0},
{0.3400, 5.00, 931.1},
{0.3600, 5.00, 928.2},
{0.3800, 5.00, 925.5},
{0.4000, 5.00, 922.7},
{0.4200, 5.00, 920.0},
{0.5200, 5.00, 907.2},
{0.5400, 5.00, 904.7}};

(*------------------------------*)
(*  liq cd g opx (ksp)  *) 

u38={{0.1200, 5.00, 1000.2},
{0.1400, 5.00, 996.0},
{0.1600, 5.00, 991.8},
{0.1800, 5.00, 987.6},
{0.2000, 5.00, 983.4},
{0.2200, 5.00, 979.2},
{0.2400, 5.00, 975.0},
{0.2600, 5.00, 970.8},
{0.2800, 5.00, 966.6},
{0.3000, 5.00, 962.4},
{0.3200, 5.00, 958.2},
{0.3400, 5.00, 954.0},
{0.3600, 5.00, 949.8},
{0.3800, 5.00, 945.6},
{0.4000, 5.00, 941.5},
{0.4200, 5.00, 937.3},
{0.4400, 5.00, 933.1},
{0.4600, 5.00, 929.0},
{0.4800, 5.00, 924.8},
{0.5000, 5.00, 920.7},
{0.5200, 5.00, 916.5},
{0.5400, 5.00, 912.4},
{0.5600, 5.00, 908.2},
{0.5800, 5.00, 904.1},
{0.6000, 5.00, 900.0},
{0.6200, 5.00, 895.8}};



\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{1,3};\n   \n  \n  \t\n  \tlu1 = makeline[u1, i1, ur];\n  \tlu2 = \
makeline[u2, i1, ur];\n  \tlu3 = makeline[u3, i2, ur];\n  \tlu4 = \
makeline[u4, i3, ur];\n  \tlu5 = makeline[u5, i1, lr];\n  \tlu6 = \
makeline[u6, i1, i2];\n  \tlu7 = makeline[u7, i3, i2];\n  \tlu8 = \
makeline[u8, i2, lr];\n  \tlu9 = makeline[u9, i4, ur];\n  \tlu10 = \
makeline[u10, i5, ur];\n  \tlu11 = makeline[u11, ll, i3];\n  \tlu12 = \
makeline[u12, i4, i3];\n  \tlu13 = makeline[u13, i4, i5];\n  \tlu14 = \
makeline[u14, i4, lr];\n  \tlu15 = makeline[u15, i5, i6];\n  \tlu16 = \
makeline[u16, i5, ll];\n  \tlu17 = makeline[u17, i6, i7];\n  \tlu18 = \
makeline[u18, ll, i7];\n  \tlu19 = makeline[u19, i12, i7];\n  \tlu20 = \
makeline[u20, i10, i7];\n  \tlu21 = makeline[u21, ur, i8];\n  \tlu22 = \
makeline[u22, i6, i8];\n  \tlu23 = makeline[u23, i6, i9];\n  \tlu24 = \
makeline[u24, i10, i9];\n  \tlu25 = makeline[u25, i10, i11];\n  \tlu26 = \
makeline[u26, i12, i10];\n  \tlu27 = makeline[u27, i9, i8];\n  \tlu28 = \
makeline[u28, ur, i8];\n  \tlu29 = makeline[u29, i11, i9];\n  \tlu30 = \
makeline[u30, i11, ur];\n  \tlu31 = makeline[u31, i11, ul];\n  \tlu32 = \
makeline[u32, ll, i12];\n  \tlu33 = makeline[u33, i12, ul];\n  \tlu34 = \
makeline[u34, lr, i13];\n  \tlu35 = makeline[u35, lr, i13];\n  \tlu36 = \
makeline[u36, lr, ul];\n  \tlu37 = makeline[u37, ul, i13];\n  \tlu38 = \
makeline[u38, ul, i13];\n  \n  \t\n      \t\t\n        \t\t\n  Show[Graphics[\
\n         {GrayLevel[0.85],\n          area[{lu18, lu17, lu15, lu16}],\n     \
     area[{lu23, lu22, lu27}],\n          area[{lu21, lu28}],\n          \
area[{lu10, lu13, lu9}],\n          area[{lu1, lu2}],\n          area[{lu4, \
lu7, lu3}],\n          \n              \n          \n          \
GrayLevel[0.65],\n          area[{lu37, lu38}],\n          area[{lu18, lu19, \
lu32}],\n          area[{lu17, lu23, lu24, lu20}],\n          area[{lu30, \
lu29, lu27, lu28}],\n          area[{lu16, lu13, lu14}],\n          \
area[{lu9, lu12, lu4}],\n          area[{lu8, lu7, lu11}],\n          \
area[{lu2, lu6, lu3}],\n          area[{lu1, lu5}],\n          \n          \n \
          \n          GrayLevel[0.35],\n          area[{lu30, lu31}],\n       \
   area[{lu35, lu38}],\n          area[{lu32, lu33}],\n          area[{lu26, \
lu20, lu19}],\n          area[{lu24, lu25, lu29}],\n          area[{lu11, \
lu12, lu14}],\n          area[{lu5, lu6, lu8}],\n          \n         \n      \
   \n          \n          \n          GrayLevel[0.15], \n          \
area[{lu36}],\n          area[{lu34, lu35}],\n          area[{lu31, lu25, \
lu26, lu33}],\n          \n          GrayLevel[0],\n          \
GrayLevel[0.65],\n          \n          area[{lu37, lu38}],\n          \n     \
     GrayLevel[0], \n   \n          AbsoluteThickness[0.3],\n          \
drawline[lu1],\n          drawline[lu2],\n          drawline[lu3],\n          \
drawline[lu4],\n          drawline[lu5],\n          drawline[lu6],\n          \
drawline[lu7],\n          drawline[lu8],\n          drawline[lu9],\n          \
drawline[lu10],\n          drawline[lu11],\n          drawline[lu12],\n       \
   ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu13],\n          drawline[lu14],\n          \
drawline[lu15],\n          drawline[lu16],\n          drawline[lu17],\n       \
   drawline[lu18],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu19],\n          drawline[lu20],\n          \
drawline[lu21],\n          drawline[lu22],\n          drawline[lu23],\n       \
   drawline[lu24],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu25],\n          drawline[lu26],\n          \
drawline[lu27],\n          drawline[lu28],\n          drawline[lu29],\n       \
   ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu30],\n          drawline[lu31],\n          \
drawline[lu32],\n          drawline[lu33],\n          drawline[lu34],\n       \
   drawline[lu35],\n          drawline[lu36],\n          drawline[lu37],\n    \
      drawline[lu38],",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n         \n         \n         \n          \n         \n        \
  \n          AbsoluteThickness[0.5], \n         \n          \n          \n   \
       \n           \n          \n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[0,1,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["RGBColor[0,0,1],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n           outline}],\n        \t\t",
    FontWeight->"Plain"],
  StyleBox["\n           \n           \n           \n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n          \n               \n         AspectRatio -> 1, Frame \
-> True,\n         PlotRange -> {{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 0; xhigh = 1.0; ylow = 630; yhigh =1000;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 -1.7027 0.0027027 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(650)] -0.0125 .05405 1 0 Msboxa
[(700)] -0.0125 .18919 1 0 Msboxa
[(750)] -0.0125 .32432 1 0 Msboxa
[(800)] -0.0125 .45946 1 0 Msboxa
[(850)] -0.0125 .59459 1 0 Msboxa
[(900)] -0.0125 .72973 1 0 Msboxa
[(950)] -0.0125 .86486 1 0 Msboxa
[(1000)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .05405 m
.00625 .05405 L
s
P
[(650)] -0.0125 .05405 1 0 Mshowa
p
.002 w
0 .18919 m
.00625 .18919 L
s
P
[(700)] -0.0125 .18919 1 0 Mshowa
p
.002 w
0 .32432 m
.00625 .32432 L
s
P
[(750)] -0.0125 .32432 1 0 Mshowa
p
.002 w
0 .45946 m
.00625 .45946 L
s
P
[(800)] -0.0125 .45946 1 0 Mshowa
p
.002 w
0 .59459 m
.00625 .59459 L
s
P
[(850)] -0.0125 .59459 1 0 Mshowa
p
.002 w
0 .72973 m
.00625 .72973 L
s
P
[(900)] -0.0125 .72973 1 0 Mshowa
p
.002 w
0 .86486 m
.00625 .86486 L
s
P
[(950)] -0.0125 .86486 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(1000)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .08108 m
.00375 .08108 L
s
P
p
.001 w
0 .10811 m
.00375 .10811 L
s
P
p
.001 w
0 .13514 m
.00375 .13514 L
s
P
p
.001 w
0 .16216 m
.00375 .16216 L
s
P
p
.001 w
0 .21622 m
.00375 .21622 L
s
P
p
.001 w
0 .24324 m
.00375 .24324 L
s
P
p
.001 w
0 .27027 m
.00375 .27027 L
s
P
p
.001 w
0 .2973 m
.00375 .2973 L
s
P
p
.001 w
0 .35135 m
.00375 .35135 L
s
P
p
.001 w
0 .37838 m
.00375 .37838 L
s
P
p
.001 w
0 .40541 m
.00375 .40541 L
s
P
p
.001 w
0 .43243 m
.00375 .43243 L
s
P
p
.001 w
0 .48649 m
.00375 .48649 L
s
P
p
.001 w
0 .51351 m
.00375 .51351 L
s
P
p
.001 w
0 .54054 m
.00375 .54054 L
s
P
p
.001 w
0 .56757 m
.00375 .56757 L
s
P
p
.001 w
0 .62162 m
.00375 .62162 L
s
P
p
.001 w
0 .64865 m
.00375 .64865 L
s
P
p
.001 w
0 .67568 m
.00375 .67568 L
s
P
p
.001 w
0 .7027 m
.00375 .7027 L
s
P
p
.001 w
0 .75676 m
.00375 .75676 L
s
P
p
.001 w
0 .78378 m
.00375 .78378 L
s
P
p
.001 w
0 .81081 m
.00375 .81081 L
s
P
p
.001 w
0 .83784 m
.00375 .83784 L
s
P
p
.001 w
0 .89189 m
.00375 .89189 L
s
P
p
.001 w
0 .91892 m
.00375 .91892 L
s
P
p
.001 w
0 .94595 m
.00375 .94595 L
s
P
p
.001 w
0 .97297 m
.00375 .97297 L
s
P
p
.001 w
0 .02703 m
.00375 .02703 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .05405 m
1 .05405 L
s
P
p
.002 w
.99375 .18919 m
1 .18919 L
s
P
p
.002 w
.99375 .32432 m
1 .32432 L
s
P
p
.002 w
.99375 .45946 m
1 .45946 L
s
P
p
.002 w
.99375 .59459 m
1 .59459 L
s
P
p
.002 w
.99375 .72973 m
1 .72973 L
s
P
p
.002 w
.99375 .86486 m
1 .86486 L
s
P
p
.001 w
.99625 .08108 m
1 .08108 L
s
P
p
.001 w
.99625 .10811 m
1 .10811 L
s
P
p
.001 w
.99625 .13514 m
1 .13514 L
s
P
p
.001 w
.99625 .16216 m
1 .16216 L
s
P
p
.001 w
.99625 .21622 m
1 .21622 L
s
P
p
.001 w
.99625 .24324 m
1 .24324 L
s
P
p
.001 w
.99625 .27027 m
1 .27027 L
s
P
p
.001 w
.99625 .2973 m
1 .2973 L
s
P
p
.001 w
.99625 .35135 m
1 .35135 L
s
P
p
.001 w
.99625 .37838 m
1 .37838 L
s
P
p
.001 w
.99625 .40541 m
1 .40541 L
s
P
p
.001 w
.99625 .43243 m
1 .43243 L
s
P
p
.001 w
.99625 .48649 m
1 .48649 L
s
P
p
.001 w
.99625 .51351 m
1 .51351 L
s
P
p
.001 w
.99625 .54054 m
1 .54054 L
s
P
p
.001 w
.99625 .56757 m
1 .56757 L
s
P
p
.001 w
.99625 .62162 m
1 .62162 L
s
P
p
.001 w
.99625 .64865 m
1 .64865 L
s
P
p
.001 w
.99625 .67568 m
1 .67568 L
s
P
p
.001 w
.99625 .7027 m
1 .7027 L
s
P
p
.001 w
.99625 .75676 m
1 .75676 L
s
P
p
.001 w
.99625 .78378 m
1 .78378 L
s
P
p
.001 w
.99625 .81081 m
1 .81081 L
s
P
p
.001 w
.99625 .83784 m
1 .83784 L
s
P
p
.001 w
.99625 .89189 m
1 .89189 L
s
P
p
.001 w
.99625 .91892 m
1 .91892 L
s
P
p
.001 w
.99625 .94595 m
1 .94595 L
s
P
p
.001 w
.99625 .97297 m
1 .97297 L
s
P
p
.001 w
.99625 .02703 m
1 .02703 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
.107 .20351 L
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
.3 .28568 L
.319 .28542 L
.338 .28517 L
.357 .28467 L
.376 .28437 L
.395 .28414 L
.414 .28367 L
.433 .2833 L
.452 .28324 L
.452 .28324 L
.43235 .2781 L
.4127 .27209 L
.39304 .26588 L
.37339 .25943 L
.35374 .25263 L
.33409 .24537 L
.31443 .2378 L
.29478 .22968 L
.27513 .22112 L
.25548 .21219 L
.23583 .2025 L
.21617 .19226 L
.19652 .18126 L
.17687 .16975 L
.15722 .15774 L
.13757 .14512 L
.11791 .13153 L
.09826 .11765 L
.07861 .103 L
.05896 .08782 L
.0393 .07186 L
.01965 .05538 L
0 .03865 L
F
.149 .36757 m
.16788 .35583 L
.18675 .34394 L
.20563 .33263 L
.2245 .32173 L
.24338 .31114 L
.26225 .30123 L
.28112 .29204 L
.3 .28568 L
.3 .28568 L
.32026 .28622 L
.34053 .2865 L
.36079 .28704 L
.38105 .28731 L
.40132 .2876 L
.42158 .28814 L
.44184 .2884 L
.46211 .2887 L
.48237 .28922 L
.50263 .28952 L
.52289 .29008 L
.54316 .29059 L
.56342 .29089 L
.58368 .29146 L
.60395 .29195 L
.62421 .29226 L
.64447 .29283 L
.66474 .29336 L
.685 .29378 L
.685 .29378 L
.66515 .29613 L
.6453 .29834 L
.62544 .30068 L
.60559 .3031 L
.58574 .30552 L
.56589 .30793 L
.54604 .31033 L
.52619 .31294 L
.50633 .31563 L
.48648 .31831 L
.46663 .321 L
.44678 .32366 L
.42693 .32654 L
.40707 .32931 L
.38722 .33216 L
.36737 .33512 L
.34752 .33807 L
.32767 .34102 L
.30781 .34397 L
.28796 .34692 L
.26811 .34988 L
.24826 .35283 L
.22841 .35576 L
.20856 .35888 L
.1887 .36197 L
.16885 .36495 L
.149 .36757 L
F
1 .29865 m
.98031 .29838 L
.96062 .29812 L
.94094 .29785 L
.92125 .29733 L
.90156 .29704 L
.88187 .29678 L
.86219 .29652 L
.8425 .29626 L
.82281 .29575 L
.80312 .29544 L
.78344 .29518 L
.76375 .29492 L
.74406 .29465 L
.72438 .29438 L
.70469 .29412 L
.685 .29378 L
.685 .29378 L
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
F
1 .2973 m
.9797 .29675 L
.95941 .29619 L
.93911 .29538 L
.91881 .29484 L
.89852 .29427 L
.87822 .29346 L
.85793 .29292 L
.83763 .29234 L
.81733 .29154 L
.79704 .291 L
.77674 .29045 L
.75644 .2899 L
.73615 .28936 L
.71585 .28881 L
.69556 .28826 L
.67526 .28771 L
.65496 .28716 L
.63467 .2866 L
.61437 .28614 L
.59407 .28579 L
.57378 .28532 L
.55348 .28496 L
.53319 .2845 L
.51289 .28414 L
.49259 .28366 L
.4723 .28344 L
.452 .28324 L
.452 .28324 L
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
.567 .25378 L
.58668 .25415 L
.60636 .25449 L
.62605 .25496 L
.64573 .2552 L
.66541 .25554 L
.68509 .25609 L
.70477 .25656 L
.72445 .25686 L
.74414 .25741 L
.76382 .25794 L
.7835 .25847 L
.80318 .259 L
.82286 .25954 L
.84255 .26007 L
.86223 .2606 L
.88191 .26116 L
.90159 .26194 L
.92127 .26246 L
.94095 .26301 L
.96064 .2638 L
.98032 .26433 L
1 .26514 L
F
1 .08541 m
.97938 .08541 L
.95877 .08541 L
.93815 .08541 L
.91754 .08541 L
.89692 .08541 L
.87631 .08541 L
.85569 .08541 L
.83508 .08541 L
.81446 .08541 L
.79385 .08541 L
.77323 .08541 L
.75262 .08541 L
.732 .08541 L
.732 .08541 L
.75262 .08656 L
.77323 .08791 L
.79385 .0893 L
.81446 .09089 L
.83508 .09257 L
.85569 .09422 L
.87631 .09635 L
.89692 .09834 L
.91754 .10078 L
.93815 .10303 L
.95877 .10577 L
.97938 .10856 L
1 .11162 L
F
1 .16243 m
.97981 .16161 L
.95962 .16052 L
.93943 .1597 L
.91924 .15861 L
.89905 .1578 L
.87886 .15698 L
.85867 .15616 L
.83848 .15534 L
.81829 .15455 L
.7981 .15398 L
.7779 .15318 L
.75771 .15261 L
.73752 .15182 L
.71733 .15128 L
.69714 .15073 L
.67695 .15019 L
.65676 .14964 L
.63657 .14909 L
.61638 .14859 L
.59619 .14832 L
.576 .14784 L
.576 .14784 L
.59475 .14713 L
.6135 .14685 L
.63225 .14644 L
.651 .14592 L
.66975 .1454 L
.6885 .14501 L
.70725 .14476 L
.726 .14432 L
.726 .14432 L
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
F
.65 g
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
F
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
.107 .20351 L
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
.0505 .50351 L
.05004 .48357 L
.0492 .46363 L
.04795 .44369 L
.04626 .42375 L
.04409 .4038 L
.04142 .38386 L
.03821 .36392 L
.03444 .34398 L
.03006 .32403 L
.02501 .30409 L
.01948 .28415 L
.01344 .26421 L
.00692 .24427 L
0 .22432 L
F
.107 .20351 m
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
.3 .28568 L
.28112 .29204 L
.26225 .30123 L
.24338 .31114 L
.2245 .32173 L
.20563 .33263 L
.18675 .34394 L
.16788 .35583 L
.149 .36757 L
.149 .36757 L
.13985 .35108 L
.13102 .33459 L
.12183 .31811 L
.1125 .30162 L
.1125 .30162 L
.11098 .282 L
.10982 .26238 L
.10887 .24276 L
.10798 .22314 L
.107 .20351 L
F
1 .47459 m
.97992 .47297 L
.95984 .47134 L
.93976 .46998 L
.91968 .46835 L
.8996 .46672 L
.87952 .46482 L
.85944 .4632 L
.83936 .46156 L
.81928 .45967 L
.7992 .45804 L
.77913 .45613 L
.75905 .45425 L
.73897 .45261 L
.71889 .45069 L
.69881 .44853 L
.67873 .44664 L
.65865 .44474 L
.63857 .44282 L
.61849 .44067 L
.59841 .43875 L
.57833 .43658 L
.55825 .4344 L
.53817 .43226 L
.51809 .43034 L
.49801 .42816 L
.47793 .42599 L
.45785 .42382 L
.43777 .42168 L
.41769 .41976 L
.39761 .41758 L
.37753 .4154 L
.35745 .41326 L
.33737 .41138 L
.3173 .40944 L
.29722 .40729 L
.27714 .4054 L
.25706 .4035 L
.23698 .40164 L
.2169 .40003 L
.19682 .39835 L
.17674 .39647 L
.15666 .3949 L
.13658 .39354 L
.1165 .39189 L
.1165 .39189 L
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
.149 .36757 L
.16885 .36495 L
.1887 .36197 L
.20856 .35888 L
.22841 .35576 L
.24826 .35283 L
.26811 .34988 L
.28796 .34692 L
.30781 .34397 L
.32767 .34102 L
.34752 .33807 L
.36737 .33512 L
.38722 .33216 L
.40707 .32931 L
.42693 .32654 L
.44678 .32366 L
.46663 .321 L
.48648 .31831 L
.50633 .31563 L
.52619 .31294 L
.54604 .31033 L
.56589 .30793 L
.58574 .30552 L
.60559 .3031 L
.62544 .30068 L
.6453 .29834 L
.66515 .29613 L
.685 .29378 L
.685 .29378 L
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
F
0 .03865 m
.01965 .05538 L
.0393 .07186 L
.05896 .08782 L
.07861 .103 L
.09826 .11765 L
.11791 .13153 L
.13757 .14512 L
.15722 .15774 L
.17687 .16975 L
.19652 .18126 L
.21617 .19226 L
.23583 .2025 L
.25548 .21219 L
.27513 .22112 L
.29478 .22968 L
.31443 .2378 L
.33409 .24537 L
.35374 .25263 L
.37339 .25943 L
.39304 .26588 L
.4127 .27209 L
.43235 .2781 L
.452 .28324 L
.452 .28324 L
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
.567 .25378 L
.56765 .23426 L
.56805 .21474 L
.56825 .19522 L
.5683 .1757 L
.56825 .15617 L
.56814 .13665 L
.56803 .11713 L
.56818 .09761 L
.56849 .07809 L
.56883 .05857 L
.56919 .03904 L
.56957 .01952 L
.56997 0 L
0 0 L
F
1 .26514 m
.98032 .26433 L
.96064 .2638 L
.94095 .26301 L
.92127 .26246 L
.90159 .26194 L
.88191 .26116 L
.86223 .2606 L
.84255 .26007 L
.82286 .25954 L
.80318 .259 L
.7835 .25847 L
.76382 .25794 L
.74414 .25741 L
.72445 .25686 L
.70477 .25656 L
.68509 .25609 L
.66541 .25554 L
.64573 .2552 L
.62605 .25496 L
.60636 .25449 L
.58668 .25415 L
.567 .25378 L
.567 .25378 L
.56876 .23259 L
.56986 .21141 L
.57172 .19022 L
.57387 .16903 L
.576 .14784 L
.576 .14784 L
.59619 .14832 L
.61638 .14859 L
.63657 .14909 L
.65676 .14964 L
.67695 .15019 L
.69714 .15073 L
.71733 .15128 L
.73752 .15182 L
.75771 .15261 L
.7779 .15318 L
.7981 .15398 L
.81829 .15455 L
.83848 .15534 L
.85867 .15616 L
.87886 .15698 L
.89905 .1578 L
.91924 .15861 L
.93943 .1597 L
.95962 .16052 L
.97981 .16161 L
1 .16243 L
F
.72814 0 m
.72762 .02062 L
.72713 .04124 L
.72668 .06185 L
.72631 .08247 L
.72606 .10309 L
.72604 .12371 L
.726 .14432 L
.726 .14432 L
.70725 .14476 L
.6885 .14501 L
.66975 .1454 L
.651 .14592 L
.63225 .14644 L
.6135 .14685 L
.59475 .14713 L
.576 .14784 L
.576 .14784 L
.57624 .12672 L
.5762 .1056 L
.5762 .08448 L
.5762 .06336 L
.5762 .04224 L
.5762 .02112 L
.5762 0 L
F
1 .11162 m
.97938 .10856 L
.95877 .10577 L
.93815 .10303 L
.91754 .10078 L
.89692 .09834 L
.87631 .09635 L
.85569 .09422 L
.83508 .09257 L
.81446 .09089 L
.79385 .0893 L
.77323 .08791 L
.75262 .08656 L
.732 .08541 L
.732 .08541 L
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
.726 .14432 L
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
F
1 .08541 m
.97938 .08541 L
.95877 .08541 L
.93815 .08541 L
.91754 .08541 L
.89692 .08541 L
.87631 .08541 L
.85569 .08541 L
.83508 .08541 L
.81446 .08541 L
.79385 .08541 L
.77323 .08541 L
.75262 .08541 L
.732 .08541 L
.732 .08541 L
.73249 .06405 L
.73259 .0427 L
.73282 .02135 L
.73365 0 L
1 0 L
F
.35 g
1 .47459 m
.97992 .47297 L
.95984 .47134 L
.93976 .46998 L
.91968 .46835 L
.8996 .46672 L
.87952 .46482 L
.85944 .4632 L
.83936 .46156 L
.81928 .45967 L
.7992 .45804 L
.77913 .45613 L
.75905 .45425 L
.73897 .45261 L
.71889 .45069 L
.69881 .44853 L
.67873 .44664 L
.65865 .44474 L
.63857 .44282 L
.61849 .44067 L
.59841 .43875 L
.57833 .43658 L
.55825 .4344 L
.53817 .43226 L
.51809 .43034 L
.49801 .42816 L
.47793 .42599 L
.45785 .42382 L
.43777 .42168 L
.41769 .41976 L
.39761 .41758 L
.37753 .4154 L
.35745 .41326 L
.33737 .41138 L
.3173 .40944 L
.29722 .40729 L
.27714 .4054 L
.25706 .4035 L
.23698 .40164 L
.2169 .40003 L
.19682 .39835 L
.17674 .39647 L
.15666 .3949 L
.13658 .39354 L
.1165 .39189 L
.1165 .39189 L
.11348 .41169 L
.11033 .4315 L
.10711 .4513 L
.10381 .4711 L
.10041 .4909 L
.09689 .5107 L
.09326 .5305 L
.08953 .55031 L
.08568 .57011 L
.08173 .58991 L
.07765 .60971 L
.07347 .62951 L
.06921 .64932 L
.06488 .66912 L
.06048 .68892 L
.05602 .70872 L
.05151 .72852 L
.04698 .74832 L
.04245 .76813 L
.03796 .78793 L
.03353 .80773 L
.02919 .82753 L
.02497 .84733 L
.02094 .86714 L
.01724 .88694 L
.01377 .90674 L
.0104 .92654 L
.00704 .94634 L
.0036 .96614 L
0 .98595 L
0 1 L
1 1 L
F
1 .58351 m
.98042 .59039 L
.96083 .59728 L
.94125 .60416 L
.92166 .61104 L
.90208 .61792 L
.88249 .6248 L
.86291 .63168 L
.84333 .63856 L
.82374 .64544 L
.80416 .65232 L
.78457 .6592 L
.76499 .66608 L
.74541 .67297 L
.72582 .67985 L
.70624 .68673 L
.68665 .69361 L
.66707 .70051 L
.64748 .70718 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
1 1 L
F
0 .22432 m
.00692 .24427 L
.01344 .26421 L
.01948 .28415 L
.02501 .30409 L
.03006 .32403 L
.03444 .34398 L
.03821 .36392 L
.04142 .38386 L
.04409 .4038 L
.04626 .42375 L
.04795 .44369 L
.0492 .46363 L
.05004 .48357 L
.0505 .50351 L
.0505 .50351 L
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
F
.0505 .50351 m
.05778 .48332 L
.06479 .46314 L
.0715 .44295 L
.0779 .42276 L
.08409 .40257 L
.09009 .38238 L
.09585 .36219 L
.10149 .342 L
.1071 .32181 L
.1125 .30162 L
.1125 .30162 L
.11098 .282 L
.10982 .26238 L
.10887 .24276 L
.10798 .22314 L
.107 .20351 L
.107 .20351 L
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
F
.149 .36757 m
.13985 .35108 L
.13102 .33459 L
.12183 .31811 L
.1125 .30162 L
.1125 .30162 L
.11339 .31968 L
.11422 .33773 L
.11502 .35578 L
.11577 .37384 L
.1165 .39189 L
.1165 .39189 L
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
F
.5762 0 m
.5762 .02112 L
.5762 .04224 L
.5762 .06336 L
.5762 .08448 L
.5762 .1056 L
.57624 .12672 L
.576 .14784 L
.576 .14784 L
.57387 .16903 L
.57172 .19022 L
.56986 .21141 L
.56876 .23259 L
.567 .25378 L
.567 .25378 L
.56765 .23426 L
.56805 .21474 L
.56825 .19522 L
.5683 .1757 L
.56825 .15617 L
.56814 .13665 L
.56803 .11713 L
.56818 .09761 L
.56849 .07809 L
.56883 .05857 L
.56919 .03904 L
.56957 .01952 L
.56997 0 L
F
.73365 0 m
.73282 .02135 L
.73259 .0427 L
.73249 .06405 L
.732 .08541 L
.732 .08541 L
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
.726 .14432 L
.72604 .12371 L
.72606 .10309 L
.72631 .08247 L
.72668 .06185 L
.72713 .04124 L
.72762 .02062 L
.72814 0 L
F
.15 g
.24233 1 m
.26 .99595 L
.28 .99162 L
.3 .98703 L
.32 .98243 L
.34 .97784 L
.36 .97297 L
.38 .96838 L
.4 .96378 L
.42 .95919 L
.44 .95459 L
.46 .94973 L
.48 .94514 L
.5 .94054 L
.52 .93568 L
.54 .93108 L
.56 .92649 L
.58 .92162 L
.6 .91703 L
.62 .91216 L
.64 .90757 L
.66 .90297 L
.68 .89811 L
.7 .89351 L
.72 .88865 L
.74 .88405 L
.76 .87946 L
.78 .87459 L
.8 .87 L
.82 .86541 L
.84 .86081 L
.86 .85595 L
.88 .85135 L
.9 .84676 L
.92 .84216 L
.94 .83757 L
.96 .8327 L
.98 .82811 L
1 .82351 L
1 1 L
F
1 .51054 m
.98042 .52113 L
.96083 .53171 L
.94125 .5423 L
.92166 .55288 L
.90208 .56347 L
.88249 .57405 L
.86291 .58488 L
.84333 .5955 L
.82374 .60631 L
.80416 .61694 L
.78457 .62774 L
.76499 .63838 L
.74541 .64916 L
.72582 .66002 L
.70624 .67089 L
.68665 .68154 L
.66707 .69229 L
.64748 .70314 L
.6279 .71405 L
.6279 .71405 L
.64748 .70718 L
.66707 .70051 L
.68665 .69361 L
.70624 .68673 L
.72582 .67985 L
.74541 .67297 L
.76499 .66608 L
.78457 .6592 L
.80416 .65232 L
.82374 .64544 L
.84333 .63856 L
.86291 .63168 L
.88249 .6248 L
.90208 .61792 L
.92166 .61104 L
.94125 .60416 L
.96083 .59728 L
.98042 .59039 L
1 .58351 L
F
0 .98595 m
.0036 .96614 L
.00704 .94634 L
.0104 .92654 L
.01377 .90674 L
.01724 .88694 L
.02094 .86714 L
.02497 .84733 L
.02919 .82753 L
.03353 .80773 L
.03796 .78793 L
.04245 .76813 L
.04698 .74832 L
.05151 .72852 L
.05602 .70872 L
.06048 .68892 L
.06488 .66912 L
.06921 .64932 L
.07347 .62951 L
.07765 .60971 L
.08173 .58991 L
.08568 .57011 L
.08953 .55031 L
.09326 .5305 L
.09689 .5107 L
.10041 .4909 L
.10381 .4711 L
.10711 .4513 L
.11033 .4315 L
.11348 .41169 L
.1165 .39189 L
.1165 .39189 L
.11577 .37384 L
.11502 .35578 L
.11422 .33773 L
.11339 .31968 L
.1125 .30162 L
.1125 .30162 L
.1071 .32181 L
.10149 .342 L
.09585 .36219 L
.09009 .38238 L
.08409 .40257 L
.0779 .42276 L
.0715 .44295 L
.06479 .46314 L
.05778 .48332 L
.0505 .50351 L
.0505 .50351 L
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
F
0 g
.65 g
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
F
0 g
.3 Mabswid
.732 .08541 m
.75262 .08541 L
.77323 .08541 L
.79385 .08541 L
.81446 .08541 L
.83508 .08541 L
.85569 .08541 L
.87631 .08541 L
.89692 .08541 L
.91754 .08541 L
.93815 .08541 L
.95877 .08541 L
.97938 .08541 L
1 .08541 L
s
.732 .08541 m
.75262 .08656 L
.77323 .08791 L
.79385 .0893 L
.81446 .09089 L
.83508 .09257 L
.85569 .09422 L
.87631 .09635 L
.89692 .09834 L
.91754 .10078 L
.93815 .10303 L
.95877 .10577 L
.97938 .10856 L
1 .11162 L
s
.726 .14432 m
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
s
.576 .14784 m
.59619 .14832 L
.61638 .14859 L
.63657 .14909 L
.65676 .14964 L
.67695 .15019 L
.69714 .15073 L
.71733 .15128 L
.73752 .15182 L
.75771 .15261 L
.7779 .15318 L
.7981 .15398 L
.81829 .15455 L
.83848 .15534 L
.85867 .15616 L
.87886 .15698 L
.89905 .1578 L
.91924 .15861 L
.93943 .1597 L
.95962 .16052 L
.97981 .16161 L
s
1 .16243 m
.97981 .16161 L
s
s
.73365 0 m
.73282 .02135 L
.73259 .0427 L
.73249 .06405 L
.732 .08541 L
s
.732 .08541 m
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
s
.576 .14784 m
.59475 .14713 L
.6135 .14685 L
.63225 .14644 L
.651 .14592 L
.66975 .1454 L
.6885 .14501 L
.70725 .14476 L
.726 .14432 L
s
.72814 0 m
.72762 .02062 L
.72713 .04124 L
.72668 .06185 L
.72631 .08247 L
.72606 .10309 L
.72604 .12371 L
.726 .14432 L
s
.567 .25378 m
.58668 .25415 L
.60636 .25449 L
.62605 .25496 L
.64573 .2552 L
.66541 .25554 L
.68509 .25609 L
.70477 .25656 L
.72445 .25686 L
.74414 .25741 L
.76382 .25794 L
.7835 .25847 L
.80318 .259 L
.82286 .25954 L
.84255 .26007 L
.86223 .2606 L
.88191 .26116 L
.90159 .26194 L
.92127 .26246 L
.94095 .26301 L
.96064 .2638 L
.98032 .26433 L
1 .26514 L
s
.452 .28324 m
.4723 .28344 L
.49259 .28366 L
.51289 .28414 L
.53319 .2845 L
.55348 .28496 L
.57378 .28532 L
.59407 .28579 L
.61437 .28614 L
.63467 .2866 L
.65496 .28716 L
.67526 .28771 L
.69556 .28826 L
.71585 .28881 L
.73615 .28936 L
.75644 .2899 L
.77674 .29045 L
.79704 .291 L
.81733 .29154 L
.83763 .29234 L
.85793 .29292 L
.87822 .29346 L
.89852 .29427 L
.91881 .29484 L
.93911 .29538 L
.95941 .29619 L
.9797 .29675 L
1 .2973 L
s
.5762 0 m
.5762 .02112 L
.5762 .04224 L
.5762 .06336 L
.5762 .08448 L
.5762 .1056 L
.57624 .12672 L
.576 .14784 L
s
.576 .14784 m
.57387 .16903 L
.57172 .19022 L
.56986 .21141 L
.56876 .23259 L
.567 .25378 L
s
.452 .28324 m
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
s
.56997 0 m
.56957 .01952 L
.56919 .03904 L
.56883 .05857 L
.56849 .07809 L
.56818 .09761 L
.56803 .11713 L
.56814 .13665 L
.56825 .15617 L
.5683 .1757 L
.56825 .19522 L
.56805 .21474 L
.56765 .23426 L
.567 .25378 L
s
.3 .28568 m
.319 .28542 L
.338 .28517 L
.357 .28467 L
.376 .28437 L
.395 .28414 L
.414 .28367 L
.433 .2833 L
.452 .28324 L
s
0 .03865 m
.01965 .05538 L
.0393 .07186 L
.05896 .08782 L
.07861 .103 L
.09826 .11765 L
.11791 .13153 L
.13757 .14512 L
.15722 .15774 L
.17687 .16975 L
.19652 .18126 L
.21617 .19226 L
.23583 .2025 L
.25548 .21219 L
.27513 .22112 L
.29478 .22968 L
.31443 .2378 L
.33409 .24537 L
.35374 .25263 L
.37339 .25943 L
.39304 .26588 L
.4127 .27209 L
.43235 .2781 L
.452 .28324 L
s
.107 .20351 m
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
s
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
s
.107 .20351 m
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
s
.107 .20351 m
.10798 .22314 L
.10887 .24276 L
.10982 .26238 L
.11098 .282 L
.1125 .30162 L
s
.685 .29378 m
.70469 .29412 L
.72438 .29438 L
.74406 .29465 L
.76375 .29492 L
.78344 .29518 L
.80312 .29544 L
.82281 .29575 L
.8425 .29626 L
.86219 .29652 L
.88187 .29678 L
.90156 .29704 L
.92125 .29733 L
.94094 .29785 L
.96062 .29812 L
.98031 .29838 L
1 .29865 L
s
.3 .28568 m
.32026 .28622 L
.34053 .2865 L
.36079 .28704 L
.38105 .28731 L
.40132 .2876 L
.42158 .28814 L
.44184 .2884 L
.46211 .2887 L
.48237 .28922 L
.50263 .28952 L
.52289 .29008 L
.54316 .29059 L
.56342 .29089 L
.58368 .29146 L
.60395 .29195 L
.62421 .29226 L
.64447 .29283 L
.66474 .29336 L
.685 .29378 L
s
.149 .36757 m
.16788 .35583 L
.18675 .34394 L
.20563 .33263 L
.2245 .32173 L
.24338 .31114 L
.26225 .30123 L
.28112 .29204 L
.3 .28568 L
s
.1125 .30162 m
.12183 .31811 L
.13102 .33459 L
.13985 .35108 L
.149 .36757 L
s
.1125 .30162 m
.11339 .31968 L
.11422 .33773 L
.11502 .35578 L
.11577 .37384 L
.1165 .39189 L
s
.1125 .30162 m
.1071 .32181 L
.10149 .342 L
.09585 .36219 L
.09009 .38238 L
.08409 .40257 L
.0779 .42276 L
.0715 .44295 L
.06479 .46314 L
.05778 .48332 L
.0505 .50351 L
s
.149 .36757 m
.16885 .36495 L
.1887 .36197 L
.20856 .35888 L
.22841 .35576 L
.24826 .35283 L
.26811 .34988 L
.28796 .34692 L
.30781 .34397 L
.32767 .34102 L
.34752 .33807 L
.36737 .33512 L
.38722 .33216 L
.40707 .32931 L
.42693 .32654 L
.44678 .32366 L
.46663 .321 L
.48648 .31831 L
.50633 .31563 L
.52619 .31294 L
.54604 .31033 L
.56589 .30793 L
.58574 .30552 L
.60559 .3031 L
.62544 .30068 L
.6453 .29834 L
.66515 .29613 L
.685 .29378 L
s
.685 .29378 m
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
s
.1165 .39189 m
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
s
.1165 .39189 m
.13658 .39354 L
.15666 .3949 L
.17674 .39647 L
.19682 .39835 L
.2169 .40003 L
.23698 .40164 L
.25706 .4035 L
.27714 .4054 L
.29722 .40729 L
.3173 .40944 L
.33737 .41138 L
.35745 .41326 L
.37753 .4154 L
.39761 .41758 L
.41769 .41976 L
.43777 .42168 L
.45785 .42382 L
.47793 .42599 L
.49801 .42816 L
.51809 .43034 L
.53817 .43226 L
.55825 .4344 L
.57833 .43658 L
.59841 .43875 L
.61849 .44067 L
.63857 .44282 L
.65865 .44474 L
.67873 .44664 L
.69881 .44853 L
.71889 .45069 L
.73897 .45261 L
.75905 .45425 L
.77913 .45613 L
.7992 .45804 L
.81928 .45967 L
.83936 .46156 L
.85944 .4632 L
.87952 .46482 L
.8996 .46672 L
.91968 .46835 L
.93976 .46998 L
.95984 .47134 L
.97992 .47297 L
s
1 .47459 m
.97992 .47297 L
s
s
.1165 .39189 m
.11348 .41169 L
.11033 .4315 L
.10711 .4513 L
.10381 .4711 L
.10041 .4909 L
.09689 .5107 L
.09326 .5305 L
.08953 .55031 L
.08568 .57011 L
.08173 .58991 L
.07765 .60971 L
.07347 .62951 L
.06921 .64932 L
.06488 .66912 L
.06048 .68892 L
.05602 .70872 L
.05151 .72852 L
.04698 .74832 L
.04245 .76813 L
.03796 .78793 L
.03353 .80773 L
.02919 .82753 L
.02497 .84733 L
.02094 .86714 L
.01724 .88694 L
.01377 .90674 L
.0104 .92654 L
.00704 .94634 L
.0036 .96614 L
0 .98595 L
s
0 .22432 m
.00692 .24427 L
.01344 .26421 L
.01948 .28415 L
.02501 .30409 L
.03006 .32403 L
.03444 .34398 L
.03821 .36392 L
.04142 .38386 L
.04409 .4038 L
.04626 .42375 L
.04795 .44369 L
.0492 .46363 L
.05004 .48357 L
.0505 .50351 L
s
.0505 .50351 m
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
s
.6279 .71405 m
.64748 .70314 L
.66707 .69229 L
.68665 .68154 L
.70624 .67089 L
.72582 .66002 L
.74541 .64916 L
.76499 .63838 L
.78457 .62774 L
.80416 .61694 L
.82374 .60631 L
.84333 .5955 L
.86291 .58488 L
.88249 .57405 L
.90208 .56347 L
.92166 .55288 L
.94125 .5423 L
.96083 .53171 L
.98042 .52113 L
1 .51054 L
s
.6279 .71405 m
.64748 .70718 L
.66707 .70051 L
.68665 .69361 L
.70624 .68673 L
.72582 .67985 L
.74541 .67297 L
.76499 .66608 L
.78457 .6592 L
.80416 .65232 L
.82374 .64544 L
.84333 .63856 L
.86291 .63168 L
.88249 .6248 L
.90208 .61792 L
.92166 .61104 L
.94125 .60416 L
.96083 .59728 L
.98042 .59039 L
1 .58351 L
s
.24233 1 m
.26 .99595 L
.28 .99162 L
.3 .98703 L
.32 .98243 L
.34 .97784 L
.36 .97297 L
.38 .96838 L
.4 .96378 L
.42 .95919 L
.44 .95459 L
.46 .94973 L
.48 .94514 L
.5 .94054 L
.52 .93568 L
.54 .93108 L
.56 .92649 L
.58 .92162 L
.6 .91703 L
.62 .91216 L
.64 .90757 L
.66 .90297 L
.68 .89811 L
.7 .89351 L
.72 .88865 L
.74 .88405 L
.76 .87946 L
.78 .87459 L
.8 .87 L
.82 .86541 L
.84 .86081 L
.86 .85595 L
.88 .85135 L
.9 .84676 L
.92 .84216 L
.94 .83757 L
.96 .8327 L
.98 .82811 L
s
1 .82351 m
.98 .82811 L
s
s
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
s
.12095 1 m
.14032 .98901 L
.16063 .97748 L
.18095 .96595 L
.20126 .95442 L
.22158 .94289 L
.2419 .93136 L
.26221 .91983 L
.28253 .90829 L
.30284 .89676 L
.32316 .88523 L
.34348 .8737 L
.36379 .86216 L
.38411 .85069 L
.40442 .83939 L
.42474 .82784 L
.44506 .81638 L
.46537 .80506 L
.48569 .7936 L
.506 .78227 L
.52632 .77082 L
.54664 .75948 L
.56695 .74802 L
.58727 .73679 L
.60758 .7255 L
.6279 .71405 L
s
0 1 0 r
1 0 0 r
0 0 1 r
p
0 g
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{453, 453},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000750001aA000`40O003h00OogooaWoo003oOoo6
Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00
JWoo0P0017oo00@007ooOomoo`D004Eoo`8000Aoo`03001oogoo00=oo`<004Eoo`8000Aoo`03001o
ogoo009oo`<004Ioo`8000Aoo`03001oogoo009oo`<004Yoo`<000Aoo`00JGoo00@007ooOol000Qo
o`04001oogoo0014Ool01000Oomoo`002Woo00<007ooOol0@goo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`001goo00D007ooOomoo`0004Yoo`03001oogoo00=oo`00JGoo00@007oo
Ool000Uoo`03001oogoo04Aoo`04001oogoo0007Ool50014Ool01000Oomoo`001goo00D007ooOomo
o`0004Aoo`04001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomo
o`002Woo00<007ooOol0@goo00@007ooOol000Moo`04001oogoo0015Ool01000Oomoo`001goo1000
AGoo00@007ooOol000Qoo`<004]oo`03001oogoo00=oo`00JGoo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`0027oo00<007oo0000AGoo00@007ooOol000Moo`03001oogoo04Ioo`04
001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomoo`001goo00D0
07ooOomoo`0004Aoo`04001oogoo0009Ool20015Ool01000Oomoo`0027oo00<007ooOol0AGoo00@0
07ooOol000Moo`05001oogooOol00019Ool20005Ool006Yoo`8000Uoo`<004Ioo`8000]oo`03001o
ogoo04Aoo`8000Yoo`8004Ioo`8000Uoo`<004]oo`03001oogoo00=oo`00ogooaWoo003oOoo6Ool0
0?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`007Gooo`00Y@0017oo000MOol00`00DYABU03/
DY@01000;F/]J`00?U:D00@002e[;F/006iBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@0
02e[;F/003iBU004000]Jbe[001^DY@00`00Oomoo`02Ool001eoo`03001BU5:D0>aBU004000]Jbe[
000nDY@01000;F/]J`00KU:D00<007ooOol00Woo000MOol00`00DYABU03/DY@01000;F/]J`00?U:D
00@002e[;F/006iBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]
J`0006mBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]J`0006mB
U003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]J`0006mBU003001o
ogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009o
o`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`007Goo
00<005:DDY@0k5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`007Goo00<005:D
DY@0k5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`007Goo00<005:DDY@0k5:D
00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[
;F/003iBU003000]J`0006mBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iB
U003000]J`0006mBU003001oogoo009oo`007Goo00<005:DDY@0k5:D00@002e[;F/003iBU003000]
J`0006mBU003001oogoo009oo`007Goo0P00kE:D00@002e[;F/003iBU003000]J`0006mBU003001o
ogoo009oo`007Goo00<006mk0000k5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009o
o`007Goo0P0000=_N`00DY@0jU:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`00
7Goo0P000Vmk00<005:DDY@0j5:D00@002e[;F/003iBU003000]J`0006mBU003001oogoo009oo`00
1goo0`000goo0`0017oo0P001goo0P000fmk00<005:DDY@0ie:D00@002e[;F/003iBU003000]J`00
06mBU003001oogoo009oo`001Woo00L007ooOomoo`00Ool00003Ool01000Oomoo`000Woo00<007oo
Ool017oo00<005:D00000fmk00<005:DDY@0iU:D00@002e[;F/003iBU003000]J`0006mBU003001o
ogoo009oo`001Woo00D007ooOomoo`0000Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DY@0
0004Kg/00`00DYABU03UDY@01000;F/]J`00?U:D00<002e[0000Ke:D00<007ooOol00Woo0006Ool4
0006Ool01000Oomoo`000Woo00<007ooOol017oo00<005:D00001Fmk0P00iE:D00@002e[;F/003iB
U003000]J`0006mBU003001oogoo009oo`001Woo00<007ooOol00goo10000goo00@007ooOol000Io
o`04001BU5:D0006Kg/00`00DYABU03RDY@01000;F/]J`00?U:D00<002e[0000Ke:D00<007ooOol0
0Woo0007Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`001Woo00@005:DDY@000M_N`03
001BU5:D0>5BU004000]Jbe[000nDY@00`00;F/0001_DY@00`00Oomoo`02Ool000Qoo`80009oo`D0
00=oo`8000Moo`04001BU5:D0008Kg/00`00DYABU03PDY@01000;F/]J`00?U:D00<002e[0000Ke:D
00<007ooOol00Woo000MOol01@00DYABU5:D000026mk00<005:DDY@0ge:D00@002e[;F/003iBU003
000]J`0006mBU003001oogoo009oo`007Goo00D005:DDYABU00000U_N`03001BU5:D0=iBU004000]
Jbe[000nDY@00`00;F/0001_DY@00`00Oomoo`02Ool001eoo`05001BU5:DDY@0000:Kg/00`00DYAB
U03MDY@01000;F/]J`00?U:D00<002e[0000Ke:D00<007ooOol00Woo000MOol00`00DYABU002DY@0
0`00Kg]_N`08Kg/2003LDY@01@00;F/]Jbe[0000?U:D00<002e[0000Ke:D00<007ooOol00Woo000M
Ool00`00DYABU002DY@00`00Kg]_N`0:Kg/00`00DYABU03IDY@01@00;F/]Jbe[0000?U:D00<002e[
0000Ke:D00<007ooOol00Woo000MOol00`00DYABU002DY@00`00Kg]_N`0;Kg/00`00DYABU03HDY@0
1@00;F/]Jbe[0000?U:D00<002e[0000Ke:D00<007ooOol00Woo000MOol00`00DYABU003DY@00`00
Kg]_N`0;Kg/00`00DYABU03GDY@01@00;F/]Jbe[0000?U:D00<002e[0000Ke:D00<007ooOol00Woo
000MOol00`00DYABU003DY@00`00Kg]_N`0<Kg/00`00DYABU03FDY@01@00;F/]Jbe[0000?U:D00<0
02e[0000Ke:D00<007ooOol00Woo000MOol00`00DYABU003DY@00`00Kg]_N`0=Kg/00`00DYABU03E
DY@01@00;F/]Jbe[0000?U:D00<002e[0000Ke:D00<007ooOol00Woo000MOol00`00DYABU004DY@0
0`00Kg]_N`0=Kg/00`00DYABU03DDY@01@00;F/]Jbe[0000?U:D00<002e[0000L00017oo000MOol0
0`00DYABU004DY@00`00Kg]_N`0>Kg/2003DDY@01@00;F/]Jbe[0000?U:D00<002e[00003E:D2@00
FFmk00<007ooOol00Woo000MOol00`00DYABU005DY@00`00Kg]_N`0?Kg/00`00DYABU03ADY@01@00
;F/]Jbe[0000?U:D00<002e[00005U:D4@00B6mk00<007ooOol00Woo000MOol00`00DYABU005DY@0
0`00Kg]_N`0@Kg/2003ADY@01@00;F/]Jbe[0000?U:D00<002e[00009e:D2@00?fmk00<007ooOol0
0Woo000MOol00`00DYABU006DY@00`00Kg]_N`0AKg/00`00DYABU03>DY@01@00;F/]Jbe[0000?U:D
0P00<E:D2@00=Vmk00<007ooOol00Woo000MOol00`00DYABU006DY@00`00Kg]_N`0BKg/2003>DY@0
1@00;F/]Jbe[0000?U:D0P00>U:D4@009Fmk00<007ooOol00Woo000MOol00`00DYABU007DY@00`00
Kg]_N`0CKg/00`00DYABU03;DY@01@00;F/]Jbe[0000?U:D0P00Be:D2@0076mk00<007ooOol00Woo
000MOol00`00DYABU007DY@00`00Kg]_N`0DKg/2003;DY@01@00;F/]Jbe[0000?U:D0P00E5:D1P00
5Vmk00<007ooOol00Woo000MOol00`00DYABU008DY@00`00Kg]_N`0EKg/00`00DYABU038DY@01@00
;F/]Jbe[0000?U:D0P00FU:D10004Vmk00<007ooOol00Woo000MOol00`00DYABU008DY@00`00Kg]_
N`0FKg/00`00DYABU037DY@01@00;F/]Jbe[0000?U:D0P00GU:D1`002fmk00<007ooOol00Woo000M
Ool00`00DYABU009DY@00`00Kg]_N`0FKg/00`00DYABU036DY@01@00;F/]Jbe[0000?U:D0P00IE:D
20000fmk00<007ooOol00Woo000MOol00`00DYABU00:DY@00`00Kg]_N`0FKg/00`00DYABU035DY@0
1@00;F/]Jbe[0000?U:D0P00KE:D100017oo000MOol00`00DYABU00:DY@00`00Kg]_N`0GKg/00`00
DYABU034DY@01@00;F/]Jbe[0000?U:D0P00L5:D00<007ooOol00Woo000MOol00`00DYABU00;DY@0
0`00Kg]_N`0GKg/00`00DYABU033DY@01@00;F/]Jbe[0000?U:D0P00L5:D00<007ooOol00Woo000M
Ool00`00DYABU00;DY@00`00Kg]_N`0HKg/20033DY@01@00;F/]Jbe[0000?U:D0P00L5:D00<007oo
Ool00Woo000MOol00`00DYABU00<DY@00`00Kg]_N`0IKg/00`00DYABU030DY@01@00;F/]Jbe[0000
?U:D0P00L5:D00<007ooOol00Woo000MOol00`00DYABU00<DY@00`00Kg]_N`0JKg/20030DY@01@00
;F/]Jbe[0000?U:D00<005:DDY@0Ke:D00<007ooOol00Woo000MOol00`00DYABU00=DY@00`00Kg]_
N`0KKg/2002nDY@01@00;F/]Jbe[0000?U:D00<005:DDY@0Ke:D00<007ooOol00Woo000MOol00`00
DYABU00>DY@00`00Kg]_N`0LKg/00`00DYABU02kDY@01@00;F/]Jbe[0000?U:D00<005:DDY@0Ke:D
00<007ooOol00Woo000MOol00`00DYABU00>DY@00`00Kg]_N`0MKg/2002kDY@01@00;F/]Jbe[0000
?U:D00<005:DDY@0Ke:D00<007ooOol00Woo000MOol00`00DYABU00?DY@00`00Kg]_N`0NKg/00`00
DYABU02hDY@01@00;F/]Jbe[0000?U:D00<005:DDY@0Ke:D00<007ooOol00Woo000MOol00`00DYAB
U00@DY@00`00Kg]_N`0NKg/00`00DYABU02gDY@01@00;F/]Jbe[0000?E:D0P00LE:D00<007ooOol0
0Woo000MOol00`00DYABU00@DY@00`00Kg]_N`0OKg/2002gDY@01@00;F/]Jbe[0000?E:D0P00LE:D
00<007ooOol00Woo000MOol00`00DYABU00ADY@00`00Kg]_N`0PKg/00`00DYABU02dDY@01@00;F/]
Jbe[0000?E:D00<005:DDY@0L5:D00<007ooOol00Woo000MOol00`00DYABU00BDY@00`00Kg]_N`0P
Kg/00`00DYABU02cDY@01@00;F/]Jbe[0000?E:D00<005:DDY@0L5:D00<007ooOol00Woo000MOol0
0`00DYABU00BDY@00`00Kg]_N`0QKg/2002cDY@01@00;F/]Jbe[00006U:D@@00EE:D00<007ooOol0
0Woo000MOol00`00DYABU00CDY@00`00Kg]_N`0RKg/2002aDY@01000;F/]Jbe[6`00@Fmk6@00?5:D
00<007ooOol00Woo000MOol00`00DYABU00DDY@00`00Kg]_N`0SKg/2002_DY@01@00;F/]Jbe[0000
5E:D8P00?Fmk4000;5:D00<007ooOol00Woo000MOol00`00DYABU00EDY@00`00Kg]_N`0TKg/00`00
DYABU02/DY@01@00;F/]Jbe[0000=e:D8P00:fmk4@006e:D00<007ooOol00Woo000MOol00`00DYAB
U00FDY@00`00Kg]_N`0TKg/2002/DY@01@00;F/]Jbe[0000FE:D6@008fmk40002e:D00<007ooOol0
0Woo000MOol00`00DYABU00GDY@00`00Kg]_N`0UKg/2002ZDY@01@00;F/]Jbe[0000LU:D6P006Fmk
20000e:D00<007ooOol00Woo000MOol00`00DYABU00HDY@00`00Kg]_N`0VKg/00`00DYABU02WDY@0
1000;F/]J`00SE:D4@0046mk100017oo000MOol00`00DYABU00IDY@00`00Kg]_N`0VKg/2002WDY@0
1000;F/]J`00WU:D500017oo000MOol00`00DYABU00IDY@00`00Kg]_N`0XKg/2002UDY@01000;F/]
J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00JDY@00`00Kg]_N`0YKg/00`00DYABU02RDY@0
1000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00KDY@00`00Kg]_N`0YKg/2002RDY@0
1000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00LDY@00`00Kg]_N`0ZKg/00`00DYAB
U02ODY@01000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00MDY@00`00Kg]_N`0ZKg/2
002ODY@01000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00NDY@00`00Kg]_N`0[Kg/2
002MDY@01000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00ODY@00`00Kg]_N`0/Kg/0
0`00DYABU02JDY@01000;F/]J`00/E:D00<007ooOol00Woo000MOol00`00DYABU00PDY@00`00Kg]_
N`0/Kg/2002JDY@00`00;F/0002bDY@00`00Oomoo`02Ool000Qoo`03001oogoo00=oo`8000Aoo`80
00Moo`03001BU5:D025BU003001_Nfmk02e_N`03001BU5:D09MBU003000]J`000;9BU003001oogoo
009oo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0006Ool00`00DYABU00RDY@0
0`00Kg]_N`0]Kg/2002GDY@00`00;F/0002bDY@00`00Oomoo`02Ool000Uoo`05001oogooOol00002
Ool01000Oomoo`000Woo00<007ooOol017oo00<005:DDY@08e:D00<006mkKg/0;Vmk0P00UE:D00<0
02e[0000/U:D00<007ooOol00Woo0009Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`03001BU5:D02ABU003001_Nfmk02m_N`03001BU5:D099BU003000]J`000;9BU003001o
ogoo009oo`002Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU00U
DY@00`00Kg]_N`0_Kg/2002BDY@00`00;F/0002bDY@00`00Oomoo`02Ool000Ioo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol000Ioo`03001BU5:D02IBU003001_Nfmk031_N`80091B
U003000]J`000;9BU003001oogoo009oo`001Woo1@000goo0P0017oo0P001goo00<005:DDY@09e:D
00<006mkKg/0<Fmk0`00SE:D00<002e[0000/U:D00<007ooOol00Woo000MOol00`00DYABU00XDY@0
0`00Kg]_N`0cKg/2002;DY@00`00;F/0002bDY@00`00Oomoo`02Ool001eoo`03001BU5:D02UBU003
001_Nfmk03A_N`8008UBU0800;=BU003001oogoo009oo`007Goo00<005:DDY@0:U:D0P00=Vmk0P00
Qe:D0P00/e:D00<007ooOol00Woo000MOol00`00DYABU00ZDY@01000DY@00000=Vmk0P00QE:D0P00
/e:D00<007ooOol00Woo000MOol00`00DYABU00ZDY@01000DYABU5:D0P00=Vmk0P00Pe:D0P00/e:D
00<007ooOol00Woo000MOol00`00DYABU00YDY@20005DY@2000fKg/20021DY@2002cDY@00`00Oomo
o`02Ool001eoo`03001BU5:D02UBU08000MBU08003I_N`8007mBU0800;=BU003001oogoo009oo`00
7Goo00<005:DDY@0:E:D0P002E:D0P00=Vmk0P00OE:D0P00/e:D00<007ooOol00Woo000MOol00`00
DYABU00YDY@2000;DY@2000fKg/2001kDY@2002cDY@00`00Oomoo`02Ool001eoo`03001BU5:D02QB
U003000]J`0000eBU08003I_N`8007UBU0800;=BU003001oogoo009oo`007Goo00<005:DDY@0:5:D
00<002e[00003e:D0P00=Vmk0P00Me:D00<005:DDY@0/U:D00<007ooOol00Woo000MOol00`00DYAB
U00XDY@00`00;F/0000ADY@2000fKg/2001eDY@00`00DYABU02bDY@00`00Oomoo`02Ool001eoo`80
02UBU003000]J`0001=BU08003I_N`8007=BU003001BU5:D0;9BU003001oogoo009oo`007Goo0P00
:5:D00@002e[;F/001EBU08003I_N`<0071BU003001BU5:D0;9BU003001oogoo009oo`007Goo0P00
:5:D00@002e[;F/001MBU08003M_N`<006eBU003001BU5:D0;9BU003001oogoo009oo`007Goo00<0
02e[00009e:D00@002e[;F/001UBU08003Q_N`<006YBU003001BU5:D0;9BU003001oogoo009oo`00
7Goo00<002e[00009e:D00@002e[;F/001]BU08003U_N`8006QBU003001BU5:D0;9BU003001oogoo
009oo`007Goo00<002e[00009U:D00D002e[;F/]J`0001eBU08003U_N`<006EBU003001BU5:D0;9B
U003001oogoo009oo`007Goo00@002e[;F/002EBU005000]Jbe[;F/0000ODY@2000jKg/3001RDY@0
0`00DYABU02bDY@00`00Oomoo`02Ool001eoo`04000]Jbe[000UDY@01@00;F/]Jbe[00008E:D0`00
>Vmk0P00H5:D00<005:DDY@0/U:D00<007ooOol00Woo000MOol01000;F/]J`009E:D00D002e[;F/]
J`0002ABU0<003U_N`<005eBU003001BU5:D0;9BU003001oogoo009oo`007Goo00@002e[;F/002EB
U005000]Jbe[;F/0000WDY@2000jKg/3001JDY@00`00DYABU02bDY@00`00Oomoo`02Ool001eoo`05
000]Jbe[;F/0000TDY@01@00;F/]Jbe[0000:E:D0P00>fmk0P00F5:D00<005:DDY@0/U:D00<007oo
Ool00Woo000MOol01@00;F/]Jbe[00008e:D00<002e[;F/00be[00<005:DDY@0:5:D0P00>fmk0`00
DE:D<P00Qe:D00<007ooOol00Woo000MOol01@00;F/]Jbe[00008e:D00<002e[;F/00be[00<005:D
DY@0:U:D0P00?6mk0`00B5:D1P00<Vmk:P00GE:D00<007ooOol00Woo000MOol01@00;F/]Jbe[0000
8e:D00<002e[;F/00be[00<005:DDY@0;5:D0P00?Fmk0`00@E:D1000HVmk8@00?5:D00<007ooOol0
0Woo000MOol00`00;F/]J`02;F/00`00DYABU00PDY@00`00;F/]J`03;F/00`00DYABU00^DY@3000m
Kg/3000jDY@40027Kg/Q000KDY@00`00Oomoo`02Ool001eoo`03000]Jbe[008]J`03001BU5:D021B
U003000]Jbe[00<]J`03001BU5:D035BU0<003e_N`<003=BU0@00:a_Na`000Aoo`007Goo00<002e[
;F/00Re[00<005:DDY@085:D00<002e[;F/00be[00<005:DDY@0=5:D0P00?Vmk0`00;5:D1000bfmk
00<007ooOol00Woo000MOol00`00;F/]J`03;F/00`00DYABU00ODY@00`00;F/]J`03;F/00`00DYAB
U00fDY@3000nKg/4000TDY@4003?Kg/00`00Oomoo`02Ool001eoo`03000]Jbe[00<]J`03001BU5:D
01iBU003000]Jbe[00@]J`03001BU5:D03UBU0<003m_N`<001eBU0@00==_N`03001oogoo009oo`00
7Goo00<002e[;F/00be[00<005:DDY@07U:D00<002e[;F/012e[00<005:DDY@0?5:D0`00?fmk0`00
5U:D1000efmk00<007ooOol00Woo000MOol00`00;F/]J`04;F/00`00DYABU00MDY@00`00;F/]J`04
;F/00`00DYABU00oDY@3000oKg/3000@DY@3003KKg/00`00Oomoo`02Ool001eoo`03000]Jbe[00@]
J`03001BU5:D01eBU003000]Jbe[00@]J`03001BU5:D049BU0<003m_N`<000YBU0<00=i_N`03001o
ogoo009oo`007Goo00<002e[;F/012e[00<005:DDY@075:D00<002e[;F/01Be[00<005:DDY@0AE:D
0`00?fmk10000e:D0`00hFmk00<007ooOol00Woo000MOol00`00;F/]J`05;F/00`00DYABU00KDY@0
0`00;F/]J`05;F/00`00DYABU018DY@4000MKg]30036Kg/00`00Oomoo`02Ool001eoo`03000]Jbe[
00D]J`03001BU5:D01]BU003000]Jbe[00D]J`03001BU5:D04aBU1d004=ooc<009=_N`03001oogoo
009oo`007Goo00<002e[;F/01Be[00<005:DDY@06e:D00<002e[;F/01Be[00<005:DDY@0BE:D0`00
5fmk<`00BGoo8P00LFmk00<007ooOol00Woo000MOol00`00;F/]J`06;F/00`00DYABU00JDY@00`00
;F/]J`05;F/00`00DYABU016DY@3001=Kg/c000hOolZ0017Kg/00`00Oomoo`02Ool001eoo`03000]
Jbe[00H]J`03001BU5:D01YBU003000]Jbe[00H]J`03001BU5:D04=BU08008=_Nb/003MooaX002e_
N`03001oogoo009oo`007Goo00<002e[;F/01Re[00<005:DDY@06E:D00<002e[;F/01be[00<005:D
DY@0@E:D0P00WVmk20002U:D@P003goo8P002fmk00<007ooOol00Woo000MOol00`00;F/]J`06;F/0
0`00DYABU00IDY@00`00;F/]J`07;F/00`00DYABU00oDY@2002HKg/8000RDY@I000IKg/m0004Ool0
01eoo`03000]Jbe[00H]J`03001BU5:D01UBU003000]Jbe[00L]J`03001BU5:D03eBU080095_N`T0
04=BU10004E_N`03001oogoo009oo`007Goo00<002e[;F/01be[00<005:DDY@065:D00<002e[;F/0
1be[00<005:DDY@0>e:D0P00Rfmk2000G5:D6@00;6mk00<007ooOol00Woo000MOol00`00;F/]J`07
;F/00`00DYABU00HDY@00`00;F/]J`07;F/00`00DYABU00iDY@20025Kg/8001mDY@A000KKg/00`00
Oomoo`02Ool001eoo`03000]Jbe[00L]J`03001BU5:D01QBU003000]Jbe[00L]J`8003QBU08007i_
N`T009IBU1P000=_N`03001oogoo009oo`007Goo00<002e[;F/01be[00<005:DDY@065:D00<002e[
;F/01Re[0`00=U:D0P00N6mk2000]e:D100017oo000MOol00`00;F/]J`08;F/00`00DYABU00FDY@0
0`00;F/]J`07;F/200000be[001BU00bDY@2001dKg/60032DY@00`00Oomoo`02Ool001eoo`03000]
Jbe[00P]J`03001BU5:D01IBU003000]Jbe[00L]J`80008]J`03001BU5:D02iBU080075_N`D00<QB
U003001oogoo009oo`007Goo00<002e[;F/022e[00<005:DDY@05U:D00<002e[;F/01be[0P000Re[
00<005:DDY@0;5:D0P00KFmk1P00cE:D00<007ooOol00Woo0008Ool00`00Oomoo`02Ool30004Ool2
0007Ool00`00;F/]J`08;F/00`00DYABU00FDY@00`00;F/]J`06;F/00`0048@00003;F/00`00DYAB
U00YDY@2001WKg/8003CDY@00`00Oomoo`02Ool000Qoo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol017oo00<002e[;F/02Be[00<005:DDY@055:D00<002e[;F/01be[00<001240000
0be[00<005:DDY@09e:D0P00HFmk2000fe:D00<007ooOol00Woo0009Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol017oo00<002e[;F/02Be[00<005:DDY@055:D00<002e[;F/01be[00<0
0124000012e[00<005:DDY@09E:D00<006mkKg/0F6mk2@00he:D00<007ooOol00Woo0009Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol017oo00<002e[;F/02Be[00<005:DDY@055:D00<0
02e[;F/01Re[00@0012448@000@]J`03001BU5:D02=BU08005=_N`P00>aBU003001oogoo009oo`00
2Woo00<007oo00000`000goo00@007ooOol000Ioo`03000]Jbe[00T]J`03001BU5:D01ABU003000]
Jbe[00H]J`04000@Q1240005;F/00`00DYABU00PDY@2001?Kg/6003dDY@00`00Oomoo`02Ool000Io
o`07001oogooOol007oo00001Woo00@007ooOol000Ioo`03000]Jbe[00X]J`03001BU5:D01=BU003
000]Jbe[00H]J`05000@Q12448@00005;F/00`00DYABU00NDY@00`00Kg]_N`1:Kg/5003jDY@00`00
Oomoo`02Ool000Ioo`D00003Ool0000000<000=oo`8000Moo`03000]Jbe[00X]J`03001BU5:D01=B
U003000]Jbe[00D]J`03000@Q124008@Q003000]Jbe[00<]J`03001BU5:D01aBU08004M_N`H00?mB
U003001oogoo009oo`007Goo00<002e[;F/02Re[00<005:DDY@04U:D00<002e[;F/01Re[00<00124
48@00Q2400<002e[;F/012e[00<005:DDY@06E:D0P00@Fmk2000oe:D1U:D00<007ooOol00Woo000M
Ool00`00;F/]J`0:;F/00`00DYABU00BDY@00`00;F/]J`06;F/00`0048@@Q00248@00`00;F/]J`04
;F/00`00DYABU00GDY@2000kKg/8003oDY@>DY@00`00Oomoo`02Ool001eoo`03000]Jbe[00X]J`03
001BU5:D019BU003000]Jbe[00D]J`03000@Q12400<@Q003000]Jbe[00D]J`03001BU5:D01ABU080
03I_N`L00?mBU1IBU003001oogoo009oo`007Goo00<002e[;F/02be[00<005:DDY@04E:D00<002e[
;F/01Be[00<0012448@00a2400<002e[;F/01Be[00<005:DDY@04U:D0P00=6mk1000oe:D7E:D00<0
07ooOol00Woo000MOol00`00;F/]J`0;;F/00`00DYABU00ADY@00`00;F/]J`05;F/00`0048@@Q003
48@00`00;F/]J`06;F/00`00DYABU00@DY@00`00Kg]_N`0^Kg/6003oDY@QDY@00`00Oomoo`02Ool0
01eoo`03000]Jbe[00/]J`03001BU5:D015BU003000]Jbe[00D]J`03000@Q12400<@Q003000]Jbe[
00H]J`03001BU5:D00iBU08002U_N`P00?mBU2MBU003001oogoo009oo`007Goo00<002e[;F/02be[
00<005:DDY@04E:D00<002e[;F/012e[00<0012448@0112400<002e[;F/01be[00<005:DDY@02e:D
0P008Vmk2@00oe:D;e:D00<007ooOol00Woo000MOol00`00;F/]J`0<;F/00`00DYABU00@DY@00`00
;F/]J`04;F/00`0048@@Q00448@00`00;F/]J`07;F/00`00DYABU00:DY@00`00Kg]_N`0JKg/8003o
DY@hDY@00`00Oomoo`02Ool001eoo`03000]Jbe[00`]J`03001BU5:D00mBU003000]Jbe[00D]J`03
000@Q12400@@Q003000]Jbe[00P]J`03001BU5:D00MBU08001M_N`H00?mBU41BU003001oogoo009o
o`007Goo00<002e[;F/032e[00<005:DDY@03e:D00<002e[;F/01Be[00<0012448@0112400<002e[
;F/022e[00<005:DDY@01U:D00<006mkKg/04Vmk1@00oe:DAU:D00<007ooOol00Woo000MOol00`00
;F/]J`0<;F/00`00DYABU00?DY@00`00;F/]J`04;F/00`0048@@Q00548@00`00;F/]J`09;F/00`00
DYABU003DY@2000?Kg/6003oDYA;DY@00`00Oomoo`02Ool001eoo`03000]Jbe[00d]J`03001BU5:D
00iBU003000]Jbe[00@]J`03000@Q12400D@Q003000]Jbe[00X]J`03001BU5:D008000U_N`P00?mB
U55BU003001oogoo009oo`007Goo00<002e[;F/03Be[00<005:DDY@03U:D00<002e[;F/012e[00<0
012448@01A2400<002e[;F/02Re[00<005:D00000fmk2000oe:DFE:D00<007ooOol00Woo000MOol0
0`00;F/]J`0=;F/00`00DYABU00>DY@00`00;F/]J`04;F/00`0048@@Q00548@00`00;F/]J`0;;F/5
003oDYAQDY@00`00Oomoo`02Ool001eoo`03000]Jbe[00d]J`03001BU5:D00iBU003000]Jbe[00<]
J`03000@Q12400H@Q003000]Jbe[00X]J`03001BU5:D0?mBU6ABU003001oogoo009oo`007Goo00<0
02e[;F/03Be[00<005:DDY@03E:D00<002e[;F/012e[00<0012448@01Q2400<002e[;F/02Be[00<0
05:DDY@0oe:DIE:D00<007ooOol00Woo000MOol00`00;F/]J`0=;F/00`00DYABU00=DY@00`00;F/]
J`04;F/00`0048@@Q00648@00`00;F/]J`07;F/2003oDYAXDY@00`00Oomoo`02Ool001eoo`03000]
Jbe[00h]J`03001BU5:D00aBU003000]Jbe[00@]J`03000@Q12400H@Q003000]Jbe[00H]J`03001B
U5:D0?mBU6QBU003001oogoo009oo`007Goo00<002e[;F/03Re[00<005:DDY@035:D00<002e[;F/0
12e[00<0012448@01Q2400<002e[;F/01Be[00<005:DDY@0oe:DJE:D00<007ooOol00Woo000MOol0
0`00;F/]J`0>;F/00`00DYABU00;DY@00`00;F/]J`04;F/00`0048@@Q00748@00`00;F/]J`03;F/2
003oDYA/DY@00`00Oomoo`02Ool001eoo`03000]Jbe[00h]J`03001BU5:D00]BU003000]Jbe[00@]
J`03000@Q12400L@Q003000]Jbe[008]J`03001BU5:D0?mBU6aBU003001oogoo009oo`007Goo00<0
02e[;F/03Re[00<005:DDY@02e:D00<002e[;F/012e[00<0012448@0212400@002e[;F/00?mBU6mB
U003001oogoo009oo`007Goo00<002e[;F/03Re[00<005:DDY@02e:D00<002e[;F/00be[00<00124
48@02A2400<002e[0000oe:DL5:D00<007ooOol00Woo000MOol00`00;F/]J`0>;F/00`00DYABU00:
DY@00`00;F/]J`04;F/00`0048@@Q00948@2003oDYAaDY@00`00Oomoo`02Ool001eoo`03000]Jbe[
00h]J`03001BU5:D00YBU003000]Jbe[00@]J`03000@Q12400T@Q0h00?mBU6EBU003001oogoo009o
o`007Goo00<002e[;F/03be[00<005:DDY@02E:D00<002e[;F/00be[00<0012448@02Q2400<002e[
;F/02be[2000oe:DGE:D00<007ooOol00Woo000MOol00`00;F/]J`0?;F/00`00DYABU009DY@00`00
;F/]J`03;F/00`0048@@Q00:48@00`00;F/]J`0C;F/A003oDYA<DY@00`00Oomoo`02Ool001eoo`03
000]Jbe[00l]J`03001BU5:D00QBU003000]Jbe[00@]J`03000@Q12400T@Q003000]Jbe[02D]J`P0
0?mBU4ABU003001oogoo009oo`007Goo00<002e[;F/03be[00<005:DDY@025:D00<002e[;F/00be[
00<0012448@02Q2400<002e[;F/0;Be[4@00oe:D<e:D00<007ooOol00Woo000MOol00`00;F/]J`0?
;F/00`00DYABU008DY@00`00;F/]J`03;F/00`0048@@Q00:48@00`00;F/]J`0n;F/9003oDY@ZDY@0
0`00Oomoo`02Ool001eoo`03000]Jbe[00l]J`03001BU5:D00QBU003000]Jbe[008]J`03000@Q124
00/@Q003000]Jbe[04L]J`P00?mBU29BU003001oogoo009oo`007Goo00<002e[;F/03be[00<005:D
DY@025:D00<002e[;F/00Re[00<0012448@02Q2400<002e[;F/0D2e[2000oe:D6U:D00<007ooOol0
0Woo000MOol00`00;F/]J`0?;F/00`00DYABU008DY@00`00;F/]J`02;F/00`0048@@Q00:48@00`00
;F/]J`1H;F/9003oDY@ADY@00`00Oomoo`02Ool001eoo`03000]Jbe[00l]J`03001BU5:D00MBU003
000]Jbe[008]J`03000@Q12400/@Q003000]Jbe[064]Ja400?mBU003001oogoo009oo`007Goo00<0
02e[;F/042e[00<005:DDY@01U:D00<002e[;F/00Re[00<0012448@02a2400<002e[;F/0LRe[2000
me:D00<007ooOol00Woo000MOol00`00;F/]J`0@;F/00`00DYABU006DY@00`00;F/]J`02;F/00`00
48@@Q00;48@00`00;F/]J`1j;F/9003^DY@00`00Oomoo`02Ool001eoo`03000]Jbe[010]J`03001B
U5:D00IBU005000]Jbe[;F/0000>48@00`00;F/]J`23;F/8003VDY@00`00Oomoo`02Ool001eoo`03
000]Jbe[010]J`03001BU5:D00IBU005000]Jbe[;F/0000=48@00`00;F/]J`2<;F/8003NDY@00`00
Oomoo`02Ool001eoo`03000]Jbe[010]J`03001BU5:D00IBU005000]Jbe[;F/0000=48@00`00;F/]
J`2D;F/9003EDY@00`00Oomoo`02Ool001eoo`03000]Jbe[010]J`03001BU5:D00IBU005000]Jbe[
;F/0000=48@00`00;F/]J`2M;F/8003=DY@00`00Oomoo`02Ool001eoo`03000]Jbe[010]J`03001B
U5:D00EBU005000]Jbe[;F/0000>48@00`00;F/]J`2U;F/90034DY@00`00Oomoo`02Ool001eoo`03
000]Jbe[010]J`03001BU5:D00EBU005000]Jbe[;F/0000>48@00`00;F/]J`2^;F/A002cDY@00`00
Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D00ABU005000]Jbe[;F/0000>48@00`00;F/]
J`2o;F/8002[DY@00`00Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D00ABU005000]Jbe[
;F/0000>48@00`00;F/]J`37;F/8002SDY@00`00Oomoo`02Ool001eoo`03000]Jbe[014]J`03001B
U5:D00=BU005000]Jbe[;F/0000?48@00`00;F/]J`3?;F/9002JDY@00`00Oomoo`02Ool001eoo`03
000]Jbe[014]J`03001BU5:D00=BU005000]Jbe[;F/0000>48@00`00;F/]J`3I;F/8002BDY@00`00
Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D00=BU005000]Jbe[;F/0000>48@00`00;F/]
J`3Q;F/90029DY@00`00Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D00=BU004000]Jbe[
000?48@00`00;F/]J`3Z;F/A001hDY@00`00Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D
009BU005000]Jbe[;F/0000?48@00`00;F/]J`3k;F/8001`DY@00`00Oomoo`02Ool000Moo`<000Ao
o`8000Aoo`8000Moo`03000]Jbe[014]J`03001BU5:D009BU005000]Jbe[;F/0000?48@00`00;F/]
J`3o;F/4;F/8001XDY@00`00Oomoo`02Ool000Ioo`05001oogooOol00002Ool01000Oomoo`000Woo
00@007ooOol000Ioo`03000]Jbe[014]J`03001BU5:D009BU004000]Jbe[000@48@00`00;F/]J`3o
;F/<;F/9001ODY@00`00Oomoo`02Ool000Ioo`05001oogooOol00002Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03000]Jbe[014]J`03001BU5:D009BU004000]Jbe[000@48@00`00;F/]J`3o;F/E
;F/A001>DY@00`00Oomoo`02Ool000Moo`<000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<0
02e[;F/04Be[00<005:DDY@00U:D00@002e[;F/000l@Q003000]Jbe[0?l]JbL]J`P004IBU003001o
ogoo009oo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<002e[
;F/04Be[00D005:DDYABU000008]J`03000@Q12400h@Q003000]Jbe[0?l]Jbl]J`P003iBU003001o
ogoo009oo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<002e[
;F/04Be[00D005:DDYABU000008]J`03000@Q12400h@Q003000]Jbe[0?l]JcL]Ja4002eBU003001o
ogoo009oo`001goo0`0017oo0P0017oo0P001goo00<002e[;F/04Be[00D005:DDYABU000008]J`03
000@Q12400h@Q003000]Jbe[0?l]JdP]J`T002ABU003001oogoo009oo`007Goo00<002e[;F/04Be[
00L005:DDYABU000;F/0000@48@00`00;F/]J`3o;F]B;F/A000CDY@00`00Oomoo`02Ool001eoo`03
000]Jbe[014]J`07001BU5:DDY@002e[0000412400<002e[;F/0obe[Hbe[20002e:D00<007ooOol0
0Woo000MOol00`00;F/]J`0A;F/01`00DYABU5:D000]J`00010@Q003000]Jbe[0?l]Jf/]J``000Ao
o`007Goo00<002e[;F/04Re[00D005:D000]J`00014@Q003000]Jbe[0?l]JgH]J`03001oogoo009o
o`007Goo00<002e[;F/04Re[00D005:D000]J`00014@Q003000]Jbe[0?l]JgH]J`03001oogoo009o
o`007Goo00<002e[;F/04Re[00D005:D000]J`00014@Q003000]Jbe[0?l]JgH]J`03001oogoo009o
o`007Goo00<002e[;F/04Re[00@005:D0000014@Q003000]Jbe[0?l]JgL]J`03001oogoo009oo`00
7Goo00<002e[;F/04Re[00@005:D0000014@Q003000]Jbe[0?l]JgL]J`03001oogoo009oo`007Goo
00<002e[;F/04Re[00<005:D00004Q2400<002e[;F/0obe[Mbe[00<007ooOol00Woo000MOol00`00
;F/]J`0B;F/3000B48@00`00;F/]J`3o;F]g;F/00`00Oomoo`02Ool001eoo`03000]Jbe[018]J`<0
018@Q003000]Jbe[0?l]JgL]J`03001oogoo009oo`007Goo00<002e[;F/04Re[0P004a2400<002e[
;F/0obe[Mbe[00<007ooOol00Woo000MOol00`00;F/]J`0B;F/2000B48@00`00;F/]J`3o;F]h;F/0
0`00Oomoo`02Ool001eoo`03000]Jbe[018]J`80018@Q003000]Jbe[0?l]JgP]J`03001oogoo009o
o`007Goo00<002e[;F/04Re[00<0012448@04A2400<002e[;F/0obe[N2e[00<007ooOol00Woo000M
Ool00`00;F/]J`0B;F/00`0048@@Q00A48@00`00;F/]J`3o;F]h;F/00`00Oomoo`02Ool001eoo`03
000]Jbe[018]J`03000@Q124010@Q003000]Jbe[0?l]JgT]J`03001oogoo009oo`007Goo00<002e[
;F/04Be[00<0012448@04A2400<002e[;F/0obe[N2e[0P0017oo000MOol00`00;F/]J`0A;F/00`00
48@@Q00A48@00`00;F/]J`3o;F]g;F/00`0048@00004Ool001eoo`03000]Jbe[014]J`03000@Q124
014@Q003000]Jbe[0?l]JgD]J`80008@Q003001oogoo009oo`007Goo00<002e[;F/04Be[00<00124
48@04A2400<002e[;F/0obe[Lbe[0P00112400<007ooOol00Woo000MOol00`00;F/]J`0A;F/00`00
48@@Q00A48@00`00;F/]J`3o;F]b;F/00`0048@@Q00448@00`00Oomoo`02Ool001eoo`03000]Jbe[
010]J`03000@Q124014@Q003000]Jbe[0?l]Jg4]J`8000L@Q003001oogoo009oo`007Goo00<002e[
;F/042e[00<0012448@04A2400<002e[;F/0obe[Kbe[0P002A2400<007ooOol00Woo000MOol00`00
;F/]J`0@;F/00`0048@@Q00A48@00`00;F/]J`3o;F]];F/2000;48@00`00Oomoo`02Ool001eoo`03
000]Jbe[010]J`03000@Q124014@Q003000]Jbe[0?l]Jf/]J`8000d@Q003001oogoo009oo`007Goo
00<002e[;F/03be[00<0012448@04Q2400<002e[;F/0obe[JBe[0P003a2400<007ooOol00Woo000M
Ool00`00;F/]J`0?;F/00`0048@@Q00B48@00`00;F/]J`3o;F]X;F/00`0048@@Q00?48@00`00Oomo
o`02Ool001eoo`03000]Jbe[00l]J`03000@Q124018@Q003000]Jbe[0?l]JfH]J`80018@Q003001o
ogoo009oo`007Goo00<002e[;F/03be[00<0012448@04A2400<002e[;F/0obe[IBe[0P00512400<0
07ooOol00Woo000MOol00`00;F/]J`0>;F/00`0048@@Q00B48@00`00;F/]J`3o;F]T;F/00`0048@@
Q00D48@00`00Oomoo`02Ool001eoo`03000]Jbe[00h]J`03000@Q124018@Q003000]Jbe[0?l]Jf8]
J`8001L@Q003001oogoo009oo`007Goo00<002e[;F/03Re[00<0012448@04Q2400<002e[;F/0obe[
H2e[0P006A2400<007ooOol00Woo000MOol00`00;F/]J`0>;F/00`0048@@Q00A48@00`00;F/]J`3o
;F]O;F/2000K48@00`00Oomoo`02Ool001eoo`03000]Jbe[00h]J`03000@Q124014@Q003000]Jbe[
0?l]Jed]J`8001d@Q003001oogoo009oo`007Goo00<002e[;F/03Re[00<0012448@04A2400<002e[
;F/0obe[Fbe[0P007a2400<007ooOol00Woo000MOol00`00;F/]J`0=;F/00`0048@@Q00B48@00`00
;F/]J`3o;F]I;F/2000Q48@00`00Oomoo`02Ool001eoo`03000]Jbe[00d]J`03000@Q124018@Q003
000]Jbe[0?l]JeL]J`8002<@Q003001oogoo009oo`007Goo00<002e[;F/03Be[00<0012448@04Q24
00<002e[;F/0obe[ERe[00<0012448@08a2400<007ooOol00Woo000MOol00`00;F/]J`0=;F/00`00
48@@Q00A48@00`00;F/]J`3o;F]E;F/2000V48@00`00Oomoo`02Ool001eoo`03000]Jbe[00d]J`03
000@Q124014@Q003000]Jbe[0?l]Je<]J`8002P@Q003001oogoo009oo`007Goo00<002e[;F/03Be[
00<0012448@04A2400<002e[;F/0obe[DBe[0P00:Q2400<007ooOol00Woo000MOol00`00;F/]J`0=
;F/00`0048@@Q00A48@00`00;F/]J`3o;F]?;F/2000/48@00`00Oomoo`02Ool001eoo`03000]Jbe[
00`]J`03000@Q124018@Q003000]Jbe[0?l]Jdd]J`8002h@Q003001oogoo009oo`007Goo00<002e[
;F/032e[00<0012448@04Q2400<002e[;F/0obe[Bbe[0P00<12400<007ooOol00Woo000MOol00`00
;F/]J`0<;F/00`0048@@Q00A48@00`00;F/]J`3o;F];;F/00`0048@@Q00`48@00`00Oomoo`02Ool0
01eoo`03000]Jbe[00`]J`03000@Q124014@Q003000]Jbe[0?l]JdT]J`8003<@Q003001oogoo009o
o`007Goo00<002e[;F/02be[00<0012448@04Q2400<002e[;F/0obe[Abe[0P00=A2400<007ooOol0
0Woo000MOol00`00;F/]J`0;;F/00`0048@@Q00B48@00`00;F/]J`3o;F]6;F/00`0048@@Q00d48@2
0004Ool001eoo`03000]Jbe[00/]J`03000@Q124018@Q003000]Jbe[0?l]Jd@]J`8003@@Q0<00003
;F/007oo00=oo`001goo0`000goo0`0017oo0P001goo00<002e[;F/02be[00<0012448@04A2400<0
02e[;F/0obe[@be[0P00<a240`0012e[00<007ooOol00Woo0006Ool01`00Oomoogoo001oo`0000=o
o`04001oogoo0002Ool00`00Oomoo`04Ool00`00;F/]J`0:;F/00`0048@@Q00B48@00`00;F/]J`3o
;F]1;F/2000c48@20007;F/00`00Oomoo`02Ool000Ioo`05001oogooOol00005Ool01000Oomoo`00
0Woo00<007ooOol017oo00<002e[;F/02Re[00<0012448@04Q2400<002e[;F/0obe[?be[0P00<Q24
0`002Be[00<007ooOol00Woo0007Ool30006Ool01000Oomoo`000Woo00<007ooOol017oo00<002e[
;F/02Re[00<0012448@04Q2400<002e[;F/0obe[?Be[0P00<A240`0032e[00<007ooOol00Woo0006
Ool01P00Oomoogoo001oo`@000=oo`04001oogoo0006Ool00`00;F/]J`0:;F/00`0048@@Q00A48@0
0`00;F/]J`3o;F/m;F/00`0048@@Q00_48@2000?;F/00`00Oomoo`02Ool000Ioo`07001oogooOol0
07oo00001Woo00@007ooOol000Ioo`03000]Jbe[00T]J`03000@Q124018@Q003000]Jbe[0?l]Jc/]
J`8002l@Q0<0014]J`03001oogoo009oo`001goo0`000Woo1@000goo0P001goo00<002e[;F/02Be[
00<0012448@04Q2400<002e[;F/0obe[>Be[0P00;Q240`0052e[00<007ooOol00Woo000MOol00`00
;F/]J`09;F/00`0048@@Q00B48@00`00;F/]J`3o;F/h;F/00`0048@@Q00/48@2000G;F/00`00Oomo
o`02Ool001eoo`03000]Jbe[00T]J`03000@Q124014@Q003000]Jbe[0?l]JcL]J`8002`@Q0<001T]
J`03001oogoo009oo`007Goo00<002e[;F/022e[00<0012448@04Q2400<002e[;F/0obe[=Be[0P00
:a240`0072e[00<007ooOol00Woo000MOol00`00;F/]J`08;F/00`0048@@Q00B48@00`00;F/]J`3o
;F/b;F/3000Z48@3000O;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00P]J`03000@Q124018@Q003
000]Jbe[0?l]Jc0]J`8002P@Q0D0028]J`03001oogoo009oo`007Goo00<002e[;F/022e[00<00124
48@04Q2400<002e[;F/0obe[;Re[0P009a240`009be[00<007ooOol00Woo000MOol00`00;F/]J`08
;F/00`0048@@Q00B48@00`00;F/]J`3o;F/];F/00`0048@@Q00T48@3000Z;F/00`00Oomoo`02Ool0
01eoo`03000]Jbe[00L]J`03000@Q124018@Q003000]Jbe[0?l]Jb`]J`8002@@Q0<002d]J`03001o
ogoo009oo`007Goo00<002e[;F/01be[00<0012448@04Q2400<002e[;F/0obe[:Re[0P0091240P00
<2e[00<007ooOol00Woo000MOol00`00;F/]J`07;F/00`0048@@Q00B48@00`00;F/]J`3o;F/Y;F/0
0`0048@@Q00Q48@3000b;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00L]J`03000@Q124018@Q003
000]Jbe[0?l]JbL]J`80024@Q0<003D]J`03001oogoo009oo`007Goo00<002e[;F/01Re[00<00124
48@04a2400<002e[;F/0obe[9Be[0P008A240P00>2e[00<007ooOol00Woo000MOol00`00;F/]J`06
;F/00`0048@@Q00C48@00`00;F/]J`3o;F/S;F/2000P48@3000j;F/00`00Oomoo`02Ool001eoo`03
000]Jbe[00H]J`03000@Q124018@Q003000]Jbe[0?l]Jb8]J`8001l@Q0<003d]J`03001oogoo009o
o`007Goo00<002e[;F/01Re[00<0012448@04Q2400<002e[;F/0obe[82e[0P007a240P00@2e[00<0
07ooOol00Woo000MOol00`00;F/]J`05;F/00`0048@@Q00C48@00`00;F/]J`3o;F/O;F/00`0048@@
Q00L48@30012;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00D]J`03000@Q12401<@Q003000]Jbe[
0?l]Jad]J`8001`@Q0<004D]J`03001oogoo009oo`007Goo00<002e[;F/01Be[00<0012448@04a24
00<002e[;F/0obe[6be[0P0071240P00B2e[00<007ooOol00Woo000MOol00`00;F/]J`05;F/00`00
48@@Q00B48@00`00;F/]J`3o;F/K;F/00`0048@@Q00I48@3001:;F/00`00Oomoo`02Ool001eoo`03
000]Jbe[00@]J`03000@Q12401<@Q003000]Jbe[0?l]JaT]J`8001T@Q0<004d]J`03001oogoo009o
o`007Goo00<002e[;F/012e[00<0012448@04a2400<002e[;F/0obe[5be[0P0061240`00D2e[00<0
07ooOol00Woo000MOol00`00;F/]J`04;F/00`0048@@Q00C48@00`00;F/]J`3o;F/D;F/3000G48@3
001C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00@]J`03000@Q124018@Q003000]Jbe[0?l]Ja<]
J`8001L@Q0<005H]J`03001oogoo009oo`007Goo00<002e[;F/00be[00<0012448@04a2400<002e[
;F/0obe[4Be[0P005a240P00FBe[00<007ooOol00Woo000MOol00`00;F/]J`03;F/00`0048@@Q00C
48@00`00;F/]J`3o;F/@;F/00`0048@@Q00D48@3001K;F/00`00Oomoo`02Ool001eoo`03000]Jbe[
00<]J`03000@Q12401<@Q003000]Jbe[0?l]J`h]J`8001@@Q0<005h]J`03001oogoo009oo`007Goo
00<002e[;F/00be[00<0012448@04Q2400<002e[;F/0obe[3Be[0P0051240P00HBe[00<007ooOol0
0Woo000MOol00`00;F/]J`02;F/00`0048@@Q00C48@00`00;F/]J`3o;F/<;F/00`0048@@Q00A48@3
001S;F/00`00Oomoo`02Ool001eoo`03000]Jbe[008]J`03000@Q12401<@Q003000]Jbe[0?l]J`X]
J`80014@Q0<006H]J`03001oogoo009oo`007Goo00<002e[;F/00Re[00<0012448@04a2400<002e[
;F/0obe[22e[0P0041240`00JBe[00<007ooOol00Woo000MOol00`00;F/]J`02;F/00`0048@@Q00B
48@00`00;F/]J`3o;F/7;F/2000=48@5001/;F/00`00Oomoo`02Ool001eoo`03000]Jbe[008]J`03
000@Q124018@Q003000]Jbe[0?l]J`D]J`8000`@Q0<0074]J`03001oogoo009oo`007Goo00D002e[
;F/]J`0001D@Q003000]Jbe[0?l]J`<]J`8000/@Q0<007@]J`03001oogoo009oo`007Goo00D002e[
;F/]J`0001D@Q003000]Jbe[0?l]J`8]J`03000@Q12400P@Q0<007L]J`03001oogoo009oo`007Goo
00D002e[;F/]J`0001@@Q003000]Jbe[0?l]J`4]J`8000T@Q08007X]J`03001oogoo009oo`007Goo
00D002e[;F/]J`0001@@Q003000]Jbe[0?h]J`8000P@Q0<007`]J`03001oogoo009oo`007Goo00@0
02e[;F/001D@Q003000]Jbe[0?d]J`03000@Q12400D@Q0<007l]J`03001oogoo009oo`007Goo00@0
02e[;F/001D@Q003000]Jbe[0?/]J`8000H@Q080088]J`03001oogoo009oo`007Goo00@002e[;F/0
01@@Q003000]Jbe[0?X]J`8000D@Q0<008@]J`03001oogoo009oo`007Goo00@002e[;F/001@@Q003
000]Jbe[0?P]J`8000@@Q0<008L]J`03001oogoo009oo`007Goo00<002e[00005A2400<002e[;F/0
mRe[0P0011240P00RRe[00<007ooOol00Woo000MOol00`00;F/0000E48@00`00;F/]J`3d;F/20003
48@3002<;F/00`00Oomoo`02Ool001eoo`03000]J`0001D@Q003000]Jbe[0?8]J`80008@Q0<008l]
J`03001oogoo009oo`007Goo00<002e[0000512400<002e[;F/0lBe[0P000Q240P00TRe[00<007oo
Ool00Woo000MOol2000E48@00`00;F/]J`3`;F/00`0048@00002002D;F/00`00Oomoo`02Ool001eo
o`8001D@Q003000]Jbe[0>h]J`@009L]J`03001oogoo009oo`007Goo0P005A2400<002e[;F/0jbe[
1000VRe[00<007ooOol00Woo000MOol2000D48@00`00;F/]J`3X;F/5002M;F/00`00Oomoo`02Ool0
01eoo`03000@Q12401<@Q003000]Jbe[0>D]J`<0009BU08009h]J`03001oogoo009oo`007Goo00<0
012448@04a2400<002e[;F/0hRe[0`000e:D0P00X2e[00<007ooOol00Woo0007Ool20005Ool20004
Ool20007Ool00`0048@@Q00C48@00`00;F/]J`3O;F/30005DY@00`00;F/]J`2P;F/00`00Oomoo`02
Ool000Uoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<0012448@04Q24
00<002e[;F/0gBe[0`001U:D0P00Xbe[00<007ooOol00Woo000:Ool01000Oomoo`000Woo00@007oo
Ool0009oo`03001oogoo00Aoo`03000@Q124018@Q003000]Jbe[0=X]J`<000MBU0800:D]J`03001o
ogoo009oo`001goo10000Woo00@007ooOol0009oo`04001oogoo0006Ool00`0048@@Q00B48@00`00
;F/]J`3G;F/30007DY@3002W;F/00`00Oomoo`02Ool000Ioo`05001oogooOol00002Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03000@Q124018@Q003000]Jbe[0=D]J`8000QBU0800:X]J`03001o
ogoo009oo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<00124
48@04A2400<002e[;F/0dbe[0`0025:D0P00[2e[00<007ooOol00Woo0007Ool30004Ool20004Ool2
0007Ool00`0048@@Q00A48@00`00;F/]J`3@;F/3000:DY@00`00;F/]J`2/;F/00`00Oomoo`02Ool0
01eoo`03000@Q124014@Q003000]Jbe[0<d]J`<000]BU0800:l]J`03001oogoo009oo`007Goo00<0
012448@04A2400<002e[;F/0bRe[0`0035:D0P00/Be[00<007ooOol00Woo000MOol00`0048@@Q00@
48@00`00;F/]J`38;F/3000>DY@00`00;F/]J`2a;F/00`00Oomoo`02Ool001eoo`03000@Q124010@
Q003000]Jbe[0<H]J`8000mBU0800;@]J`03001oogoo009oo`007Goo00<0012448@0412400<002e[
;F/0`be[0`003e:D0P00]Re[00<007ooOol00Woo000MOol00`0048@@Q00@48@00`00;F/]J`30;F/3
000@DY@2002h;F/00`00Oomoo`02Ool001eoo`03000@Q124010@Q003000]Jbe[0;`]J`@0019BU003
000]Jbe[0;P]J`03001oogoo009oo`007Goo00<0012448@0412400<002e[;F/0^2e[100055:D0P00
^be[00<007ooOol00Woo000MOol00`0048@@Q00?48@00`00;F/]J`2f;F/3000FDY@2002m;F/00`00
Oomoo`02Ool001eoo`03000@Q12400l@Q003000]Jbe[0;<]J`<001QBU003000]Jbe[0;d]J`03001o
ogoo009oo`007Goo00<0012448@03a2400<002e[;F/0/2e[0`006E:D0P00`2e[00<007ooOol00Woo
000MOol00`0048@@Q00?48@00`00;F/]J`2];F/3000JDY@20032;F/00`00Oomoo`02Ool001eoo`03
000@Q12400l@Q003000]Jbe[0:X]J`<001aBU003000]Jbe[0<8]J`03001oogoo009oo`007Goo00<0
012448@03a2400<002e[;F/0Ybe[0`007E:D0P00aBe[00<007ooOol00Woo000MOol00`0048@@Q00?
48@00`00;F/]J`2U;F/2000NDY@20037;F/00`00Oomoo`02Ool001eoo`03000@Q12400h@Q003000]
Jbe[0:<]J`<001eBU0<00<T]J`03001oogoo009oo`007Goo00<0012448@03Q2400<002e[;F/0X2e[
0`007U:D0P00c2e[00<007ooOol00Woo000MOol00`0048@@Q00>48@00`00;F/]J`2M;F/3000ODY@2
003>;F/00`00Oomoo`02Ool001eoo`03000@Q12400h@Q003000]Jbe[09X]J`<0025BU003000]Jbe[
0<h]J`03001oogoo009oo`007Goo00<0012448@03A2400<002e[;F/0V2e[0`008U:D0P00dBe[00<0
07ooOol00Woo000MOol00`0048@@Q00=48@00`00;F/]J`2F;F/2000SDY@2003C;F/00`00Oomoo`02
Ool001eoo`03000@Q12400d@Q003000]Jbe[09@]J`8002ABU003000]Jbe[0=<]J`03001oogoo009o
o`007Goo00<0012448@03A2400<002e[;F/0TBe[0`0095:D0P00eRe[00<007ooOol00Woo000MOol0
0`0048@@Q00<48@00`00;F/]J`2@;F/2000UDY@2003H;F/00`00Oomoo`02Ool001eoo`03000@Q124
00`@Q003000]Jbe[08h]J`8002EBU0800=X]J`03001oogoo009oo`007Goo00<0012448@0312400<0
02e[;F/0Rbe[0`009U:D00<002e[;F/0fRe[00<007ooOol00Woo000MOol00`0048@@Q00<48@00`00
;F/]J`28;F/3000WDY@2003M;F/00`00Oomoo`02Ool001eoo`03000@Q12400/@Q003000]Jbe[08L]
J`8002QBU0800=l]J`03001oogoo009oo`007Goo00<0012448@02a2400<002e[;F/0Q2e[0`00:E:D
00<002e[;F/0gbe[00<007ooOol00Woo000MOol00`0048@@Q00;48@00`00;F/]J`21;F/3000ZDY@2
003R;F/00`00Oomoo`02Ool001eoo`03000@Q12400/@Q003000]Jbe[07h]J`<002]BU0800>@]J`03
001oogoo009oo`007Goo00<0012448@02Q2400<002e[;F/0O2e[0`00;E:D00<002e[;F/0i2e[00<0
07ooOol00Woo000MOol00`0048@@Q00:48@00`00;F/]J`1i;F/3000^DY@2003W;F/00`00Oomoo`02
Ool001eoo`03000@Q12400X@Q003000]Jbe[07L]J`8002mBU0800>T]J`03001oogoo009oo`007Goo
00<0012448@02Q2400<002e[;F/0MBe[0P00;e:D0P00jbe[00<007ooOol00Woo000MOol00`0048@@
Q00948@00`00;F/]J`1c;F/3000`DY@00`00;F/]J`3Y;F/30004Ool001eoo`03000@Q12400T@Q003
000]Jbe[074]J`80035BU0800>P]J`@0008@Q003001oogoo009oo`007Goo00<0012448@02A2400<0
02e[;F/0Kbe[0P00<E:D0P00iRe[10001Q2400<007ooOol00Woo000MOol00`0048@@Q00948@00`00
;F/]J`1/;F/3000aDY@2003T;F/4000:48@00`00Oomoo`02Ool001eoo`03000@Q12400P@Q003000]
Jbe[06X]J`<0039BU0800>8]J`@000h@Q003001oogoo009oo`007Goo00<0012448@0212400<002e[
;F/0J2e[0P00<e:D0P00gbe[1@004Q2400<007ooOol00Woo000MOol00`0048@@Q00848@00`00;F/]
J`1V;F/2000cDY@2003M;F/4000G48@00`00Oomoo`02Ool001eoo`03000@Q12400P@Q003000]Jbe[
06<]J`<003=BU0800=/]J`@001/@Q003001oogoo009oo`007Goo00<0012448@0212400<002e[;F/0
HBe[0P00=5:D0P00fBe[10007a2400<007ooOol00Woo000MOol00`0048@@Q00748@00`00;F/]J`1P
;F/2000eDY@00`00;F/]J`3E;F/4000S48@00`00Oomoo`02Ool001eoo`03000@Q12400L@Q003000]
Jbe[05d]J`<003EBU0800=8]J`H002L@Q003001oogoo009oo`007Goo00<0012448@01a2400<002e[
;F/0FRe[0`00=U:D0P00cBe[1`00;A2400<007ooOol00Woo000MOol00`0048@@Q00748@00`00;F/]
J`1H;F/2000gDY@2003;;F/4000d48@00`00Oomoo`02Ool001eoo`03000@Q12400L@Q003000]Jbe[
05H]J`8003MBU0800<T]J`@003P@Q003001oogoo009oo`007Goo00<0012448@01a2400<002e[;F/0
Dbe[0`00>5:D00<002e[;F/0a2e[1@00?12400<007ooOol00Woo0007Ool20004Ool30004Ool20007
Ool00`0048@@Q00648@00`00;F/]J`1B;F/2000iDY@20033;F/4001148@00`00Oomoo`02Ool000Uo
o`04001oogoo0003Ool01000Oomoo`000Woo00<007ooOol017oo00<0012448@01Q2400<002e[;F/0
D2e[0P00>E:D0P00`Be[1000AA2400<007ooOol00Woo000:Ool00`00Oomoo`03Ool01000Oomoo`00
0Woo00<007ooOol017oo00<0012448@01Q2400<002e[;F/0CRe[0P00>U:D00<002e[;F/0_Be[1000
BA2400<007ooOol00Woo0007Ool40005Ool01000Oomoo`000Woo00<007ooOol017oo00<0012448@0
1Q2400<002e[;F/0C2e[0P00>U:D0P00_2e[1000CA2400<007ooOol00Woo0006Ool01P00Oomoogoo
001oo`@000=oo`04001oogoo0006Ool00`0048@@Q00648@00`00;F/]J`1:;F/2000jDY@2002j;F/4
001A48@00`00Oomoo`02Ool000Ioo`07001oogooOol007oo00001Woo00@007ooOol000Ioo`03000@
Q12400H@Q003000]Jbe[04P]J`8003]BU003000]Jbe[0;D]J`D005D@Q003001oogoo009oo`001goo
0`000Woo1@000goo0P001goo00<0012448@01A2400<002e[;F/0Abe[0P00>e:D0P00]2e[1000FQ24
00<007ooOol00Woo000MOol00`0048@@Q00548@00`00;F/]J`14;F/3000kDY@2002b;F/4001N48@0
0`00Oomoo`02Ool001eoo`03000@Q12400D@Q003000]Jbe[048]J`8003aBU0800;0]J`@0068@Q003
001oogoo009oo`007Goo00<0012448@01A2400<002e[;F/0@2e[0P00?E:D00<002e[;F/0Zbe[1@00
IQ2400<007ooOol00Woo000MOol00`0048@@Q00448@00`00;F/]J`0o;F/2000mDY@2002Z;F/4001[
48@00`00Oomoo`02Ool001eoo`03000@Q12400@@Q003000]Jbe[03d]J`8003eBU0800:P]J`@006l@
Q003001oogoo009oo`007Goo00<0012448@0112400<002e[;F/0>be[0P00?U:D00<002e[;F/0Y2e[
1000La2400<007ooOol00Woo000MOol00`0048@@Q00448@00`00;F/]J`0i;F/2000nDY@2002S;F/4
001g48@00`00Oomoo`02Ool001eoo`03000@Q12400@@Q003000]Jbe[03L]J`8003iBU0800:4]J`@0
07/@Q003001oogoo009oo`007Goo00<0012448@0112400<002e[;F/0=Be[0P00?e:D00<002e[;F/0
W2e[1@00Oa2400<007ooOol00Woo000MOol00`0048@@Q00348@00`00;F/]J`0e;F/00`00DYABU00m
DY@2002K;F/4002448@00`00Oomoo`02Ool001eoo`03000@Q12400<@Q003000]Jbe[03<]J`8003iB
U08009T]J`@008P@Q003001oogoo009oo`007Goo00<0012448@00a2400<002e[;F/0<Be[0P00?E:D
0`00Ube[1000S12400<007ooOol00Woo000MOol00`0048@@Q00348@00`00;F/]J`0_;F/2000mDY@2
002E;F/5002@48@00`00Oomoo`02Ool001eoo`03000@Q12400<@Q003000]Jbe[02d]J`8003eBU080
09<]J`@009D@Q003001oogoo009oo`007Goo00<0012448@00a2400<002e[;F/0:be[0P00?U:D00<0
02e[;F/0Sbe[1000VA2400<007ooOol00Woo000MOol00`0048@@Q00348@00`00;F/]J`0Y;F/2000n
DY@2002>;F/4002M48@00`00Oomoo`02Ool001eoo`03000@Q124008@Q003000]Jbe[02P]J`8003iB
U08008`]J`@00:4@Q003001oogoo009oo`007Goo00<0012448@00Q2400<002e[;F/09Re[0P00?e:D
00<002e[;F/0R2e[1000YA2400<007ooOol00Woo000MOol00`0048@@Q00248@00`00;F/]J`0U;F/0
0`00DYABU00mDY@20026;F/5002Y48@00`00Oomoo`02Ool001eoo`03000@Q124008@Q003000]Jbe[
02<]J`8003iBU08008@]J`@00:h@Q003001oogoo009oo`007Goo00D0012448@@Q00002@]J`8003iB
U080088]J`@00;8@Q003001oogoo009oo`007Goo00D0012448@@Q00002<]J`03001BU5:D03eBU003
000]Jbe[07h]J`@00;H@Q003001oogoo009oo`007Goo00D0012448@@Q000028]J`03001BU5:D03aB
U08007`]J`D00;X@Q003001oogoo009oo`007Goo00D0012448@@Q000020]J`8003eBU08007X]J`@0
0;l@Q003001oogoo009oo`007Goo00D0012448@@Q00001l]J`03001BU5:D03aBU003000]Jbe[07H]
J`@00<<@Q003001oogoo009oo`007Goo00D0012448@@Q00001h]J`03001BU5:D03]BU08007D]J`@0
0<L@Q003001oogoo009oo`007Goo00@0012448@001d]J`8003aBU08007<]J`@00</@Q003001oogoo
009oo`007Goo00@0012448@001`]J`03001BU5:D03]BU003000]Jbe[06l]J`@00<l@Q003001oogoo
009oo`007Goo00@0012448@001X]J`8003aBU08006d]J`D00=<@Q003001oogoo009oo`007Goo00@0
012448@001T]J`03001BU5:D03YBU08006/]J`@00=P@Q003001oogoo009oo`007Goo00@0012448@0
01L]J`8003]BU08006T]J`@00=`@Q003001oogoo009oo`007Goo00@0012448@001H]J`03001BU5:D
03YBU003000]Jbe[06D]J`@00>0@Q003001oogoo009oo`007Goo00<0012400005Be[0P00>e:D0P00
Hbe[1@00i12400<007ooOol00Woo000MOol00`0048@0000D;F/00`00DYABU00iDY@2001Q;F/4003Y
48@00`00Oomoo`02Ool001eoo`03000@Q00001<]J`03001BU5:D03UBU003000]Jbe[05d]J`@00>d@
Q003001oogoo009oo`007Goo00<0012400004Re[00<005:DDY@0>5:D0P00G2e[1000lA2400<007oo
Ool00Woo000MOol00`0048@0000A;F/00`00DYABU00gDY@2001J;F/4003e48@00`00Oomoo`02Ool0
01eoo`80014]J`03001BU5:D03MBU003000]Jbe[05H]J`@00?T@Q003001oogoo009oo`007Goo0P00
42e[00<005:DDY@0=U:D0P00E2e[1@00oA2400<007ooOol00Woo000MOol2000?;F/00`00DYABU00e
DY@2001B;F/4003o48@348@00`00Oomoo`02Ool001eoo`8000h]J`03001BU5:D03=BU0<0050]J`@0
0?l@Q0L@Q003001oogoo009oo`007Goo0P003Be[00<005:DDY@0<U:D0P00Cbe[1000oa242a2400<0
07ooOol00Woo000MOol2000<;F/00`00DYABU00aDY@2001<;F/5003o48@?48@00`00Oomoo`02Ool0
01eoo`03000]Jbe[00X]J`03001BU5:D035BU003000]Jbe[04H]J`H00?l@Q1@@Q003001oogoo009o
o`007Goo00<002e[;F/02Be[00<005:DDY@0<5:D0P00@be[1P00oa246Q2400<007ooOol00Woo000M
Ool00`00;F/]J`08;F/00`00DYABU00_DY@20011;F/4003o48@P48@00`00Oomoo`02Ool001eoo`03
000]Jbe[00L]J`03001BU5:D02mBU003000]Jbe[03d]J`@00?l@Q2@@Q003001oogoo009oo`007Goo
00<002e[;F/01Re[00<005:DDY@0;U:D0P00>be[1@00oa24:12400<007ooOol00Woo000MOol00`00
;F/]J`05;F/00`00DYABU00^DY@00`00;F/]J`0g;F/4003o48@]48@00`00Oomoo`02Ool00004Ool0
00000004Ool20004Ool20004Ool20007Ool00`00;F/]J`05;F/00`00DYABU00/DY@2000f;F/4003o
48@a48@00`00Oomoo`02Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Ioo`03000]Jbe[00@]J`03001BU5:D02]BU08003@]J`@00?l@Q3D@Q003001oogoo
009oo`000Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Woo
00<002e[;F/00be[00<005:DDY@0:e:D00<002e[;F/0<2e[1000oa24>A2400<007ooOol00Woo0002
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0006Oooo002U0004
Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol00?moojmo
o`0000=oo`00000017oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00ogoo[goo0002
Ool00`00Oomoo`03Ool20004Ool20004Ool2003oOon`Ool00?moolIoo`00ogooaWoo003oOoo6Ool0
0?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00\
\>"],
  ImageRangeCache->{{{0, 452}, {452, 0}} -> {-0.0696821, 610.937, 0.00238238, \
0.88148}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["contour data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["raw data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(*------------------------------*)
(*  ksp cd g (liq)  *) 

0.1

{0.0500, 5.00, 972.4},
{0.1000, 5.00, 935.4},
{0.1500, 5.00, 900.6},
{0.2000, 5.00, 864.9},
{0.2500, 5.00, 826.1},
{0.3000, 5.00, 781.7},
{0.3500, 5.00, 728.1},
{0.4000, 5.00, 658.9},
{0.4500, 5.00, 560.8},

0.2

{0.0500, 5.00, 993.8},
{0.1000, 5.00, 969.3},
{0.1500, 5.00, 946.4},
{0.2000, 5.00, 924.4},
{0.2500, 5.00, 902.4},
{0.3000, 5.00, 880.1},
{0.3500, 5.00, 856.9},
{0.4000, 5.00, 832.4},
{0.4500, 5.00, 806.0},
{0.5000, 5.00, 777.0},
{0.5500, 5.00, 744.6},
{0.6000, 5.00, 707.2},
{0.6500, 5.00, 662.9},
{0.7000, 5.00, 608.2},
{0.7500, 5.00, 535.5},
{0.8000, 5.00, 428.2},

0.3 

{0.0500, 5.00, 1004.3},
{0.1000, 5.00, 986.3},
{0.1500, 5.00, 969.3},
{0.2000, 5.00, 952.9},
{0.2500, 5.00, 936.8},
{0.3000, 5.00, 920.9},
{0.3500, 5.00, 904.9},
{0.4000, 5.00, 888.7},
{0.4500, 5.00, 872.1},
{0.5000, 5.00, 855.0},
{0.5500, 5.00, 837.2},
{0.6000, 5.00, 818.5},
{0.6500, 5.00, 798.7},
{0.7000, 5.00, 777.5},
{0.7500, 5.00, 754.5},
{0.8000, 5.00, 729.3},
{0.8500, 5.00, 701.2},
{0.9000, 5.00, 669.5},
{0.9500, 5.00, 632.7},
{1.0000, 5.00, 588.3},

0.4

{0.0500, 5.00, 1010.9},
{0.1000, 5.00, 996.7},
{0.1500, 5.00, 983.3},
{0.2000, 5.00, 970.2},
{0.2500, 5.00, 957.5},
{0.3000, 5.00, 944.9},
{0.3500, 5.00, 932.4},
{0.4000, 5.00, 919.9},
{0.4500, 5.00, 907.3},
{0.5000, 5.00, 894.6},
{0.5500, 5.00, 881.7},
{0.6000, 5.00, 868.6},
{0.6500, 5.00, 855.1},
{0.7000, 5.00, 841.1},
{0.7500, 5.00, 826.7},
{0.8000, 5.00, 811.6},
{0.8500, 5.00, 795.9},
{0.9000, 5.00, 779.2},
{0.9500, 5.00, 761.6},
{1.0000, 5.00, 742.7},

0.5

{0.0500, 5.00, 1015.4},
{0.1000, 5.00, 1003.9},
{0.1500, 5.00, 992.8},
{0.2000, 5.00, 982.0},
{0.2500, 5.00, 971.4},
{0.3000, 5.00, 961.0},
{0.3500, 5.00, 950.7},
{0.4000, 5.00, 940.4},
{0.4500, 5.00, 930.1},
{0.5000, 5.00, 919.9},
{0.5500, 5.00, 909.5},
{0.6000, 5.00, 899.1},
{0.6500, 5.00, 888.5},
{0.7000, 5.00, 877.8},
{0.7500, 5.00, 866.9},
{0.8000, 5.00, 855.8},
{0.8500, 5.00, 844.3},
{0.9000, 5.00, 832.6},
{0.9500, 5.00, 820.4},
{1.0000, 5.00, 807.9},

(*------------------------------*)
(*  ksp bi cd g (liq)  *) 

0.1

{0.3500, 5.00, 768.8},
{0.4000, 5.00, 756.4},
{0.4500, 5.00, 744.1},
{0.5000, 5.00, 732.5},
{0.5500, 5.00, 721.4},
{0.6000, 5.00, 710.6},
{0.6500, 5.00, 699.7},
{0.7000, 5.00, 688.2},
{0.7500, 5.00, 677.6},

0.2 

{0.5000, 5.00, 784.0},
{0.5500, 5.00, 773.1},
{0.6000, 5.00, 762.1},
{0.6500, 5.00, 751.0},
{0.7000, 5.00, 740.2},
{0.7500, 5.00, 729.6},
{0.8000, 5.00, 719.1},
{0.8500, 5.00, 708.0},
{0.9000, 5.00, 695.0},
{0.9500, 5.00, 678.6},

0.3 

{0.7000, 5.00, 787.2},
{0.7500, 5.00, 777.6},
{0.8000, 5.00, 767.8},
{0.8500, 5.00, 758.0},
{0.9000, 5.00, 748.3},
{0.9500, 5.00, 738.7},
{1.0000, 5.00, 729.2},

0.4

{0.8500, 5.00, 798.2},
{0.9000, 5.00, 789.9},
{0.9500, 5.00, 781.4},
{1.0000, 5.00, 772.7},

(*------------------------------*)
(*  ksp pl bi sill (liq)  *) 

0.1

{0.5500, 5.00, 841.8},
{0.5750, 5.00, 838.5},
{0.6000, 5.00, 833.1},
{0.6250, 5.00, 825.4},
{0.6500, 5.00, 815.1},
{0.6750, 5.00, 801.7},
{0.7000, 5.00, 784.1},
{0.7250, 5.00, 761.4},
{0.7500, 5.00, 732.7},
{0.7750, 5.00, 698.2},
{0.8000, 5.00, 659.5},
{0.8250, 5.00, 617.9},
{0.8500, 5.00, 573.2},
{0.8750, 5.00, 525.1},
{0.9000, 5.00, 471.9},
{0.9250, 5.00, 410.1},

0.2

{0.5500, 5.00, 846.6},
{0.5750, 5.00, 845.3},
{0.6000, 5.00, 843.3},
{0.6250, 5.00, 840.8},
{0.6500, 5.00, 837.6},
{0.6750, 5.00, 833.9},
{0.7000, 5.00, 829.6},
{0.7250, 5.00, 824.6},
{0.7500, 5.00, 818.8},
{0.7750, 5.00, 812.1},
{0.8000, 5.00, 804.4},
{0.8250, 5.00, 795.4},
{0.8500, 5.00, 785.1},
{0.8750, 5.00, 773.0},
{0.9000, 5.00, 759.0},
{0.9250, 5.00, 743.0},
{0.9500, 5.00, 724.6},
{0.9750, 5.00, 704.0},
{1.0000, 5.00, 681.1},\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["assembled data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
lc1 = Map[#[[xycols]]&,
{{0.0500, 5.00, 972.4},
{0.1000, 5.00, 935.4},
{0.1500, 5.00, 900.6},
{0.2000, 5.00, 864.9},
{0.2500, 5.00, 826.1},
{0.3000, 5.00, 781.7},  (*
{0.3500, 5.00, 728.1},
{0.4000, 5.00, 658.9},
{0.4500, 5.00, 560.8},  *)

{0.3500, 5.00, 768.8},
{0.4000, 5.00, 756.4},
{0.4500, 5.00, 744.1}, (*
{0.5000, 5.00, 732.5}, 
{0.5500, 5.00, 721.4}, 
{0.6000, 5.00, 710.6},
{0.6500, 5.00, 699.7},
{0.7000, 5.00, 688.2},
{0.7500, 5.00, 677.6}, 

{0.4400, 5.00, 760.9},
{0.4600, 5.00, 758.2},
{0.4800, 5.00, 755.6},
{0.5000, 5.00, 752.9},
{0.5200, 5.00, 750.4},
{0.5400, 5.00, 747.9},
{0.5600, 5.00, 745.4},
{0.5800, 5.00, 743.0}, *)
{0.6000, 5.00, 740.7},
{0.6200, 5.00, 738.5},
{0.6400, 5.00, 736.3},
{0.6600, 5.00, 734.2},
{0.6800, 5.00, 732.2},
{0.7000, 5.00, 730.3},
{0.7200, 5.00, 728.5},
{0.7400, 5.00, 726.7}, (*

{0.5500, 5.00, 841.8},
{0.5750, 5.00, 838.5},
{0.6000, 5.00, 833.1},
{0.6250, 5.00, 825.4},
{0.6500, 5.00, 815.1},
{0.6750, 5.00, 801.7},
{0.7000, 5.00, 784.1},
{0.7250, 5.00, 761.4}, *)
{0.7500, 5.00, 732.7},
{0.7750, 5.00, 698.2}, (*
{0.8000, 5.00, 659.5},
{0.8250, 5.00, 617.9},
{0.8500, 5.00, 573.2},
{0.8750, 5.00, 525.1},
{0.9000, 5.00, 471.9},
{0.9250, 5.00, 410.1}, *)

{0.8800, 5.00, 685.5},
{0.8900, 5.00, 680.4},
{0.9000, 5.00, 674.7},
{0.9100, 5.00, 668.0},
{0.9200, 5.00, 660.4},
{0.9300, 5.00, 651.5},
{0.9400, 5.00, 641.0},
{0.9500, 5.00, 628.6},
{0.9600, 5.00, 613.8} }];

lc2 = Map[#[[xycols]]&,
{{0.0500, 5.00, 993.8},
{0.1000, 5.00, 969.3},
{0.1500, 5.00, 946.4},
{0.2000, 5.00, 924.4},
{0.2500, 5.00, 902.4},
{0.3000, 5.00, 880.1},
{0.3500, 5.00, 856.9},
{0.4000, 5.00, 832.4},
{0.4500, 5.00, 806.0}, (*
{0.5000, 5.00, 777.0},
{0.5500, 5.00, 744.6},
{0.6000, 5.00, 707.2},
{0.6500, 5.00, 662.9},
{0.7000, 5.00, 608.2},
{0.7500, 5.00, 535.5},
{0.8000, 5.00, 428.2}, *)

{0.5000, 5.00, 784.0},
{0.5500, 5.00, 773.1},
{0.6000, 5.00, 762.1},
{0.6500, 5.00, 751.0}, (*
{0.7000, 5.00, 740.2},
{0.7500, 5.00, 729.6},
{0.8000, 5.00, 719.1},
{0.8500, 5.00, 708.0},
{0.9000, 5.00, 695.0},
{0.9500, 5.00, 678.6}, 

{0.6800, 5.00, 756.4},
{0.7000, 5.00, 753.9},
{0.7200, 5.00, 751.4}, *)
{0.7400, 5.00, 748.9},
{0.7600, 5.00, 746.5},
{0.7800, 5.00, 744.2},
{0.8000, 5.00, 741.9},
{0.8200, 5.00, 739.7},
{0.8400, 5.00, 737.6},
{0.8600, 5.00, 735.5},
{0.8800, 5.00, 733.5},
{0.9000, 5.00, 731.6},
{0.9200, 5.00, 729.7},
{0.9400, 5.00, 728.0}, (*

{0.5500, 5.00, 846.6},
{0.5750, 5.00, 845.3},
{0.6000, 5.00, 843.3},
{0.6250, 5.00, 840.8},
{0.6500, 5.00, 837.6},
{0.6750, 5.00, 833.9},
{0.7000, 5.00, 829.6},
{0.7250, 5.00, 824.6},
{0.7500, 5.00, 818.8},
{0.7750, 5.00, 812.1},
{0.8000, 5.00, 804.4},
{0.8250, 5.00, 795.4},
{0.8500, 5.00, 785.1},
{0.8750, 5.00, 773.0},
{0.9000, 5.00, 759.0},
{0.9250, 5.00, 743.0}, *)
{0.9500, 5.00, 724.6},
{0.9750, 5.00, 704.0},
{1.0000, 5.00, 681.1} }];

lc3 = Map[#[[xycols]]&,
{{0.0500, 5.00, 1004.3},
{0.1000, 5.00, 986.3},
{0.1500, 5.00, 969.3},
{0.2000, 5.00, 952.9},
{0.2500, 5.00, 936.8},
{0.3000, 5.00, 920.9},
{0.3500, 5.00, 904.9},
{0.4000, 5.00, 888.7},
{0.4500, 5.00, 872.1},
{0.5000, 5.00, 855.0},
{0.5500, 5.00, 837.2},
{0.6000, 5.00, 818.5},
{0.6500, 5.00, 798.7}, (*
{0.7000, 5.00, 777.5},
{0.7500, 5.00, 754.5},
{0.8000, 5.00, 729.3},
{0.8500, 5.00, 701.2},
{0.9000, 5.00, 669.5},
{0.9500, 5.00, 632.7},
{1.0000, 5.00, 588.3}, *)

{0.7000, 5.00, 787.2},
{0.7500, 5.00, 777.6},
{0.8000, 5.00, 767.8},
{0.8500, 5.00, 758.0},
{0.9000, 5.00, 748.3},
{0.9500, 5.00, 738.7},
{1.0000, 5.00, 729.2} }];

lc4 = Map[#[[xycols]]&,
{{0.0500, 5.00, 1010.9},
{0.1000, 5.00, 996.7},
{0.1500, 5.00, 983.3},
{0.2000, 5.00, 970.2},
{0.2500, 5.00, 957.5},
{0.3000, 5.00, 944.9},
{0.3500, 5.00, 932.4},
{0.4000, 5.00, 919.9},
{0.4500, 5.00, 907.3},
{0.5000, 5.00, 894.6},
{0.5500, 5.00, 881.7},
{0.6000, 5.00, 868.6},
{0.6500, 5.00, 855.1},
{0.7000, 5.00, 841.1},
{0.7500, 5.00, 826.7},
{0.8000, 5.00, 811.6}, (*
{0.8500, 5.00, 795.9},
{0.9000, 5.00, 779.2},
{0.9500, 5.00, 761.6},
{1.0000, 5.00, 742.7}, *)

{0.8500, 5.00, 798.2},
{0.9000, 5.00, 789.9},
{0.9500, 5.00, 781.4},
{1.0000, 5.00, 772.7} }];

lc5 = Map[#[[xycols]]&,
{{0.0500, 5.00, 1015.4},
{0.1000, 5.00, 1003.9},
{0.1500, 5.00, 992.8},
{0.2000, 5.00, 982.0},
{0.2500, 5.00, 971.4},
{0.3000, 5.00, 961.0},
{0.3500, 5.00, 950.7},
{0.4000, 5.00, 940.4},
{0.4500, 5.00, 930.1},
{0.5000, 5.00, 919.9},
{0.5500, 5.00, 909.5},
{0.6000, 5.00, 899.1},
{0.6500, 5.00, 888.5},
{0.7000, 5.00, 877.8},
{0.7500, 5.00, 866.9},
{0.8000, 5.00, 855.8},
{0.8500, 5.00, 844.3},
{0.9000, 5.00, 832.6},
{0.9500, 5.00, 820.4},
{1.0000, 5.00, 807.9} }];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function contours", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{1,3};\n   \n  \n  \t\n  \tlu1 = makeline[u1, i1, ur];\n  \tlu2 = \
makeline[u2, i1, ur];\n  \tlu3 = makeline[u3, i2, ur];\n  \tlu4 = \
makeline[u4, i3, ur];\n  \tlu5 = makeline[u5, i1, lr];\n  \tlu6 = \
makeline[u6, i1, i2];\n  \tlu7 = makeline[u7, i3, i2];\n  \tlu8 = \
makeline[u8, i2, lr];\n  \tlu9 = makeline[u9, i4, ur];\n  \tlu10 = \
makeline[u10, i5, ur];\n  \tlu11 = makeline[u11, ll, i3];\n  \tlu12 = \
makeline[u12, i4, i3];\n  \tlu13 = makeline[u13, i4, i5];\n  \tlu14 = \
makeline[u14, i4, lr];\n  \tlu15 = makeline[u15, i5, i6];\n  \tlu16 = \
makeline[u16, i5, ll];\n  \tlu17 = makeline[u17, i6, i7];\n  \tlu18 = \
makeline[u18, ll, i7];\n  \tlu19 = makeline[u19, i12, i7];\n  \tlu20 = \
makeline[u20, i10, i7];\n  \tlu21 = makeline[u21, ur, i8];\n  \tlu22 = \
makeline[u22, i6, i8];\n  \tlu23 = makeline[u23, i6, i9];\n  \tlu24 = \
makeline[u24, i10, i9];\n  \tlu25 = makeline[u25, i10, i11];\n  \tlu26 = \
makeline[u26, i12, i10];\n  \tlu27 = makeline[u27, i9, i8];\n  \tlu28 = \
makeline[u28, ur, i8];\n  \tlu29 = makeline[u29, i11, i9];\n  \tlu30 = \
makeline[u30, i11, ur];\n  \tlu31 = makeline[u31, i11, ul];\n  \tlu32 = \
makeline[u32, ll, i12];\n  \tlu33 = makeline[u33, i12, ul];\n  \tlu34 = \
makeline[u34, lr, i13];\n  \tlu35 = makeline[u35, lr, i13];\n  \tlu36 = \
makeline[u36, lr, ul];\n  \tlu37 = makeline[u37, ul, i13];\n  \tlu38 = \
makeline[u38, ul, i13];\n   \t\n      \t\t\n        \t\t\n  Show[Graphics[\n  \
       {GrayLevel[0.85],\n          area[{lu18, lu17, lu15, lu16}],\n         \
 area[{lu23, lu22, lu27}],\n          area[{lu21, lu28}],\n          \
area[{lu10, lu13, lu9}],\n          area[{lu1, lu2}],\n          area[{lu4, \
lu7, lu3}],\n                        \n          \n          GrayLevel[0.7],\n\
          area[{lu37, lu38}],\n          area[{lu18, lu19, lu32}],\n          \
area[{lu17, lu23, lu24, lu20}],\n          area[{lu30, lu29, lu27, lu28}],\n  \
        area[{lu16, lu13, lu14}],\n          area[{lu9, lu12, lu4}],\n        \
  area[{lu8, lu7, lu11}],\n          area[{lu2, lu6, lu3}],\n          \
area[{lu1, lu5}],\n                    \n           \n          \
GrayLevel[0.55],\n          area[{lu30, lu31}],\n          area[{lu35, \
lu38}],\n          area[{lu32, lu33}],\n          area[{lu26, lu20, lu19}],\n \
         area[{lu24, lu25, lu29}],\n          area[{lu11, lu12, lu14}],\n     \
     area[{lu5, lu6, lu8}],         \n          \n          \n          \
GrayLevel[0.4], \n          area[{lu36}],\n          area[{lu34, lu35}],\n    \
      area[{lu31, lu25, lu26, lu33}],\n          \n          GrayLevel[0.7],  \
        \n           area[{lu37, lu38}],\n           \n          \
GrayLevel[0], \n   \n          AbsoluteThickness[0.3],\n          \
drawline[lu1],\n          drawline[lu2],\n          drawline[lu3],\n          \
drawline[lu4],\n          drawline[lu5],\n          drawline[lu6],\n          \
drawline[lu7],\n          drawline[lu8],\n          drawline[lu9],\n          \
drawline[lu10],\n          drawline[lu11],\n          drawline[lu12],\n       \
   ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu13],\n          drawline[lu14],\n          \
drawline[lu15],\n          drawline[lu16],\n          drawline[lu17],\n       \
   drawline[lu18],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu19],\n          drawline[lu20],\n          \
drawline[lu21],\n          drawline[lu22],\n          drawline[lu23],\n       \
   drawline[lu24],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu25],\n          drawline[lu26],\n          \
drawline[lu27],\n          drawline[lu28],\n          drawline[lu29],\n       \
   ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu30],\n          drawline[lu31],\n          \
drawline[lu32],\n          drawline[lu33],\n          drawline[lu34],\n       \
   drawline[lu35],\n          drawline[lu36],\n          drawline[lu37],\n    \
      drawline[lu38],\n          \n          drawline[lc1],",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["          drawline[lc2],",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["          drawline[lc3],",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["          drawline[lc4],",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["          drawline[lc5],",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["          \n          AbsoluteThickness[0.5], \n          \n      \
    ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[0,1,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["RGBColor[0,0,1],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n           outline}],\n        \t\t",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["               \n         AspectRatio -> 1, Frame -> True,\n      \
   PlotRange -> {{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing contours", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 0; xhigh = 1.0; ylow = 630; yhigh =1000;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 -1.7027 0.0027027 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(650)] -0.0125 .05405 1 0 Msboxa
[(700)] -0.0125 .18919 1 0 Msboxa
[(750)] -0.0125 .32432 1 0 Msboxa
[(800)] -0.0125 .45946 1 0 Msboxa
[(850)] -0.0125 .59459 1 0 Msboxa
[(900)] -0.0125 .72973 1 0 Msboxa
[(950)] -0.0125 .86486 1 0 Msboxa
[(1000)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .05405 m
.00625 .05405 L
s
P
[(650)] -0.0125 .05405 1 0 Mshowa
p
.002 w
0 .18919 m
.00625 .18919 L
s
P
[(700)] -0.0125 .18919 1 0 Mshowa
p
.002 w
0 .32432 m
.00625 .32432 L
s
P
[(750)] -0.0125 .32432 1 0 Mshowa
p
.002 w
0 .45946 m
.00625 .45946 L
s
P
[(800)] -0.0125 .45946 1 0 Mshowa
p
.002 w
0 .59459 m
.00625 .59459 L
s
P
[(850)] -0.0125 .59459 1 0 Mshowa
p
.002 w
0 .72973 m
.00625 .72973 L
s
P
[(900)] -0.0125 .72973 1 0 Mshowa
p
.002 w
0 .86486 m
.00625 .86486 L
s
P
[(950)] -0.0125 .86486 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(1000)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .08108 m
.00375 .08108 L
s
P
p
.001 w
0 .10811 m
.00375 .10811 L
s
P
p
.001 w
0 .13514 m
.00375 .13514 L
s
P
p
.001 w
0 .16216 m
.00375 .16216 L
s
P
p
.001 w
0 .21622 m
.00375 .21622 L
s
P
p
.001 w
0 .24324 m
.00375 .24324 L
s
P
p
.001 w
0 .27027 m
.00375 .27027 L
s
P
p
.001 w
0 .2973 m
.00375 .2973 L
s
P
p
.001 w
0 .35135 m
.00375 .35135 L
s
P
p
.001 w
0 .37838 m
.00375 .37838 L
s
P
p
.001 w
0 .40541 m
.00375 .40541 L
s
P
p
.001 w
0 .43243 m
.00375 .43243 L
s
P
p
.001 w
0 .48649 m
.00375 .48649 L
s
P
p
.001 w
0 .51351 m
.00375 .51351 L
s
P
p
.001 w
0 .54054 m
.00375 .54054 L
s
P
p
.001 w
0 .56757 m
.00375 .56757 L
s
P
p
.001 w
0 .62162 m
.00375 .62162 L
s
P
p
.001 w
0 .64865 m
.00375 .64865 L
s
P
p
.001 w
0 .67568 m
.00375 .67568 L
s
P
p
.001 w
0 .7027 m
.00375 .7027 L
s
P
p
.001 w
0 .75676 m
.00375 .75676 L
s
P
p
.001 w
0 .78378 m
.00375 .78378 L
s
P
p
.001 w
0 .81081 m
.00375 .81081 L
s
P
p
.001 w
0 .83784 m
.00375 .83784 L
s
P
p
.001 w
0 .89189 m
.00375 .89189 L
s
P
p
.001 w
0 .91892 m
.00375 .91892 L
s
P
p
.001 w
0 .94595 m
.00375 .94595 L
s
P
p
.001 w
0 .97297 m
.00375 .97297 L
s
P
p
.001 w
0 .02703 m
.00375 .02703 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .05405 m
1 .05405 L
s
P
p
.002 w
.99375 .18919 m
1 .18919 L
s
P
p
.002 w
.99375 .32432 m
1 .32432 L
s
P
p
.002 w
.99375 .45946 m
1 .45946 L
s
P
p
.002 w
.99375 .59459 m
1 .59459 L
s
P
p
.002 w
.99375 .72973 m
1 .72973 L
s
P
p
.002 w
.99375 .86486 m
1 .86486 L
s
P
p
.001 w
.99625 .08108 m
1 .08108 L
s
P
p
.001 w
.99625 .10811 m
1 .10811 L
s
P
p
.001 w
.99625 .13514 m
1 .13514 L
s
P
p
.001 w
.99625 .16216 m
1 .16216 L
s
P
p
.001 w
.99625 .21622 m
1 .21622 L
s
P
p
.001 w
.99625 .24324 m
1 .24324 L
s
P
p
.001 w
.99625 .27027 m
1 .27027 L
s
P
p
.001 w
.99625 .2973 m
1 .2973 L
s
P
p
.001 w
.99625 .35135 m
1 .35135 L
s
P
p
.001 w
.99625 .37838 m
1 .37838 L
s
P
p
.001 w
.99625 .40541 m
1 .40541 L
s
P
p
.001 w
.99625 .43243 m
1 .43243 L
s
P
p
.001 w
.99625 .48649 m
1 .48649 L
s
P
p
.001 w
.99625 .51351 m
1 .51351 L
s
P
p
.001 w
.99625 .54054 m
1 .54054 L
s
P
p
.001 w
.99625 .56757 m
1 .56757 L
s
P
p
.001 w
.99625 .62162 m
1 .62162 L
s
P
p
.001 w
.99625 .64865 m
1 .64865 L
s
P
p
.001 w
.99625 .67568 m
1 .67568 L
s
P
p
.001 w
.99625 .7027 m
1 .7027 L
s
P
p
.001 w
.99625 .75676 m
1 .75676 L
s
P
p
.001 w
.99625 .78378 m
1 .78378 L
s
P
p
.001 w
.99625 .81081 m
1 .81081 L
s
P
p
.001 w
.99625 .83784 m
1 .83784 L
s
P
p
.001 w
.99625 .89189 m
1 .89189 L
s
P
p
.001 w
.99625 .91892 m
1 .91892 L
s
P
p
.001 w
.99625 .94595 m
1 .94595 L
s
P
p
.001 w
.99625 .97297 m
1 .97297 L
s
P
p
.001 w
.99625 .02703 m
1 .02703 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
.107 .20351 L
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
.3 .28568 L
.319 .28542 L
.338 .28517 L
.357 .28467 L
.376 .28437 L
.395 .28414 L
.414 .28367 L
.433 .2833 L
.452 .28324 L
.452 .28324 L
.43235 .2781 L
.4127 .27209 L
.39304 .26588 L
.37339 .25943 L
.35374 .25263 L
.33409 .24537 L
.31443 .2378 L
.29478 .22968 L
.27513 .22112 L
.25548 .21219 L
.23583 .2025 L
.21617 .19226 L
.19652 .18126 L
.17687 .16975 L
.15722 .15774 L
.13757 .14512 L
.11791 .13153 L
.09826 .11765 L
.07861 .103 L
.05896 .08782 L
.0393 .07186 L
.01965 .05538 L
0 .03865 L
F
.149 .36757 m
.16788 .35583 L
.18675 .34394 L
.20563 .33263 L
.2245 .32173 L
.24338 .31114 L
.26225 .30123 L
.28112 .29204 L
.3 .28568 L
.3 .28568 L
.32026 .28622 L
.34053 .2865 L
.36079 .28704 L
.38105 .28731 L
.40132 .2876 L
.42158 .28814 L
.44184 .2884 L
.46211 .2887 L
.48237 .28922 L
.50263 .28952 L
.52289 .29008 L
.54316 .29059 L
.56342 .29089 L
.58368 .29146 L
.60395 .29195 L
.62421 .29226 L
.64447 .29283 L
.66474 .29336 L
.685 .29378 L
.685 .29378 L
.66515 .29613 L
.6453 .29834 L
.62544 .30068 L
.60559 .3031 L
.58574 .30552 L
.56589 .30793 L
.54604 .31033 L
.52619 .31294 L
.50633 .31563 L
.48648 .31831 L
.46663 .321 L
.44678 .32366 L
.42693 .32654 L
.40707 .32931 L
.38722 .33216 L
.36737 .33512 L
.34752 .33807 L
.32767 .34102 L
.30781 .34397 L
.28796 .34692 L
.26811 .34988 L
.24826 .35283 L
.22841 .35576 L
.20856 .35888 L
.1887 .36197 L
.16885 .36495 L
.149 .36757 L
F
1 .29865 m
.98031 .29838 L
.96062 .29812 L
.94094 .29785 L
.92125 .29733 L
.90156 .29704 L
.88187 .29678 L
.86219 .29652 L
.8425 .29626 L
.82281 .29575 L
.80312 .29544 L
.78344 .29518 L
.76375 .29492 L
.74406 .29465 L
.72438 .29438 L
.70469 .29412 L
.685 .29378 L
.685 .29378 L
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
F
1 .2973 m
.9797 .29675 L
.95941 .29619 L
.93911 .29538 L
.91881 .29484 L
.89852 .29427 L
.87822 .29346 L
.85793 .29292 L
.83763 .29234 L
.81733 .29154 L
.79704 .291 L
.77674 .29045 L
.75644 .2899 L
.73615 .28936 L
.71585 .28881 L
.69556 .28826 L
.67526 .28771 L
.65496 .28716 L
.63467 .2866 L
.61437 .28614 L
.59407 .28579 L
.57378 .28532 L
.55348 .28496 L
.53319 .2845 L
.51289 .28414 L
.49259 .28366 L
.4723 .28344 L
.452 .28324 L
.452 .28324 L
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
.567 .25378 L
.58668 .25415 L
.60636 .25449 L
.62605 .25496 L
.64573 .2552 L
.66541 .25554 L
.68509 .25609 L
.70477 .25656 L
.72445 .25686 L
.74414 .25741 L
.76382 .25794 L
.7835 .25847 L
.80318 .259 L
.82286 .25954 L
.84255 .26007 L
.86223 .2606 L
.88191 .26116 L
.90159 .26194 L
.92127 .26246 L
.94095 .26301 L
.96064 .2638 L
.98032 .26433 L
1 .26514 L
F
1 .08541 m
.97938 .08541 L
.95877 .08541 L
.93815 .08541 L
.91754 .08541 L
.89692 .08541 L
.87631 .08541 L
.85569 .08541 L
.83508 .08541 L
.81446 .08541 L
.79385 .08541 L
.77323 .08541 L
.75262 .08541 L
.732 .08541 L
.732 .08541 L
.75262 .08656 L
.77323 .08791 L
.79385 .0893 L
.81446 .09089 L
.83508 .09257 L
.85569 .09422 L
.87631 .09635 L
.89692 .09834 L
.91754 .10078 L
.93815 .10303 L
.95877 .10577 L
.97938 .10856 L
1 .11162 L
F
1 .16243 m
.97981 .16161 L
.95962 .16052 L
.93943 .1597 L
.91924 .15861 L
.89905 .1578 L
.87886 .15698 L
.85867 .15616 L
.83848 .15534 L
.81829 .15455 L
.7981 .15398 L
.7779 .15318 L
.75771 .15261 L
.73752 .15182 L
.71733 .15128 L
.69714 .15073 L
.67695 .15019 L
.65676 .14964 L
.63657 .14909 L
.61638 .14859 L
.59619 .14832 L
.576 .14784 L
.576 .14784 L
.59475 .14713 L
.6135 .14685 L
.63225 .14644 L
.651 .14592 L
.66975 .1454 L
.6885 .14501 L
.70725 .14476 L
.726 .14432 L
.726 .14432 L
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
F
.7 g
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
F
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
.107 .20351 L
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
.0505 .50351 L
.05004 .48357 L
.0492 .46363 L
.04795 .44369 L
.04626 .42375 L
.04409 .4038 L
.04142 .38386 L
.03821 .36392 L
.03444 .34398 L
.03006 .32403 L
.02501 .30409 L
.01948 .28415 L
.01344 .26421 L
.00692 .24427 L
0 .22432 L
F
.107 .20351 m
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
.3 .28568 L
.28112 .29204 L
.26225 .30123 L
.24338 .31114 L
.2245 .32173 L
.20563 .33263 L
.18675 .34394 L
.16788 .35583 L
.149 .36757 L
.149 .36757 L
.13985 .35108 L
.13102 .33459 L
.12183 .31811 L
.1125 .30162 L
.1125 .30162 L
.11098 .282 L
.10982 .26238 L
.10887 .24276 L
.10798 .22314 L
.107 .20351 L
F
1 .47459 m
.97992 .47297 L
.95984 .47134 L
.93976 .46998 L
.91968 .46835 L
.8996 .46672 L
.87952 .46482 L
.85944 .4632 L
.83936 .46156 L
.81928 .45967 L
.7992 .45804 L
.77913 .45613 L
.75905 .45425 L
.73897 .45261 L
.71889 .45069 L
.69881 .44853 L
.67873 .44664 L
.65865 .44474 L
.63857 .44282 L
.61849 .44067 L
.59841 .43875 L
.57833 .43658 L
.55825 .4344 L
.53817 .43226 L
.51809 .43034 L
.49801 .42816 L
.47793 .42599 L
.45785 .42382 L
.43777 .42168 L
.41769 .41976 L
.39761 .41758 L
.37753 .4154 L
.35745 .41326 L
.33737 .41138 L
.3173 .40944 L
.29722 .40729 L
.27714 .4054 L
.25706 .4035 L
.23698 .40164 L
.2169 .40003 L
.19682 .39835 L
.17674 .39647 L
.15666 .3949 L
.13658 .39354 L
.1165 .39189 L
.1165 .39189 L
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
.149 .36757 L
.16885 .36495 L
.1887 .36197 L
.20856 .35888 L
.22841 .35576 L
.24826 .35283 L
.26811 .34988 L
.28796 .34692 L
.30781 .34397 L
.32767 .34102 L
.34752 .33807 L
.36737 .33512 L
.38722 .33216 L
.40707 .32931 L
.42693 .32654 L
.44678 .32366 L
.46663 .321 L
.48648 .31831 L
.50633 .31563 L
.52619 .31294 L
.54604 .31033 L
.56589 .30793 L
.58574 .30552 L
.60559 .3031 L
.62544 .30068 L
.6453 .29834 L
.66515 .29613 L
.685 .29378 L
.685 .29378 L
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
F
0 .03865 m
.01965 .05538 L
.0393 .07186 L
.05896 .08782 L
.07861 .103 L
.09826 .11765 L
.11791 .13153 L
.13757 .14512 L
.15722 .15774 L
.17687 .16975 L
.19652 .18126 L
.21617 .19226 L
.23583 .2025 L
.25548 .21219 L
.27513 .22112 L
.29478 .22968 L
.31443 .2378 L
.33409 .24537 L
.35374 .25263 L
.37339 .25943 L
.39304 .26588 L
.4127 .27209 L
.43235 .2781 L
.452 .28324 L
.452 .28324 L
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
.567 .25378 L
.56765 .23426 L
.56805 .21474 L
.56825 .19522 L
.5683 .1757 L
.56825 .15617 L
.56814 .13665 L
.56803 .11713 L
.56818 .09761 L
.56849 .07809 L
.56883 .05857 L
.56919 .03904 L
.56957 .01952 L
.56997 0 L
0 0 L
F
1 .26514 m
.98032 .26433 L
.96064 .2638 L
.94095 .26301 L
.92127 .26246 L
.90159 .26194 L
.88191 .26116 L
.86223 .2606 L
.84255 .26007 L
.82286 .25954 L
.80318 .259 L
.7835 .25847 L
.76382 .25794 L
.74414 .25741 L
.72445 .25686 L
.70477 .25656 L
.68509 .25609 L
.66541 .25554 L
.64573 .2552 L
.62605 .25496 L
.60636 .25449 L
.58668 .25415 L
.567 .25378 L
.567 .25378 L
.56876 .23259 L
.56986 .21141 L
.57172 .19022 L
.57387 .16903 L
.576 .14784 L
.576 .14784 L
.59619 .14832 L
.61638 .14859 L
.63657 .14909 L
.65676 .14964 L
.67695 .15019 L
.69714 .15073 L
.71733 .15128 L
.73752 .15182 L
.75771 .15261 L
.7779 .15318 L
.7981 .15398 L
.81829 .15455 L
.83848 .15534 L
.85867 .15616 L
.87886 .15698 L
.89905 .1578 L
.91924 .15861 L
.93943 .1597 L
.95962 .16052 L
.97981 .16161 L
1 .16243 L
F
.72814 0 m
.72762 .02062 L
.72713 .04124 L
.72668 .06185 L
.72631 .08247 L
.72606 .10309 L
.72604 .12371 L
.726 .14432 L
.726 .14432 L
.70725 .14476 L
.6885 .14501 L
.66975 .1454 L
.651 .14592 L
.63225 .14644 L
.6135 .14685 L
.59475 .14713 L
.576 .14784 L
.576 .14784 L
.57624 .12672 L
.5762 .1056 L
.5762 .08448 L
.5762 .06336 L
.5762 .04224 L
.5762 .02112 L
.5762 0 L
F
1 .11162 m
.97938 .10856 L
.95877 .10577 L
.93815 .10303 L
.91754 .10078 L
.89692 .09834 L
.87631 .09635 L
.85569 .09422 L
.83508 .09257 L
.81446 .09089 L
.79385 .0893 L
.77323 .08791 L
.75262 .08656 L
.732 .08541 L
.732 .08541 L
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
.726 .14432 L
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
F
1 .08541 m
.97938 .08541 L
.95877 .08541 L
.93815 .08541 L
.91754 .08541 L
.89692 .08541 L
.87631 .08541 L
.85569 .08541 L
.83508 .08541 L
.81446 .08541 L
.79385 .08541 L
.77323 .08541 L
.75262 .08541 L
.732 .08541 L
.732 .08541 L
.73249 .06405 L
.73259 .0427 L
.73282 .02135 L
.73365 0 L
1 0 L
F
.55 g
1 .47459 m
.97992 .47297 L
.95984 .47134 L
.93976 .46998 L
.91968 .46835 L
.8996 .46672 L
.87952 .46482 L
.85944 .4632 L
.83936 .46156 L
.81928 .45967 L
.7992 .45804 L
.77913 .45613 L
.75905 .45425 L
.73897 .45261 L
.71889 .45069 L
.69881 .44853 L
.67873 .44664 L
.65865 .44474 L
.63857 .44282 L
.61849 .44067 L
.59841 .43875 L
.57833 .43658 L
.55825 .4344 L
.53817 .43226 L
.51809 .43034 L
.49801 .42816 L
.47793 .42599 L
.45785 .42382 L
.43777 .42168 L
.41769 .41976 L
.39761 .41758 L
.37753 .4154 L
.35745 .41326 L
.33737 .41138 L
.3173 .40944 L
.29722 .40729 L
.27714 .4054 L
.25706 .4035 L
.23698 .40164 L
.2169 .40003 L
.19682 .39835 L
.17674 .39647 L
.15666 .3949 L
.13658 .39354 L
.1165 .39189 L
.1165 .39189 L
.11348 .41169 L
.11033 .4315 L
.10711 .4513 L
.10381 .4711 L
.10041 .4909 L
.09689 .5107 L
.09326 .5305 L
.08953 .55031 L
.08568 .57011 L
.08173 .58991 L
.07765 .60971 L
.07347 .62951 L
.06921 .64932 L
.06488 .66912 L
.06048 .68892 L
.05602 .70872 L
.05151 .72852 L
.04698 .74832 L
.04245 .76813 L
.03796 .78793 L
.03353 .80773 L
.02919 .82753 L
.02497 .84733 L
.02094 .86714 L
.01724 .88694 L
.01377 .90674 L
.0104 .92654 L
.00704 .94634 L
.0036 .96614 L
0 .98595 L
0 1 L
1 1 L
F
1 .58351 m
.98042 .59039 L
.96083 .59728 L
.94125 .60416 L
.92166 .61104 L
.90208 .61792 L
.88249 .6248 L
.86291 .63168 L
.84333 .63856 L
.82374 .64544 L
.80416 .65232 L
.78457 .6592 L
.76499 .66608 L
.74541 .67297 L
.72582 .67985 L
.70624 .68673 L
.68665 .69361 L
.66707 .70051 L
.64748 .70718 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
1 1 L
F
0 .22432 m
.00692 .24427 L
.01344 .26421 L
.01948 .28415 L
.02501 .30409 L
.03006 .32403 L
.03444 .34398 L
.03821 .36392 L
.04142 .38386 L
.04409 .4038 L
.04626 .42375 L
.04795 .44369 L
.0492 .46363 L
.05004 .48357 L
.0505 .50351 L
.0505 .50351 L
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
F
.0505 .50351 m
.05778 .48332 L
.06479 .46314 L
.0715 .44295 L
.0779 .42276 L
.08409 .40257 L
.09009 .38238 L
.09585 .36219 L
.10149 .342 L
.1071 .32181 L
.1125 .30162 L
.1125 .30162 L
.11098 .282 L
.10982 .26238 L
.10887 .24276 L
.10798 .22314 L
.107 .20351 L
.107 .20351 L
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
F
.149 .36757 m
.13985 .35108 L
.13102 .33459 L
.12183 .31811 L
.1125 .30162 L
.1125 .30162 L
.11339 .31968 L
.11422 .33773 L
.11502 .35578 L
.11577 .37384 L
.1165 .39189 L
.1165 .39189 L
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
F
.5762 0 m
.5762 .02112 L
.5762 .04224 L
.5762 .06336 L
.5762 .08448 L
.5762 .1056 L
.57624 .12672 L
.576 .14784 L
.576 .14784 L
.57387 .16903 L
.57172 .19022 L
.56986 .21141 L
.56876 .23259 L
.567 .25378 L
.567 .25378 L
.56765 .23426 L
.56805 .21474 L
.56825 .19522 L
.5683 .1757 L
.56825 .15617 L
.56814 .13665 L
.56803 .11713 L
.56818 .09761 L
.56849 .07809 L
.56883 .05857 L
.56919 .03904 L
.56957 .01952 L
.56997 0 L
F
.73365 0 m
.73282 .02135 L
.73259 .0427 L
.73249 .06405 L
.732 .08541 L
.732 .08541 L
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
.726 .14432 L
.72604 .12371 L
.72606 .10309 L
.72631 .08247 L
.72668 .06185 L
.72713 .04124 L
.72762 .02062 L
.72814 0 L
F
.4 g
.24233 1 m
.26 .99595 L
.28 .99162 L
.3 .98703 L
.32 .98243 L
.34 .97784 L
.36 .97297 L
.38 .96838 L
.4 .96378 L
.42 .95919 L
.44 .95459 L
.46 .94973 L
.48 .94514 L
.5 .94054 L
.52 .93568 L
.54 .93108 L
.56 .92649 L
.58 .92162 L
.6 .91703 L
.62 .91216 L
.64 .90757 L
.66 .90297 L
.68 .89811 L
.7 .89351 L
.72 .88865 L
.74 .88405 L
.76 .87946 L
.78 .87459 L
.8 .87 L
.82 .86541 L
.84 .86081 L
.86 .85595 L
.88 .85135 L
.9 .84676 L
.92 .84216 L
.94 .83757 L
.96 .8327 L
.98 .82811 L
1 .82351 L
1 1 L
F
1 .51054 m
.98042 .52113 L
.96083 .53171 L
.94125 .5423 L
.92166 .55288 L
.90208 .56347 L
.88249 .57405 L
.86291 .58488 L
.84333 .5955 L
.82374 .60631 L
.80416 .61694 L
.78457 .62774 L
.76499 .63838 L
.74541 .64916 L
.72582 .66002 L
.70624 .67089 L
.68665 .68154 L
.66707 .69229 L
.64748 .70314 L
.6279 .71405 L
.6279 .71405 L
.64748 .70718 L
.66707 .70051 L
.68665 .69361 L
.70624 .68673 L
.72582 .67985 L
.74541 .67297 L
.76499 .66608 L
.78457 .6592 L
.80416 .65232 L
.82374 .64544 L
.84333 .63856 L
.86291 .63168 L
.88249 .6248 L
.90208 .61792 L
.92166 .61104 L
.94125 .60416 L
.96083 .59728 L
.98042 .59039 L
1 .58351 L
F
0 .98595 m
.0036 .96614 L
.00704 .94634 L
.0104 .92654 L
.01377 .90674 L
.01724 .88694 L
.02094 .86714 L
.02497 .84733 L
.02919 .82753 L
.03353 .80773 L
.03796 .78793 L
.04245 .76813 L
.04698 .74832 L
.05151 .72852 L
.05602 .70872 L
.06048 .68892 L
.06488 .66912 L
.06921 .64932 L
.07347 .62951 L
.07765 .60971 L
.08173 .58991 L
.08568 .57011 L
.08953 .55031 L
.09326 .5305 L
.09689 .5107 L
.10041 .4909 L
.10381 .4711 L
.10711 .4513 L
.11033 .4315 L
.11348 .41169 L
.1165 .39189 L
.1165 .39189 L
.11577 .37384 L
.11502 .35578 L
.11422 .33773 L
.11339 .31968 L
.1125 .30162 L
.1125 .30162 L
.1071 .32181 L
.10149 .342 L
.09585 .36219 L
.09009 .38238 L
.08409 .40257 L
.0779 .42276 L
.0715 .44295 L
.06479 .46314 L
.05778 .48332 L
.0505 .50351 L
.0505 .50351 L
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
F
.7 g
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
.6279 .71405 L
.60758 .7255 L
.58727 .73679 L
.56695 .74802 L
.54664 .75948 L
.52632 .77082 L
.506 .78227 L
.48569 .7936 L
.46537 .80506 L
.44506 .81638 L
.42474 .82784 L
.40442 .83939 L
.38411 .85069 L
.36379 .86216 L
.34348 .8737 L
.32316 .88523 L
.30284 .89676 L
.28253 .90829 L
.26221 .91983 L
.2419 .93136 L
.22158 .94289 L
.20126 .95442 L
.18095 .96595 L
.16063 .97748 L
.14032 .98901 L
.12095 1 L
F
0 g
.3 Mabswid
.732 .08541 m
.75262 .08541 L
.77323 .08541 L
.79385 .08541 L
.81446 .08541 L
.83508 .08541 L
.85569 .08541 L
.87631 .08541 L
.89692 .08541 L
.91754 .08541 L
.93815 .08541 L
.95877 .08541 L
.97938 .08541 L
1 .08541 L
s
.732 .08541 m
.75262 .08656 L
.77323 .08791 L
.79385 .0893 L
.81446 .09089 L
.83508 .09257 L
.85569 .09422 L
.87631 .09635 L
.89692 .09834 L
.91754 .10078 L
.93815 .10303 L
.95877 .10577 L
.97938 .10856 L
1 .11162 L
s
.726 .14432 m
.74557 .1448 L
.76514 .14555 L
.78471 .14612 L
.80429 .14693 L
.82386 .14772 L
.84343 .14855 L
.863 .14962 L
.88257 .15067 L
.90214 .15176 L
.92171 .15309 L
.94129 .15441 L
.96086 .15574 L
.98043 .15733 L
1 .15892 L
s
.576 .14784 m
.59619 .14832 L
.61638 .14859 L
.63657 .14909 L
.65676 .14964 L
.67695 .15019 L
.69714 .15073 L
.71733 .15128 L
.73752 .15182 L
.75771 .15261 L
.7779 .15318 L
.7981 .15398 L
.81829 .15455 L
.83848 .15534 L
.85867 .15616 L
.87886 .15698 L
.89905 .1578 L
.91924 .15861 L
.93943 .1597 L
.95962 .16052 L
.97981 .16161 L
s
1 .16243 m
.97981 .16161 L
s
s
.73365 0 m
.73282 .02135 L
.73259 .0427 L
.73249 .06405 L
.732 .08541 L
s
.732 .08541 m
.73063 .10014 L
.72911 .11486 L
.72747 .12959 L
.726 .14432 L
s
.576 .14784 m
.59475 .14713 L
.6135 .14685 L
.63225 .14644 L
.651 .14592 L
.66975 .1454 L
.6885 .14501 L
.70725 .14476 L
.726 .14432 L
s
.72814 0 m
.72762 .02062 L
.72713 .04124 L
.72668 .06185 L
.72631 .08247 L
.72606 .10309 L
.72604 .12371 L
.726 .14432 L
s
.567 .25378 m
.58668 .25415 L
.60636 .25449 L
.62605 .25496 L
.64573 .2552 L
.66541 .25554 L
.68509 .25609 L
.70477 .25656 L
.72445 .25686 L
.74414 .25741 L
.76382 .25794 L
.7835 .25847 L
.80318 .259 L
.82286 .25954 L
.84255 .26007 L
.86223 .2606 L
.88191 .26116 L
.90159 .26194 L
.92127 .26246 L
.94095 .26301 L
.96064 .2638 L
.98032 .26433 L
1 .26514 L
s
.452 .28324 m
.4723 .28344 L
.49259 .28366 L
.51289 .28414 L
.53319 .2845 L
.55348 .28496 L
.57378 .28532 L
.59407 .28579 L
.61437 .28614 L
.63467 .2866 L
.65496 .28716 L
.67526 .28771 L
.69556 .28826 L
.71585 .28881 L
.73615 .28936 L
.75644 .2899 L
.77674 .29045 L
.79704 .291 L
.81733 .29154 L
.83763 .29234 L
.85793 .29292 L
.87822 .29346 L
.89852 .29427 L
.91881 .29484 L
.93911 .29538 L
.95941 .29619 L
.9797 .29675 L
1 .2973 L
s
.5762 0 m
.5762 .02112 L
.5762 .04224 L
.5762 .06336 L
.5762 .08448 L
.5762 .1056 L
.57624 .12672 L
.576 .14784 L
s
.576 .14784 m
.57387 .16903 L
.57172 .19022 L
.56986 .21141 L
.56876 .23259 L
.567 .25378 L
s
.452 .28324 m
.47117 .27725 L
.49033 .27208 L
.5095 .26716 L
.52867 .26248 L
.54783 .2581 L
.567 .25378 L
s
.56997 0 m
.56957 .01952 L
.56919 .03904 L
.56883 .05857 L
.56849 .07809 L
.56818 .09761 L
.56803 .11713 L
.56814 .13665 L
.56825 .15617 L
.5683 .1757 L
.56825 .19522 L
.56805 .21474 L
.56765 .23426 L
.567 .25378 L
s
.3 .28568 m
.319 .28542 L
.338 .28517 L
.357 .28467 L
.376 .28437 L
.395 .28414 L
.414 .28367 L
.433 .2833 L
.452 .28324 L
s
0 .03865 m
.01965 .05538 L
.0393 .07186 L
.05896 .08782 L
.07861 .103 L
.09826 .11765 L
.11791 .13153 L
.13757 .14512 L
.15722 .15774 L
.17687 .16975 L
.19652 .18126 L
.21617 .19226 L
.23583 .2025 L
.25548 .21219 L
.27513 .22112 L
.29478 .22968 L
.31443 .2378 L
.33409 .24537 L
.35374 .25263 L
.37339 .25943 L
.39304 .26588 L
.4127 .27209 L
.43235 .2781 L
.452 .28324 L
s
.107 .20351 m
.1263 .2139 L
.1456 .22394 L
.1649 .23345 L
.1842 .24246 L
.2035 .25096 L
.2228 .259 L
.2421 .26676 L
.2614 .27406 L
.2807 .28099 L
.3 .28568 L
s
0 .03865 m
.00711 .05926 L
.01555 .07986 L
.02557 .10047 L
.03743 .12108 L
.05142 .14169 L
.06757 .1623 L
.08601 .18291 L
.107 .20351 L
s
.107 .20351 m
.10294 .22351 L
.09886 .24351 L
.09517 .26351 L
.09165 .28351 L
.08825 .30351 L
.08491 .32351 L
.08159 .34351 L
.07807 .36351 L
.07436 .38351 L
.07058 .40351 L
.06673 .42351 L
.0628 .44351 L
.05881 .46351 L
.05472 .48351 L
.0505 .50351 L
s
.107 .20351 m
.10798 .22314 L
.10887 .24276 L
.10982 .26238 L
.11098 .282 L
.1125 .30162 L
s
.685 .29378 m
.70469 .29412 L
.72438 .29438 L
.74406 .29465 L
.76375 .29492 L
.78344 .29518 L
.80312 .29544 L
.82281 .29575 L
.8425 .29626 L
.86219 .29652 L
.88187 .29678 L
.90156 .29704 L
.92125 .29733 L
.94094 .29785 L
.96062 .29812 L
.98031 .29838 L
1 .29865 L
s
.3 .28568 m
.32026 .28622 L
.34053 .2865 L
.36079 .28704 L
.38105 .28731 L
.40132 .2876 L
.42158 .28814 L
.44184 .2884 L
.46211 .2887 L
.48237 .28922 L
.50263 .28952 L
.52289 .29008 L
.54316 .29059 L
.56342 .29089 L
.58368 .29146 L
.60395 .29195 L
.62421 .29226 L
.64447 .29283 L
.66474 .29336 L
.685 .29378 L
s
.149 .36757 m
.16788 .35583 L
.18675 .34394 L
.20563 .33263 L
.2245 .32173 L
.24338 .31114 L
.26225 .30123 L
.28112 .29204 L
.3 .28568 L
s
.1125 .30162 m
.12183 .31811 L
.13102 .33459 L
.13985 .35108 L
.149 .36757 L
s
.1125 .30162 m
.11339 .31968 L
.11422 .33773 L
.11502 .35578 L
.11577 .37384 L
.1165 .39189 L
s
.1125 .30162 m
.1071 .32181 L
.10149 .342 L
.09585 .36219 L
.09009 .38238 L
.08409 .40257 L
.0779 .42276 L
.0715 .44295 L
.06479 .46314 L
.05778 .48332 L
.0505 .50351 L
s
.149 .36757 m
.16885 .36495 L
.1887 .36197 L
.20856 .35888 L
.22841 .35576 L
.24826 .35283 L
.26811 .34988 L
.28796 .34692 L
.30781 .34397 L
.32767 .34102 L
.34752 .33807 L
.36737 .33512 L
.38722 .33216 L
.40707 .32931 L
.42693 .32654 L
.44678 .32366 L
.46663 .321 L
.48648 .31831 L
.50633 .31563 L
.52619 .31294 L
.54604 .31033 L
.56589 .30793 L
.58574 .30552 L
.60559 .3031 L
.62544 .30068 L
.6453 .29834 L
.66515 .29613 L
.685 .29378 L
s
.685 .29378 m
.70469 .29479 L
.72438 .29563 L
.74406 .29671 L
.76375 .29772 L
.78344 .29856 L
.80312 .29959 L
.82281 .30042 L
.8425 .30146 L
.86219 .30228 L
.88187 .30332 L
.90156 .30414 L
.92125 .30519 L
.94094 .30598 L
.96062 .30679 L
.98031 .30785 L
1 .30865 L
s
.1165 .39189 m
.12463 .38596 L
.13275 .37981 L
.14088 .37366 L
.149 .36757 L
s
.1165 .39189 m
.13658 .39354 L
.15666 .3949 L
.17674 .39647 L
.19682 .39835 L
.2169 .40003 L
.23698 .40164 L
.25706 .4035 L
.27714 .4054 L
.29722 .40729 L
.3173 .40944 L
.33737 .41138 L
.35745 .41326 L
.37753 .4154 L
.39761 .41758 L
.41769 .41976 L
.43777 .42168 L
.45785 .42382 L
.47793 .42599 L
.49801 .42816 L
.51809 .43034 L
.53817 .43226 L
.55825 .4344 L
.57833 .43658 L
.59841 .43875 L
.61849 .44067 L
.63857 .44282 L
.65865 .44474 L
.67873 .44664 L
.69881 .44853 L
.71889 .45069 L
.73897 .45261 L
.75905 .45425 L
.77913 .45613 L
.7992 .45804 L
.81928 .45967 L
.83936 .46156 L
.85944 .4632 L
.87952 .46482 L
.8996 .46672 L
.91968 .46835 L
.93976 .46998 L
.95984 .47134 L
.97992 .47297 L
s
1 .47459 m
.97992 .47297 L
s
s
.1165 .39189 m
.11348 .41169 L
.11033 .4315 L
.10711 .4513 L
.10381 .4711 L
.10041 .4909 L
.09689 .5107 L
.09326 .5305 L
.08953 .55031 L
.08568 .57011 L
.08173 .58991 L
.07765 .60971 L
.07347 .62951 L
.06921 .64932 L
.06488 .66912 L
.06048 .68892 L
.05602 .70872 L
.05151 .72852 L
.04698 .74832 L
.04245 .76813 L
.03796 .78793 L
.03353 .80773 L
.02919 .82753 L
.02497 .84733 L
.02094 .86714 L
.01724 .88694 L
.01377 .90674 L
.0104 .92654 L
.00704 .94634 L
.0036 .96614 L
0 .98595 L
s
0 .22432 m
.00692 .24427 L
.01344 .26421 L
.01948 .28415 L
.02501 .30409 L
.03006 .32403 L
.03444 .34398 L
.03821 .36392 L
.04142 .38386 L
.04409 .4038 L
.04626 .42375 L
.04795 .44369 L
.0492 .46363 L
.05004 .48357 L
.0505 .50351 L
s
.0505 .50351 m
.04626 .52344 L
.04197 .54337 L
.0376 .56329 L
.03313 .58322 L
.0286 .60314 L
.02401 .62307 L
.01936 .643 L
.01463 .66292 L
.00983 .68285 L
.00496 .70278 L
0 .7227 L
s
.6279 .71405 m
.64748 .70314 L
.66707 .69229 L
.68665 .68154 L
.70624 .67089 L
.72582 .66002 L
.74541 .64916 L
.76499 .63838 L
.78457 .62774 L
.80416 .61694 L
.82374 .60631 L
.84333 .5955 L
.86291 .58488 L
.88249 .57405 L
.90208 .56347 L
.92166 .55288 L
.94125 .5423 L
.96083 .53171 L
.98042 .52113 L
1 .51054 L
s
.6279 .71405 m
.64748 .70718 L
.66707 .70051 L
.68665 .69361 L
.70624 .68673 L
.72582 .67985 L
.74541 .67297 L
.76499 .66608 L
.78457 .6592 L
.80416 .65232 L
.82374 .64544 L
.84333 .63856 L
.86291 .63168 L
.88249 .6248 L
.90208 .61792 L
.92166 .61104 L
.94125 .60416 L
.96083 .59728 L
.98042 .59039 L
1 .58351 L
s
.24233 1 m
.26 .99595 L
.28 .99162 L
.3 .98703 L
.32 .98243 L
.34 .97784 L
.36 .97297 L
.38 .96838 L
.4 .96378 L
.42 .95919 L
.44 .95459 L
.46 .94973 L
.48 .94514 L
.5 .94054 L
.52 .93568 L
.54 .93108 L
.56 .92649 L
.58 .92162 L
.6 .91703 L
.62 .91216 L
.64 .90757 L
.66 .90297 L
.68 .89811 L
.7 .89351 L
.72 .88865 L
.74 .88405 L
.76 .87946 L
.78 .87459 L
.8 .87 L
.82 .86541 L
.84 .86081 L
.86 .85595 L
.88 .85135 L
.9 .84676 L
.92 .84216 L
.94 .83757 L
.96 .8327 L
.98 .82811 L
s
1 .82351 m
.98 .82811 L
s
s
.01244 1 m
.02025 .99106 L
.04051 .96953 L
.06076 .95266 L
.08102 .93823 L
.10127 .92516 L
.12153 .91318 L
.14178 .90201 L
.16204 .89139 L
.18229 .88133 L
.20255 .87179 L
.2228 .86252 L
.24306 .85352 L
.26331 .84482 L
.28357 .83633 L
.30382 .82794 L
.32408 .82002 L
.34433 .81207 L
.36459 .80425 L
.38484 .79682 L
.4051 .7892 L
.42535 .78186 L
.44561 .77468 L
.46586 .76763 L
.48612 .76068 L
.50637 .7538 L
.52663 .74694 L
.54688 .74013 L
.56714 .73342 L
.58739 .72682 L
.60765 .72036 L
.6279 .71405 L
s
.12095 1 m
.14032 .98901 L
.16063 .97748 L
.18095 .96595 L
.20126 .95442 L
.22158 .94289 L
.2419 .93136 L
.26221 .91983 L
.28253 .90829 L
.30284 .89676 L
.32316 .88523 L
.34348 .8737 L
.36379 .86216 L
.38411 .85069 L
.40442 .83939 L
.42474 .82784 L
.44506 .81638 L
.46537 .80506 L
.48569 .7936 L
.506 .78227 L
.52632 .77082 L
.54664 .75948 L
.56695 .74802 L
.58727 .73679 L
.60758 .7255 L
.6279 .71405 L
s
.05 .92541 m
.1 .82541 L
.15 .73135 L
.2 .63486 L
.25 .53 L
.3 .41 L
.35 .37514 L
.4 .34162 L
.45 .30838 L
.6 .29919 L
.62 .29324 L
.64 .2873 L
.66 .28162 L
.68 .27622 L
.7 .27108 L
.72 .26622 L
.74 .26135 L
.75 .27757 L
.775 .18432 L
.88 .15 L
.89 .13622 L
.9 .12081 L
.91 .1027 L
.92 .08216 L
.93 .05811 L
.94 .02973 L
s
.94887 0 m
.94 .02973 L
s
s
s
.05 .98324 m
.1 .91703 L
.15 .85514 L
.2 .79568 L
.25 .73622 L
.3 .67595 L
.35 .61324 L
.4 .54703 L
.45 .47568 L
.5 .41622 L
.55 .38676 L
.6 .35703 L
.65 .32703 L
.74 .32135 L
.76 .31486 L
.78 .30865 L
.8 .30243 L
.82 .29649 L
.84 .29081 L
.86 .28514 L
.88 .27973 L
.9 .27459 L
.92 .26946 L
.94 .26486 L
.95 .25568 L
.975 .2 L
1 .13811 L
s
s
.06194 1 m
.1 .96297 L
s
.1 .96297 m
.15 .91703 L
.2 .8727 L
.25 .82919 L
.3 .78622 L
.35 .74297 L
.4 .69919 L
.45 .65432 L
.5 .60811 L
.55 .56 L
.6 .50946 L
.65 .45595 L
.7 .42486 L
.75 .39892 L
.8 .37243 L
.85 .34595 L
.9 .31973 L
.95 .29378 L
1 .26811 L
s
s
.08838 1 m
.1 .99108 L
s
.1 .99108 m
.15 .95486 L
.2 .91946 L
.25 .88514 L
.3 .85108 L
.35 .8173 L
.4 .78351 L
.45 .74946 L
.5 .71514 L
.55 .68027 L
.6 .64486 L
.65 .60838 L
.7 .57054 L
.75 .53162 L
.8 .49081 L
.85 .45459 L
.9 .43216 L
.95 .40919 L
1 .38568 L
s
s
s
.11757 1 m
.15 .98054 L
s
.15 .98054 m
.2 .95135 L
.25 .9227 L
.3 .89459 L
.35 .86676 L
.4 .83892 L
.45 .81108 L
.5 .78351 L
.55 .75541 L
.6 .7273 L
.65 .69865 L
.7 .66973 L
.75 .64027 L
.8 .61027 L
.85 .57919 L
.9 .54757 L
.95 .51459 L
1 .48081 L
s
0 1 0 r
1 0 0 r
0 0 1 r
p
0 g
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{453, 453},
  ImageMargins->{{1, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["T-x (Al) pseudosection", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ox and als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["points data ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
i1={0.1925, 740.2};
i2={0.0593, 738.1};
i3={0.0438, 726.1};
i4={0.0562, 687.6};
i5={0.1583, 684.4};
i6={0.1689, 663.4};
i7={0.1762, 661.6};
i8={0.1231, 647.7};
i9={0.1337, 646.1};
i10={0.0165, 653.9};
i11={0.0115, 648.8};
i12={0.9630, 742.9};
i13={0.9460, 660.7};
i14={0.9470, 662.5};
i15={0.9986, 694.6};
i16={0.9481, 682.2};
i17={0.9632, 742.9};
i18={0.9825, 743.0};
i19={0.9976, 711.3};
i20={0.6987, 742.4};
i21={0.0646, 753.9};
i22={0.2934, 743.8};
i23={0.0971, 808.0};
i24={0.2000, 809.4};
i25={0.0703, 810.1};
i26={0.3547, 862.0};
i27={0.0756, 848.3};
i28={0.2135, 855.3};
i29={0.9652, 783.7};
i30={0.8691, 849.5};
i31={0.9948, 783.3};
i32={0.9892, 846.6};
i33={0.7322, 881.4};
i34={1.0000, 783.3};
i35={1.0000, 846.6};
i36={0.3765, 880.8};
i37={0.4176, 882.2};
i38={0.3927, 926.4};
i39={0.4506, 947.7};
i40={0.2793, 951.5};
i41={0.0497, 908.2};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["crossover[u86,u87]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["{0.0497, 908.2}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["{0.2793, 951.5}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["{0.4506, 947.7}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["{0.3927, 926.4}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["{0.7322, 881.4}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.7322, 881.4}\
\>", "\<\
{0.7322, 881.4}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{0.8691, 849.5}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.8691, 849.5}\
\>", "\<\
{0.8691, 849.5}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (1-20)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  pl bi mu sill H2O (liq)  *) 

u1={{0.1800, 5.00, 661.6},
{0.2000, 5.00, 661.6},
{0.2200, 5.00, 661.6},
{0.2400, 5.00, 661.6},
{0.2600, 5.00, 661.6},
{0.2800, 5.00, 661.6},
{0.3000, 5.00, 661.6},
{0.3200, 5.00, 661.6},
{0.3400, 5.00, 661.6},
{0.3600, 5.00, 661.6},
{0.3800, 5.00, 661.6},
{0.4000, 5.00, 661.6},
{0.4200, 5.00, 661.5},
{0.4400, 5.00, 661.5},
{0.4600, 5.00, 661.5},
{0.4800, 5.00, 661.5},
{0.5000, 5.00, 661.5},
{0.5200, 5.00, 661.5},
{0.5400, 5.00, 661.5},
{0.5600, 5.00, 661.5},
{0.5800, 5.00, 661.5},
{0.6000, 5.00, 661.5},
{0.6200, 5.00, 661.5},
{0.6400, 5.00, 661.5},
{0.6600, 5.00, 661.5},
{0.6800, 5.00, 661.5},
{0.7000, 5.00, 661.5},
{0.7200, 5.00, 661.5},
{0.7400, 5.00, 661.5},
{0.7600, 5.00, 661.5},
{0.7800, 5.00, 661.4},
{0.8000, 5.00, 661.4},
{0.8200, 5.00, 661.4},
{0.8400, 5.00, 661.4},
{0.8600, 5.00, 661.3},
{0.8800, 5.00, 661.3},
{0.9000, 5.00, 661.2},
{0.9200, 5.00, 661.1},
{0.9400, 5.00, 660.8}};

(*------------------------------*)
(*  liq pl bi mu sill (H2O)  *) 

u2={{0.1800, 5.00, 663.4},
{0.2000, 5.00, 663.4},
{0.2200, 5.00, 663.4},
{0.2400, 5.00, 663.4},
{0.2600, 5.00, 663.4},
{0.2800, 5.00, 663.4},
{0.3000, 5.00, 663.4},
{0.3200, 5.00, 663.4},
{0.3400, 5.00, 663.4},
{0.3600, 5.00, 663.4},
{0.3800, 5.00, 663.4},
{0.4000, 5.00, 663.4},
{0.4200, 5.00, 663.4},
{0.4400, 5.00, 663.4},
{0.4600, 5.00, 663.4},
{0.4800, 5.00, 663.4},
{0.5000, 5.00, 663.4},
{0.5200, 5.00, 663.4},
{0.5400, 5.00, 663.4},
{0.5600, 5.00, 663.4},
{0.5800, 5.00, 663.4},
{0.6000, 5.00, 663.3},
{0.6200, 5.00, 663.3},
{0.6400, 5.00, 663.3},
{0.6600, 5.00, 663.3},
{0.6800, 5.00, 663.3},
{0.7000, 5.00, 663.3},
{0.7200, 5.00, 663.3},
{0.7400, 5.00, 663.3},
{0.7600, 5.00, 663.3},
{0.7800, 5.00, 663.3},
{0.8000, 5.00, 663.3},
{0.8200, 5.00, 663.2},
{0.8400, 5.00, 663.2},
{0.8600, 5.00, 663.2},
{0.8800, 5.00, 663.1},
{0.9000, 5.00, 663.0},
{0.9200, 5.00, 662.9},
{0.9400, 5.00, 662.6}};


(*------------------------------*)
(*  liq ksp pl bi g sill (cd)  *) 

u3={{0.0600, 5.00, 738.2},
{0.0800, 5.00, 738.3},
{0.1000, 5.00, 738.4},
{0.1200, 5.00, 738.6},
{0.1400, 5.00, 738.7},
{0.1600, 5.00, 738.8},
{0.1800, 5.00, 738.9},
{0.2000, 5.00, 739.1},
{0.2200, 5.00, 739.2},
{0.2400, 5.00, 739.3},
{0.2600, 5.00, 739.4},
{0.2800, 5.00, 739.6},
{0.3000, 5.00, 739.7},
{0.3200, 5.00, 739.8},
{0.3400, 5.00, 739.9},
{0.3600, 5.00, 740.0},
{0.3800, 5.00, 740.1},
{0.4000, 5.00, 740.3},
{0.4200, 5.00, 740.4},
{0.4400, 5.00, 740.5},
{0.4600, 5.00, 740.6},
{0.4800, 5.00, 740.7},
{0.5000, 5.00, 740.8},
{0.5200, 5.00, 740.9},
{0.5400, 5.00, 741.0},
{0.5600, 5.00, 741.1},
{0.5800, 5.00, 741.2},
{0.6000, 5.00, 741.3},
{0.6200, 5.00, 741.4},
{0.6400, 5.00, 741.5},
{0.6600, 5.00, 741.6},
{0.6800, 5.00, 741.7},
{0.7000, 5.00, 741.8},
{0.7200, 5.00, 741.9},
{0.7400, 5.00, 742.0},
{0.7600, 5.00, 742.1},
{0.7800, 5.00, 742.1},
{0.8000, 5.00, 742.2},
{0.8200, 5.00, 742.3},
{0.8400, 5.00, 742.4},
{0.8600, 5.00, 742.5},
{0.8800, 5.00, 742.6},
{0.9000, 5.00, 742.6},
{0.9200, 5.00, 742.7},
{0.9400, 5.00, 742.8},
{0.9600, 5.00, 742.9}};


(*------------------------------*)
(*  liq ksp pl bi g (sill)  *) 

u4={{0.0450, 5.00, 727.0},
{0.0500, 5.00, 730.8},
{0.0550, 5.00, 734.7},
{0.0600, 5.00, 738.7}};

(*------------------------------*)
(*  liq ksp bi cd g sill (pl)  *) 

u5={{0.2000, 5.00, 740.3},
{0.2200, 5.00, 740.4},
{0.2400, 5.00, 740.4},
{0.2600, 5.00, 740.5},
{0.2800, 5.00, 740.6},
{0.3000, 5.00, 740.7},
{0.3200, 5.00, 740.8},
{0.3400, 5.00, 740.9},
{0.3600, 5.00, 741.0},
{0.3800, 5.00, 741.1},
{0.4000, 5.00, 741.1},
{0.4200, 5.00, 741.2},
{0.4400, 5.00, 741.3},
{0.4600, 5.00, 741.4},
{0.4800, 5.00, 741.5},
{0.5000, 5.00, 741.6},
{0.5200, 5.00, 741.7},
{0.5400, 5.00, 741.7},
{0.5600, 5.00, 741.8},
{0.5800, 5.00, 741.9},
{0.6000, 5.00, 742.0},
{0.6200, 5.00, 742.1},
{0.6400, 5.00, 742.1},
{0.6600, 5.00, 742.2},
{0.6800, 5.00, 742.3}};

(*------------------------------*)
(*  liq ksp pl bi cd g (sill)  *) 

u6={{0.0600, 5.00, 738.2},
{0.0800, 5.00, 738.5},
{0.1000, 5.00, 738.9},
{0.1200, 5.00, 739.2},
{0.1400, 5.00, 739.5},
{0.1600, 5.00, 739.8},
{0.1800, 5.00, 740.1}};


(*------------------------------*)
(*  liq ksp pl bi g (cd)  *) 

u7={{0.0580, 5.00, 731.2},
{0.0590, 5.00, 736.9},
{0.0600, 5.00, 740.9},
{0.0610, 5.00, 744.3},
{0.0620, 5.00, 747.3},
{0.0630, 5.00, 750.0},
{0.0640, 5.00, 752.5}};

(*------------------------------*)
(*  liq ksp bi cd g (pl)  *) 

u8={{0.0700, 5.00, 753.4},
{0.0800, 5.00, 752.4},
{0.0900, 5.00, 751.4},
{0.1000, 5.00, 750.4},
{0.1100, 5.00, 749.4},
{0.1200, 5.00, 748.4},
{0.1300, 5.00, 747.3},
{0.1400, 5.00, 746.3},
{0.1500, 5.00, 745.2},
{0.1600, 5.00, 744.1},
{0.1700, 5.00, 742.9},
{0.1800, 5.00, 741.7},
{0.1900, 5.00, 740.5},
{0.2000, 5.00, 739.3},
{0.2100, 5.00, 738.0},
{0.2200, 5.00, 736.7},
{0.2300, 5.00, 735.4},
{0.2400, 5.00, 734.0},
{0.2500, 5.00, 732.5},
{0.2600, 5.00, 731.0},
{0.2700, 5.00, 729.5},
{0.2800, 5.00, 727.9},
{0.2900, 5.00, 726.2},
{0.3000, 5.00, 724.5},
{0.3100, 5.00, 722.7},
{0.3200, 5.00, 720.9}};

(*------------------------------*)
(*  liq ksp bi cd g (sill)  *) 

u9={{0.0700, 5.00, 734.9},
{0.0800, 5.00, 735.4},
{0.0900, 5.00, 735.8},
{0.1000, 5.00, 736.3},
{0.1100, 5.00, 736.8},
{0.1200, 5.00, 737.2},
{0.1300, 5.00, 737.7},
{0.1400, 5.00, 738.1},
{0.1500, 5.00, 738.5},
{0.1600, 5.00, 738.9},
{0.1700, 5.00, 739.3},
{0.1800, 5.00, 739.7},
{0.1900, 5.00, 740.1},
{0.2000, 5.00, 740.5},
{0.2100, 5.00, 740.9},
{0.2200, 5.00, 741.3},
{0.2300, 5.00, 741.6},
{0.2400, 5.00, 742.0},
{0.2500, 5.00, 742.4},
{0.2600, 5.00, 742.7},
{0.2700, 5.00, 743.0},
{0.2800, 5.00, 743.4},
{0.2900, 5.00, 743.7}};

(*------------------------------*)
(*  liq ksp pl bi sill (g)  *) 

u10={{0.0600, 5.00, 726.2},
{0.0800, 5.00, 726.4},
{0.1000, 5.00, 726.5},
{0.1200, 5.00, 726.7},
{0.1400, 5.00, 726.8},
{0.1600, 5.00, 727.0},
{0.1800, 5.00, 727.1},
{0.2000, 5.00, 727.3},
{0.2200, 5.00, 727.4},
{0.2400, 5.00, 727.6},
{0.2600, 5.00, 727.7},
{0.2800, 5.00, 727.9},
{0.3000, 5.00, 728.0},
{0.3200, 5.00, 728.2},
{0.3400, 5.00, 728.3},
{0.3600, 5.00, 728.4},
{0.3800, 5.00, 728.6},
{0.4000, 5.00, 728.7},
{0.4200, 5.00, 728.9},
{0.4400, 5.00, 729.0},
{0.4600, 5.00, 729.2},
{0.4800, 5.00, 729.3},
{0.5000, 5.00, 729.5},
{0.5200, 5.00, 729.6},
{0.5400, 5.00, 729.8},
{0.5600, 5.00, 729.9},
{0.5800, 5.00, 730.1},
{0.6000, 5.00, 730.2},
{0.6200, 5.00, 730.4},
{0.6400, 5.00, 730.5},
{0.6600, 5.00, 730.7},
{0.6800, 5.00, 730.8},
{0.7000, 5.00, 731.0},
{0.7200, 5.00, 731.2},
{0.7400, 5.00, 731.4},
{0.7600, 5.00, 731.6},
{0.7800, 5.00, 731.8},
{0.8000, 5.00, 732.0},
{0.8200, 5.00, 732.3},
{0.8400, 5.00, 732.6},
{0.8600, 5.00, 733.0},
{0.8800, 5.00, 733.5},
{0.9000, 5.00, 734.1},
{0.9200, 5.00, 735.1},
{0.9400, 5.00, 736.9},
{0.9600, 5.00, 741.4}};

(*------------------------------*)
(*  liq ksp pl bi (sill)  *) 

u11={{0.0400, 5.00, 738.8},
{0.0500, 5.00, 706.2},
{0.0600, 5.00, 676.9},
{0.0700, 5.00, 650.8},
{0.0800, 5.00, 626.3},
{0.0900, 5.00, 602.9}};

(*------------------------------*)
(*  liq ksp pl bi (g)  *) 

u12={{0.0000, 5.00, 738.9},
{0.0100, 5.00, 735.4},
{0.0200, 5.00, 732.2},
{0.0300, 5.00, 729.5},
{0.0400, 5.00, 727.0},
{0.0500, 5.00, 724.8},
{0.0600, 5.00, 722.8},
{0.0700, 5.00, 721.0},
{0.0800, 5.00, 719.3},
{0.0900, 5.00, 717.8},
{0.1000, 5.00, 716.5},
{0.1100, 5.00, 715.2},
{0.1200, 5.00, 714.0},
{0.1300, 5.00, 712.9},
{0.1400, 5.00, 711.9},
{0.1500, 5.00, 710.8},
{0.1600, 5.00, 709.7},
{0.1700, 5.00, 708.6},
{0.1800, 5.00, 707.5},
{0.1900, 5.00, 706.3},
{0.2000, 5.00, 705.2}};

(*------------------------------*)
(*  liq ksp pl bi sill (mu)  *) 

u13={{0.0600, 5.00, 687.6},
{0.0800, 5.00, 687.8},
{0.1000, 5.00, 688.1},
{0.1200, 5.00, 688.3},
{0.1400, 5.00, 688.5},
{0.1600, 5.00, 688.7},
{0.1800, 5.00, 688.9},
{0.2000, 5.00, 689.1},
{0.2200, 5.00, 689.3},
{0.2400, 5.00, 689.5},
{0.2600, 5.00, 689.7},
{0.2800, 5.00, 689.9},
{0.3000, 5.00, 690.2},
{0.3200, 5.00, 690.4},
{0.3400, 5.00, 690.6},
{0.3600, 5.00, 690.8},
{0.3800, 5.00, 691.0},
{0.4000, 5.00, 691.2},
{0.4200, 5.00, 691.4},
{0.4400, 5.00, 691.6},
{0.4600, 5.00, 691.9},
{0.4800, 5.00, 692.1},
{0.5000, 5.00, 692.3},
{0.5200, 5.00, 692.5},
{0.5400, 5.00, 692.7},
{0.5600, 5.00, 692.9},
{0.5800, 5.00, 693.1},
{0.6000, 5.00, 693.3},
{0.6200, 5.00, 693.5},
{0.6400, 5.00, 693.7},
{0.6600, 5.00, 693.8},
{0.6800, 5.00, 694.0},
{0.7000, 5.00, 694.2},
{0.7200, 5.00, 694.4},
{0.7400, 5.00, 694.6},
{0.7600, 5.00, 694.8},
{0.7800, 5.00, 694.9},
{0.8000, 5.00, 695.1},
{0.8200, 5.00, 695.3},
{0.8400, 5.00, 695.4},
{0.8600, 5.00, 695.6},
{0.8800, 5.00, 695.8},
{0.9000, 5.00, 695.9},
{0.9200, 5.00, 696.1},
{0.9400, 5.00, 696.2},
{0.9600, 5.00, 696.4},
{0.9800, 5.00, 696.4}};

(*------------------------------*)
(*  liq pl bi mu sill (ksp)  *) 

u14={{0.1600, 5.00, 684.4},
{0.1800, 5.00, 684.4},
{0.2000, 5.00, 684.4},
{0.2200, 5.00, 684.3},
{0.2400, 5.00, 684.3},
{0.2600, 5.00, 684.3},
{0.2800, 5.00, 684.3},
{0.3000, 5.00, 684.3},
{0.3200, 5.00, 684.3},
{0.3400, 5.00, 684.3},
{0.3600, 5.00, 684.3},
{0.3800, 5.00, 684.3},
{0.4000, 5.00, 684.3},
{0.4200, 5.00, 684.3},
{0.4400, 5.00, 684.3},
{0.4600, 5.00, 684.3},
{0.4800, 5.00, 684.3},
{0.5000, 5.00, 684.3},
{0.5200, 5.00, 684.3},
{0.5400, 5.00, 684.3},
{0.5600, 5.00, 684.3},
{0.5800, 5.00, 684.3},
{0.6000, 5.00, 684.2},
{0.6200, 5.00, 684.2},
{0.6400, 5.00, 684.2},
{0.6600, 5.00, 684.2},
{0.6800, 5.00, 684.2},
{0.7000, 5.00, 684.2},
{0.7200, 5.00, 684.1},
{0.7400, 5.00, 684.1},
{0.7600, 5.00, 684.1},
{0.7800, 5.00, 684.1},
{0.8000, 5.00, 684.0},
{0.8200, 5.00, 684.0},
{0.8400, 5.00, 683.9},
{0.8600, 5.00, 683.8},
{0.8800, 5.00, 683.6},
{0.9000, 5.00, 683.4},
{0.9200, 5.00, 683.1},
{0.9400, 5.00, 682.5}};

(*------------------------------*)
(*  liq ksp pl bi mu (sill)  *) 

u15={{0.0600, 5.00, 687.5},
{0.0700, 5.00, 687.1},
{0.0800, 5.00, 686.8},
{0.0900, 5.00, 686.4},
{0.1000, 5.00, 686.1},
{0.1100, 5.00, 685.8},
{0.1200, 5.00, 685.5},
{0.1300, 5.00, 685.2},
{0.1400, 5.00, 684.9},
{0.1500, 5.00, 684.6}};

(*------------------------------*)
(*  liq ksp pl bi (mu)  *) 

u16={{0.0000, 5.00, 639.9},
{0.0100, 5.00, 648.5},
{0.0200, 5.00, 656.9},
{0.0300, 5.00, 665.4},
{0.0400, 5.00, 673.9},
{0.0500, 5.00, 682.4},
{0.0600, 5.00, 690.8},
{0.0700, 5.00, 699.2},
{0.0800, 5.00, 707.2},
{0.0900, 5.00, 714.9},
{0.1000, 5.00, 721.9}};

(*------------------------------*)
(*  liq pl bi mu (ksp)  *) 

u17={{0.0600, 5.00, 582.7},
{0.0700, 5.00, 593.9},
{0.0800, 5.00, 604.6},
{0.0900, 5.00, 614.8},
{0.1000, 5.00, 624.8},
{0.1100, 5.00, 634.7},
{0.1200, 5.00, 644.6},
{0.1300, 5.00, 654.5},
{0.1400, 5.00, 664.8},
{0.1500, 5.00, 675.4},
{0.1600, 5.00, 686.3},
{0.1700, 5.00, 697.5},
{0.1800, 5.00, 708.7},
{0.1900, 5.00, 719.4},
{0.2000, 5.00, 728.7}};

(*------------------------------*)
(*  liq pl bi mu (sill)  *) 

u18={{0.0600, 5.00, 697.9},
{0.0700, 5.00, 701.1},
{0.0800, 5.00, 704.3},
{0.0900, 5.00, 706.6},
{0.1000, 5.00, 707.1},
{0.1100, 5.00, 706.3},
{0.1200, 5.00, 704.6},
{0.1300, 5.00, 702.1},
{0.1400, 5.00, 698.3},
{0.1500, 5.00, 692.3},
{0.1600, 5.00, 682.1},
{0.1700, 5.00, 660.1}};

(*------------------------------*)
(*  liq pl bi mu (H2O)  *) 

u19={{0.1000, 5.00, 638.7},
{0.1100, 5.00, 642.6},
{0.1200, 5.00, 646.5},
{0.1300, 5.00, 650.2},
{0.1400, 5.00, 653.8},
{0.1500, 5.00, 657.3},
{0.1600, 5.00, 660.6},
{0.1700, 5.00, 663.7},
{0.1800, 5.00, 666.6},
{0.1900, 5.00, 669.1},
{0.2000, 5.00, 671.2}};

(*------------------------------*)
(*  pl bi mu H2O (liq)  *) 

u20={{0.0800, 5.00, 623.2},
{0.0900, 5.00, 627.5},
{0.1000, 5.00, 631.9},
{0.1100, 5.00, 636.3},
{0.1200, 5.00, 640.5},
{0.1300, 5.00, 644.6},
{0.1400, 5.00, 648.5},
{0.1500, 5.00, 652.4},
{0.1600, 5.00, 656.0},
{0.1700, 5.00, 659.5},
{0.1800, 5.00, 662.8},
{0.1900, 5.00, 665.7},
{0.2000, 5.00, 668.2}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (21-40)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  pl bi mu H2O (sill)  *) 

u21={{0.1700, 5.00, 702.6},
{0.1710, 5.00, 698.6},
{0.1720, 5.00, 693.9},
{0.1730, 5.00, 688.3},
{0.1740, 5.00, 681.7},
{0.1750, 5.00, 673.9},
{0.1760, 5.00, 664.2},
{0.1770, 5.00, 652.1},
{0.1780, 5.00, 636.4},
{0.1790, 5.00, 614.7},
{0.1800, 5.00, 580.3}};

(*------------------------------*)
(*  liq ksp pl bi mu (H2O)  *) 

u23={{0.0300, 5.00, 653.0},
{0.0400, 5.00, 652.3},
{0.0500, 5.00, 651.7},
{0.0600, 5.00, 651.1},
{0.0700, 5.00, 650.5},
{0.0800, 5.00, 649.9},
{0.0900, 5.00, 649.3},
{0.1000, 5.00, 648.8},
{0.1100, 5.00, 648.3},
{0.1200, 5.00, 647.8}};

(*------------------------------*)
(*  ksp pl bi mu H2O (liq)  *) 

u24={{0.0200, 5.00, 648.6},
{0.0300, 5.00, 648.3},
{0.0400, 5.00, 648.1},
{0.0500, 5.00, 647.9},
{0.0600, 5.00, 647.6},
{0.0700, 5.00, 647.4},
{0.0800, 5.00, 647.2},
{0.0900, 5.00, 647.0},
{0.1000, 5.00, 646.8},
{0.1100, 5.00, 646.5},
{0.1200, 5.00, 646.3},
{0.1300, 5.00, 646.1}};

(*------------------------------*)
(*  pl bi mu H2O (ksp)  *) 

u25={{0.0800, 5.00, 586.3},
{0.0850, 5.00, 592.0},
{0.0900, 5.00, 597.5},
{0.0950, 5.00, 603.0},
{0.1000, 5.00, 608.5},
{0.1050, 5.00, 614.0},
{0.1100, 5.00, 619.5},
{0.1150, 5.00, 625.0},
{0.1200, 5.00, 630.5},
{0.1250, 5.00, 636.1},
{0.1300, 5.00, 641.8},
{0.1350, 5.00, 647.6},
{0.1400, 5.00, 653.5}};

(*------------------------------*)
(*  liq ksp pl bi (H2O)  *) 

u27={{0.0000, 5.00, 654.5},
{0.0100, 5.00, 654.2},
{0.0200, 5.00, 653.8},
{0.0300, 5.00, 653.4},
{0.0400, 5.00, 653.0}};

(*------------------------------*)
(*  ksp pl bi H2O (liq)  *) 

u28={{0.0000, 5.00, 649.1},
{0.0100, 5.00, 648.8},
{0.0200, 5.00, 648.5},
{0.0300, 5.00, 648.2},
{0.0400, 5.00, 647.8}};

(*------------------------------*)
(*  ksp pl bi H2O (mu)  *) 

u29={{0.0000, 5.00, 636.5},
{0.0050, 5.00, 641.8},
{0.0100, 5.00, 647.1},
{0.0150, 5.00, 652.6},
{0.0200, 5.00, 658.1},
{0.0250, 5.00, 663.8},
{0.0300, 5.00, 669.6},
{0.0350, 5.00, 675.5},
{0.0400, 5.00, 681.7}};

(*------------------------------*)
(*  liq ksp pl bi sill (cd)  *) 

u31={{0.9000, 5.00, 746.9},
{0.9100, 5.00, 746.6},
{0.9200, 5.00, 746.3},
{0.9300, 5.00, 745.8},
{0.9400, 5.00, 745.3},
{0.9500, 5.00, 744.5},
{0.9600, 5.00, 743.4},
{0.9700, 5.00, 741.6},
{0.9800, 5.00, 738.7},
{0.9900, 5.00, 732.3},
{0.9965, 5.00, 725.0},
{0.9970, 5.00, 720.0},
{0.9975, 5.00, 713.0},
{0.9980, 5.00, 703.0},
{0.9985, 5.00, 690.0}};

(*------------------------------*)
(*  liq pl mu sill (bi)  *) 


u32={{0.9470, 5.00, 655.0},
{0.9470, 5.00, 660.0},
{0.9470, 5.00, 665.0},
{0.9470, 5.00, 670.0},
{0.9475, 5.00, 675.0},
{0.9475, 5.00, 680.0},
{0.9480, 5.00, 685.0},
{0.9490, 5.00, 690.0}};


(*------------------------------*)
(*  pl bi mu sill H2O ()  *) 


u33={{0.9465, 5.00, 620.0},
{0.9465, 5.00, 625.0},
{0.9465, 5.00, 630.0},
{0.9465, 5.00, 635.0},
{0.9465, 5.00, 640.0},
{0.9460, 5.00, 645.0},
{0.9460, 5.00, 650.0},
{0.9460, 5.00, 655.0},
{0.9460, 5.00, 660.0},
{0.9460, 5.00, 665.0},
{0.9460, 5.00, 670.0}};

(*------------------------------*)
(*  pl mu sill H2O (liq)  *) 

u34={{0.9000, 5.00, 660.9},
{0.9100, 5.00, 662.2},
{0.9200, 5.00, 662.4},
{0.9300, 5.00, 662.0},
{0.9400, 5.00, 661.3},
{0.9500, 5.00, 660.4},
{0.9700, 5.00, 658.6},
{0.9800, 5.00, 657.7},
{0.9900, 5.00, 656.9},
{1.0000, 5.00, 656.1}};

(*------------------------------*)
(*  liq pl mu sill (H2O)  *) 

u35={{0.9000, 5.00, 663.3},
{0.9100, 5.00, 664.2},
{0.9200, 5.00, 664.3},
{0.9300, 5.00, 663.9},
{0.9400, 5.00, 663.2},
{0.9500, 5.00, 662.3},
{0.9600, 5.00, 661.3},
{0.9700, 5.00, 660.3},
{0.9900, 5.00, 658.5},
{1.0000, 5.00, 657.7}};

(*------------------------------*)
(*  liq pl mu sill (ksp)  *) 

u37={{0.9000, 5.00, 692.1},
{0.9100, 5.00, 690.7},
{0.9200, 5.00, 688.8},
{0.9300, 5.00, 686.6},
{0.9400, 5.00, 684.2},
{0.9500, 5.00, 681.7},
{0.9600, 5.00, 679.4},
{0.9700, 5.00, 677.1},
{0.9800, 5.00, 674.9},
{0.9900, 5.00, 672.9},
{1.0000, 5.00, 671.0}};

(*------------------------------*)
(*  liq ksp pl mu sill (bi)  *) 

u38={{0.9500, 5.00, 682.6},
{0.9550, 5.00, 683.8},
{0.9600, 5.00, 685.1},
{0.9650, 5.00, 686.5},
{0.9700, 5.00, 688.0},
{0.9750, 5.00, 689.3},
{0.9800, 5.00, 690.6},
{0.9850, 5.00, 691.8},
{0.9900, 5.00, 692.9},
{0.9950, 5.00, 693.9}};

(*------------------------------*)
(*  liq ksp pl sill (mu)  *) 

u39={{0.9980, 5.00, 695.5},
{0.9981, 5.00, 695.4},
{0.9982, 5.00, 695.2},
{0.9983, 5.00, 695.1},
{0.9984, 5.00, 694.9},
{0.9985, 5.00, 694.8},
{0.9986, 5.00, 694.6},
{0.9987, 5.00, 694.4},
{0.9988, 5.00, 694.2},
{0.9989, 5.00, 694.0},
{0.9990, 5.00, 693.8},
{0.9991, 5.00, 693.5},
{0.9992, 5.00, 693.3},
{0.9993, 5.00, 693.0},
{0.9994, 5.00, 692.6},
{0.9995, 5.00, 692.3},
{0.9996, 5.00, 691.8},
{0.9997, 5.00, 691.3},
{0.9998, 5.00, 690.5},
{1.0000, 5.00, 689.0}};

(*------------------------------*)
(*  liq ksp pl cd g sill (bi)  *) 

u40={{0.7000, 5.00, 742.4},
{0.7200, 5.00, 742.4},
{0.7400, 5.00, 742.5},
{0.7600, 5.00, 742.5},
{0.7800, 5.00, 742.5},
{0.8000, 5.00, 742.6},
{0.8200, 5.00, 742.6},
{0.8400, 5.00, 742.7},
{0.8600, 5.00, 742.7},
{0.8800, 5.00, 742.8},
{0.9000, 5.00, 742.8},
{0.9200, 5.00, 742.9},
{0.9400, 5.00, 742.9},
{0.9600, 5.00, 742.9},
{0.9800, 5.00, 743.0}};







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (41-60)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi sill (cd)  *) 

u41={{0.9500, 5.00, 744.5},
{0.9525, 5.00, 744.2},
{0.9550, 5.00, 744.0},
{0.9575, 5.00, 743.7},
{0.9600, 5.00, 743.4},
{0.9625, 5.00, 743.0},
{0.9650, 5.00, 742.6},
{0.9675, 5.00, 742.1},
{0.9700, 5.00, 741.6},
{0.9725, 5.00, 741.1},
{0.9750, 5.00, 740.4},
{0.9775, 5.00, 739.6},
{0.9800, 5.00, 738.7},
{0.9825, 5.00, 737.6},
{0.9850, 5.00, 736.2},
{0.9875, 5.00, 734.5},
{0.9900, 5.00, 732.3},
{0.9925, 5.00, 729.3},
{0.9950, 5.00, 724.8}};

(*------------------------------*)
(*  liq ksp pl bi cd sill (g)  *) 

u42={{0.9640, 5.00, 742.9},
{0.9660, 5.00, 742.9},
{0.9680, 5.00, 742.9},
{0.9700, 5.00, 742.9},
{0.9720, 5.00, 742.9},
{0.9740, 5.00, 742.9},
{0.9760, 5.00, 743.0},
{0.9780, 5.00, 743.0},
{0.9800, 5.00, 743.0},
{0.9820, 5.00, 743.0}};

(*------------------------------*)
(*  liq ksp pl cd sill (bi)  *) 

u43={{0.9800, 5.00, 745.0},
{0.9810, 5.00, 744.3},
{0.9820, 5.00, 743.6},
{0.9830, 5.00, 742.8},
{0.9840, 5.00, 742.0},
{0.9850, 5.00, 741.1},
{0.9860, 5.00, 740.2},
{0.9870, 5.00, 739.1},
{0.9880, 5.00, 738.0},
{0.9890, 5.00, 736.8},
{0.9900, 5.00, 735.5},
{0.9910, 5.00, 734.0},
{0.9920, 5.00, 732.4},
{0.9930, 5.00, 730.6},
{0.9940, 5.00, 728.5},
{0.9950, 5.00, 726.0}};

(*------------------------------*)
(*  liq ksp pl cd sill (g)  *) 

u44={{0.9720, 5.00, 771.0},
{0.9740, 5.00, 766.7},
{0.9760, 5.00, 762.1},
{0.9780, 5.00, 757.1},
{0.9800, 5.00, 751.7},
{0.9820, 5.00, 745.6},
{0.9840, 5.00, 738.9},
{0.9860, 5.00, 731.2},
{0.9880, 5.00, 722.4},
{0.9900, 5.00, 712.0}};

(*------------------------------*)
(*  liq ksp pl sill (cd)  *) 

u45={{0.9955, 5.00, 774.3},
{0.9960, 5.00, 763.4},
{0.9965, 5.00, 750.6},
{0.9970, 5.00, 735.1},
{0.9975, 5.00, 715.6},
{0.9980, 5.00, 689.3},
{0.9985, 5.00, 648.3}};

(*------------------------------*)
(*  liq ksp cd g sill (bi)  *) 

u46={{0.3000, 5.00, 743.8},
{0.3200, 5.00, 743.8},
{0.3400, 5.00, 743.7},
{0.3600, 5.00, 743.7},
{0.3800, 5.00, 743.6},
{0.4000, 5.00, 743.6},
{0.4200, 5.00, 743.5},
{0.4400, 5.00, 743.5},
{0.4600, 5.00, 743.4},
{0.4800, 5.00, 743.4},
{0.5000, 5.00, 743.3},
{0.5200, 5.00, 743.2},
{0.5400, 5.00, 743.2},
{0.5600, 5.00, 743.1},
{0.5800, 5.00, 743.0},
{0.6000, 5.00, 742.9},
{0.6200, 5.00, 742.8},
{0.6400, 5.00, 742.7},
{0.6600, 5.00, 742.6},
{0.6800, 5.00, 742.5},
{0.7000, 5.00, 742.4},
{0.7200, 5.00, 742.2},
{0.7400, 5.00, 742.1},
{0.7600, 5.00, 741.9},
{0.7800, 5.00, 741.7},
{0.8000, 5.00, 741.5}};

(*------------------------------*)
(*  liq ksp cd g sill (pl)  *) 

u47={{0.5000, 5.00, 643.0},
{0.5200, 5.00, 666.7},
{0.5400, 5.00, 683.2},
{0.5600, 5.00, 695.5},
{0.5800, 5.00, 705.3},
{0.6000, 5.00, 713.7},
{0.6200, 5.00, 720.8},
{0.6400, 5.00, 727.2},
{0.6600, 5.00, 732.8},
{0.6800, 5.00, 738.0},
{0.7000, 5.00, 742.7},
{0.7200, 5.00, 747.0},
{0.7400, 5.00, 751.0},
{0.7600, 5.00, 754.8},
{0.7800, 5.00, 758.3},
{0.8000, 5.00, 761.6},
{0.8200, 5.00, 764.8},
{0.8400, 5.00, 767.8},
{0.8600, 5.00, 770.6},
{0.8800, 5.00, 773.4},
{0.9000, 5.00, 776.0},
{0.9200, 5.00, 778.5},
{0.9400, 5.00, 780.9},
{0.9600, 5.00, 783.2}};

(*------------------------------*)
(*  liq ksp bi g (pl)  *) 

u48={{0.0000, 5.00, 773.5},
{0.0100, 5.00, 769.4},
{0.0200, 5.00, 765.7},
{0.0300, 5.00, 762.5},
{0.0400, 5.00, 759.5},
{0.0500, 5.00, 757.0},
{0.0600, 5.00, 754.8},
{0.0700, 5.00, 752.9},
{0.0800, 5.00, 751.3},
{0.0900, 5.00, 749.9},
{0.1000, 5.00, 748.7},
{0.1100, 5.00, 747.8},
{0.1200, 5.00, 747.0},
{0.1300, 5.00, 746.3},
{0.1400, 5.00, 745.7},
{0.1500, 5.00, 745.1},
{0.1600, 5.00, 744.6},
{0.1700, 5.00, 744.2},
{0.1800, 5.00, 743.7},
{0.1900, 5.00, 743.3},
{0.2000, 5.00, 742.9}};

(*------------------------------*)
(*  liq ksp bi g (cd)  *) 

u49={{0.0650, 5.00, 755.3},
{0.0700, 5.00, 767.8},
{0.0750, 5.00, 777.2},
{0.0800, 5.00, 785.2},
{0.0850, 5.00, 792.4},
{0.0900, 5.00, 799.1},
{0.0950, 5.00, 805.4},
{0.1000, 5.00, 811.3},
{0.1050, 5.00, 817.1},
{0.1100, 5.00, 822.6},
{0.1150, 5.00, 828.0},
{0.1200, 5.00, 833.3},
{0.1250, 5.00, 838.5}};

(*------------------------------*)
(*  liq ksp cd g (bi)  *) 

u50={{0.1400, 5.00, 835.4},
{0.1600, 5.00, 828.1},
{0.1800, 5.00, 819.7},
{0.2000, 5.00, 810.1},
{0.2200, 5.00, 799.0},
{0.2400, 5.00, 786.2},
{0.2600, 5.00, 771.5},
{0.2800, 5.00, 755.2},
{0.3000, 5.00, 738.1},
{0.3200, 5.00, 721.4},
{0.3400, 5.00, 706.1},
{0.3600, 5.00, 692.0},
{0.3800, 5.00, 678.3},
{0.4000, 5.00, 662.5}};

(*------------------------------*)
(*  liq ksp cd g (sill)  *) 

u51={{0.2600, 5.00, 645.3},
{0.2800, 5.00, 706.6},
{0.3000, 5.00, 760.9},
{0.3200, 5.00, 805.9},
{0.3400, 5.00, 841.4},
{0.3450, 5.00, 848.9},
{0.3500, 5.00, 855.9},
{0.3505, 5.00, 856.6},
{0.3510, 5.00, 857.3},
{0.3515, 5.00, 857.9},
{0.3520, 5.00, 858.6},
{0.3525, 5.00, 859.3},
{0.3530, 5.00, 859.9},
{0.3535, 5.00, 860.6},
{0.3540, 5.00, 861.2},
{0.3545, 5.00, 861.8}};

(*------------------------------*)
(*  liq ksp bi cd g (opx)  *) 

u52={{0.1000, 5.00, 808.0},
{0.1100, 5.00, 808.2},
{0.1200, 5.00, 808.3},
{0.1300, 5.00, 808.5},
{0.1400, 5.00, 808.6},
{0.1500, 5.00, 808.7},
{0.1600, 5.00, 808.9},
{0.1700, 5.00, 809.0},
{0.1800, 5.00, 809.2},
{0.1900, 5.00, 809.3},
{0.2000, 5.00, 809.4}};

(*------------------------------*)
(*  liq ksp bi g (opx)  *) 

u53={{0.0000, 5.00, 787.3},
{0.0100, 5.00, 789.7},
{0.0200, 5.00, 792.0},
{0.0300, 5.00, 794.2},
{0.0400, 5.00, 796.4},
{0.0500, 5.00, 798.6},
{0.0600, 5.00, 800.7},
{0.0700, 5.00, 802.7},
{0.0800, 5.00, 804.7},
{0.0900, 5.00, 806.6},
{0.1000, 5.00, 808.5},
{0.1100, 5.00, 810.3},
{0.1200, 5.00, 812.0},
{0.1300, 5.00, 813.6},
{0.1400, 5.00, 815.2},
{0.1500, 5.00, 816.6}};

(*------------------------------*)
(*  liq ksp cd g opx (bi)  *) 

u54={{0.0800, 5.00, 810.1},
{0.1000, 5.00, 810.0},
{0.1200, 5.00, 809.9},
{0.1400, 5.00, 809.8},
{0.1600, 5.00, 809.7},
{0.1800, 5.00, 809.5},
{0.2000, 5.00, 809.4}};

(*------------------------------*)
(*  liq ksp g opx (bi)  *) 

u55={{0.0000, 5.00, 803.8},
{0.0100, 5.00, 804.7},
{0.0200, 5.00, 805.6},
{0.0300, 5.00, 806.5},
{0.0400, 5.00, 807.4},
{0.0500, 5.00, 808.3},
{0.0600, 5.00, 809.2},
{0.0700, 5.00, 810.1},
{0.0800, 5.00, 811.0},
{0.0900, 5.00, 811.9},
{0.1000, 5.00, 812.7},
{0.1100, 5.00, 813.6},
{0.1200, 5.00, 814.4},
{0.1300, 5.00, 815.3},
{0.1400, 5.00, 816.1},
{0.1500, 5.00, 816.9}};

(*------------------------------*)
(*  liq ksp g opx (cd)  *) 

u56={{0.0500, 5.00, 588.8},
{0.0520, 5.00, 634.6},
{0.0540, 5.00, 666.6},
{0.0560, 5.00, 691.0},
{0.0580, 5.00, 710.4},
{0.0600, 5.00, 728.5},
{0.0620, 5.00, 745.7},
{0.0640, 5.00, 762.2},
{0.0660, 5.00, 778.0},
{0.0680, 5.00, 793.3},
{0.0700, 5.00, 808.2},
{0.0720, 5.00, 822.7},
{0.0740, 5.00, 836.9},
{0.0742, 5.00, 838.3},
{0.0744, 5.00, 839.7},
{0.0746, 5.00, 841.1},
{0.0748, 5.00, 842.5},
{0.0750, 5.00, 843.9},
{0.0752, 5.00, 845.3},
{0.0754, 5.00, 846.7},
{0.0756, 5.00, 848.1}};

(*------------------------------*)
(*  liq ksp bi g opx (cd)  *) 

u57={{0.0750, 5.00, 809.8},
{0.0800, 5.00, 809.4},
{0.0850, 5.00, 809.0},
{0.0900, 5.00, 808.6},
{0.0950, 5.00, 808.2}};
(*------------------------------*)
(*  liq ksp cd g (opx)  *) 

u58={{0.1920, 5.00, 631.8},
{0.1940, 5.00, 727.5},
{0.1960, 5.00, 764.8},
{0.1980, 5.00, 786.0},
{0.2000, 5.00, 801.3},
{0.2020, 5.00, 813.3},
{0.2040, 5.00, 823.1},
{0.2060, 5.00, 831.5},
{0.2080, 5.00, 838.8},
{0.2100, 5.00, 845.3},
{0.2120, 5.00, 851.2}};

(*------------------------------*)
(*  liq cd g (ksp)  *) 

u59={{0.1400, 5.00, 850.1},
{0.1600, 5.00, 851.6},
{0.1800, 5.00, 853.1},
{0.2000, 5.00, 854.5},
{0.2200, 5.00, 855.7},
{0.2400, 5.00, 856.9},
{0.2600, 5.00, 858.0},
{0.2800, 5.00, 859.1},
{0.3000, 5.00, 860.0},
{0.3200, 5.00, 860.8},
{0.3400, 5.00, 861.5},
{0.3600, 5.00, 862.2},
{0.3800, 5.00, 862.7},
{0.4000, 5.00, 863.2},
{0.4200, 5.00, 863.6},
{0.4400, 5.00, 864.0}};


(*------------------------------*)
(*  liq cd g sill (ksp)  *) 

u60={{0.3600, 5.00, 861.9},
{0.3800, 5.00, 861.5},
{0.4000, 5.00, 861.0},
{0.4200, 5.00, 860.6},
{0.4400, 5.00, 860.1},
{0.4600, 5.00, 859.7},
{0.4800, 5.00, 859.2},
{0.5000, 5.00, 858.8},
{0.5200, 5.00, 858.3},
{0.5400, 5.00, 857.9},
{0.5600, 5.00, 857.4},
{0.5800, 5.00, 856.9},
{0.6000, 5.00, 856.4},
{0.6200, 5.00, 855.9},
{0.6400, 5.00, 855.5},
{0.6600, 5.00, 855.0},
{0.6800, 5.00, 854.5},
{0.7000, 5.00, 854.0},
{0.7200, 5.00, 853.5},
{0.7400, 5.00, 852.9},
{0.7600, 5.00, 852.4},
{0.7800, 5.00, 851.9},
{0.8000, 5.00, 851.4},
{0.8200, 5.00, 850.9},
{0.8400, 5.00, 850.3},
{0.8600, 5.00, 849.8}};
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (61-80)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq cd g sill (sp)  *) 

u61={{0.3800, 5.00, 880.8},
{0.4000, 5.00, 880.8},
{0.4200, 5.00, 880.8},
{0.4400, 5.00, 880.9},
{0.4600, 5.00, 880.9},
{0.4800, 5.00, 880.9},
{0.5000, 5.00, 881.0},
{0.5200, 5.00, 881.0},
{0.5400, 5.00, 881.1},
{0.5600, 5.00, 881.1},
{0.5800, 5.00, 881.1},
{0.6000, 5.00, 881.2},
{0.6200, 5.00, 881.2},
{0.6400, 5.00, 881.2},
{0.6600, 5.00, 881.3},
{0.6800, 5.00, 881.3},
{0.7000, 5.00, 881.3},
{0.7200, 5.00, 881.3}};

(*------------------------------*)
(*  liq cd g (sill)  *) 

u62={{0.2000, 5.00, 608.6},
{0.2200, 5.00, 663.8},
{0.2400, 5.00, 709.2},
{0.2600, 5.00, 746.5},
{0.2800, 5.00, 777.7},
{0.3000, 5.00, 804.3},
{0.3200, 5.00, 827.6},
{0.3400, 5.00, 848.2},
{0.3600, 5.00, 866.8},
{0.3800, 5.00, 883.6},
{0.4000, 5.00, 899.0},
{0.4200, 5.00, 913.1}};

(*------------------------------*)
(*  liq cd g opx (ksp)  *) 

u63={{0.1000, 5.00, 849.6},
{0.1200, 5.00, 850.6},
{0.1400, 5.00, 851.6},
{0.1600, 5.00, 852.6},
{0.1800, 5.00, 853.6},
{0.2000, 5.00, 854.7}};

(*------------------------------*)
(*  liq g opx (ksp)  *) 

u64={{0.0000, 5.00, 848.2},
{0.0200, 5.00, 848.3},
{0.0400, 5.00, 848.3},
{0.0600, 5.00, 848.3},
{0.0800, 5.00, 848.3},
{0.1000, 5.00, 848.2},
{0.1200, 5.00, 848.1},
{0.1400, 5.00, 848.0},
{0.1600, 5.00, 847.8}};

(*------------------------------*)
(*  liq g opx (cd)  *) 

u65={{0.0500, 5.00, 907.7},
{0.0550, 5.00, 899.5},
{0.0600, 5.00, 890.2},
{0.0650, 5.00, 879.4},
{0.0700, 5.00, 866.5},
{0.0750, 5.00, 850.6},
{0.0800, 5.00, 829.5},
{0.0850, 5.00, 796.9}};

(*------------------------------*)
(*  liq cd g (opx)  *) 

u66={{0.1700, 5.00, 691.0},
{0.1800, 5.00, 754.1},
{0.1900, 5.00, 793.3},
{0.2000, 5.00, 823.2},
{0.2100, 5.00, 847.6},
{0.2200, 5.00, 868.4},
{0.2300, 5.00, 886.5},
{0.2400, 5.00, 902.6},
{0.2500, 5.00, 916.9},
{0.2600, 5.00, 929.9},
{0.2700, 5.00, 941.6}};

(*------------------------------*)
(*  liq cd g sp (sill)  *) 

u67={{0.3775, 5.00, 880.8},
{0.3800, 5.00, 880.9},
{0.3825, 5.00, 881.0},
{0.3850, 5.00, 881.0},
{0.3875, 5.00, 881.1},
{0.3900, 5.00, 881.2},
{0.3925, 5.00, 881.3},
{0.3950, 5.00, 881.4},
{0.3975, 5.00, 881.5},
{0.4000, 5.00, 881.5},
{0.4025, 5.00, 881.6},
{0.4050, 5.00, 881.7},
{0.4075, 5.00, 881.8},
{0.4100, 5.00, 881.9},
{0.4125, 5.00, 882.0},
{0.4150, 5.00, 882.1},
{0.4175, 5.00, 882.2}};

(*------------------------------*)
(*  liq cd sp sill (g)  *) 

u68={{0.4300, 5.00, 882.3},
{0.4400, 5.00, 882.3},
{0.4500, 5.00, 882.2},
{0.4600, 5.00, 882.2},
{0.4700, 5.00, 882.2},
{0.4800, 5.00, 882.1},
{0.4900, 5.00, 882.1},
{0.5000, 5.00, 882.1},
{0.5100, 5.00, 882.1},
{0.5200, 5.00, 882.0},
{0.5300, 5.00, 882.0},
{0.5400, 5.00, 882.0},
{0.5500, 5.00, 881.9},
{0.5600, 5.00, 881.9},
{0.5700, 5.00, 881.9},
{0.5800, 5.00, 881.8},
{0.5900, 5.00, 881.8},
{0.6000, 5.00, 881.8},
{0.6100, 5.00, 881.8},
{0.6200, 5.00, 881.7},
{0.6300, 5.00, 881.7},
{0.6400, 5.00, 881.7},
{0.6500, 5.00, 881.6},
{0.6600, 5.00, 881.6},
{0.6700, 5.00, 881.6},
{0.6800, 5.00, 881.5},
{0.6900, 5.00, 881.5},
{0.7000, 5.00, 881.5},
{0.7100, 5.00, 881.4},
{0.7200, 5.00, 881.4},
{0.7300, 5.00, 881.4}};

(*------------------------------*)
(*  liq ksp cd sill (g)  *) 

u69={{0.8700, 5.00, 849.2},
{0.8800, 5.00, 845.1},
{0.8900, 5.00, 840.7},
{0.9000, 5.00, 835.9},
{0.9100, 5.00, 830.6},
{0.9200, 5.00, 824.6},
{0.9300, 5.00, 817.9},
{0.9400, 5.00, 810.3},
{0.9500, 5.00, 801.3},
{0.9600, 5.00, 790.3},
{0.9700, 5.00, 776.5},
{0.9800, 5.00, 757.3},
{0.9900, 5.00, 725.8}};

(*------------------------------*)
(*  liq ksp cd sill (pl)  *) 

u70={{0.9000, 5.00, 786.3},
{0.9050, 5.00, 786.1},
{0.9100, 5.00, 785.8},
{0.9150, 5.00, 785.6},
{0.9200, 5.00, 785.4},
{0.9250, 5.00, 785.2},
{0.9300, 5.00, 785.0},
{0.9350, 5.00, 784.8},
{0.9400, 5.00, 784.6},
{0.9450, 5.00, 784.4},
{0.9500, 5.00, 784.2},
{0.9550, 5.00, 784.1},
{0.9600, 5.00, 783.9},
{0.9650, 5.00, 783.7},
{0.9700, 5.00, 783.6},
{0.9750, 5.00, 783.5},
{0.9800, 5.00, 783.4},
{0.9850, 5.00, 783.3},
{0.9900, 5.00, 783.3}};

(*------------------------------*)
(*  liq cd sill (ksp)  *) 

u71={{0.8000, 5.00, 851.9},
{0.8100, 5.00, 851.6},
{0.8200, 5.00, 851.2},
{0.8300, 5.00, 850.9},
{0.8400, 5.00, 850.5},
{0.8500, 5.00, 850.2},
{0.8600, 5.00, 849.8},
{0.8700, 5.00, 849.5},
{0.8800, 5.00, 849.2},
{0.8900, 5.00, 848.9},
{0.9000, 5.00, 848.6},
{0.9100, 5.00, 848.3},
{0.9200, 5.00, 848.0},
{0.9300, 5.00, 847.7},
{0.9400, 5.00, 847.4},
{0.9500, 5.00, 847.2},
{0.9600, 5.00, 847.0},
{0.9700, 5.00, 846.8},
{0.9800, 5.00, 846.7}};

(*------------------------------*)
(*  liq cd sill (g)  *) 

u72={{0.6000, 5.00, 898.3},
{0.6200, 5.00, 896.2},
{0.6400, 5.00, 893.9},
{0.6600, 5.00, 891.5},
{0.6800, 5.00, 889.0},
{0.7000, 5.00, 886.2},
{0.7200, 5.00, 883.3},
{0.7400, 5.00, 880.1},
{0.7600, 5.00, 876.6},
{0.7800, 5.00, 872.8},
{0.8000, 5.00, 868.6},
{0.8200, 5.00, 864.0},
{0.8400, 5.00, 858.7},
{0.8600, 5.00, 852.6},
{0.8800, 5.00, 845.5},
{0.9000, 5.00, 837.1},
{0.9200, 5.00, 826.6},
{0.9400, 5.00, 812.9},
{0.9600, 5.00, 793.3},
{0.9800, 5.00, 759.7}};

(*------------------------------*)
(*  liq cd sill (sp)  *) 

u74={{0.4550, 5.00, 947.1},
{0.4700, 5.00, 944.5},
{0.4850, 5.00, 941.8},
{0.5000, 5.00, 939.1},
{0.5150, 5.00, 936.3},
{0.5300, 5.00, 933.4},
{0.5450, 5.00, 930.3},
{0.5600, 5.00, 927.2},
{0.5750, 5.00, 924.0},
{0.5900, 5.00, 920.7},
{0.6050, 5.00, 917.2},
{0.6200, 5.00, 913.6},
{0.6350, 5.00, 909.9},
{0.6500, 5.00, 906.0},
{0.6650, 5.00, 901.9},
{0.6800, 5.00, 897.7},
{0.6950, 5.00, 893.3},
{0.7100, 5.00, 888.7},
{0.7250, 5.00, 883.8},
{0.7400, 5.00, 878.7},
{0.7550, 5.00, 873.3},
{0.7700, 5.00, 867.6},
{0.7850, 5.00, 861.5},
{0.8000, 5.00, 855.0}};

(*------------------------------*)
(*  liq sill (cd)  *) 

u75={{0.9180, 5.00, 1061.0},
{0.9220, 5.00, 1057.0},
{0.9260, 5.00, 1052.8},
{0.9300, 5.00, 1048.3},
{0.9340, 5.00, 1043.5},
{0.9380, 5.00, 1038.2},
{0.9420, 5.00, 1032.5},
{0.9460, 5.00, 1026.3},
{0.9500, 5.00, 1019.4},
{0.9540, 5.00, 1011.8},
{0.9580, 5.00, 1003.3},
{0.9620, 5.00, 993.7},
{0.9660, 5.00, 982.7},
{0.9700, 5.00, 970.0},
{0.9740, 5.00, 955.0},
{0.9780, 5.00, 936.9},
{0.9820, 5.00, 914.1},
{0.9860, 5.00, 884.1},
{0.9900, 5.00, 840.9}};

(*------------------------------*)
(*  liq cd sp (g)  *) 

u78={{0.3950, 5.00, 924.2},
{0.3975, 5.00, 921.7},
{0.4000, 5.00, 919.0},
{0.4025, 5.00, 916.0},
{0.4050, 5.00, 912.9},
{0.4075, 5.00, 909.5},
{0.4100, 5.00, 905.9},
{0.4125, 5.00, 901.8},
{0.4150, 5.00, 897.3},
{0.4175, 5.00, 672.0},
{0.4200, 5.00, 702.0}};

(*------------------------------*)
(*  liq cd sp (sill)  *) 

u79={{0.4050, 5.00, 771.4},
{0.4100, 5.00, 823.2},
{0.4150, 5.00, 854.6},
{0.4200, 5.00, 877.0},
{0.4250, 5.00, 894.4},
{0.4300, 5.00, 908.4},
{0.4350, 5.00, 920.1},
{0.4400, 5.00, 930.2},
{0.4450, 5.00, 938.9},
{0.4500, 5.00, 946.7}};

(*------------------------------*)
(*  liq cd g (sp)  *) 

u80={{0.3000, 5.00, 662.2},
{0.3050, 5.00, 676.7},
{0.3100, 5.00, 691.7},
{0.3150, 5.00, 708.0},
{0.3200, 5.00, 723.8},
{0.3250, 5.00, 739.1},
{0.3300, 5.00, 753.9},
{0.3350, 5.00, 768.4},
{0.3400, 5.00, 782.6},
{0.3450, 5.00, 796.4},
{0.3500, 5.00, 810.1},
{0.3550, 5.00, 823.6},
{0.3600, 5.00, 836.9},
{0.3650, 5.00, 850.2},
{0.3700, 5.00, 863.5},
{0.3750, 5.00, 876.8},
{0.3800, 5.00, 890.3},
{0.3850, 5.00, 904.2},
{0.3900, 5.00, 918.4}};






\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (81-> )", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq cd (g)  *) 

u81={{0.1000, 5.00, 970.8},
{0.1200, 5.00, 968.8},
{0.1400, 5.00, 966.8},
{0.1600, 5.00, 964.9},
{0.1800, 5.00, 962.9},
{0.2000, 5.00, 960.8},
{0.2200, 5.00, 958.7},
{0.2400, 5.00, 956.4},
{0.2600, 5.00, 954.0},
{0.2800, 5.00, 951.4},
{0.3000, 5.00, 948.4},
{0.3200, 5.00, 945.0},
{0.3400, 5.00, 941.1},
{0.3600, 5.00, 936.5},
{0.3800, 5.00, 930.8},
{0.4000, 5.00, 923.5},
{0.4200, 5.00, 913.5},
{0.4400, 5.00, 897.3}};

(*------------------------------*)
(*  liq cd (sp)  *) 

u82={{0.3000, 5.00, 862.9},
{0.3200, 5.00, 880.8},
{0.3400, 5.00, 896.2},
{0.3600, 5.00, 909.2},
{0.3800, 5.00, 920.3},
{0.4000, 5.00, 929.7},
{0.4200, 5.00, 937.7},
{0.4400, 5.00, 944.5},
{0.4600, 5.00, 950.4},
{0.4800, 5.00, 955.5},
{0.5000, 5.00, 959.8}};

(*------------------------------*)
(*  liq cd (sill)  *) 

u83={{0.4000, 5.00, 863.3},
{0.4200, 5.00, 912.8},
{0.4400, 5.00, 937.9},
{0.4600, 5.00, 955.0},
{0.4800, 5.00, 968.0},
{0.5000, 5.00, 978.5},
{0.5200, 5.00, 987.2},
{0.5400, 5.00, 994.7},
{0.5600, 5.00, 1001.3},
{0.5800, 5.00, 1007.2},
{0.6000, 5.00, 1012.5},
{0.6200, 5.00, 1017.3},
{0.6400, 5.00, 1021.7},
{0.6600, 5.00, 1025.8},
{0.6800, 5.00, 1029.6},
{0.7000, 5.00, 1033.1},
{0.7200, 5.00, 1036.4},
{0.7400, 5.00, 1039.5},
{0.7600, 5.00, 1042.5},
{0.7800, 5.00, 1045.2},
{0.8000, 5.00, 1047.9},
{0.8200, 5.00, 1050.4},
{0.8400, 5.00, 1052.7},
{0.8600, 5.00, 1055.0},
{0.8800, 5.00, 1057.2},
{0.9000, 5.00, 1059.2}};

(*------------------------------*)
(*  liq cd opx (g)  *) 

u84={{0.0600, 5.00, 910.2},
{0.0800, 5.00, 914.1},
{0.1000, 5.00, 917.9},
{0.1200, 5.00, 921.8},
{0.1400, 5.00, 925.6},
{0.1600, 5.00, 929.4},
{0.1800, 5.00, 933.2},
{0.2000, 5.00, 936.9},
{0.2200, 5.00, 940.6},
{0.2400, 5.00, 944.3},
{0.2600, 5.00, 948.0}};

(*------------------------------*)
(*  liq cd (opx)  *) 

u85={{0.2200, 5.00, 1005.7},
{0.2400, 5.00, 986.8},
{0.2600, 5.00, 967.9},
{0.2800, 5.00, 950.9},
{0.3000, 5.00, 934.4},
{0.3200, 5.00, 917.5},
{0.3400, 5.00, 899.0},
{0.3600, 5.00, 876.9},
{0.3800, 5.00, 846.2},
{0.4000, 5.00, 783.7}};

(*------------------------------*)
(*  liq opx (g)  *) 

u86={{0.0000, 5.00, 868.8},
{0.0100, 5.00, 878.5},
{0.0200, 5.00, 887.2},
{0.0300, 5.00, 895.0},
{0.0400, 5.00, 902.1},
{0.0500, 5.00, 908.4},
{0.0600, 5.00, 914.2},
{0.0700, 5.00, 919.4},
{0.0800, 5.00, 924.2},
{0.0900, 5.00, 928.6},
{0.1000, 5.00, 932.6},
{0.1100, 5.00, 936.3},
{0.1200, 5.00, 939.8},
{0.1300, 5.00, 943.0},
{0.1400, 5.00, 945.9},
{0.1500, 5.00, 948.7},
{0.1600, 5.00, 951.3},
{0.1700, 5.00, 953.7},
{0.1800, 5.00, 956.0},
{0.1900, 5.00, 958.1},
{0.2000, 5.00, 960.1}};

(*------------------------------*)
(*  liq opx (cd)  *) 

u87={{0.0000, 5.00, 788.0},
{0.0200, 5.00, 843.9},
{0.0400, 5.00, 889.1},
{0.0600, 5.00, 926.9},
{0.0800, 5.00, 958.7},
{0.1000, 5.00, 985.1},
{0.1200, 5.00, 1007.0},
{0.1400, 5.00, 1025.2},
{0.1600, 5.00, 1040.8}};



\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{1,3};\n   \n  \n  \t\n  \tlu1 = makeline[u1, i7, i13];\n  \tlu2 = \
makeline[u2, i6, i14];\n  \tlu3 = makeline[u3, i2, i17];\n  \tlu4 = \
makeline[u4, i3, i2];\n  \tlu5 = makeline[u5, i1, ur];\n  \tlu6 = \
makeline[u6, i2, i1];\n  \tlu7 = makeline[u7, i2, i21];\n  \tlu8 = \
makeline[u8, i21, i1];\n  \tlu9 = makeline[u9, i1, i22];\n  \tlu10 = \
makeline[u10, i3, i17];\n  \tlu11 = makeline[u11, i3, i4];\n  \tlu12 = \
makeline[u12, ul, i3];\n  \tlu13 = makeline[u13, i4, i15];\n  \tlu14 = \
makeline[u14, i5, i16];\n  \tlu15 = makeline[u15, i4, i5];\n  \tlu16 = \
makeline[u16, i10, i4];\n  \tlu17 = makeline[u17, i8, i5];\n  \tlu18 = \
makeline[u18, i5, i6];\n  \tlu19 = makeline[u19, i8, i6];\n  \tlu20 = \
makeline[u20, i9, i7];\n  \tlu21 = makeline[u21, lr, i7];\n  \tlu22 = \
connect[i6, i7];\n  \tlu23 = makeline[u23, i10, i8];\n  \tlu24 = \
makeline[u24, i11, i9];\n  \tlu25 = makeline[u25, ll, i9];\n  \tlu26 = \
connect[i8, i9];\n  \tlu27 = makeline[u27, ul, i10];\n  \tlu28 = \
makeline[u28, ul, i11];\n  \tlu29 = makeline[u29, ll, i11];\n  \tlu30 = \
connect[i10, i11];\n  \tlu31 = makeline[u31, i19, i15];\n  \tlu32 = \
makeline[u32, i14, i16];\n  \tlu33 = makeline[u33, lr, i13];\n  \tlu34 = \
makeline[u34, lr, i13];\n  \tlu35 = makeline[u35, lr, i14];\n  \tlu36 = \
connect[i13, i14];\n  \tlu37 = makeline[u37, lr, i16];\n  \tlu38 = \
makeline[u38, i15, i16];\n  \tlu39 = makeline[u39, i15, lr];\n  \tlu40 = \
makeline[u40, i20, i18];\n  \tlu41 = makeline[u41, i17, i19];\n  \tlu42 = \
makeline[u42, i17, i18];\n  \tlu43 = makeline[u43, i18, i19];\n  \tlu44 = \
makeline[u44, i18, i29];\n  \tlu45 = makeline[u45, i19, i31];\n  \tlu46 = \
makeline[u46, i20, i22];\n  \tlu47 = makeline[u47, i20, i29];\n  \tlu48 = \
makeline[u48, ul, i21];\n  \tlu49 = makeline[u49, i21, i23];\n  \tlu50 = \
makeline[u50, i24, i22];\n  \tlu51 = makeline[u51, i22, i26];\n  \tlu52 = \
makeline[u52, i23, i24];\n  \tlu53 = makeline[u53, ll, i23];\n  \tlu54 = \
makeline[u54, i25, i24];\n  \tlu55 = makeline[u55, ll, i25];\n  \tlu56 = \
makeline[u56, i25, i27];\n  \tlu57 = makeline[u57, i25, i23];\n  \tlu58 = \
makeline[u58, i24, i28];\n  \tlu59 = makeline[u59, i28, i26];\n  \tlu60 = \
makeline[u60, i26, i30];\n  \tlu61 = makeline[u61, i36, i33];\n  \tlu62 = \
makeline[u62, i26, i36];\n  \tlu63 = makeline[u63, i27, i28];\n  \tlu64 = \
makeline[u64, ul, i27];\n  \tlu65 = makeline[u65, i27, i41];\n  \tlu66 = \
makeline[u66, i28, i40];\n  \tlu67 = makeline[u67, i36, i37];\n  \tlu68 = \
makeline[u68, i37, i33];\n  \tlu69 = makeline[u69, i30, i29];\n  \tlu70 = \
makeline[u70, i29, i31];\n  \tlu71 = makeline[u71, i30, i32];\n  \tlu72 = \
makeline[u72, i30, i33];\n  \tlu73 = connect[i31, i32];\n  \tlu74 = \
makeline[u74, i33, i39];\n  \tlu75 = makeline[u75, i32, ul];\n  \tlu76 = \
connect[i31, i34];\n  \tlu77 = connect[i35, i32];\n  \tlu78 = makeline[u78, \
i37, i38];\n  \tlu79 = makeline[u79, i37, i39];\n  \tlu80 = makeline[u80, \
i36, i38];\n  \tlu81 = makeline[u81, i40, i38];\n  \tlu82 = makeline[u82, \
i38, i39];\n  \tlu83 = makeline[u83, i39, ur];\n  \tlu84 = makeline[u84, i41, \
i40];\n  \tlu85 = makeline[u85, ul, i40];\n  \tlu86 = makeline[u86, ll, i41];\
\n  \tlu87 = makeline[u87, ur, i41];\n  \n  \t\n  \t\n  \n  \t\n  \n  \t\n    \
  \t\t\n        \t\t\n  Show[Graphics[\n         {GrayLevel[0.85],\n          \
area[{lu54, lu57, lu52}],\n          area[{lu44, lu47, lu40}],\n          \
area[{lu6, lu7, lu8}],\n          area[{lu46, lu9, lu5}],\n          \
area[{lu3, lu4, lu10}],\n          area[{lu43, lu42, lu41}],\n          \
area[{lu23, lu30, lu24, lu26}],\n          area[{lu13, lu15, lu14, lu38}],\n  \
        area[{lu2, lu22, lu1, lu36}],\n         \n          GrayLevel[0.65],\n\
          area[{lu68, lu67, lu61}],\n          area[{lu63, lu58, lu54, \
lu56}],\n          area[{lu60, lu51, lu46, lu47, lu69}],\n          \
area[{lu55, lu57, lu53}],\n          area[{lu52, lu50, lu9, lu8, lu49}],\n    \
      area[{lu70, lu44, lu43, lu45}],\n          area[{lu48, lu7, lu4, \
lu12}],\n          area[{lu10, lu11, lu13, lu31, lu41}],\n          \
area[{lu27, lu30, lu28}],\n          area[{lu16, lu23, lu17, lu15}],\n        \
  area[{lu29, lu24, lu25}],\n          area[{lu19, lu26, lu20, lu22}],\n      \
    area[{lu14, lu18, lu2, lu32}],\n          area[{lu21, lu1, lu33}],\n      \
    area[{lu39, lu38, lu37}],\n          area[{lu35, lu36, lu34}],\n         \
\n          GrayLevel[0.35],\n          area[{lu84, lu66, lu63, lu65}],\n     \
     area[{lu67, lu78, lu80}],\n          area[{lu68, lu74, lu79}],\n         \
 area[{lu61, lu62, lu60, lu72}],\n          area[{lu64, lu56, lu55}],\n       \
   area[{lu59, lu51, lu50, lu58}],\n          area[{lu71, lu69, lu70, lu73}],\
\n          area[{lu48, lu49, lu53}],\n          area[{lu76, lu45, lu31, \
lu39}],\n          area[{lu12, lu11, lu16, lu27}],\n          area[{lu28, \
lu29}],\n          area[{lu18, lu17, lu19}],\n          area[{lu25, lu20, \
lu21}],\n          area[{lu37, lu32, lu35}],\n          area[{lu34, lu33}],\n \
        \n          \n          GrayLevel[0.15],\n          area[{lu85, lu84, \
lu87}],\n          area[{lu83, lu74, lu72, lu71, lu75}],\n          \
area[{lu86, lu65, lu64}],\n          area[{lu81, lu80, lu62, lu59, lu66}],\n  \
        area[{lu82, lu78, lu79}],\n          area[{lu77, lu73, lu76}],\n      \
   \n          \n          GrayLevel[0],\n          area[{lu86, lu87}],\n     \
     area[{lu85, lu81, lu82, lu83}],\n          area[{lu75, lu77}],\n         \
\n   \n          AbsoluteThickness[0.3],\n          drawline[lu1],\n          \
drawline[lu2],\n          drawline[lu3],\n          drawline[lu4],\n          \
drawline[lu5],\n          drawline[lu6],\n          drawline[lu7],\n          \
drawline[lu8],\n          drawline[lu9],\n          drawline[lu10],\n         \
 drawline[lu11],\n          drawline[lu12],\n          drawline[lu13],\n      \
    drawline[lu14],\n          drawline[lu15],\n          drawline[lu16],\n   \
       drawline[lu17],\n          drawline[lu18],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu19],\n          drawline[lu20],\n          \
drawline[lu21],\n          drawline[lu22],\n          drawline[lu23],\n       \
   drawline[lu24],\n          drawline[lu25],\n          drawline[lu26],\n    \
      ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu27],\n          drawline[lu28],\n          \
drawline[lu29],\n          drawline[lu30],\n          drawline[lu31],\n       \
   drawline[lu32],\n          drawline[lu33],\n          drawline[lu34],\n    \
      drawline[lu35],\n          drawline[lu36],\n          drawline[lu37],\n \
         drawline[lu38],\n          drawline[lu39],\n          \
drawline[lu40],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu41],\n          drawline[lu42],\n          \
drawline[lu43],\n          drawline[lu44],\n          drawline[lu45],\n       \
   ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu46],\n          drawline[lu47],\n          \
drawline[lu48],\n          drawline[lu49],\n          drawline[lu50],\n       \
   drawline[lu51],\n         \n          drawline[lu52],\n          \
drawline[lu53],\n          drawline[lu54],\n          drawline[lu55],\n       \
   drawline[lu56],\n          drawline[lu57],\n          drawline[lu58],\n    \
      drawline[lu59],\n          drawline[lu60],\n          drawline[lu61],\n \
         drawline[lu62],\n          drawline[lu63],\n          \
drawline[lu64],\n          drawline[lu65],\n          drawline[lu66],\n       \
   drawline[lu67],\n          drawline[lu68],\n          drawline[lu69],\n    \
      drawline[lu70],\n          drawline[lu71],\n          drawline[lu72],\n \
         drawline[lu73],\n          drawline[lu74],\n          \
drawline[lu75],\n          drawline[lu76],\n          drawline[lu77],\n       \
   drawline[lu78],\n          drawline[lu79],\n          drawline[lu80],\n    \
      ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu81],\n          drawline[lu82],\n          \
drawline[lu83],\n          drawline[lu84],\n          drawline[lu85],\n       \
   drawline[lu86],\n          drawline[lu87],\n          \n         \n        \
 \n          \n          AbsoluteThickness[0.5], \n         \n        \n      \
    ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[0,1,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["RGBColor[0,0,1],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n           outline}],\n        \t\t",
    FontWeight->"Plain"],
  StyleBox["\n       ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  \n         AspectRatio -> 1, Frame -> True,\n         PlotRange \
-> {{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 0; xhigh = 1; ylow = 630; yhigh =1000;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 -1.7027 0.0027027 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(650)] -0.0125 .05405 1 0 Msboxa
[(700)] -0.0125 .18919 1 0 Msboxa
[(750)] -0.0125 .32432 1 0 Msboxa
[(800)] -0.0125 .45946 1 0 Msboxa
[(850)] -0.0125 .59459 1 0 Msboxa
[(900)] -0.0125 .72973 1 0 Msboxa
[(950)] -0.0125 .86486 1 0 Msboxa
[(1000)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .05405 m
.00625 .05405 L
s
P
[(650)] -0.0125 .05405 1 0 Mshowa
p
.002 w
0 .18919 m
.00625 .18919 L
s
P
[(700)] -0.0125 .18919 1 0 Mshowa
p
.002 w
0 .32432 m
.00625 .32432 L
s
P
[(750)] -0.0125 .32432 1 0 Mshowa
p
.002 w
0 .45946 m
.00625 .45946 L
s
P
[(800)] -0.0125 .45946 1 0 Mshowa
p
.002 w
0 .59459 m
.00625 .59459 L
s
P
[(850)] -0.0125 .59459 1 0 Mshowa
p
.002 w
0 .72973 m
.00625 .72973 L
s
P
[(900)] -0.0125 .72973 1 0 Mshowa
p
.002 w
0 .86486 m
.00625 .86486 L
s
P
[(950)] -0.0125 .86486 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(1000)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .08108 m
.00375 .08108 L
s
P
p
.001 w
0 .10811 m
.00375 .10811 L
s
P
p
.001 w
0 .13514 m
.00375 .13514 L
s
P
p
.001 w
0 .16216 m
.00375 .16216 L
s
P
p
.001 w
0 .21622 m
.00375 .21622 L
s
P
p
.001 w
0 .24324 m
.00375 .24324 L
s
P
p
.001 w
0 .27027 m
.00375 .27027 L
s
P
p
.001 w
0 .2973 m
.00375 .2973 L
s
P
p
.001 w
0 .35135 m
.00375 .35135 L
s
P
p
.001 w
0 .37838 m
.00375 .37838 L
s
P
p
.001 w
0 .40541 m
.00375 .40541 L
s
P
p
.001 w
0 .43243 m
.00375 .43243 L
s
P
p
.001 w
0 .48649 m
.00375 .48649 L
s
P
p
.001 w
0 .51351 m
.00375 .51351 L
s
P
p
.001 w
0 .54054 m
.00375 .54054 L
s
P
p
.001 w
0 .56757 m
.00375 .56757 L
s
P
p
.001 w
0 .62162 m
.00375 .62162 L
s
P
p
.001 w
0 .64865 m
.00375 .64865 L
s
P
p
.001 w
0 .67568 m
.00375 .67568 L
s
P
p
.001 w
0 .7027 m
.00375 .7027 L
s
P
p
.001 w
0 .75676 m
.00375 .75676 L
s
P
p
.001 w
0 .78378 m
.00375 .78378 L
s
P
p
.001 w
0 .81081 m
.00375 .81081 L
s
P
p
.001 w
0 .83784 m
.00375 .83784 L
s
P
p
.001 w
0 .89189 m
.00375 .89189 L
s
P
p
.001 w
0 .91892 m
.00375 .91892 L
s
P
p
.001 w
0 .94595 m
.00375 .94595 L
s
P
p
.001 w
0 .97297 m
.00375 .97297 L
s
P
p
.001 w
0 .02703 m
.00375 .02703 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .05405 m
1 .05405 L
s
P
p
.002 w
.99375 .18919 m
1 .18919 L
s
P
p
.002 w
.99375 .32432 m
1 .32432 L
s
P
p
.002 w
.99375 .45946 m
1 .45946 L
s
P
p
.002 w
.99375 .59459 m
1 .59459 L
s
P
p
.002 w
.99375 .72973 m
1 .72973 L
s
P
p
.002 w
.99375 .86486 m
1 .86486 L
s
P
p
.001 w
.99625 .08108 m
1 .08108 L
s
P
p
.001 w
.99625 .10811 m
1 .10811 L
s
P
p
.001 w
.99625 .13514 m
1 .13514 L
s
P
p
.001 w
.99625 .16216 m
1 .16216 L
s
P
p
.001 w
.99625 .21622 m
1 .21622 L
s
P
p
.001 w
.99625 .24324 m
1 .24324 L
s
P
p
.001 w
.99625 .27027 m
1 .27027 L
s
P
p
.001 w
.99625 .2973 m
1 .2973 L
s
P
p
.001 w
.99625 .35135 m
1 .35135 L
s
P
p
.001 w
.99625 .37838 m
1 .37838 L
s
P
p
.001 w
.99625 .40541 m
1 .40541 L
s
P
p
.001 w
.99625 .43243 m
1 .43243 L
s
P
p
.001 w
.99625 .48649 m
1 .48649 L
s
P
p
.001 w
.99625 .51351 m
1 .51351 L
s
P
p
.001 w
.99625 .54054 m
1 .54054 L
s
P
p
.001 w
.99625 .56757 m
1 .56757 L
s
P
p
.001 w
.99625 .62162 m
1 .62162 L
s
P
p
.001 w
.99625 .64865 m
1 .64865 L
s
P
p
.001 w
.99625 .67568 m
1 .67568 L
s
P
p
.001 w
.99625 .7027 m
1 .7027 L
s
P
p
.001 w
.99625 .75676 m
1 .75676 L
s
P
p
.001 w
.99625 .78378 m
1 .78378 L
s
P
p
.001 w
.99625 .81081 m
1 .81081 L
s
P
p
.001 w
.99625 .83784 m
1 .83784 L
s
P
p
.001 w
.99625 .89189 m
1 .89189 L
s
P
p
.001 w
.99625 .91892 m
1 .91892 L
s
P
p
.001 w
.99625 .94595 m
1 .94595 L
s
P
p
.001 w
.99625 .97297 m
1 .97297 L
s
P
p
.001 w
.99625 .02703 m
1 .02703 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
.2 .48486 m
.17838 .48518 L
.15677 .48573 L
.13515 .48601 L
.11353 .48631 L
.09192 .48658 L
.0703 .48676 L
.0703 .48676 L
.0971 .48108 L
.0971 .48108 L
.11768 .48182 L
.13826 .48266 L
.15884 .48345 L
.17942 .4843 L
.2 .48486 L
F
.9825 .30541 m
.98056 .32374 L
.97821 .34207 L
.97547 .36041 L
.97241 .37874 L
.96901 .39707 L
.9652 .41541 L
.9652 .41541 L
.9447 .40931 L
.9242 .40274 L
.9037 .39586 L
.8832 .38872 L
.8627 .38103 L
.8422 .37328 L
.8217 .36503 L
.8012 .3562 L
.7807 .34708 L
.7602 .3374 L
.7397 .32687 L
.7192 .31577 L
.6987 .30378 L
.6987 .30378 L
.71897 .30377 L
.73924 .30405 L
.75951 .30406 L
.77979 .30405 L
.80006 .30432 L
.82033 .30433 L
.8406 .3046 L
.86087 .3046 L
.88114 .30487 L
.90141 .30488 L
.92169 .30514 L
.94196 .30513 L
.96223 .30514 L
.9825 .30541 L
F
.1925 .29784 m
.17347 .29734 L
.15444 .29653 L
.13541 .29576 L
.11639 .295 L
.09736 .29419 L
.07833 .29315 L
.0593 .29216 L
.0593 .29216 L
.06032 .30284 L
.06155 .31351 L
.06298 .32419 L
.0646 .33486 L
.0646 .33486 L
.08592 .32921 L
.10723 .32345 L
.12855 .31745 L
.14987 .31139 L
.17118 .30475 L
.1925 .29784 L
F
.6987 .30378 m
.67843 .30408 L
.65817 .30435 L
.6379 .30462 L
.61764 .3049 L
.59737 .30517 L
.57711 .30544 L
.55684 .30573 L
.53658 .30595 L
.51631 .30598 L
.49605 .30628 L
.47578 .30649 L
.45552 .30654 L
.43525 .30676 L
.41499 .30682 L
.39472 .30703 L
.37446 .3071 L
.35419 .3073 L
.33393 .30737 L
.31366 .30764 L
.2934 .30757 L
.2934 .30757 L
.27322 .30575 L
.25304 .30405 L
.23286 .30192 L
.21268 .30003 L
.1925 .29784 L
.1925 .29784 L
.21281 .29834 L
.23313 .29837 L
.25344 .29855 L
.27375 .29883 L
.29406 .29911 L
.31438 .29938 L
.33469 .29966 L
.355 .29993 L
.37531 .30022 L
.39563 .30027 L
.41594 .30048 L
.43625 .30076 L
.45656 .30103 L
.47688 .30131 L
.49719 .30158 L
.5175 .30187 L
.53781 .30189 L
.55813 .30213 L
.57844 .30241 L
.59875 .30269 L
.61906 .30296 L
.63937 .30297 L
.65969 .30324 L
.68 .30351 L
F
.9632 .30514 m
.94311 .3049 L
.92303 .30464 L
.90294 .30435 L
.88285 .30433 L
.86277 .3041 L
.84268 .30382 L
.82259 .30355 L
.80251 .30328 L
.78242 .303 L
.76233 .30298 L
.74225 .30274 L
.72216 .30246 L
.70207 .30219 L
.68199 .30192 L
.6619 .30165 L
.64181 .30138 L
.62173 .3011 L
.60164 .30083 L
.58155 .30056 L
.56147 .30029 L
.54138 .30002 L
.52129 .29975 L
.50121 .29948 L
.48112 .2992 L
.46103 .29893 L
.44095 .29866 L
.42086 .29839 L
.40077 .29812 L
.38069 .29758 L
.3606 .2973 L
.34051 .29703 L
.32043 .29676 L
.30034 .29649 L
.28025 .29622 L
.26017 .29568 L
.24008 .29541 L
.21999 .29514 L
.19991 .29486 L
.17982 .29432 L
.15973 .29405 L
.13965 .29378 L
.11956 .2935 L
.09947 .29296 L
.07939 .29269 L
.0593 .29216 L
.0593 .29216 L
.05551 .28405 L
.05168 .27595 L
.04778 .26784 L
.0438 .25973 L
.0438 .25973 L
.06379 .2601 L
.08377 .2606 L
.10376 .26091 L
.12375 .26141 L
.14373 .26172 L
.16372 .26222 L
.18371 .26253 L
.2037 .26303 L
.22368 .26334 L
.24367 .26384 L
.26366 .26415 L
.28364 .26465 L
.30363 .26496 L
.32362 .26547 L
.3436 .26572 L
.36359 .26604 L
.38358 .26654 L
.40357 .26685 L
.42355 .26735 L
.44354 .26766 L
.46353 .26816 L
.48351 .26847 L
.5035 .26897 L
.52349 .26928 L
.54347 .26978 L
.56346 .27009 L
.58345 .27059 L
.60343 .2709 L
.62342 .2714 L
.64341 .27171 L
.6634 .27221 L
.68338 .27251 L
.70337 .27306 L
.72336 .2736 L
.74334 .27414 L
.76333 .27468 L
.78332 .27522 L
.8033 .2758 L
.82329 .27661 L
.84328 .27746 L
.86327 .27858 L
.88325 .27995 L
.90324 .28169 L
.92323 .28454 L
.94321 .2903 L
.9632 .30514 L
F
.9976 .21973 m
.9968 .24115 L
.99456 .26257 L
.9903 .28399 L
.9825 .30541 L
.9825 .30541 L
.9632 .30514 L
.9632 .30514 L
.98682 .28378 L
.99389 .26243 L
.99661 .24108 L
.9976 .21973 L
F
.1231 .04784 m
.10178 .05057 L
.08046 .05371 L
.05914 .05717 L
.03782 .06067 L
.0165 .06459 L
.0165 .06459 L
.0115 .05081 L
.0115 .05081 L
.03187 .04935 L
.05223 .0482 L
.0726 .04689 L
.09297 .0458 L
.11333 .04439 L
.1337 .04351 L
.1337 .04351 L
.1231 .04784 L
F
.9986 .17459 m
.97855 .17959 L
.9585 .17943 L
.93845 .1789 L
.9184 .17861 L
.89834 .17808 L
.87829 .1778 L
.85824 .17725 L
.83819 .17673 L
.81814 .17644 L
.79809 .17589 L
.77804 .17538 L
.75799 .17509 L
.73794 .17454 L
.71789 .174 L
.69783 .17345 L
.67778 .17291 L
.65773 .1724 L
.63768 .17211 L
.61763 .17156 L
.59758 .17102 L
.57753 .17047 L
.55748 .16993 L
.53743 .16939 L
.51737 .16885 L
.49732 .16831 L
.47727 .16777 L
.45722 .16719 L
.43717 .1664 L
.41712 .16587 L
.39707 .16533 L
.37702 .16478 L
.35697 .16424 L
.33691 .1637 L
.31686 .16317 L
.29681 .16258 L
.27676 .16179 L
.25671 .16126 L
.23666 .16072 L
.21661 .16018 L
.19656 .15964 L
.17651 .15909 L
.15646 .15855 L
.1364 .15801 L
.11635 .15748 L
.0963 .15688 L
.07625 .15608 L
.0562 .15568 L
.0562 .15568 L
.07662 .1538 L
.09704 .15185 L
.11746 .15021 L
.13788 .14855 L
.1583 .14703 L
.1583 .14703 L
.17855 .14702 L
.1988 .14703 L
.21905 .14677 L
.23931 .14676 L
.25956 .14676 L
.27981 .14676 L
.30006 .14676 L
.32031 .14676 L
.34056 .14676 L
.36081 .14676 L
.38106 .14676 L
.40132 .14676 L
.42157 .14676 L
.44182 .14676 L
.46207 .14676 L
.48232 .14676 L
.50257 .14676 L
.52282 .14676 L
.54307 .14676 L
.56333 .14676 L
.58358 .14671 L
.60383 .14647 L
.62408 .14649 L
.64433 .14649 L
.66458 .14649 L
.68483 .1465 L
.70508 .14642 L
.72534 .1462 L
.74559 .14622 L
.76584 .14623 L
.78609 .14614 L
.80634 .14594 L
.82659 .14587 L
.84684 .1456 L
.86709 .14523 L
.88735 .14468 L
.9076 .14407 L
.92785 .14303 L
.9481 .14108 L
.9481 .14108 L
.96073 .14945 L
.97335 .15914 L
.98598 .16763 L
.9986 .17459 L
F
.947 .08784 m
.92705 .08875 L
.9071 .08911 L
.88715 .08936 L
.86719 .08965 L
.84724 .08974 L
.82729 .08971 L
.80734 .0899 L
.78739 .09001 L
.76744 .09 L
.74749 .09 L
.72754 .09 L
.70758 .09 L
.68763 .09 L
.66768 .09 L
.64773 .09 L
.62778 .09 L
.60783 .08998 L
.58788 .09017 L
.56793 .09029 L
.54797 .09027 L
.52802 .09027 L
.50807 .09027 L
.48812 .09027 L
.46817 .09027 L
.44822 .09027 L
.42827 .09027 L
.40832 .09027 L
.38836 .09027 L
.36841 .09027 L
.34846 .09027 L
.32851 .09027 L
.30856 .09027 L
.28861 .09027 L
.26866 .09027 L
.24871 .09027 L
.22875 .09027 L
.2088 .09027 L
.18885 .09027 L
.1689 .09027 L
.1689 .09027 L
.1762 .08541 L
.1762 .08541 L
.19646 .08541 L
.21672 .08541 L
.23697 .08541 L
.25723 .08541 L
.27749 .08541 L
.29775 .08541 L
.31801 .08541 L
.33826 .08541 L
.35852 .08541 L
.37878 .08541 L
.39904 .08541 L
.41929 .08514 L
.43955 .08513 L
.45981 .08514 L
.48007 .08514 L
.50033 .08514 L
.52058 .08514 L
.54084 .08514 L
.5611 .08514 L
.58136 .08514 L
.60162 .08514 L
.62187 .08514 L
.64213 .08514 L
.66239 .08514 L
.68265 .08514 L
.70291 .08514 L
.72316 .08514 L
.74342 .08514 L
.76368 .08509 L
.78394 .08485 L
.80419 .08486 L
.82445 .08487 L
.84471 .08481 L
.86497 .08459 L
.88523 .08454 L
.90548 .08427 L
.92574 .08391 L
.946 .08297 L
.946 .08297 L
.947 .08784 L
F
.65 g
.7322 .67946 m
.71254 .67944 L
.69288 .67974 L
.67321 .67992 L
.65355 .67998 L
.63389 .68029 L
.61423 .68043 L
.59456 .68054 L
.5749 .68068 L
.55524 .68079 L
.53557 .6811 L
.51591 .68119 L
.49625 .68135 L
.47659 .68144 L
.45693 .68161 L
.43726 .68192 L
.4176 .68162 L
.4176 .68162 L
.40733 .68052 L
.39705 .67969 L
.38678 .67856 L
.3765 .67784 L
.3765 .67784 L
.39626 .67785 L
.41602 .67782 L
.43578 .67806 L
.45554 .67812 L
.47531 .67809 L
.49507 .67832 L
.51483 .67837 L
.53459 .67858 L
.55435 .67866 L
.57411 .67863 L
.59387 .67884 L
.61363 .67893 L
.63339 .6789 L
.65316 .6791 L
.67292 .6792 L
.69268 .67919 L
.71244 .67915 L
.7322 .67946 L
F
.0756 .59 m
.0953 .59286 L
.115 .59555 L
.1347 .5982 L
.1544 .60086 L
.1741 .60351 L
.1938 .60641 L
.2135 .60892 L
.2135 .60892 L
.21077 .58824 L
.20835 .56757 L
.20622 .54689 L
.20436 .52622 L
.20308 .50554 L
.2 .48486 L
.2 .48486 L
.17838 .48518 L
.15677 .48573 L
.13515 .48601 L
.11353 .48631 L
.09192 .48658 L
.0703 .48676 L
.0703 .48676 L
.07133 .50741 L
.07237 .52805 L
.07345 .5487 L
.07454 .56935 L
.0756 .59 L
F
.8691 .59324 m
.84932 .59465 L
.82953 .59627 L
.80975 .59774 L
.78996 .59906 L
.77018 .60039 L
.75039 .60171 L
.73061 .60319 L
.71082 .60469 L
.69104 .60601 L
.67125 .60735 L
.65147 .6087 L
.63168 .60991 L
.6119 .61107 L
.59212 .61242 L
.57233 .61376 L
.55255 .61511 L
.53276 .61634 L
.51298 .6175 L
.49319 .61875 L
.47341 .6199 L
.45362 .62116 L
.43384 .6223 L
.41405 .62357 L
.39427 .6247 L
.37448 .62603 L
.3547 .62703 L
.3547 .62703 L
.34908 .60706 L
.34385 .58709 L
.339 .56713 L
.33443 .54716 L
.33012 .5272 L
.32605 .50723 L
.3222 .48726 L
.31851 .4673 L
.31494 .44733 L
.31153 .42736 L
.30825 .4074 L
.30509 .38743 L
.30204 .36747 L
.29908 .3475 L
.2962 .32753 L
.2934 .30757 L
.2934 .30757 L
.31366 .30764 L
.33393 .30737 L
.35419 .3073 L
.37446 .3071 L
.39472 .30703 L
.41499 .30682 L
.43525 .30676 L
.45552 .30654 L
.47578 .30649 L
.49605 .30628 L
.51631 .30598 L
.53658 .30595 L
.55684 .30573 L
.57711 .30544 L
.59737 .30517 L
.61764 .3049 L
.6379 .30462 L
.65817 .30435 L
.67843 .30408 L
.6987 .30378 L
.6987 .30378 L
.7192 .31577 L
.7397 .32687 L
.7602 .3374 L
.7807 .34708 L
.8012 .3562 L
.8217 .36503 L
.8422 .37328 L
.8627 .38103 L
.8832 .38872 L
.9037 .39586 L
.9242 .40274 L
.9447 .40931 L
.9652 .41541 L
.9652 .41541 L
.95941 .43517 L
.95291 .45492 L
.94541 .47468 L
.93668 .49444 L
.92662 .5142 L
.91521 .53396 L
.90201 .55372 L
.88671 .57348 L
.8691 .59324 L
F
0 .46973 m
.01758 .474 L
.03515 .47828 L
.05273 .48256 L
.0703 .48676 L
.0703 .48676 L
.0971 .48108 L
.0971 .48108 L
.07768 .47092 L
.05826 .46038 L
.03884 .44904 L
.01942 .43748 L
0 .42514 L
F
.0971 .48108 m
.11768 .48182 L
.13826 .48266 L
.15884 .48345 L
.17942 .4843 L
.2 .48486 L
.2 .48486 L
.21421 .46517 L
.22697 .44547 L
.23808 .42577 L
.24842 .40607 L
.25813 .38637 L
.26735 .36667 L
.27621 .34697 L
.28487 .32727 L
.2934 .30757 L
.2934 .30757 L
.27322 .30575 L
.25304 .30405 L
.23286 .30192 L
.21268 .30003 L
.1925 .29784 L
.1925 .29784 L
.17118 .30475 L
.14987 .31139 L
.12855 .31745 L
.10723 .32345 L
.08592 .32921 L
.0646 .33486 L
.0646 .33486 L
.06729 .35575 L
.07076 .37664 L
.07493 .39753 L
.07974 .41842 L
.0851 .43931 L
.09089 .46019 L
.0971 .48108 L
F
.9948 .41432 m
.9652 .41541 L
.9652 .41541 L
.96901 .39707 L
.97241 .37874 L
.97547 .36041 L
.97821 .34207 L
.98056 .32374 L
.9825 .30541 L
.9825 .30541 L
.9903 .28399 L
.99456 .26257 L
.9968 .24115 L
.9976 .21973 L
.9976 .21973 L
.99743 .23919 L
.99725 .25865 L
.99706 .27811 L
.99685 .29757 L
.99662 .31703 L
.99636 .33649 L
.99607 .35595 L
.99578 .37541 L
.99539 .39486 L
.9948 .41432 L
F
0 .38784 m
.01615 .37046 L
.0323 .35617 L
.04845 .34422 L
.0646 .33486 L
.0646 .33486 L
.06298 .32419 L
.06155 .31351 L
.06032 .30284 L
.0593 .29216 L
.0593 .29216 L
.05551 .28405 L
.05168 .27595 L
.04778 .26784 L
.0438 .25973 L
.0438 .25973 L
.03285 .26691 L
.0219 .27475 L
.01095 .284 L
0 .29432 L
F
.9632 .30514 m
.94321 .2903 L
.92323 .28454 L
.90324 .28169 L
.88325 .27995 L
.86327 .27858 L
.84328 .27746 L
.82329 .27661 L
.8033 .2758 L
.78332 .27522 L
.76333 .27468 L
.74334 .27414 L
.72336 .2736 L
.70337 .27306 L
.68338 .27251 L
.6634 .27221 L
.64341 .27171 L
.62342 .2714 L
.60343 .2709 L
.58345 .27059 L
.56346 .27009 L
.54347 .26978 L
.52349 .26928 L
.5035 .26897 L
.48351 .26847 L
.46353 .26816 L
.44354 .26766 L
.42355 .26735 L
.40357 .26685 L
.38358 .26654 L
.36359 .26604 L
.3436 .26572 L
.32362 .26547 L
.30363 .26496 L
.28364 .26465 L
.26366 .26415 L
.24367 .26384 L
.22368 .26334 L
.2037 .26303 L
.18371 .26253 L
.16372 .26222 L
.14373 .26172 L
.12375 .26141 L
.10376 .26091 L
.08377 .2606 L
.06379 .2601 L
.0438 .25973 L
.0438 .25973 L
.04616 .23892 L
.04856 .21811 L
.05103 .1973 L
.05358 .17649 L
.0562 .15568 L
.0562 .15568 L
.07625 .15608 L
.0963 .15688 L
.11635 .15748 L
.1364 .15801 L
.15646 .15855 L
.17651 .15909 L
.19656 .15964 L
.21661 .16018 L
.23666 .16072 L
.25671 .16126 L
.27676 .16179 L
.29681 .16258 L
.31686 .16317 L
.33691 .1637 L
.35697 .16424 L
.37702 .16478 L
.39707 .16533 L
.41712 .16587 L
.43717 .1664 L
.45722 .16719 L
.47727 .16777 L
.49732 .16831 L
.51737 .16885 L
.53743 .16939 L
.55748 .16993 L
.57753 .17047 L
.59758 .17102 L
.61763 .17156 L
.63768 .17211 L
.65773 .1724 L
.67778 .17291 L
.69783 .17345 L
.71789 .174 L
.73794 .17454 L
.75799 .17509 L
.77804 .17538 L
.79809 .17589 L
.81814 .17644 L
.83819 .17673 L
.85824 .17725 L
.87829 .1778 L
.89834 .17808 L
.9184 .17861 L
.93845 .1789 L
.9585 .17943 L
.97855 .17959 L
.9986 .17459 L
.9986 .17459 L
.99837 .18588 L
.998 .19716 L
.9978 .20845 L
.9976 .21973 L
.9976 .21973 L
.99661 .24108 L
.99389 .26243 L
.98682 .28378 L
.9632 .30514 L
F
0 .06622 m
.0165 .06459 L
.0165 .06459 L
.0115 .05081 L
.0115 .05081 L
0 .05162 L
F
.0562 .15568 m
.04818 .13746 L
.04026 .11924 L
.03233 .10103 L
.02444 .08281 L
.0165 .06459 L
.0165 .06459 L
.03782 .06067 L
.05914 .05717 L
.08046 .05371 L
.10178 .05057 L
.1231 .04784 L
.1231 .04784 L
.13054 .06768 L
.13769 .08751 L
.14467 .10735 L
.15155 .12719 L
.1583 .14703 L
.1583 .14703 L
.13788 .14855 L
.11746 .15021 L
.09704 .15185 L
.07662 .1538 L
.0562 .15568 L
F
0 .01757 m
.00291 .02588 L
.00579 .03419 L
.00866 .0425 L
.0115 .05081 L
.0115 .05081 L
.03187 .04935 L
.05223 .0482 L
.0726 .04689 L
.09297 .0458 L
.11333 .04439 L
.1337 .04351 L
.1337 .04351 L
.12028 .00218 L
.11955 0 L
0 0 L
F
.1689 .09027 m
.15745 .08047 L
.146 .07005 L
.13455 .05904 L
.1231 .04784 L
.1231 .04784 L
.1337 .04351 L
.1337 .04351 L
.14433 .05458 L
.15495 .06542 L
.16558 .07559 L
.1762 .08541 L
.1762 .08541 L
.1689 .09027 L
F
.9481 .14108 m
.92785 .14303 L
.9076 .14407 L
.88735 .14468 L
.86709 .14523 L
.84684 .1456 L
.82659 .14587 L
.80634 .14594 L
.78609 .14614 L
.76584 .14623 L
.74559 .14622 L
.72534 .1462 L
.70508 .14642 L
.68483 .1465 L
.66458 .14649 L
.64433 .14649 L
.62408 .14649 L
.60383 .14647 L
.58358 .14671 L
.56333 .14676 L
.54307 .14676 L
.52282 .14676 L
.50257 .14676 L
.48232 .14676 L
.46207 .14676 L
.44182 .14676 L
.42157 .14676 L
.40132 .14676 L
.38106 .14676 L
.36081 .14676 L
.34056 .14676 L
.32031 .14676 L
.30006 .14676 L
.27981 .14676 L
.25956 .14676 L
.23931 .14676 L
.21905 .14677 L
.1988 .14703 L
.17855 .14702 L
.1583 .14703 L
.1583 .14703 L
.1689 .09027 L
.1689 .09027 L
.18885 .09027 L
.2088 .09027 L
.22875 .09027 L
.24871 .09027 L
.26866 .09027 L
.28861 .09027 L
.30856 .09027 L
.32851 .09027 L
.34846 .09027 L
.36841 .09027 L
.38836 .09027 L
.40832 .09027 L
.42827 .09027 L
.44822 .09027 L
.46817 .09027 L
.48812 .09027 L
.50807 .09027 L
.52802 .09027 L
.54797 .09027 L
.56793 .09029 L
.58788 .09017 L
.60783 .08998 L
.62778 .09 L
.64773 .09 L
.66768 .09 L
.68763 .09 L
.70758 .09 L
.72754 .09 L
.74749 .09 L
.76744 .09 L
.78739 .09001 L
.80734 .0899 L
.82729 .08971 L
.84724 .08974 L
.86719 .08965 L
.88715 .08936 L
.9071 .08911 L
.92705 .08875 L
.947 .08784 L
.947 .08784 L
.94698 .10115 L
.9472 .11446 L
.94776 .12777 L
.9481 .14108 L
F
.17834 0 m
.17792 .02135 L
.17744 .0427 L
.17687 .06405 L
.1762 .08541 L
.1762 .08541 L
.19646 .08541 L
.21672 .08541 L
.23697 .08541 L
.25723 .08541 L
.27749 .08541 L
.29775 .08541 L
.31801 .08541 L
.33826 .08541 L
.35852 .08541 L
.37878 .08541 L
.39904 .08541 L
.41929 .08514 L
.43955 .08513 L
.45981 .08514 L
.48007 .08514 L
.50033 .08514 L
.52058 .08514 L
.54084 .08514 L
.5611 .08514 L
.58136 .08514 L
.60162 .08514 L
.62187 .08514 L
.64213 .08514 L
.66239 .08514 L
.68265 .08514 L
.70291 .08514 L
.72316 .08514 L
.74342 .08514 L
.76368 .08509 L
.78394 .08485 L
.80419 .08486 L
.82445 .08487 L
.84471 .08481 L
.86497 .08459 L
.88523 .08454 L
.90548 .08427 L
.92574 .08391 L
.946 .08297 L
.946 .08297 L
.946 .06223 L
.94599 .04149 L
.94653 .02074 L
.9465 0 L
F
1 .15946 m
.9986 .17459 L
.9986 .17459 L
.98598 .16763 L
.97335 .15914 L
.96073 .14945 L
.9481 .14108 L
.9481 .14108 L
.96108 .13284 L
.97405 .12484 L
.98703 .11751 L
1 .11081 L
F
1 .07486 m
.98675 .07777 L
.9735 .08099 L
.96025 .08453 L
.947 .08784 L
.947 .08784 L
.946 .08297 L
.946 .08297 L
.9595 .07971 L
.973 .07655 L
.9865 .07345 L
1 .07054 L
F
.35 g
.0497 .75189 m
.07057 .76288 L
.09145 .77371 L
.11232 .7846 L
.13319 .79544 L
.15406 .80614 L
.17494 .81687 L
.19581 .82737 L
.21668 .8378 L
.23755 .84824 L
.25843 .85868 L
.2793 .86892 L
.2793 .86892 L
.27227 .84892 L
.26569 .82892 L
.25951 .80892 L
.25373 .78892 L
.24825 .76892 L
.24303 .74892 L
.23811 .72892 L
.23347 .70892 L
.22907 .68892 L
.22487 .66892 L
.22089 .64892 L
.21709 .62892 L
.2135 .60892 L
.2135 .60892 L
.1938 .60641 L
.1741 .60351 L
.1544 .60086 L
.1347 .5982 L
.115 .59555 L
.0953 .59286 L
.0756 .59 L
.0756 .59 L
.07348 .61024 L
.07111 .63047 L
.06845 .65071 L
.06549 .67095 L
.06216 .69118 L
.05845 .71142 L
.0543 .73166 L
.0497 .75189 L
F
.3765 .67784 m
.38678 .67856 L
.39705 .67969 L
.40733 .68052 L
.4176 .68162 L
.4176 .68162 L
.3927 .80108 L
.3927 .80108 L
.39014 .78054 L
.38749 .76 L
.38479 .73946 L
.38207 .71892 L
.37931 .69838 L
.3765 .67784 L
F
.4176 .68162 m
.43726 .68192 L
.45693 .68161 L
.47659 .68144 L
.49625 .68135 L
.51591 .68119 L
.53557 .6811 L
.55524 .68079 L
.5749 .68068 L
.59456 .68054 L
.61423 .68043 L
.63389 .68029 L
.65355 .67998 L
.67321 .67992 L
.69288 .67974 L
.71254 .67944 L
.7322 .67946 L
.7322 .67946 L
.71209 .6974 L
.69197 .71407 L
.67186 .72973 L
.65174 .74468 L
.63163 .75877 L
.61151 .77202 L
.5914 .78481 L
.57129 .79676 L
.55117 .80819 L
.53106 .81942 L
.51094 .82991 L
.49083 .83988 L
.47071 .84966 L
.4506 .85865 L
.4506 .85865 L
.44593 .83898 L
.44163 .81931 L
.43776 .79964 L
.43431 .77997 L
.43117 .7603 L
.42854 .74063 L
.42597 .72096 L
.42082 .70129 L
.4176 .68162 L
F
.7322 .67946 m
.71244 .67915 L
.69268 .67919 L
.67292 .6792 L
.65316 .6791 L
.63339 .6789 L
.61363 .67893 L
.59387 .67884 L
.57411 .67863 L
.55435 .67866 L
.53459 .67858 L
.51483 .67837 L
.49507 .67832 L
.47531 .67809 L
.45554 .67812 L
.43578 .67806 L
.41602 .67782 L
.39626 .67785 L
.3765 .67784 L
.3765 .67784 L
.3708 .66514 L
.36526 .65243 L
.35989 .63973 L
.3547 .62703 L
.3547 .62703 L
.37448 .62603 L
.39427 .6247 L
.41405 .62357 L
.43384 .6223 L
.45362 .62116 L
.47341 .6199 L
.49319 .61875 L
.51298 .6175 L
.53276 .61634 L
.55255 .61511 L
.57233 .61376 L
.59212 .61242 L
.6119 .61107 L
.63168 .60991 L
.65147 .6087 L
.67125 .60735 L
.69104 .60601 L
.71082 .60469 L
.73061 .60319 L
.75039 .60171 L
.77018 .60039 L
.78996 .59906 L
.80975 .59774 L
.82953 .59627 L
.84932 .59465 L
.8691 .59324 L
.8691 .59324 L
.84954 .61055 L
.82999 .62553 L
.81043 .63857 L
.79087 .65018 L
.77131 .66079 L
.75176 .6705 L
.7322 .67946 L
F
0 .58973 m
.0189 .58999 L
.0378 .59 L
.0567 .59 L
.0756 .59 L
.0756 .59 L
.07454 .56935 L
.07345 .5487 L
.07237 .52805 L
.07133 .50741 L
.0703 .48676 L
.0703 .48676 L
.05273 .48256 L
.03515 .47828 L
.01758 .474 L
0 .46973 L
F
.2135 .60892 m
.23367 .61223 L
.25384 .61531 L
.27401 .61833 L
.29419 .62095 L
.31436 .6232 L
.33453 .62517 L
.3547 .62703 L
.3547 .62703 L
.34908 .60706 L
.34385 .58709 L
.339 .56713 L
.33443 .54716 L
.33012 .5272 L
.32605 .50723 L
.3222 .48726 L
.31851 .4673 L
.31494 .44733 L
.31153 .42736 L
.30825 .4074 L
.30509 .38743 L
.30204 .36747 L
.29908 .3475 L
.2962 .32753 L
.2934 .30757 L
.2934 .30757 L
.28487 .32727 L
.27621 .34697 L
.26735 .36667 L
.25813 .38637 L
.24842 .40607 L
.23808 .42577 L
.22697 .44547 L
.21421 .46517 L
.2 .48486 L
.2 .48486 L
.20308 .50554 L
.20436 .52622 L
.20622 .54689 L
.20835 .56757 L
.21077 .58824 L
.2135 .60892 L
F
.9892 .58541 m
.96918 .58599 L
.94917 .58707 L
.92915 .58845 L
.90913 .59007 L
.88912 .59169 L
.8691 .59324 L
.8691 .59324 L
.88671 .57348 L
.90201 .55372 L
.91521 .53396 L
.92662 .5142 L
.93668 .49444 L
.94541 .47468 L
.95291 .45492 L
.95941 .43517 L
.9652 .41541 L
.9652 .41541 L
.9948 .41432 L
.9948 .41432 L
.9892 .58541 L
F
0 .38784 m
.01615 .37046 L
.0323 .35617 L
.04845 .34422 L
.0646 .33486 L
.0646 .33486 L
.06729 .35575 L
.07076 .37664 L
.07493 .39753 L
.07974 .41842 L
.0851 .43931 L
.09089 .46019 L
.0971 .48108 L
.0971 .48108 L
.07768 .47092 L
.05826 .46038 L
.03884 .44904 L
.01942 .43748 L
0 .42514 L
F
1 .41432 m
.9948 .41432 L
.9948 .41432 L
.99539 .39486 L
.99578 .37541 L
.99607 .35595 L
.99636 .33649 L
.99662 .31703 L
.99685 .29757 L
.99706 .27811 L
.99725 .25865 L
.99743 .23919 L
.9976 .21973 L
.9976 .21973 L
.9978 .20845 L
.998 .19716 L
.99837 .18588 L
.9986 .17459 L
.9986 .17459 L
1 .15946 L
F
0 .29432 m
.01095 .284 L
.0219 .27475 L
.03285 .26691 L
.0438 .25973 L
.0438 .25973 L
.04616 .23892 L
.04856 .21811 L
.05103 .1973 L
.05358 .17649 L
.0562 .15568 L
.0562 .15568 L
.04818 .13746 L
.04026 .11924 L
.03233 .10103 L
.02444 .08281 L
.0165 .06459 L
.0165 .06459 L
0 .06622 L
F
0 .05162 m
.0115 .05081 L
.0115 .05081 L
.00866 .0425 L
.00579 .03419 L
.00291 .02588 L
0 .01757 L
F
.1689 .09027 m
.1583 .14703 L
.1583 .14703 L
.15155 .12719 L
.14467 .10735 L
.13769 .08751 L
.13054 .06768 L
.1231 .04784 L
.1231 .04784 L
.13455 .05904 L
.146 .07005 L
.15745 .08047 L
.1689 .09027 L
F
.11955 0 m
.12028 .00218 L
.1337 .04351 L
.1337 .04351 L
.14433 .05458 L
.15495 .06542 L
.16558 .07559 L
.1762 .08541 L
.1762 .08541 L
.17687 .06405 L
.17744 .0427 L
.17792 .02135 L
.17834 0 L
F
1 .11081 m
.98703 .11751 L
.97405 .12484 L
.96108 .13284 L
.9481 .14108 L
.9481 .14108 L
.94776 .12777 L
.9472 .11446 L
.94698 .10115 L
.947 .08784 L
.947 .08784 L
.96025 .08453 L
.9735 .08099 L
.98675 .07777 L
1 .07486 L
F
1 .07054 m
.9865 .07345 L
.973 .07655 L
.9595 .07971 L
.946 .08297 L
.946 .08297 L
.946 .06223 L
.94599 .04149 L
.94653 .02074 L
.9465 0 L
1 0 L
F
.15 g
.22618 1 m
.23349 .98127 L
.24068 .96255 L
.24789 .94382 L
.25523 .9251 L
.26291 .90637 L
.27101 .88764 L
.2793 .86892 L
.2793 .86892 L
.25843 .85868 L
.23755 .84824 L
.21668 .8378 L
.19581 .82737 L
.17494 .81687 L
.15406 .80614 L
.13319 .79544 L
.11232 .7846 L
.09145 .77371 L
.07057 .76288 L
.0497 .75189 L
.0497 .75189 L
.0538 .77257 L
.05806 .79324 L
.06247 .81392 L
.06706 .83459 L
.07185 .85527 L
.07686 .87595 L
.08212 .89662 L
.08764 .9173 L
.09348 .93797 L
.09967 .95865 L
.1062 .97932 L
.11318 1 L
F
.55587 1 m
.55274 .99728 L
.53231 .97821 L
.51188 .95634 L
.49145 .93047 L
.47103 .89877 L
.4506 .85865 L
.4506 .85865 L
.47071 .84966 L
.49083 .83988 L
.51094 .82991 L
.53106 .81942 L
.55117 .80819 L
.57129 .79676 L
.5914 .78481 L
.61151 .77202 L
.63163 .75877 L
.65174 .74468 L
.67186 .72973 L
.69197 .71407 L
.71209 .6974 L
.7322 .67946 L
.7322 .67946 L
.75176 .6705 L
.77131 .66079 L
.79087 .65018 L
.81043 .63857 L
.82999 .62553 L
.84954 .61055 L
.8691 .59324 L
.8691 .59324 L
.88912 .59169 L
.90913 .59007 L
.92915 .58845 L
.94917 .58707 L
.96918 .58599 L
.9892 .58541 L
.9892 .58541 L
.98837 .60515 L
.98771 .62489 L
.98715 .64463 L
.98663 .66438 L
.98608 .68412 L
.98527 .70386 L
.98435 .7236 L
.98335 .74335 L
.98227 .76309 L
.98112 .78283 L
.97987 .80257 L
.97852 .82232 L
.97705 .84206 L
.97545 .8618 L
.97371 .88154 L
.97183 .90129 L
.96977 .92103 L
.96753 .94077 L
.96507 .96051 L
.96239 .98026 L
.95943 1 L
F
0 .64541 m
.00804 .6667 L
.01685 .688 L
.02661 .7093 L
.03738 .73059 L
.0497 .75189 L
.0497 .75189 L
.0543 .73166 L
.05845 .71142 L
.06216 .69118 L
.06549 .67095 L
.06845 .65071 L
.07111 .63047 L
.07348 .61024 L
.0756 .59 L
.0756 .59 L
.0567 .59 L
.0378 .59 L
.0189 .58999 L
0 .58973 L
F
.2793 .86892 m
.2982 .86132 L
.3171 .85276 L
.336 .84305 L
.3549 .83179 L
.3738 .81814 L
.3927 .80108 L
.3927 .80108 L
.39014 .78054 L
.38749 .76 L
.38479 .73946 L
.38207 .71892 L
.37931 .69838 L
.3765 .67784 L
.3765 .67784 L
.3708 .66514 L
.36526 .65243 L
.35989 .63973 L
.3547 .62703 L
.3547 .62703 L
.33453 .62517 L
.31436 .6232 L
.29419 .62095 L
.27401 .61833 L
.25384 .61531 L
.23367 .61223 L
.2135 .60892 L
.2135 .60892 L
.21709 .62892 L
.22089 .64892 L
.22487 .66892 L
.22907 .68892 L
.23347 .70892 L
.23811 .72892 L
.24303 .74892 L
.24825 .76892 L
.25373 .78892 L
.25951 .80892 L
.26569 .82892 L
.27227 .84892 L
.2793 .86892 L
F
.4506 .85865 m
.43613 .84666 L
.42165 .83325 L
.40718 .8182 L
.3927 .80108 L
.3927 .80108 L
.4176 .68162 L
.4176 .68162 L
.42082 .70129 L
.42597 .72096 L
.42854 .74063 L
.43117 .7603 L
.43431 .77997 L
.43776 .79964 L
.44163 .81931 L
.44593 .83898 L
.4506 .85865 L
F
1 .58541 m
.9892 .58541 L
.9892 .58541 L
.9948 .41432 L
.9948 .41432 L
1 .41432 L
F
0 g
0 .64541 m
.00804 .6667 L
.01685 .688 L
.02661 .7093 L
.03738 .73059 L
.0497 .75189 L
.0497 .75189 L
.0538 .77257 L
.05806 .79324 L
.06247 .81392 L
.06706 .83459 L
.07185 .85527 L
.07686 .87595 L
.08212 .89662 L
.08764 .9173 L
.09348 .93797 L
.09967 .95865 L
.1062 .97932 L
.11318 1 L
0 1 L
F
.22618 1 m
.23349 .98127 L
.24068 .96255 L
.24789 .94382 L
.25523 .9251 L
.26291 .90637 L
.27101 .88764 L
.2793 .86892 L
.2793 .86892 L
.2982 .86132 L
.3171 .85276 L
.336 .84305 L
.3549 .83179 L
.3738 .81814 L
.3927 .80108 L
.3927 .80108 L
.40718 .8182 L
.42165 .83325 L
.43613 .84666 L
.4506 .85865 L
.4506 .85865 L
.47103 .89877 L
.49145 .93047 L
.51188 .95634 L
.53231 .97821 L
.55274 .99728 L
.55587 1 L
F
.95943 1 m
.96239 .98026 L
.96507 .96051 L
.96753 .94077 L
.96977 .92103 L
.97183 .90129 L
.97371 .88154 L
.97545 .8618 L
.97705 .84206 L
.97852 .82232 L
.97987 .80257 L
.98112 .78283 L
.98227 .76309 L
.98335 .74335 L
.98435 .7236 L
.98527 .70386 L
.98608 .68412 L
.98663 .66438 L
.98715 .64463 L
.98771 .62489 L
.98837 .60515 L
.9892 .58541 L
.9892 .58541 L
1 .58541 L
1 1 L
F
.3 Mabswid
.1762 .08541 m
.19646 .08541 L
.21672 .08541 L
.23697 .08541 L
.25723 .08541 L
.27749 .08541 L
.29775 .08541 L
.31801 .08541 L
.33826 .08541 L
.35852 .08541 L
.37878 .08541 L
.39904 .08541 L
.41929 .08514 L
.43955 .08513 L
.45981 .08514 L
.48007 .08514 L
.50033 .08514 L
.52058 .08514 L
.54084 .08514 L
.5611 .08514 L
.58136 .08514 L
.60162 .08514 L
.62187 .08514 L
.64213 .08514 L
.66239 .08514 L
.68265 .08514 L
.70291 .08514 L
.72316 .08514 L
.74342 .08514 L
.76368 .08509 L
.78394 .08485 L
.80419 .08486 L
.82445 .08487 L
.84471 .08481 L
.86497 .08459 L
.88523 .08454 L
.90548 .08427 L
.92574 .08391 L
.946 .08297 L
s
.1689 .09027 m
.18885 .09027 L
.2088 .09027 L
.22875 .09027 L
.24871 .09027 L
.26866 .09027 L
.28861 .09027 L
.30856 .09027 L
.32851 .09027 L
.34846 .09027 L
.36841 .09027 L
.38836 .09027 L
.40832 .09027 L
.42827 .09027 L
.44822 .09027 L
.46817 .09027 L
.48812 .09027 L
.50807 .09027 L
.52802 .09027 L
.54797 .09027 L
.56793 .09029 L
.58788 .09017 L
.60783 .08998 L
.62778 .09 L
.64773 .09 L
.66768 .09 L
.68763 .09 L
.70758 .09 L
.72754 .09 L
.74749 .09 L
.76744 .09 L
.78739 .09001 L
.80734 .0899 L
.82729 .08971 L
.84724 .08974 L
.86719 .08965 L
.88715 .08936 L
.9071 .08911 L
.92705 .08875 L
.947 .08784 L
s
.0593 .29216 m
.07939 .29269 L
.09947 .29296 L
.11956 .2935 L
.13965 .29378 L
.15973 .29405 L
.17982 .29432 L
.19991 .29486 L
.21999 .29514 L
.24008 .29541 L
.26017 .29568 L
.28025 .29622 L
.30034 .29649 L
.32043 .29676 L
.34051 .29703 L
.3606 .2973 L
.38069 .29758 L
.40077 .29812 L
.42086 .29839 L
.44095 .29866 L
.46103 .29893 L
.48112 .2992 L
.50121 .29948 L
.52129 .29975 L
.54138 .30002 L
.56147 .30029 L
.58155 .30056 L
.60164 .30083 L
.62173 .3011 L
.64181 .30138 L
.6619 .30165 L
.68199 .30192 L
.70207 .30219 L
.72216 .30246 L
.74225 .30274 L
.76233 .30298 L
.78242 .303 L
.80251 .30328 L
.82259 .30355 L
.84268 .30382 L
.86277 .3041 L
.88285 .30433 L
.90294 .30435 L
.92303 .30464 L
.94311 .3049 L
.9632 .30514 L
s
.0438 .25973 m
.04778 .26784 L
.05168 .27595 L
.05551 .28405 L
.0593 .29216 L
s
.1925 .29784 m
.21281 .29834 L
.23313 .29837 L
.25344 .29855 L
.27375 .29883 L
.29406 .29911 L
.31438 .29938 L
.33469 .29966 L
.355 .29993 L
.37531 .30022 L
.39563 .30027 L
.41594 .30048 L
.43625 .30076 L
.45656 .30103 L
.47688 .30131 L
.49719 .30158 L
.5175 .30187 L
.53781 .30189 L
.55813 .30213 L
.57844 .30241 L
.59875 .30269 L
.61906 .30296 L
.63937 .30297 L
.65969 .30324 L
.68 .30351 L
s
.0593 .29216 m
.07833 .29315 L
.09736 .29419 L
.11639 .295 L
.13541 .29576 L
.15444 .29653 L
.17347 .29734 L
.1925 .29784 L
s
.0593 .29216 m
.06032 .30284 L
.06155 .31351 L
.06298 .32419 L
.0646 .33486 L
s
.0646 .33486 m
.08592 .32921 L
.10723 .32345 L
.12855 .31745 L
.14987 .31139 L
.17118 .30475 L
.1925 .29784 L
s
.1925 .29784 m
.21268 .30003 L
.23286 .30192 L
.25304 .30405 L
.27322 .30575 L
.2934 .30757 L
s
.0438 .25973 m
.06379 .2601 L
.08377 .2606 L
.10376 .26091 L
.12375 .26141 L
.14373 .26172 L
.16372 .26222 L
.18371 .26253 L
.2037 .26303 L
.22368 .26334 L
.24367 .26384 L
.26366 .26415 L
.28364 .26465 L
.30363 .26496 L
.32362 .26547 L
.3436 .26572 L
.36359 .26604 L
.38358 .26654 L
.40357 .26685 L
.42355 .26735 L
.44354 .26766 L
.46353 .26816 L
.48351 .26847 L
.5035 .26897 L
.52349 .26928 L
.54347 .26978 L
.56346 .27009 L
.58345 .27059 L
.60343 .2709 L
.62342 .2714 L
.64341 .27171 L
.6634 .27221 L
.68338 .27251 L
.70337 .27306 L
.72336 .2736 L
.74334 .27414 L
.76333 .27468 L
.78332 .27522 L
.8033 .2758 L
.82329 .27661 L
.84328 .27746 L
.86327 .27858 L
.88325 .27995 L
.90324 .28169 L
.92323 .28454 L
.94321 .2903 L
.9632 .30514 L
s
.0562 .15568 m
.05358 .17649 L
.05103 .1973 L
.04856 .21811 L
.04616 .23892 L
.0438 .25973 L
s
0 .29432 m
.01095 .284 L
.0219 .27475 L
.03285 .26691 L
.0438 .25973 L
s
.0562 .15568 m
.07625 .15608 L
.0963 .15688 L
.11635 .15748 L
.1364 .15801 L
.15646 .15855 L
.17651 .15909 L
.19656 .15964 L
.21661 .16018 L
.23666 .16072 L
.25671 .16126 L
.27676 .16179 L
.29681 .16258 L
.31686 .16317 L
.33691 .1637 L
.35697 .16424 L
.37702 .16478 L
.39707 .16533 L
.41712 .16587 L
.43717 .1664 L
.45722 .16719 L
.47727 .16777 L
.49732 .16831 L
.51737 .16885 L
.53743 .16939 L
.55748 .16993 L
.57753 .17047 L
.59758 .17102 L
.61763 .17156 L
.63768 .17211 L
.65773 .1724 L
.67778 .17291 L
.69783 .17345 L
.71789 .174 L
.73794 .17454 L
.75799 .17509 L
.77804 .17538 L
.79809 .17589 L
.81814 .17644 L
.83819 .17673 L
.85824 .17725 L
.87829 .1778 L
.89834 .17808 L
.9184 .17861 L
.93845 .1789 L
.9585 .17943 L
.97855 .17959 L
.9986 .17459 L
s
.1583 .14703 m
.17855 .14702 L
.1988 .14703 L
.21905 .14677 L
.23931 .14676 L
.25956 .14676 L
.27981 .14676 L
.30006 .14676 L
.32031 .14676 L
.34056 .14676 L
.36081 .14676 L
.38106 .14676 L
.40132 .14676 L
.42157 .14676 L
.44182 .14676 L
.46207 .14676 L
.48232 .14676 L
.50257 .14676 L
.52282 .14676 L
.54307 .14676 L
.56333 .14676 L
.58358 .14671 L
.60383 .14647 L
.62408 .14649 L
.64433 .14649 L
.66458 .14649 L
.68483 .1465 L
.70508 .14642 L
.72534 .1462 L
.74559 .14622 L
.76584 .14623 L
.78609 .14614 L
.80634 .14594 L
.82659 .14587 L
.84684 .1456 L
.86709 .14523 L
.88735 .14468 L
.9076 .14407 L
.92785 .14303 L
.9481 .14108 L
s
.0562 .15568 m
.07662 .1538 L
.09704 .15185 L
.11746 .15021 L
.13788 .14855 L
.1583 .14703 L
s
.0165 .06459 m
.02444 .08281 L
.03233 .10103 L
.04026 .11924 L
.04818 .13746 L
.0562 .15568 L
s
.1231 .04784 m
.13054 .06768 L
.13769 .08751 L
.14467 .10735 L
.15155 .12719 L
.1583 .14703 L
s
.1583 .14703 m
.1689 .09027 L
s
.1231 .04784 m
.13455 .05904 L
.146 .07005 L
.15745 .08047 L
.1689 .09027 L
s
.1337 .04351 m
.14433 .05458 L
.15495 .06542 L
.16558 .07559 L
.1762 .08541 L
s
.17834 0 m
.17792 .02135 L
.17744 .0427 L
.17687 .06405 L
.1762 .08541 L
s
.1689 .09027 m
.1762 .08541 L
s
.0165 .06459 m
.03782 .06067 L
.05914 .05717 L
.08046 .05371 L
.10178 .05057 L
.1231 .04784 L
s
.0115 .05081 m
.03187 .04935 L
.05223 .0482 L
.0726 .04689 L
.09297 .0458 L
.11333 .04439 L
.1337 .04351 L
s
.11955 0 m
.12028 .00218 L
.1337 .04351 L
s
.1231 .04784 m
.1337 .04351 L
s
0 .06622 m
.0165 .06459 L
s
0 .05162 m
.0115 .05081 L
s
0 .01757 m
.00291 .02588 L
.00579 .03419 L
.00866 .0425 L
.0115 .05081 L
s
.0165 .06459 m
.0115 .05081 L
s
.9986 .17459 m
.99837 .18588 L
.998 .19716 L
.9978 .20845 L
.9976 .21973 L
s
.947 .08784 m
.94698 .10115 L
.9472 .11446 L
.94776 .12777 L
.9481 .14108 L
s
.9465 0 m
.94653 .02074 L
.94599 .04149 L
.946 .06223 L
.946 .08297 L
s
.946 .08297 m
.9595 .07971 L
.973 .07655 L
.9865 .07345 L
s
1 .07054 m
.9865 .07345 L
s
s
.947 .08784 m
.96025 .08453 L
.9735 .08099 L
.98675 .07777 L
1 .07486 L
s
.946 .08297 m
.947 .08784 L
s
.9481 .14108 m
.96108 .13284 L
.97405 .12484 L
.98703 .11751 L
1 .11081 L
s
.9481 .14108 m
.96073 .14945 L
.97335 .15914 L
.98598 .16763 L
.9986 .17459 L
s
1 .15946 m
.9986 .17459 L
s
.6987 .30378 m
.71897 .30377 L
.73924 .30405 L
.75951 .30406 L
.77979 .30405 L
.80006 .30432 L
.82033 .30433 L
.8406 .3046 L
.86087 .3046 L
.88114 .30487 L
.90141 .30488 L
.92169 .30514 L
.94196 .30513 L
.96223 .30514 L
.9825 .30541 L
s
.9976 .21973 m
.99661 .24108 L
.99389 .26243 L
.98682 .28378 L
.9632 .30514 L
s
.9632 .30514 m
.9825 .30541 L
s
.9976 .21973 m
.9968 .24115 L
.99456 .26257 L
.9903 .28399 L
.9825 .30541 L
s
.9825 .30541 m
.98056 .32374 L
.97821 .34207 L
.97547 .36041 L
.97241 .37874 L
.96901 .39707 L
.9652 .41541 L
s
.9976 .21973 m
.99743 .23919 L
.99725 .25865 L
.99706 .27811 L
.99685 .29757 L
.99662 .31703 L
.99636 .33649 L
.99607 .35595 L
.99578 .37541 L
.99539 .39486 L
.9948 .41432 L
s
.2934 .30757 m
.31366 .30764 L
.33393 .30737 L
.35419 .3073 L
.37446 .3071 L
.39472 .30703 L
.41499 .30682 L
.43525 .30676 L
.45552 .30654 L
.47578 .30649 L
.49605 .30628 L
.51631 .30598 L
.53658 .30595 L
.55684 .30573 L
.57711 .30544 L
.59737 .30517 L
.61764 .3049 L
.6379 .30462 L
.65817 .30435 L
.67843 .30408 L
.6987 .30378 L
s
.6987 .30378 m
.7192 .31577 L
.7397 .32687 L
.7602 .3374 L
.7807 .34708 L
.8012 .3562 L
.8217 .36503 L
.8422 .37328 L
.8627 .38103 L
.8832 .38872 L
.9037 .39586 L
.9242 .40274 L
.9447 .40931 L
.9652 .41541 L
s
0 .38784 m
.01615 .37046 L
.0323 .35617 L
.04845 .34422 L
.0646 .33486 L
s
.0646 .33486 m
.06729 .35575 L
.07076 .37664 L
.07493 .39753 L
.07974 .41842 L
.0851 .43931 L
.09089 .46019 L
.0971 .48108 L
s
.2934 .30757 m
.28487 .32727 L
.27621 .34697 L
.26735 .36667 L
.25813 .38637 L
.24842 .40607 L
.23808 .42577 L
.22697 .44547 L
.21421 .46517 L
.2 .48486 L
s
.2934 .30757 m
.2962 .32753 L
.29908 .3475 L
.30204 .36747 L
.30509 .38743 L
.30825 .4074 L
.31153 .42736 L
.31494 .44733 L
.31851 .4673 L
.3222 .48726 L
.32605 .50723 L
.33012 .5272 L
.33443 .54716 L
.339 .56713 L
.34385 .58709 L
.34908 .60706 L
.3547 .62703 L
s
.0971 .48108 m
.11768 .48182 L
.13826 .48266 L
.15884 .48345 L
.17942 .4843 L
.2 .48486 L
s
0 .42514 m
.01942 .43748 L
.03884 .44904 L
.05826 .46038 L
.07768 .47092 L
.0971 .48108 L
s
.0703 .48676 m
.09192 .48658 L
.11353 .48631 L
.13515 .48601 L
.15677 .48573 L
.17838 .48518 L
.2 .48486 L
s
0 .46973 m
.01758 .474 L
.03515 .47828 L
.05273 .48256 L
.0703 .48676 L
s
.0703 .48676 m
.07133 .50741 L
.07237 .52805 L
.07345 .5487 L
.07454 .56935 L
.0756 .59 L
s
.0703 .48676 m
.0971 .48108 L
s
.2 .48486 m
.20308 .50554 L
.20436 .52622 L
.20622 .54689 L
.20835 .56757 L
.21077 .58824 L
.2135 .60892 L
s
.2135 .60892 m
.23367 .61223 L
.25384 .61531 L
.27401 .61833 L
.29419 .62095 L
.31436 .6232 L
.33453 .62517 L
.3547 .62703 L
s
.3547 .62703 m
.37448 .62603 L
.39427 .6247 L
.41405 .62357 L
.43384 .6223 L
.45362 .62116 L
.47341 .6199 L
.49319 .61875 L
.51298 .6175 L
.53276 .61634 L
.55255 .61511 L
.57233 .61376 L
.59212 .61242 L
.6119 .61107 L
.63168 .60991 L
.65147 .6087 L
.67125 .60735 L
.69104 .60601 L
.71082 .60469 L
.73061 .60319 L
.75039 .60171 L
.77018 .60039 L
.78996 .59906 L
.80975 .59774 L
.82953 .59627 L
.84932 .59465 L
.8691 .59324 L
s
.3765 .67784 m
.39626 .67785 L
.41602 .67782 L
.43578 .67806 L
.45554 .67812 L
.47531 .67809 L
.49507 .67832 L
.51483 .67837 L
.53459 .67858 L
.55435 .67866 L
.57411 .67863 L
.59387 .67884 L
.61363 .67893 L
.63339 .6789 L
.65316 .6791 L
.67292 .6792 L
.69268 .67919 L
.71244 .67915 L
.7322 .67946 L
s
.3547 .62703 m
.35989 .63973 L
.36526 .65243 L
.3708 .66514 L
.3765 .67784 L
s
.0756 .59 m
.0953 .59286 L
.115 .59555 L
.1347 .5982 L
.1544 .60086 L
.1741 .60351 L
.1938 .60641 L
.2135 .60892 L
s
0 .58973 m
.0189 .58999 L
.0378 .59 L
.0567 .59 L
.0756 .59 L
s
.0756 .59 m
.07348 .61024 L
.07111 .63047 L
.06845 .65071 L
.06549 .67095 L
.06216 .69118 L
.05845 .71142 L
.0543 .73166 L
.0497 .75189 L
s
.2135 .60892 m
.21709 .62892 L
.22089 .64892 L
.22487 .66892 L
.22907 .68892 L
.23347 .70892 L
.23811 .72892 L
.24303 .74892 L
.24825 .76892 L
.25373 .78892 L
.25951 .80892 L
.26569 .82892 L
.27227 .84892 L
.2793 .86892 L
s
.3765 .67784 m
.38678 .67856 L
.39705 .67969 L
.40733 .68052 L
.4176 .68162 L
s
.4176 .68162 m
.43726 .68192 L
.45693 .68161 L
.47659 .68144 L
.49625 .68135 L
.51591 .68119 L
.53557 .6811 L
.55524 .68079 L
.5749 .68068 L
.59456 .68054 L
.61423 .68043 L
.63389 .68029 L
.65355 .67998 L
.67321 .67992 L
.69288 .67974 L
.71254 .67944 L
.7322 .67946 L
s
.9652 .41541 m
.95941 .43517 L
.95291 .45492 L
.94541 .47468 L
.93668 .49444 L
.92662 .5142 L
.91521 .53396 L
.90201 .55372 L
.88671 .57348 L
.8691 .59324 L
s
.9652 .41541 m
.9948 .41432 L
s
.8691 .59324 m
.88912 .59169 L
.90913 .59007 L
.92915 .58845 L
.94917 .58707 L
.96918 .58599 L
.9892 .58541 L
s
.7322 .67946 m
.75176 .6705 L
.77131 .66079 L
.79087 .65018 L
.81043 .63857 L
.82999 .62553 L
.84954 .61055 L
.8691 .59324 L
s
.9948 .41432 m
.9892 .58541 L
s
.4506 .85865 m
.47071 .84966 L
.49083 .83988 L
.51094 .82991 L
.53106 .81942 L
.55117 .80819 L
.57129 .79676 L
.5914 .78481 L
.61151 .77202 L
.63163 .75877 L
.65174 .74468 L
.67186 .72973 L
.69197 .71407 L
.71209 .6974 L
.7322 .67946 L
s
.9892 .58541 m
.98837 .60515 L
.98771 .62489 L
.98715 .64463 L
.98663 .66438 L
.98608 .68412 L
.98527 .70386 L
.98435 .7236 L
.98335 .74335 L
.98227 .76309 L
.98112 .78283 L
.97987 .80257 L
.97852 .82232 L
.97705 .84206 L
.97545 .8618 L
.97371 .88154 L
.97183 .90129 L
.96977 .92103 L
.96753 .94077 L
.96507 .96051 L
.96239 .98026 L
.95943 1 L
s
.9948 .41432 m
1 .41432 L
s
1 .58541 m
.9892 .58541 L
s
.3927 .80108 m
.4176 .68162 L
s
.4176 .68162 m
.42082 .70129 L
.42597 .72096 L
.42854 .74063 L
.43117 .7603 L
.43431 .77997 L
.43776 .79964 L
.44163 .81931 L
.44593 .83898 L
.4506 .85865 L
s
.3765 .67784 m
.37931 .69838 L
.38207 .71892 L
.38479 .73946 L
.38749 .76 L
.39014 .78054 L
.3927 .80108 L
s
.2793 .86892 m
.2982 .86132 L
.3171 .85276 L
.336 .84305 L
.3549 .83179 L
.3738 .81814 L
.3927 .80108 L
s
.3927 .80108 m
.40718 .8182 L
.42165 .83325 L
.43613 .84666 L
.4506 .85865 L
s
.4506 .85865 m
.47103 .89877 L
.49145 .93047 L
.51188 .95634 L
.53231 .97821 L
.55274 .99728 L
.55587 1 L
s
.0497 .75189 m
.07057 .76288 L
.09145 .77371 L
.11232 .7846 L
.13319 .79544 L
.15406 .80614 L
.17494 .81687 L
.19581 .82737 L
.21668 .8378 L
.23755 .84824 L
.25843 .85868 L
.2793 .86892 L
s
.2793 .86892 m
.27101 .88764 L
.26291 .90637 L
.25523 .9251 L
.24789 .94382 L
.24068 .96255 L
.23349 .98127 L
s
.22618 1 m
.23349 .98127 L
s
s
0 .64541 m
.00804 .6667 L
.01685 .688 L
.02661 .7093 L
.03738 .73059 L
.0497 .75189 L
s
.0497 .75189 m
.0538 .77257 L
.05806 .79324 L
.06247 .81392 L
.06706 .83459 L
.07185 .85527 L
.07686 .87595 L
.08212 .89662 L
.08764 .9173 L
.09348 .93797 L
.09967 .95865 L
.1062 .97932 L
.11318 1 L
s
0 1 0 r
1 0 0 r
0 0 1 r
p
0 g
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{453, 453},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000750001aA000`40O003h00OogooaWoo003oOoo6
Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00
JWoo0P0017oo00@007ooOomoo`D004Eoo`8000Aoo`03001oogoo00=oo`<004Eoo`8000Aoo`03001o
ogoo009oo`<004Ioo`8000Aoo`03001oogoo009oo`<004Yoo`<000Aoo`00JGoo00@007ooOol000Qo
o`04001oogoo0014Ool01000Oomoo`002Woo00<007ooOol0@goo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`001goo00D007ooOomoo`0004Yoo`03001oogoo00=oo`00JGoo00@007oo
Ool000Uoo`03001oogoo04Aoo`04001oogoo0007Ool50014Ool01000Oomoo`001goo00D007ooOomo
o`0004Aoo`04001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomo
o`002Woo00<007ooOol0@goo00@007ooOol000Moo`04001oogoo0015Ool01000Oomoo`001goo1000
AGoo00@007ooOol000Qoo`<004]oo`03001oogoo00=oo`00JGoo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`0027oo00<007oo0000AGoo00@007ooOol000Moo`03001oogoo04Ioo`04
001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomoo`001goo00D0
07ooOomoo`0004Aoo`04001oogoo0009Ool20015Ool01000Oomoo`0027oo00<007ooOol0AGoo00@0
07ooOol000Moo`05001oogooOol00019Ool20005Ool006Yoo`8000Uoo`<004Ioo`8000]oo`03001o
ogoo04Aoo`8000Yoo`8004Ioo`8000Uoo`<004]oo`03001oogoo00=oo`00ogooaWoo003oOoo6Ool0
0?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`007Gooo`00Y@0017oo000MOol00`00DYABU00_
DY@00`00;F/]J`0F;F/00`00DYABU03oDYA0DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03
001BU5:D02mBU003000]Jbe[01H]J`03001BU5:D0?mBU41BU003000]Jbe[01<]J`03001oogoo009o
o`007Goo00<005:DDY@0<5:D00<002e[;F/05Be[00<005:DDY@0oe:D@5:D00<002e[;F/04be[00<0
07ooOol00Woo000MOol00`00DYABU00`DY@00`00;F/]J`0E;F/00`00DYABU03oDYA0DY@00`00;F/]
J`0C;F/00`00Oomoo`02Ool001eoo`03001BU5:D031BU003000]Jbe[01@]J`03001BU5:D0?mBU45B
U003000]Jbe[01<]J`03001oogoo009oo`007Goo00<005:DDY@0<E:D00<002e[;F/04be[00<005:D
DY@0oe:D@E:D00<002e[;F/04be[00<007ooOol00Woo000MOol00`00DYABU00aDY@00`00;F/]J`0C
;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03001BU5:D035BU003
000]Jbe[01<]J`03001BU5:D0?mBU45BU003000]Jbe[01<]J`03001oogoo009oo`007Goo00<005:D
DY@0<U:D00<002e[;F/04Re[00<005:DDY@0oe:D@E:D00<002e[;F/04be[00<007ooOol00Woo000M
Ool2000cDY@00`00;F/]J`0B;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool0
01eoo`8003=BU003000]Jbe[018]J`03001BU5:D0?mBU45BU003000]Jbe[01<]J`03001oogoo009o
o`007Goo0P00=5:D00<002e[;F/04Be[00<005:DDY@0oe:D@E:D00<002e[;F/04be[00<007ooOol0
0Woo000MOol00`00;F/0000cDY@00`00;F/]J`0A;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/0
0`00Oomoo`02Ool001eoo`03000]J`0003=BU003000]Jbe[014]J`03001BU5:D0?mBU45BU003000]
Jbe[01<]J`03001oogoo009oo`007Goo00<002e[0000=5:D00<002e[;F/042e[00<005:DDY@0oe:D
@E:D00<002e[;F/04be[00<007ooOol00Woo000MOol00`00;F/0000dDY@00`00;F/]J`0@;F/00`00
DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`04000]Jbe[000cDY@00`00;F/]
J`0@;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`04000]Jbe[000`
DY@5000A;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`04000]Jbe[
000ODY@D00000e:D000]J`0@;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool0
00Moo`<000=oo`<000Aoo`8000Moo`05000]Jbe[;F/0000=DY@A000<Kg/50005DY@00`00;F/]J`0>
;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool000Ioo`07001oogooOol007oo
00000goo00@007ooOol0009oo`03001oogoo00Aoo`03000]Jbe[00l001I_N`L000ABU08000EBU003
000]Jbe[00d]J`03001BU5:D0?mBU45BU003000]Jbe[01<]J`03001oogoo009oo`001Woo00D007oo
Oomoo`0000Eoo`04001oogoo0002Ool00`00Oomoo`04Ool30002DY@00`00Kg]_N`0LKg/4000<DY@2
0005DY@00`00;F/]J`0<;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool000Io
o`@000Ioo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU003DY@00`00Kg]_N`0EKg/6000@
DY@00`00;F/00005DY@00`00;F/]J`0;;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C;F/00`00Oomo
o`02Ool000Ioo`03001oogoo00=oo`@000=oo`04001oogoo0006Ool00`00DYABU003DY@00`00Kg]_
N`0>Kg/7000GDY@00`00;F/00005DY@00`00;F/]J`0:;F/00`00DYABU03oDYA1DY@00`00;F/]J`0C
;F/00`00Oomoo`02Ool000Moo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0006Ool00`00
DYABU003DY@00`00Kg]_N`09Kg/5000NDY@01000;F/]J`001E:D00<002e[;F/02Be[00<005:DDY@0
oe:D@E:D00<002e[;F/04be[00<007ooOol00Woo0008Ool20002Ool50003Ool20007Ool00`00DYAB
U004DY@00`00Kg]_N`02Kg/6000SDY@01@00;F/]Jbe[00001E:D00<002e[;F/022e[00<005:DDY@0
oe:D@E:D00<002e[;F/04be[00<007ooOol00Woo000MOol01000DYABU5:D2000:U:D00D002e[;F/]
J`0000EBU003000]Jbe[00L]J`03001BU5:D0?mBU45BU003000]Jbe[01<]J`03001oogoo009oo`00
7Goo10000be[00<005:DDY@0;5:D00<002e[;F/00Re[00<005:DDY@00e:D00<002e[;F/01Re[00<0
05:DDY@0oe:D@E:D00<002e[;F/04be[00<007ooOol00Woo000MOol00`00;F/]J`05;F/00`00DYAB
U00/DY@00`00;F/]J`02;F/00`00DYABU003DY@00`00;F/]J`05;F/00`00DYABU03oDYA1DY@00`00
;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00D]J`03001BU5:D02aBU003000]Jbe[00<]
J`8000ABU003000]Jbe[00@]J`03001BU5:D0?mBU45BU003000]Jbe[014]J`<000Aoo`007Goo00<0
02e[;F/01Be[00<005:DDY@0;E:D00<002e[;F/012e[00<005:DDY@00U:D00<002e[;F/00be[00<0
05:DDY@0oe:D@E:D00<002e[;F/02be[1P000U:D00<007ooOol00Woo000MOol00`00;F/]J`06;F/0
0`00DYABU00/DY@00`00;F/]J`05;F/00`00DYABU002DY@20003;F/00`00DYABU03oDYA1DY@00`00
;F/]J`07;F/40006DY@30004Ool001eoo`03000]Jbe[00H]J`03001BU5:D02aBU003000]Jbe[00H]
J`03001BU5:D00=BU004000]Jbe[003oDYA3DY@00`00;F/]J`04;F/30004DY@60002;F/00`00Oomo
o`02Ool001eoo`03000]Jbe[00H]J`03001BU5:D02eBU003000]Jbe[00H]J`8000ABU003000]J`00
0?mBU4=BU003000]Jbe[00@000=BU0@000P]J`03001oogoo009oo`007Goo00<002e[;F/01be[00<0
05:DDY@0;5:D00<002e[;F/022e[00<005:DDY@00U:D0P00oe:D;U:D600015:D0`0032e[00<007oo
Ool00Woo000MOol00`00;F/]J`07;F/00`00DYABU00/DY@00`00;F/]J`09;F/01000DYABU5:Do`00
<0005Fmk00<005:DDY@010003be[00<007ooOol00Woo000MOol00`00;F/]J`08;F/00`00DYABU00/
DY@00`00;F/]J`09;F/00`00DY@0003oKg/iKg/?000C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[
00P]J`03001BU5:D02aBU003000]Jbe[00X]Jol003/000aBU003000]Jbe[01<]J`03001oogoo009o
o`007Goo00<002e[;F/022e[00<005:DDY@0;5:D00<002e[;F/02Re[00<005:DDY@0oe:DA5:D00<0
02e[;F/04be[00<007ooOol00Woo000MOol00`00;F/]J`09;F/00`00DYABU00/DY@00`00;F/]J`09
;F/00`00DYABU03oDYA4DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00T]J`03
001BU5:D02aBU003000]Jbe[00P]J`03001BU5:D0?mBU4EBU003000]Jbe[01<]J`03001oogoo009o
o`007Goo00<002e[;F/02Be[00<005:DDY@0;5:D00<002e[;F/022e[00<005:DDY@0oe:DAE:D00<0
02e[;F/04be[00<007ooOol00Woo000MOol00`00;F/]J`0:;F/00`00DYABU00[DY@00`00;F/]J`08
;F/00`00DYABU03oDYA5DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00X]J`03
001BU5:D02aBU003000]Jbe[00L]J`03001BU5:D0?mBU4EBU003000]Jbe[01<]J`03001oogoo009o
o`007Goo00<002e[;F/02be[00<005:DDY@0:e:D00<002e[;F/01be[00<005:DDY@0oe:DAE:D00<0
02e[;F/04be[00<007ooOol00Woo000MOol00`00;F/]J`0;;F/00`00DYABU00[DY@00`00;F/]J`06
;F/00`00DYABU03oDYA6DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03000]Jbe[00`]J`03
001BU5:D02]BU003000]Jbe[00D]J`03001BU5:D0?mBU4IBU003000]Jbe[018]J`8000Aoo`007Goo
00<002e[;F/03Be[00<005:DDY@0:U:D00<002e[;F/01Be[00<005:DDY@0oe:DAU:D00<002e[;F/0
3be[0`0000=BU000Ool00goo000MOol00`00;F/]J`0=;F/00`00DYABU00ZDY@00`00;F/]J`05;F/0
0`00DYABU03oDYA6DY@00`00;F/]J`0=;F/20004DY@00`00Oomoo`02Ool001eoo`03000]Jbe[00h]
J`03001BU5:D02YBU003000]Jbe[00@]J`03001BU5:D0?mBU4IBU003000]Jbe[00`]J`03001BU5:D
00ABU003001oogoo009oo`007Goo00<002e[;F/03Re[00<005:DDY@0:U:D00<002e[;F/00be[00<0
05:DDY@0oe:DAe:D00<002e[;F/02be[00<005:DDY@01E:D00<007ooOol00Woo000MOol00`00;F/]
J`0?;F/00`00DYABU00YDY@00`00;F/]J`03;F/00`00DYABU03oDYA8DY@00`00;F/]J`09;F/00`00
DYABU006DY@00`00Oomoo`02Ool001eoo`03000]Jbe[00l]J`03001BU5:D02YBU003000]Jbe[008]
J`03001BU5:D0?mBU4QBU003000]Jbe[00L]J`8000UBU003001oogoo009oo`007Goo00<002e[;F/0
3be[00<005:DDY@0:U:D00<002e[;F/00Re[00<005:DDY@0oe:DB5:D00<002e[;F/01Be[0P002e:D
00<007ooOol00Woo000MOol00`00;F/]J`0@;F/00`00DYABU00YDY@00`00;F/]J`02;F/00`00DYAB
U03oDYA8DY@00`00;F/]J`03;F/2000=DY@00`00Oomoo`02Ool001eoo`03000]Jbe[010]J`03001B
U5:D02YBU004000]Jbe[003oDYA;DY@01000;F/]Jbe[0P003e:D00<007ooOol00Woo000MOol00`00
;F/]J`0@;F/00`00DYABU00ZDY@01000;F/]J`00oe:DBe:D00@002e[0000015BU003001oogoo009o
o`007Goo00<002e[;F/04Be[00<005:DDY@0:E:D00@002e[;F/00?mBU4]BU08001=BU003001oogoo
009oo`007Goo00<002e[;F/04Be[00<005:DDY@0:U:D00<002e[0000oe:DAe:D1P004e:D00<007oo
Ool00Woo000MOol00`00;F/]J`0B;F/00`00DYABU00YDY@00`00;F/0003oDY@nDY@90006Kg/00`00
DYABU00@DY@00`00Oomoo`02Ool001eoo`03000]Jbe[018]J`03001BU5:D02UBU0800>UBU18000QB
U3/0011_N`03001BU5:D00mBU003001oogoo009oo`007Goo00<002e[;F/04be[00<005:DDY@07E:D
mP004Vmk2000C6mk00<005:DDY@03U:D00<007ooOol00Woo000MOol00`00;F/]J`0C;F/00`00DYAB
U00DDY@9003oKg]NKg/2000>DY@00`00Oomoo`02Ool001eoo`03000]Jbe[01<]J`03001BU5:D00]B
U0T00?m_NfU_N`03001BU5:D00]BU003001oogoo009oo`007Goo00<002e[;F/052e[3@00ofmkLfmk
00<005:DDY@02U:D00<007ooOol00Woo000MOol00`00;F/]J`0D;F/00`00DYABU003DY@Q003oKg]J
Kg/00`00DYABU009DY@00`00Oomoo`02Ool001eoo`03000]Jbe[01@]J`03001BU5:D02ABU2800?m_
NcU_N`8000UBU003001oogoo009oo`007Goo00<002e[;F/052e[00<005:DDY@0AU:D8P00ofmk6Fmk
0P001e:D00<007ooOol00Woo000MOol00`00;F/]J`0D;F/00`00DYABU01XDY@Q003iKg/20005DY@0
0`00Oomoo`02Ool001eoo`03000]Jbe[01<]J`03001BU5:D08YBU2800=U_N`8000=BU003001oogoo
009oo`007Goo00<002e[;F/04be[00<005:DDY@0[5:D:P00/Fmk0P0000=BU000Ool00goo000MOol0
0`00;F/]J`0C;F/00`00DYABU03FDY@Z0029Kg/20004Ool001eoo`03000]Jbe[01<]J`03001BU5:D
0?mBU05BU28006M_N`8000Aoo`007Goo00<002e[;F/04be[00<005:DDY@0oe:D8e:D:P00>Vmk0`00
00=BU000Ool00goo000MOol00`00;F/]J`0C;F/00`00DYABU03oDYA=DY@b0005Kg/30004DY@00`00
Oomoo`02Ool001eoo`03000]Jbe[01<]J`03001BU5:D0?mBU7mBU0D000MBU003001oogoo009oo`00
27oo00<007ooOol00goo0P0017oo0P001goo00<002e[;F/04be[00<005:DDY@0oe:DRe:D00<007oo
Ool00Woo0008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Ioo`03000]Jbe[01<]
J`03001BU5:D0?mBU8]BU003001oogoo009oo`002Goo00D007ooOomoo`00009oo`04001oogoo0002
Ool00`00Oomoo`04Ool00`00;F/]J`0B;F/00`00DYABU03oDYB<DY@00`00Oomoo`02Ool000Uoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol017oo00<002e[;F/04Re[00<005:DDY@0
oe:DS5:D00<007ooOol00Woo000:Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00Ao
o`03000]Jbe[018]J`03001BU5:D0?mBU8aBU003001oogoo009oo`001Woo00D007ooOomoo`00009o
o`04001oogoo0002Ool01000Oomoo`001Woo00<002e[;F/04Re[00<005:DDY@0oe:DS5:D00<007oo
Ool00Woo0006Ool50003Ool20004Ool20007Ool00`00;F/]J`0B;F/00`00DYABU03oDYB<DY@00`00
Oomoo`02Ool001eoo`03000]Jbe[018]J`03001BU5:D0?mBU8aBU003001oogoo009oo`007Goo00<0
02e[;F/04Re[00<005:DDY@0oe:DS5:D00<007ooOol00Woo000MOol00`00;F/]J`0B;F/00`00DYAB
U03oDYB<DY@00`00Oomoo`02Ool001eoo`03000]Jbe[018]J`03001BU5:D0?mBU8aBU003001oogoo
009oo`007Goo00<002e[;F/04Be[00<005:DDY@0oe:DSE:D00<007ooOol00Woo000MOol00`00;F/]
J`0A;F/00`00DYABU03oDYB=DY@00`00Oomoo`02Ool001eoo`03000]Jbe[014]J`03001BU5:D0?mB
U8eBU003001oogoo009oo`007Goo00<002e[;F/04Be[00<005:DDY@0oe:DS5:D0P0017oo000MOol0
0`00;F/]J`0A;F/00`00DYABU03oDYB<DY@20004Ool001eoo`03000]Jbe[014]J`03001BU5:D0?mB
U8aBU08000Aoo`007Goo00<002e[;F/04Be[00<005:DDY@0oe:DS5:D0P0017oo000MOol00`00;F/]
J`0A;F/00`00DYABU03oDYB<DY@20004Ool001eoo`03000]Jbe[014]J`03001BU5:D0?mBU8aBU080
00Aoo`007Goo00<002e[;F/042e[00<005:DDY@0oe:DSE:D0P0017oo000MOol00`00;F/]J`0@;F/0
0`00DYABU03oDYB=DY@20004Ool001eoo`03000]Jbe[010]J`03001BU5:D0?mBU8eBU08000Aoo`00
7Goo00<002e[;F/042e[00<005:DDY@0oe:DSE:D0P0017oo000MOol00`00;F/]J`0@;F/00`00DYAB
U03oDYB=DY@20004Ool001eoo`03000]Jbe[010]J`03001BU5:D0?mBU8eBU08000Aoo`007Goo00<0
02e[;F/042e[00<005:DDY@0oe:DSE:D0P0017oo000MOol00`00;F/]J`0@;F/00`00DYABU03oDYB=
DY@20004Ool001eoo`03000]Jbe[00l]J`03001BU5:D0?mBU8iBU08000Aoo`007Goo00<002e[;F/0
3be[00<005:DDY@0oe:DSE:D0`0017oo000MOol00`00;F/]J`0?;F/00`00DYABU03oDYB=DY@30004
Ool001eoo`03000]Jbe[00l]J`03001BU5:D0?mBU8eBU0<000Aoo`007Goo00<002e[;F/03Re[3`00
oe:DPU:D0`0017oo000MOol00`00;F/]J`0=;F/00`00DY@0000=Kg/b003oDYA@DY@30004Ool001eo
o`03000]Jbe[00`]J`05001BU5:DDY@0000nKg/c003oDY@MDY@30004Ool001eoo`03000]Jbe[00X]
J`8000ABU003001_Nfmk06m_NcX00>5BU0@000Aoo`007Goo00<002e[;F/022e[0P001e:D00<006mk
Kg/0Z6mk<`00[U:D00@005:D000000Aoo`007Goo00<002e[;F/01be[00<005:DDY@01e:D00<006mk
Kg/0ffmk:P00Q5:D00@005:D000000Aoo`007Goo00<002e[;F/01Be[0P002e:D00<006mkKg/0ofmk
1Fmk:P00FE:D0P0000=BU000000017oo000MOol00`00;F/]J`04;F/00`00DYABU00;DY@00`00Kg]_
N`3oKg/_Kg/I0010DY@200000e:D00000004Ool001eoo`03000]Jbe[00<]J`03001BU5:D00aBU003
001_Nfmk0?m_NdQ_Na00031BU0800003DY@0000000Aoo`007Goo00<002e[;F/00Re[00<005:DDY@0
3U:D00<006mkKg/0ofmkEfmk3`0085:D0P000U:D0P0017oo000MOol01@00;F/]Jbe[00004U:D00<0
06mkKg/0ofmkIFmk10006e:D0`000U:D0P0017oo000MOol01@00;F/]Jbe[00004U:D00<006mkKg/0
ofmkJFmk10005U:D00@006mkKg/0009BU08000Aoo`007Goo00@002e[;F/001ABU003001_Nfmk0?m_
Nfa_N`D0011BU004001_Nfmk0003DY@20004Ool001eoo`03000]J`0001EBU003001_Nfmk0?m_Ng5_
N`<000aBU005001_NfmkKg/00003DY@20004Ool001eoo`8001MBU2L00?m_Ndm_N`03001BU5:D00QB
U003001_Nfmk009_N`04001BU5:DDY@20004Ool001eoo`03001BU5:D01IBU003001_Nfmk00Y_NaP0
009ooc/00?m_NaE_N`03001BU5:D00IBU003001_Nfmk009_N`03001BU5:D009BU08000Aoo`007Goo
00<005:DDY@05U:D00<006mkKg/08Vmk<P002goo@`00dVmk0P001E:D00<006mkKg/00fmk00<005:D
DY@00U:D0P0017oo000MOol00`00DYABU00FDY@00`00Kg]_N`0aKg/30006DY@8000BKg^B002@Kg/0
1@00DYABU5:D00001Vmk00<005:DDY@00U:D0P0017oo000MOol00`00DYABU00FDY@00`00Kg]_N`0^
Kg/3000ADY@9001NKg^A000mKg/00`00DY@00006Kg/00`00DYABU003DY@20004Ool001eoo`03001B
U5:D01IBU003001_Nfmk02]_N`<001eBU14006e_NkP000EBU08000Aoo`007Goo00<005:DDY@05U:D
00<006mkKg/0:6mk0`00<E:DK@00@U:D0P00Lfmk00<005:DDY@00e:D0P0017oo000MOol00`00DYAB
U00GDY@00`00Kg]_N`0TKg/3000gDY@00`00DYABU02[DY@2001aKg/00`00DYABU003DY@20004Ool0
01eoo`03001BU5:D01MBU003001_Nfmk021_N`@003UBU0800:mBU003001_Nfmk06i_N`03001BU5:D
00=BU08000Aoo`007Goo00<005:DDY@05e:D00<006mkKg/06fmk1@00?E:D0P00/5:D0P00KVmk00<0
05:DDY@00e:D0P0017oo000MOol00`00DYABU00GDY@00`00Kg]_N`0HKg/30011DY@00`00;F/0002b
DY@2001[Kg/00`00DYABU004DY@20004Ool000Qoo`03001oogoo009oo`<000Aoo`8000Moo`03001B
U5:D01MBU003001_Nfmk01E_N`<004ABU004000]Jbe[002cDY@2001YKg/00`00DYABU004DY@20004
Ool000Qoo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol017oo00<005:DDY@05e:D
00<006mkKg/04Vmk0`00AU:D00D002e[;F/]J`000;EBU08006M_N`03001BU5:D00ABU08000Aoo`00
2Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo00Aoo`03001BU5:D01MBU003001_Nfmk
00i_N`@004UBU005000]Jbe[;F/0002gDY@2001UKg/00`00DYABU004DY@20004Ool000Uoo`03001o
ogoo00Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU00GDY@00`00Kg]_N`09Kg/5001<
DY@00`00;F/]J`02;F/00`00DYABU02gDY@2001SKg/00`00DYABU004DY@20004Ool000Yoo`03001o
o`0000<000=oo`04001oogoo0006Ool00`00DYABU00GDY@00`00Kg]_N`06Kg/3001ADY@00`00;F/]
J`02;F/00`00DYABU02iDY@2001QKg/00`00DYABU004DY@20004Ool000Ioo`07001oogooOol007oo
00001Woo00@007ooOol000Ioo`03001BU5:D01QBU003001_Nfmk009_N`<005=BU003000]Jbe[00<]
J`03001BU5:D0;]BU08005m_N`03001BU5:D00ABU08000Aoo`001Woo1@0000=oo`0000000`000goo
0P001goo00<005:DDY@065:D00<006mk00000P00EU:D00<002e[;F/00be[00<005:DDY@0_E:D00<0
06mkKg/0G6mk00<005:DDY@015:D0P0017oo000MOol00`00DYABU00GDY@3001IDY@00`00;F/]J`03
;F/00`00DYABU02nDY@2001KKg/00`00DYABU005DY@20004Ool001eoo`03001BU5:D01EBU0800003
;F/005:D05QBU003000]Jbe[00@]J`03001BU5:D0<1BU08005U_N`03001BU5:D00EBU08000Aoo`00
7Goo00<005:DDY@055:D00D002e[;F/]J`0005UBU003000]Jbe[00D]J`03001BU5:D0<5BU08005M_
N`03001BU5:D00EBU08000Aoo`007Goo00<005:DDY@04U:D0P0012e[00<005:DDY@0Ee:D00<002e[
;F/01Be[00<005:DDY@0`e:D0P00EFmk00<005:DDY@01E:D0P0017oo000MOol00`00DYABU00@DY@2
0006;F/00`00DYABU01FDY@00`00;F/]J`06;F/00`00DYABU035DY@2001CKg/00`00DYABU005DY@2
0004Ool001eoo`03001BU5:D00mBU003000]Jbe[00L]J`03001BU5:D05EBU003000]Jbe[00H]J`03
001BU5:D0<MBU080055_N`03001BU5:D00EBU08000Aoo`007Goo00<005:DDY@03E:D0P002Re[00<0
05:DDY@0EE:D00<002e[;F/01Re[00<005:DDY@0bE:D0P00Cfmk00<005:DDY@01E:D0P0017oo000M
Ool00`00DYABU00<DY@00`00;F/]J`0:;F/00`00DYABU01DDY@00`00;F/]J`07;F/00`00DYABU03;
DY@3001;Kg/00`00DYABU006DY@20004Ool001eoo`03001BU5:D00]BU003000]Jbe[00/]J`03001B
U5:D05ABU003000]Jbe[00P]J`03001BU5:D0<eBU08004U_N`03001BU5:D00IBU08000Aoo`007Goo
00<005:DDY@02U:D00<002e[;F/032e[00<005:DDY@0De:D00<002e[;F/02Be[00<005:DDY@0ce:D
0`00AVmk00<005:DDY@01U:D0P0017oo000MOol00`00DYABU009DY@00`00;F/]J`0=;F/00`00DYAB
U01CDY@00`00;F/]J`09;F/00`00DYABU03BDY@30013Kg/00`00DYABU006DY@20004Ool001eoo`03
001BU5:D00QBU003000]Jbe[00h]J`03001BU5:D059BU003000]Jbe[00X]J`03001BU5:D0=EBU0<0
041_N`03001BU5:D00IBU08000Aoo`007Goo00<005:DDY@01e:D00<002e[;F/03be[00<005:DDY@0
DU:D00<002e[;F/02be[00<005:DDY@0ee:D0P00?Vmk00<005:DDY@01U:D0P0017oo000MOol00`00
DYABU006DY@00`00;F/]J`0A;F/00`00DYABU01@DY@00`00;F/]J`0<;F/00`00DYABU03IDY@2000l
Kg/00`00DYABU006DY@20004Ool001eoo`03001BU5:D00EBU003000]Jbe[018]J`03001BU5:D051B
U003000]Jbe[00`]J`03001BU5:D0=]BU08003Y_N`03001BU5:D00IBU08000Aoo`007Goo00<005:D
DY@015:D00<002e[;F/04be[00<005:DDY@0Ce:D00<002e[;F/03Be[00<005:DDY@0gE:D0P00=fmk
00<005:DDY@01e:D0P0017oo000MOol00`00DYABU003DY@00`00;F/]J`0D;F/00`00DYABU01?DY@0
0`00;F/]J`0=;F/00`00DYABU03ODY@3000dKg/00`00DYABU007DY@20004Ool001eoo`03001BU5:D
009BU003000]Jbe[01D]J`03001BU5:D04iBU003000]Jbe[00h]J`03001BU5:D0>9BU0<0035_N`03
001BU5:D00MBU08000Aoo`007Goo00D005:DDYABU00001P]J`03001BU5:D04iBU003000]Jbe[00l]
J`03001BU5:D0>ABU0<002i_N`03001BU5:D00MBU08000Aoo`007Goo00@005:DDY@001T]J`03001B
U5:D04eBU003000]Jbe[010]J`03001BU5:D0>MBU08002a_N`03001BU5:D00MBU08000Aoo`007Goo
00<005:D00006be[00<005:DDY@0C5:D00<002e[;F/042e[00<005:DDY@0jE:D0`00:Fmk00<005:D
DY@01e:D0P0017oo000MOol2000L;F/00`00DYABU01;DY@00`00;F/]J`0A;F/00`00DYABU03/DY@3
000UKg/00`00DYABU008DY@20004Ool001eoo`03000]Jbe[01/]J`03001BU5:D04]BU003000]Jbe[
014]J`03001BU5:D0>mBU0<0029_N`03001BU5:D00QBU08000Aoo`007Goo00<002e[;F/06be[00<0
05:DDY@0BU:D00<002e[;F/04Re[00<005:DDY@0lU:D0`007fmk00<005:DDY@025:D0P0017oo000M
Ool00`00;F/]J`0K;F/00`00DYABU01:DY@00`00;F/]J`0B;F/00`00DYABU03eDY@3000LKg/00`00
DYABU008DY@20004Ool001eoo`03000]Jbe[01`]J`03001BU5:D04QBU003000]Jbe[01<]J`03001B
U5:D0?QBU0<001Q_N`03001BU5:D00UBU08000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0B5:D
00<002e[;F/04be[00<005:DDY@0ne:D0`005Fmk00<005:DDY@02E:D0P0017oo000MOol00`00;F/]
J`0L;F/00`00DYABU018DY@00`00;F/]J`0D;F/00`00DYABU03mDY@3000BKg/00`00DYABU009DY@2
0004Ool001eoo`03000]Jbe[01`]J`03001BU5:D04MBU003000]Jbe[01D]J`03001BU5:D0?mBU05B
U080011_N`03001BU5:D00UBU08000Aoo`007Goo00<002e[;F/07Be[00<005:DDY@0AU:D00<002e[
;F/05Be[00<005:DDY@0oe:D0e:D0`003Fmk00<005:DDY@02E:D0P0017oo000MOol00`00;F/]J`0M
;F/00`00DYABU015DY@00`00;F/]J`0F;F/00`00DYABU03oDY@6DY@30009Kg/00`00DYABU009DY@0
0`00;F/00004Ool001eoo`03000]Jbe[01d]J`03001BU5:D04EBU003000]Jbe[01H]J`03001BU5:D
0?mBU0UBU0<000I_N`03001BU5:D00UBU003000]J`0000Aoo`007Goo00<002e[;F/07Be[00<005:D
DY@0A5:D00<002e[;F/05be[00<005:DDY@0oe:D35:D1@0000=_N`00DY@02U:D00<002e[000017oo
000MOol00`00;F/]J`0M;F/00`00DYABU014DY@00`00;F/]J`0H;F/00`00DYABU03oDY@@DY@@0004
Ool001eoo`03000]Jbe[01h]J`03001BU5:D049BU003000]Jbe[01T]J`03001BU5:D0?mBU15BU003
000]Jbe[00T]J`03000@Q00000Aoo`007Goo00<002e[;F/07Re[00<005:DDY@0@U:D00<002e[;F/0
6Be[00<005:DDY@0oe:D45:D00<002e[;F/02Re[00<00124000017oo000MOol00`00;F/]J`0N;F/0
0`00DYABU011DY@00`00;F/]J`0J;F/00`00DYABU03oDY@@DY@00`00;F/]J`0:;F/00`0048@00004
Ool001eoo`03000]Jbe[01h]J`03001BU5:D045BU003000]Jbe[01X]J`03001BU5:D0?mBU11BU003
000]Jbe[00X]J`03000@Q00000Aoo`007Goo0P0082e[00<005:DDY@0?e:D00<002e[;F/072e[00<0
05:DDY@0oe:D3U:D00<002e[;F/02be[00<00124000017oo000MOol00`00DY@0000O;F/00`00DYAB
U00oDY@00`00;F/]J`0L;F/00`00DYABU03oDY@>DY@00`00;F/]J`0;;F/00`0048@00004Ool001eo
o`03001BU5:D008001d]J`03001BU5:D03iBU003000]Jbe[01d]J`03001BU5:D0?mBU0iBU003000]
Jbe[00/]J`03000@Q00000Aoo`007Goo00<005:DDY@00U:D0P006be[00<005:DDY@0?E:D00<002e[
;F/07Re[00<005:DDY@0oe:D3E:D00<002e[;F/032e[00<00124000017oo000MOol00`00DYABU004
DY@00`00;F/]J`0H;F/00`00DYABU00mDY@00`00;F/]J`0N;F/00`00DYABU03oDY@=DY@00`00;F/]
J`0<;F/00`0048@00004Ool001eoo`03001BU5:D00EBU08001T]J`03001BU5:D03]BU003000]Jbe[
01l]J`03001BU5:D0?mBU0eBU003000]Jbe[00`]J`03000@Q00000Aoo`007Goo00<005:DDY@01e:D
00<002e[;F/05Re[00<005:DDY@0>e:D00<002e[;F/082e[00<005:DDY@0oe:D35:D00<002e[;F/0
32e[00<00124000017oo000MOol00`00DYABU008DY@2000F;F/00`00DYABU00jDY@00`00;F/]J`0Q
;F/00`00DYABU03oDY@;DY@00`00;F/]J`0=;F/00`0048@00004Ool001eoo`03001BU5:D00YBU080
01D]J`03001BU5:D03QBU003000]Jbe[028]J`03001BU5:D0?mBU0]BU003000]Jbe[00d]J`03000@
Q00000Aoo`007Goo00<005:DDY@035:D00<002e[;F/04Re[00<005:DDY@0>5:D00<002e[;F/08Re[
00<005:DDY@0oe:D2e:D00<002e[;F/03Be[00<00124000017oo000MOol00`00DYABU00=DY@2000B
;F/00`00DYABU00gDY@00`00;F/]J`0S;F/00`00DYABU03oDY@;DY@00`00;F/]J`0=;F/00`0048@0
0004Ool000Moo`<000Aoo`8000Aoo`8000Moo`03001BU5:D00mBU080014]J`03001BU5:D03EBU003
000]Jbe[02@]J`03001BU5:D0?mBU0YBU003000]Jbe[00h]J`03000@Q00000Aoo`001Woo00D007oo
Oomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<005:DDY@04E:D0P003be[00<005:D
DY@0=E:D00<002e[;F/092e[00<005:DDY@0oe:D2U:D00<002e[;F/03Re[00<00124000017oo0006
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0006Ool00`00DYABU00CDY@2000=
;F/00`00DYABU00dDY@00`00;F/]J`0U;F/00`00DYABU03oDY@:DY@00`00;F/]J`0>;F/00`0048@0
0004Ool000Moo`<000=oo`04001oogoo0002Ool01000Oomoo`001Woo00<005:DDY@05E:D0P0032e[
00<005:DDY@0<e:D00<002e[;F/09Re[00<005:DDY@0oe:D25:D00<002e[;F/03Re[00@0012448@0
00Aoo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo00<005:DDY@0
5e:D00<002e[;F/02Be[00<005:DDY@0<U:D00<002e[;F/09be[00<005:DDY@0oe:D25:D00<002e[
;F/03Re[00@0012448@000Aoo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomo
o`001Woo00<005:DDY@065:D0P002Re[00<005:DDY@0<5:D00<002e[;F/0:2e[00<005:DDY@0oe:D
25:D00<002e[;F/03Re[00@0012448@000Aoo`001goo0`0017oo0P0017oo0P001goo00<005:DDY@0
6U:D0P0022e[00<005:DDY@0<5:D00<002e[;F/0:2e[00<005:DDY@0oe:D1e:D00<002e[;F/03be[
00@0012448@000Aoo`007Goo0`0075:D00<002e[;F/01Be[00<005:DDY@0;e:D00<002e[;F/0:Be[
00<005:DDY@0oe:D1e:D00<002e[;F/03be[00@0012448@000Aoo`007Goo00<002e[;F/00`006U:D
0P001Re[00<005:DDY@0;E:D00<002e[;F/0:Re[00<005:DDY@0oe:D1e:D00<002e[;F/03be[00@0
012448@000Aoo`007Goo00<002e[;F/00be[100065:D0P0012e[00<005:DDY@0;E:D00<002e[;F/0
:be[00<005:DDY@0oe:D1E:D00<002e[;F/042e[00@0012448@000Aoo`007Goo00<002e[;F/01be[
10005U:D0`0000<]J`00DY@0;E:D00<002e[;F/0;2e[00<005:DDY@0oe:D1E:D00<002e[;F/042e[
00@0012448@000Aoo`007Goo00<002e[;F/02be[10005E:D0`00;5:D00<002e[;F/0;Be[00<005:D
DY@0oe:D15:D00<002e[;F/04Be[00@0012448@000Aoo`007Goo00<002e[;F/03be[0`004E:D4@00
7e:D00<002e[;F/0;Be[00<005:DDY@0oe:D15:D00<002e[;F/04Be[00@0012448@000Aoo`007Goo
00<002e[;F/04Re[1P001E:D1P004Fmk6P0015:D00<002e[;F/0;Re[00<005:DDY@0oe:D0e:D00<0
02e[;F/04Re[00@0012448@000Aoo`007Goo00<002e[;F/062e[>P00<Re[00<005:DDY@0oe:D0U:D
00<002e[;F/04Re[00@0012448@000Aoo`007Goo00<002e[;F/06Re[00<005:DDY@0=5:D00<002e[
;F/0<2e[00<005:DDY@0oe:D0U:D00<002e[;F/04Re[00@0012448@000Aoo`007Goo00<002e[;F/0
6Re[00<005:DDY@0=5:D00<002e[;F/0<2e[00<005:DDY@0oe:D0E:D00<002e[;F/04be[00@00124
48@000Aoo`007Goo00<002e[;F/06Re[00<005:DDY@0=5:D00<002e[;F/0<2e[00<005:DDY@0oe:D
0E:D00<002e[;F/04be[00@0012448@000Aoo`007Goo00<002e[;F/06Re[00<005:DDY@0=5:D00<0
02e[;F/0<Be[00<005:DDY@0oU:D00<002e[;F/052e[00@0012448@000Aoo`007Goo00<002e[;F/0
6be[00<005:DDY@0=5:D00<002e[;F/0<2e[00<005:DDY@0oU:D00<002e[;F/052e[00@0012448@0
00Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=5:D00<002e[;F/0<2e[00<005:DDY@0oE:D00<0
02e[;F/05Be[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=5:D00<002e[;F/0
<2e[00<005:DDY@0oE:D00<002e[;F/05Be[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<0
05:DDY@0=5:D00<002e[;F/0<Be[00<005:DDY@0ne:D00<002e[;F/05Re[00@0012448@000Aoo`00
7Goo00<002e[;F/06be[00<005:DDY@0=5:D00<002e[;F/0<Be[00<005:DDY@0ne:D00<002e[;F/0
5Re[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=5:D00<002e[;F/0<Be[00<0
05:DDY@0nU:D00<002e[;F/05be[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0
=5:D00<002e[;F/0<Be[00<005:DDY@0nU:D00<002e[;F/05be[00@0012448@000Aoo`007Goo00<0
02e[;F/06be[00<005:DDY@0=5:D00<002e[;F/0<Be[00<005:DDY@0nE:D00<002e[;F/062e[00@0
012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0<2e[00<005:DDY@0
nE:D00<002e[;F/062e[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=E:D00<0
02e[;F/0<Be[00<005:DDY@0me:D00<002e[;F/06Be[00@0012448@000Aoo`007Goo00<002e[;F/0
6be[00<005:DDY@0=E:D00<002e[;F/0<Be[00<005:DDY@0mU:D00<002e[;F/06Re[00@0012448@0
00Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0<Be[00<005:DDY@0mU:D00<0
02e[;F/06Re[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0
<Be[00<005:DDY@0mE:D00<002e[;F/06be[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<0
05:DDY@0=E:D00<002e[;F/0<Be[00<005:DDY@0mE:D00<002e[;F/06be[00@0012448@000Aoo`00
7Goo00<002e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0<Be[00<005:DDY@0m5:D00<002e[;F/0
72e[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0<Re[00<0
05:DDY@0lU:D00<002e[;F/07Be[00@0012448@000Aoo`007Goo00<002e[;F/06be[00<005:DDY@0
=E:D00<002e[;F/0<Re[00<005:DDY@0lU:D00<002e[;F/07Be[00@0012448@000Aoo`007Goo00<0
02e[;F/06be[00<005:DDY@0=E:D00<002e[;F/0<Re[00<005:DDY@0lE:D00<002e[;F/07Re[00@0
012448@000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D00<002e[;F/0<Re[00<005:DDY@0
l5:D00<002e[;F/07be[00@0012448@000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D00<0
02e[;F/0<Re[00<005:DDY@0l5:D00<002e[;F/07be[00@0012448@000Aoo`007Goo00<002e[;F/0
72e[00<005:DDY@0=5:D00<002e[;F/0<be[00<005:DDY@0kU:D00<002e[;F/07be[00D0012448@@
Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D00<002e[;F/0<be[00<005:DDY@0kE:D
00<002e[;F/082e[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D00<0
02e[;F/0<be[00<005:DDY@0kE:D00<002e[;F/082e[00D0012448@@Q00000Aoo`007Goo00<002e[
;F/072e[00<005:DDY@0=5:D00<002e[;F/0<be[00<005:DDY@0k5:D00<002e[;F/08Be[00D00124
48@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D00<002e[;F/0=2e[00<005:DDY@0
jU:D00<002e[;F/08Re[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=5:D
00<002e[;F/0=2e[00<005:DDY@0jU:D00<002e[;F/08Re[00D0012448@@Q00000Aoo`007Goo00<0
02e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0<be[00<005:DDY@0jE:D00<002e[;F/08be[00D0
012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0<be[00<005:D
DY@0j5:D00<002e[;F/092e[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0
=E:D00<002e[;F/0=2e[00<005:DDY@0iU:D00<002e[;F/09Be[00D0012448@@Q00000Aoo`007Goo
00<002e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0=2e[00<005:DDY@0iU:D00<002e[;F/09Be[
00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0=2e[00<0
05:DDY@0iE:D00<002e[;F/09Re[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:D
DY@0=E:D00<002e[;F/0=2e[00<005:DDY@0i5:D00<002e[;F/09be[00D0012448@@Q00000Aoo`00
7Goo00<002e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0=Be[00<005:DDY@0hU:D00<002e[;F/0
:2e[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=E:D00<002e[;F/0=Be[
00<005:DDY@0hU:D00<002e[;F/0:2e[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<0
05:DDY@0=U:D00<002e[;F/0=2e[00<005:DDY@0hE:D00<002e[;F/0:Be[00D0012448@@Q00000Ao
o`007Goo00<002e[;F/072e[00<005:DDY@0=U:D00<002e[;F/0=2e[00<005:DDY@0h5:D00<002e[
;F/0:Re[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[00<005:DDY@0=U:D00<002e[;F/0
=2e[00<005:DDY@0ge:D00<002e[;F/0:be[00D0012448@@Q00000Aoo`007Goo00<002e[;F/072e[
00<005:DDY@0=U:D00<002e[;F/0=Be[00<005:DDY@0gE:D00<002e[;F/082e[4@0017oo0007Ool3
0003Ool30004Ool20007Ool00`00;F/]J`0L;F/00`00DYABU00fDY@00`00;F/]J`0e;F/00`00DYAB
U03LDY@00`00;F/]J`0@;F/A000<48@50004Ool000Ioo`07001oogooOol007oo00000goo00@007oo
Ool0009oo`03001oogoo00AoobD003=BU003000]Jbe[03D]J`03001BU5:D0=]BU003000]Jbe[0140
01d@Q0D000Aoo`001Woo00D007ooOomoo`0000Eoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00
48@@Q00L48@00`00;F/]J`03;F/8000[DY@00`00;F/]J`0e;F/00`00DYABU03FDY@8000^48@50004
Ool000Moo`<000Ioo`04001oogoo0002Ool00`00Oomoo`04Ool00`0048@@Q00L48@00`00;F/]J`0;
;F/8000SDY@00`00;F/]J`0f;F/00`00DYABU034DY@A0002;F/00`0048@@Q00a48@50004Ool000Io
o`06001oogooOol007oo10000goo00@007ooOol000Ioo`03000@Q12401`@Q003000]Jbe[01<]J`T0
01YBU003000]Jbe[03H]J`03001BU5:D0;aBU0P0018]J`03000@Q124038@Q0D000Aoo`001Woo00L0
07ooOomoo`00Ool00006Ool01000Oomoo`001Woo00<0012448@0712400<002e[;F/072e[20004e:D
00<002e[;F/0=Be[00<005:DDY@0Ze:D4@0062e[0P00=A241@0017oo0007Ool30002Ool50003Ool2
0007Ool00`0048@@Q00L48@00`00;F/]J`0T;F/6000=DY@00`00;F/]J`0e;F/00`00DYABU02JDY@A
000X;F/00`0048@@Q00e48@50004Ool001eoo`03000@Q12401`@Q003000]Jbe[02X]J`@000UBU003
000]Jbe[03H]J`03001BU5:D08UBU10003P]J`03000@Q12403H@Q0D000Aoo`007Goo00<0012448@0
712400<002e[;F/0;Re[1P000e:D00<002e[;F/0=Re[00<005:DDY@0PE:D2000Abe[00<0012448@0
=a241@0017oo000MOol00`0048@@Q00L48@00`00;F/]J`0d;F/9000c;F/00`00DYABU01`DY@A001=
;F/2000j48@50004Ool001eoo`03000@Q12401`@Q003000]Jbe[03L]J`03000@Q12400<@Q0P002`]
J`03001BU5:D05iBU14005d]J`03000@Q12403X@Q0D000Aoo`007Goo00<0012448@0712400<002e[
;F/0=be[00<0012448@02a241P009Re[00<005:DDY@0CU:D4000KBe[00<0012448@0>a241@0017oo
000MOol00`0048@@Q00L48@00`00;F/]J`0h;F/00`0048@@Q00@48@5000Q;F/00`00DYABU00mDY@A
001l;F/00`0048@@Q00k48@60004Ool001eoo`03000@Q12401`@Q003000]Jbe[03P]J`03000@Q124
01D@Q0H001`]J`03001BU5:D02]BU14008`]J`03000@Q12403`@Q0H000Aoo`007Goo00<0012448@0
6a2400<002e[;F/0>Be[00<0012448@06a242@004be[00<005:DDY@06e:D4000W2e[00<0012448@0
?A241P0017oo000MOol00`0048@@Q00K48@00`00;F/]J`0i;F/00`0048@@Q00T48@8000;;F/00`00
DYABU00:DY@A002[;F/00`0048@@Q00n48@60004Ool001eoo`03000@Q12401/@Q003000]Jbe[03X]
J`03000@Q12402/@Q1P00;X]J`80044@Q0H000Aoo`007Goo00<0012448@06a2400<002e[;F/0>Re[
00<0012448@0=a2400<002e[;F/0`Re[00<0012448@0@A241P0017oo000MOol00`0048@@Q00K48@0
0`00;F/]J`0j;F/00`0048@@Q00h48@00`00;F/]J`2o;F/2001448@60004Ool001eoo`03000@Q124
01/@Q003000]Jbe[03X]J`03000@Q12403P@Q003000]Jbe[0;d]J`8004H@Q0H000Aoo`007Goo00<0
012448@06a2400<002e[;F/0>Re[00<0012448@0>12400<002e[;F/0_2e[00<0012448@0AQ241P00
17oo000MOol00`0048@@Q00J48@00`00;F/]J`0k;F/00`0048@@Q00i48@00`00;F/]J`2i;F/20019
48@60004Ool001eoo`03000@Q12401X@Q003000]Jbe[03`]J`03000@Q12403P@Q003000]Jbe[0;P]
J`03000@Q12404T@Q0H000Aoo`007Goo00<0012448@06Q2400<002e[;F/0?2e[00<0012448@0>124
00<002e[;F/0]Re[0P00C1241P0017oo000MOol00`0048@@Q00J48@00`00;F/]J`0l;F/00`0048@@
Q00i48@00`00;F/]J`2c;F/2001>48@60004Ool001eoo`03000@Q12401T@Q003000]Jbe[03d]J`03
000@Q12403T@Q003000]Jbe[0;8]J`03000@Q12404h@Q0H000Aoo`007Goo0P006Q2400<002e[;F/0
?Be[00<0012448@0>A2400<002e[;F/0/2e[0P00DA241P0017oo000MOol2000J48@00`00;F/]J`0m
;F/00`0048@@Q00j48@00`00;F/]J`2];F/2001C48@60004Ool001eoo`8001X@Q003000]Jbe[03d]
J`03000@Q12403X@Q003000]Jbe[0:/]J`8005D@Q0H000Aoo`007Goo0`006A2400<002e[;F/0?Re[
00<0012448@0>Q2400<002e[;F/0Z2e[0P00Ea241P0017oo000MOol3000I48@00`00;F/]J`0n;F/0
0`0048@@Q00j48@00`00;F/]J`2V;F/2001I48@60004Ool001eoo`<001P@Q003000]Jbe[03l]J`03
000@Q12403X@Q003000]Jbe[0:@]J`8005/@Q0H000Aoo`007Goo10005a2400<002e[;F/0?be[00<0
012448@0>a2400<002e[;F/0XBe[0P00GA241P0017oo000MOol4000G48@00`00;F/]J`10;F/00`00
48@@Q00j48@00`00;F/]J`2P;F/00`0048@@Q01M48@60004Ool001eoo`@001L@Q003000]Jbe[040]
J`03000@Q12403/@Q003000]Jbe[09d]J`80060@Q0H000Aoo`007Goo1@005Q2400<002e[;F/0@2e[
00<0012448@0>a2400<002e[;F/0Vbe[0P00HQ241P0017oo000MOol5000F48@00`00;F/]J`10;F/0
0`0048@@Q00l48@00`00;F/]J`2G;F/3001T48@60004Ool001eoo`H001D@Q003000]Jbe[044]J`03
000@Q12403/@Q003000]Jbe[09@]J`<006L@Q0H000Aoo`007Goo1P005A2400<002e[;F/0@Be[00<0
012448@0?124UP00JQ241P0017oo000MOol6000E48@00`00;F/]J`11;F/00`0048@@Q00l48@00`00
;F/]J`09;F]e000C;F/00`0048@@Q01Y48@60004Ool001eoo`L001<@Q003000]Jbe[048]J`03000@
Q12403`@Q003000]Jbe[00h]J`03000]Jbe[07l]J`03000@Q12406X@Q0H000Aoo`007Goo1`004a24
00<002e[;F/0@be[00<0012448@0>a2400<002e[;F/03Re[00<002e[;F/0ORe[00<0012448@0Ja24
1P0017oo000MOol8000B48@00`00;F/]J`13;F/00`0048@@Q00k48@00`00;F/]J`0=;F/2001o;F/0
0`0048@@Q01/48@60004Ool001eoo`P0018@Q003000]Jbe[04<]J`03000@Q12403`@Q003000]Jbe[
00`]J`8007h]J`03000@Q12406d@Q0H000Aoo`007Goo2@004A2400<002e[;F/0@be[00<0012448@0
?12400<002e[;F/032e[00<001240000O2e[00<0012448@0KQ241P0017oo000MOol9000A48@00`00
;F/]J`14;F/00`0048@@Q00k48@00`00;F/]J`0<;F/00`0048@0001k;F/00`0048@@Q01^48@70004
Ool001eoo`X000l@Q003000]Jbe[04D]J`03000@Q12403/@Q003000]Jbe[00`]J`03000@Q00007T]
J`80074@Q0L000Aoo`007Goo2P003a2400<002e[;F/0ABe[00<0012448@0>a2400<002e[;F/02be[
00@0012448@007P]J`03000@Q124074@Q0L000Aoo`007Goo2P003a2400<002e[;F/0ABe[00<00124
48@0>a2400<002e[;F/02be[00@0012448@007L]J`03000@Q124078@Q0L000Aoo`007Goo2`003Q24
00<002e[;F/0ABe[00<0012448@0>a2400<002e[;F/02be[00D0012448@@Q00007@]J`8007D@Q0L0
00Aoo`007Goo2`003Q2400<002e[;F/0ARe[00<0012448@0>Q2400<002e[;F/02be[00D0012448@@
Q00007<]J`03000@Q12407D@Q0L000Aoo`007Goo3000312400<002e[;F/0Abe[00<0012448@0>a24
00<002e[;F/02Re[00D0012448@@Q000078]J`03000@Q12407H@Q0L000Aoo`007Goo3000312400<0
02e[;F/0Abe[00<0012448@0>a2400<002e[;F/02Be[00<0012448@00a2400<002e[;F/0KRe[00<0
012448@0Ma241`0017oo000MOol=000;48@00`00;F/]J`17;F/00`0048@@Q00k48@00`00;F/]J`09
;F/00`0048@@Q00348@00`00;F/]J`1/;F/2001j48@70004Ool001eoo`d000/@Q003000]Jbe[04P]
J`03000@Q12403X@Q003000]Jbe[00T]J`03000@Q12400<@Q003000]Jbe[06/]J`03000@Q12407X@
Q0L000Aoo`007Goo3P002Q2400<002e[;F/0B2e[00<0012448@0>Q2400<002e[;F/02Be[00<00124
48@0112400<002e[;F/0JBe[00<0012448@0Na241`0017oo000MOol>000:48@00`00;F/]J`18;F/0
0`0048@@Q00j48@00`00;F/]J`09;F/00`0048@@Q00448@00`00;F/]J`1W;F/2001n48@70004Ool0
00Moo`8000Eoo`8000Aoo`8000Moo`h000T@Q003000]Jbe[04T]J`03000@Q12403X@Q003000]Jbe[
00P]J`03000@Q12400D@Q003000]Jbe[06H]J`03000@Q12407h@Q0L000Aoo`002Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool?000848@00`00;F/]J`1:;F/00`0048@@Q00i
48@00`00;F/]J`08;F/00`0048@@Q00548@00`00;F/]J`1U;F/00`0048@@Q01o48@70004Ool000Yo
o`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol017oo3`00212400<002e[;F/0BRe[00<0
012448@0>A2400<002e[;F/022e[00<0012448@01A2400<002e[;F/0Hbe[0P00PQ241`0017oo0007
Ool40002Ool01000Oomoo`000Woo00@007ooOol000Iooa0000L@Q003000]Jbe[04X]J`03000@Q124
03X@Q003000]Jbe[00L]J`03000@Q12400D@Q003000]Jbe[068]J`03000@Q124088@Q0L000Aoo`00
1Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`001Woo40001a2400<002e[;F/0
BRe[00<0012448@0>Q2400<002e[;F/01be[00<0012448@01Q2400<002e[;F/0H2e[00<0012448@0
Pa241`0017oo0006Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0006OolA0006
48@00`00;F/]J`1;;F/00`0048@@Q00i48@00`00;F/]J`06;F/00`0048@@Q00748@00`00;F/]J`1N
;F/2002648@70004Ool000Moo`<000Aoo`8000Aoo`8000Mooa8000@@Q003000]Jbe[04`]J`03000@
Q12403T@Q003000]Jbe[00H]J`03000@Q12400L@Q003000]Jbe[05d]J`03000@Q12408H@Q0L000Ao
o`007Goo4P00112400<002e[;F/0C2e[00<0012448@0>A2400<002e[;F/01Re[00<0012448@01a24
00<002e[;F/0G2e[00<0012448@0Qa241`0017oo000MOolC000348@00`00;F/]J`1<;F/00`0048@@
Q00i48@00`00;F/]J`06;F/00`0048@@Q00748@00`00;F/]J`1K;F/00`0048@@Q02848@70004Ool0
01eooa@0008@Q003000]Jbe[04d]J`03000@Q12403P@Q003000]Jbe[00H]J`03000@Q12400L@Q003
000]Jbe[05T]J`8008/@Q0L000Aoo`007Goo50000Q2400<002e[;F/0CBe[00<0012448@0>12400<0
02e[;F/01Be[00<0012448@0212400<002e[;F/0F2e[00<0012448@0Ra241`0017oo000MOolF001@
;F/00`0048@@Q00h48@00`00;F/]J`05;F/00`0048@@Q00848@00`00;F/]J`1G;F/00`0048@@Q02<
48@70004Ool001eooaL004l]J`03000@Q12403T@Q003000]Jbe[00@]J`03000@Q12400T@Q003000]
Jbe[05@]J`8008l@Q0L000Aoo`007Goo5P0000<@Q0000000CRe[00<0012448@0>12400<002e[;F/0
12e[00<0012448@02A2400<002e[;F/0Dbe[00<0012448@0SQ24200017oo000MOolF000348@2001<
;F/00`0048@@Q00h48@00`00;F/]J`04;F/00`0048@@Q00948@00`00;F/]J`1B;F/00`0048@@Q02?
48@80004Ool001eooaH000D@Q08004X]J`03000@Q12403P@Q003000]Jbe[00<]J`03000@Q12400X@
Q003000]Jbe[050]J`80098@Q0P000Aoo`007Goo5P001a240P00B2e[00<0012448@0>12400<002e[
;F/00be[00<0012448@02Q2400<002e[;F/0CRe[0P00U124200017oo000MOolG000848@20016;F/0
0`0048@@Q00h48@00`00;F/]J`03;F/00`0048@@Q00:48@00`00;F/]J`1<;F/2002F48@80004Ool0
01eooaL000X@Q08004D]J`03000@Q12403P@Q003000]Jbe[008]J`03000@Q12400X@Q003000]Jbe[
04/]J`03000@Q12409H@Q0P000Aoo`007Goo5`00312400<002e[;F/0@Re[00<0012448@0>12400<0
02e[;F/00Re[00<0012448@02Q2400<002e[;F/0BBe[0P00VA24200017oo000MOolG000=48@20012
;F/00`0048@@Q00h48@01@00;F/]Jbe[00003Q2400<002e[;F/0ARe[0P00Va24200017oo000MOolG
000?48@20010;F/00`0048@@Q00h48@01@00;F/]Jbe[00003Q2400<002e[;F/0ABe[00<0012448@0
Va24200017oo000MOolG000A48@2000o;F/00`0048@@Q00g48@01@00;F/]Jbe[00003Q2400<002e[
;F/0A2e[00<0012448@0W124200017oo000MOolH000B48@3000l;F/00`0048@@Q00h48@01000;F/]
J`003Q2400<002e[;F/0@Re[0P00Wa24200017oo000MOolH000E48@2000j;F/00`0048@@Q00h48@0
1000;F/]J`003Q2400<002e[;F/0@Be[00<0012448@0Wa24200017oo000MOolH000G48@2000h;F/0
0`0048@@Q00h48@00`00;F/0000?48@00`00;F/]J`10;F/00`0048@@Q02P48@80004Ool001eooaP0
01T@Q08003L]J`03000@Q12403L@Q003000]J`0000l@Q003000]Jbe[03h]J`800:<@Q0P000Aoo`00
7Goo60006a240P00=Be[00<0012448@0=a2400<002e[0000412400<002e[;F/0?2e[00<0012448@0
Xa24200017oo000MOolI000L48@00`00;F/]J`0b;F/00`0048@@Q00g48@00`00;F/0000@48@00`00
;F/]J`0j;F/2002V48@80004Ool001eooaT001d@Q08003<]J`03000@Q12403L@Q080010@Q003000]
Jbe[03P]J`800:P@Q0P000Aoo`007Goo6@007a240P00<Be[00<0012448@0=a2400<0012448@03a24
00<002e[;F/0=be[00<0012448@0Ya242@0017oo000MOolI000Q48@2000_;F/00`0048@@Q00g48@0
0`0048@@Q00@48@00`00;F/]J`0d;F/2002Z48@90004Ool001eooaX0028@Q08002h]J`03000@Q124
03H@Q003000@Q124010@Q003000]Jbe[038]J`800:`@Q0T000Aoo`007Goo6P0091240P00;2e[00<0
012448@0=A240P004Q2400<002e[;F/0;be[0`00[Q242@0017oo000MOolJ000V48@2000Z;F/00`00
48@@Q00d48@4000A48@00`00;F/]J`0];F/2002a48@90004Ool001eooaX002P@Q08002T]J`03000@
Q124038@Q0H0010@Q003000]Jbe[02/]J`800;<@Q0T000Aoo`007Goo6P00:Q240P009be[00<00124
48@0<A2420003a2400<002e[;F/0:Re[00<0012448@0/a242@0017oo000MOolK000[48@00`00;F/]
J`0T;F/00`0048@@Q00`48@9000@48@00`00;F/]J`0W;F/2002f48@90004Ool001eooa/002`@Q080
02@]J`03000@Q12402l@Q0/000l@Q003000]Jbe[02D]J`800;L@Q0X000Aoo`007Goo6`00;Q240P00
8be[00<0012448@0;A243@003Q2400<002e[;F/092e[00<0012448@0]a242P0017oo000MOolK000`
48@2000Q;F/00`0048@@Q00[48@@000=48@00`00;F/]J`0R;F/2002j48@:0004Ool001eooa`0034@
Q0<001h]J`03000@Q12402X@Q18000`@Q003000]Jbe[020]J`800;`@Q0X000Aoo`007Goo7000=124
0P0072e[00<0012448@0:1245@002a2400<002e[;F/07Be[0`00_Q242P0017oo000MOolL000f48@2
000K;F/00`0048@@Q00U48@H000;48@00`00;F/]J`0J;F/2003148@:0004Ool001eooa`003P@Q080
01T]J`03000@Q12402@@Q1X000X@Q003000]Jbe[01P]J`800<<@Q0X000Aoo`007Goo7@00>A240P00
5be[00<0012448@08Q247@002A2400<002e[;F/05be[00<0012448@0`a242P0017oo000MOolM000k
48@00`00;F/]J`0E;F/00`0048@@Q00P48@O000848@00`00;F/]J`0E;F/2003648@:0004Ool001eo
oad003`@Q08001D]J`03000@Q12401h@Q28000P@Q003000]Jbe[018]J`800<P@Q0X000Aoo`007Goo
7@00?Q240P004be[00<0012448@071249@001a2400<002e[;F/04Be[00<0012448@0b1242P0017oo
000MOolN000o48@2000B;F/00`0048@@Q00J48@W000648@00`00;F/]J`0?;F/2003;48@:0004Ool0
01eooah0044@Q080010]J`03000@Q12401P@Q2X000D@Q003000]Jbe[00d]J`800<d@Q0X000Aoo`00
7Goo7P00@a240P003Re[00<0012448@05Q24;@001A2400<002e[;F/02Be[0`00ca242P0017oo000M
OolN001548@2000=;F/00`0048@@Q00C48@a000348@00`00;F/]J`07;F/2003B48@:0004Ool001eo
oah004L@Q08000/]J`03000@Q124014@Q3@0008@Q003000]Jbe[00D]J`800=@@Q0X000Aoo`007Goo
7`00B1240P002Re[00<0012448@03Q24=`0000<@Q000;F/012e[0P00eQ242P0017oo000MOolO001:
48@00`00;F/]J`07;F/00`0048@@Q00<48@k0003;F/2003G48@;0004Ool001eooal004/@Q08000L]
J`03000@Q12400X@Q4000=T@Q0/000Aoo`001goo0P0017oo0`0017oo0P001goo7`00CA240P001Re[
00<0012448@01a24@000fa242`0017oo0009Ool01000Oomoo`000goo00@007ooOol0009oo`03001o
ogoo00Aoob0004h@Q08000@]J`03000@Q12400D@Q4800=/@Q0/000Aoo`002Woo00<007ooOol00goo
00@007ooOol0009oo`03001oogoo00Aoob00050@Q0<00003;F/0012400<@Q4H00=X@Q0/000Aoo`00
1goo10001Goo00@007ooOol0009oo`03001oogoo00Aoob0005<@Q4`00=X@Q0/000Aoo`001Woo00H0
07ooOomoo`00Ool40003Ool01000Oomoo`001Woo8000EA24B`00fA242`0017oo0006Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0006OolP001E48A;003I48@;0004Ool000Moo`<0009oo`D000=o
o`8000Moob4005<@Q4d00=L@Q0`000Aoo`007Goo8@00Da24C@00ea24300017oo000MOolQ001C48A>
003F48@<0004Ool001eoob40058@Q4l00=H@Q0`000Aoo`007Goo8P00DA24D000eA24300017oo000M
OolR001A48A@003E48@<0004Ool001eoob80050@Q5800=@@Q0`000Aoo`007Goo8P00D124DP00e124
300017oo000MOolS001>48AD003C48@<0004Ool001eoob<004h@Q5@00=<@Q0`000Aoo`007Goo8`00
CA24EP00dQ24300017oo000MOolT001<48AF003B48@<0004Ool001eoob@004/@Q5P00=4@Q0`000Ao
o`007Goo9000Ba24F@00d124300017oo000MOolU001948AJ003@48@<0004Ool001eoobD004T@Q5/0
0<l@Q0`000Aoo`007Goo9@00B124G@00cA243@0017oo000MOolV001748AM003=48@=0004Ool001eo
obH004H@Q5l00<`@Q0d000Aoo`007Goo9P00AQ24G`00c1243@0017oo000MOolV001648AP003;48@=
0004Ool001eoobL004@@Q6800<X@Q0d000Aoo`007Goo9`00A124HP00bQ243@0017oo000MOolW0013
48AT003948@=0004Ool001eoobL004<@Q6D00<P@Q0d000Aoo`007Goo9`00@a24I@00aa243P0017oo
000MOolX001148AW003648@>0004Ool001eoobP0044@Q6P00<D@Q0h000Aoo`007Goo:000@A24J@00
a1243P0017oo000MOolY000o48A[003348@>0004Ool001eoobT003l@Q6`00<8@Q0h000Aoo`007Goo
:@00?Q24K@00`Q243P0017oo000MOolZ000m48A^003148@>0004Ool001eoobX003d@Q6l00;l@Q0l0
00Aoo`007Goo:P00?124L@00_Q243`0017oo000MOol[000k48Ab002m48@?0004Ool001eoob/003/@
Q7800;d@Q0l000Aoo`007Goo:`00>Q24M000_1243`0017oo000MOol[000j48Ae002k48@?0004Ool0
01eoob`003P@Q7L00;X@Q0l000Aoo`007Goo;000>124N000^A243`0017oo000MOol/000h48Ai002g
48@@0004Ool001eoob`003L@Q7/00;H@Q10000Aoo`007Goo;@00=Q24O000]A24400017oo000MOol]
000f48An002c48@@0004Ool001eoobd003D@Q8000;8@Q10000Aoo`007Goo;P00=124P@00/A244000
17oo000MOol^000c48B3002`48@@0004Ool001eoobh003<@Q8@00:h@Q14000Aoo`007Goo;`00<Q24
Q@00[A244@0017oo000017oo0000000017oo0P0017oo0P0017oo0P001goo;`00<A24Q`00[1244@00
17oo0002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0006Ool_
000a48B8002[48@A0004Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Iooc00030@Q8T00:T@Q18000Aoo`000Woo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`001Wooo`00Y@0017oo0002Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo003oOon_Ool00003Ool0000000Aoo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol00?moojmoo`000Woo00<007ooOol00goo0P0017oo0P0017oo
0P00ogoo/7oo003oOoo6Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00ogooaWoo003o
Ooo6Ool00001\
\>"],
  ImageRangeCache->{{{0, 452}, {452, 0}} -> {-0.0696821, 610.937, 0.00238238, \
0.88148}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["T-x (Fe) pseudosection", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["data", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["ox and als data", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(* aluminosilicates*)
trp={505.1, 3.82};


ka={{0.1, 206.0}, {1.6, 325.4}, {3.1, 446.3}, {4.6, 569.0}, {6.1, 693.5}, 
 
  {7.6, 820.0}, {9.1, 948.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
sk={{0.1, 329.5}, {1.6, 400.4}, {3.1, 471.2}, {4.6, 541.5}, {6.1, \
611.4}, 
 
  {7.6, 680.7}, {9.1, 749.3}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
as={{0.1, 768.5}, {1.6, 656.6}, {3.1, 552.5}, {4.6, 456.1}, 
 
  {6.1, 367.1}, {7.6, 284.7}, {9.1, 208.2}};\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["points data ", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
i1={0.1747, 659.8};
i2={0.8389, 662.0};
i3={0.8800, 658.9};
i4={0.8400, 662.5};
i5={0.8800, 659.3};
i6={0.1758, 660.4};
i7={0.1531, 678.8};
i8={0.1600, 658.4};
i9={0.8698, 685.2};
i10={0.8600, 687.5};
i11={0.9080, 683.5};
i12={0.1633, 660.1};
i13={0.1628, 682.08};
i14={0.1418, 678.7};
i15={0.1445, 684.9};
i16={0.8970, 689.4};
i17={0.9392, 684.9};
i18={0.9637, 698.5};
i19={0.9587, 690.8};
i20={0.6014, 736.7};
i21={0.7045, 738.6};
i22={0.5450, 738.8};
i23={0.6370, 739.7};
i24={0.8510, 748.0};
i25={0.7639, 746.5};
i26={0.6305, 808.9};
i27={0.4321, 805.3};
i28={0.3751, 804.3};
i29={0.8435, 847.0};
i30={0.8524, 874.1};
i31={0.8045, 852.1};
i32={0.6481, 858.0};
i33={0.8270, 874.8};
i34={0.8537, 874.5};
i35={0.5025, 863.9};
i36={0.4250, 809.6};
i37={0.4357, 810.1};
i38={0.7476, 986.7};
i39={0.8335, 1001.0};
i40={0.8510, 1000.6};

\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
crossover[u88, u89]
crossover[u21, u23]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
crossover[u88, u89]\
\>", "\<\
crossover[u88, u89]\
\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
crossover[u21, u23]\
\>", "\<\
crossover[u21, u23]\
\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{0.7476, 986.7}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.7476000000000001, 986.7}\
\>", "\<\
{0.7476, \
986.7}\
\>"], "Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["{0.4357, 810.1}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{0.4357, 810.1}\
\>", "\<\
{0.4357, 810.1}\
\>"], \
"Output",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (1-20)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  pl bi mu sill H2O (liq)  *) 

u1={{0.0200, 5.00, 659.1},
{0.0400, 5.00, 659.2},
{0.0600, 5.00, 659.2},
{0.0800, 5.00, 659.3},
{0.1000, 5.00, 659.4},
{0.1200, 5.00, 659.5},
{0.1400, 5.00, 659.6},
{0.1600, 5.00, 659.7},
{0.1800, 5.00, 659.8},
{0.2000, 5.00, 659.9},
{0.2200, 5.00, 660.0},
{0.2400, 5.00, 660.1},
{0.2600, 5.00, 660.1},
{0.2800, 5.00, 660.2},
{0.3000, 5.00, 660.3},
{0.3200, 5.00, 660.4},
{0.3400, 5.00, 660.5},
{0.3600, 5.00, 660.6},
{0.3800, 5.00, 660.7},
{0.4000, 5.00, 660.8},
{0.4200, 5.00, 660.8},
{0.4400, 5.00, 660.9},
{0.4600, 5.00, 661.0},
{0.4800, 5.00, 661.0},
{0.5000, 5.00, 661.1},
{0.5200, 5.00, 661.2},
{0.5400, 5.00, 661.2},
{0.5600, 5.00, 661.3},
{0.5800, 5.00, 661.4},
{0.6000, 5.00, 661.4},
{0.6200, 5.00, 661.5},
{0.6400, 5.00, 661.5},
{0.6600, 5.00, 661.6},
{0.6800, 5.00, 661.6},
{0.7000, 5.00, 661.7},
{0.7200, 5.00, 661.7},
{0.7400, 5.00, 661.8},
{0.7600, 5.00, 661.8},
{0.7800, 5.00, 661.9},
{0.8000, 5.00, 661.9},
{0.8200, 5.00, 662.0},
{0.8400, 5.00, 662.0},
{0.8600, 5.00, 662.1},
{0.8800, 5.00, 662.1},
{0.9000, 5.00, 662.2},
{0.9200, 5.00, 662.2},
{0.9400, 5.00, 662.3},
{0.9600, 5.00, 662.3},
{0.9800, 5.00, 662.4}};

(*------------------------------*)
(*  liq pl bi mu sill (H2O)  *) 

u2={{0.0200, 5.00, 659.7},
{0.0400, 5.00, 659.8},
{0.0600, 5.00, 659.9},
{0.0800, 5.00, 660.0},
{0.1000, 5.00, 660.1},
{0.1200, 5.00, 660.1},
{0.1400, 5.00, 660.2},
{0.1600, 5.00, 660.3},
{0.1800, 5.00, 660.4},
{0.2000, 5.00, 660.5},
{0.2200, 5.00, 660.6},
{0.2400, 5.00, 660.7},
{0.2600, 5.00, 660.8},
{0.2800, 5.00, 660.9},
{0.3000, 5.00, 661.0},
{0.3200, 5.00, 661.1},
{0.3400, 5.00, 661.1},
{0.3600, 5.00, 661.2},
{0.3800, 5.00, 661.3},
{0.4000, 5.00, 661.4},
{0.4200, 5.00, 661.5},
{0.4400, 5.00, 661.6},
{0.4600, 5.00, 661.6},
{0.4800, 5.00, 661.7},
{0.5000, 5.00, 661.8},
{0.5200, 5.00, 661.8},
{0.5400, 5.00, 661.9},
{0.5600, 5.00, 662.0},
{0.5800, 5.00, 662.0},
{0.6000, 5.00, 662.1},
{0.6200, 5.00, 662.1},
{0.6400, 5.00, 662.2},
{0.6600, 5.00, 662.2},
{0.6800, 5.00, 662.3},
{0.7000, 5.00, 662.3},
{0.7200, 5.00, 662.4},
{0.7400, 5.00, 662.4},
{0.7600, 5.00, 662.5},
{0.7800, 5.00, 662.5},
{0.8000, 5.00, 662.6},
{0.8200, 5.00, 662.6},
{0.8400, 5.00, 662.7},
{0.8600, 5.00, 662.7},
{0.8800, 5.00, 662.8},
{0.9000, 5.00, 662.8},
{0.9200, 5.00, 662.9},
{0.9400, 5.00, 662.9},
{0.9600, 5.00, 663.0},
{0.9800, 5.00, 663.0}};

(*------------------------------*)
(*  pl bi mu sill H2O (cd)  *) 

u3={{0.0200, 5.00, 596.3},
{0.0400, 5.00, 604.0},
{0.0600, 5.00, 611.8},
{0.0800, 5.00, 619.8},
{0.1000, 5.00, 628.0},
{0.1200, 5.00, 636.3},
{0.1400, 5.00, 644.7},
{0.1600, 5.00, 653.3},
{0.1800, 5.00, 662.1},
{0.2000, 5.00, 671.0},
{0.2200, 5.00, 680.0},
{0.2400, 5.00, 689.4},
{0.2600, 5.00, 699.3},
{0.2800, 5.00, 709.3},
{0.3000, 5.00, 719.3}};

(*------------------------------*)
(*  pl bi mu sill H2O (g)  *) 

u4={{0.7200, 5.00, 584.6},
{0.7400, 5.00, 597.3},
{0.7600, 5.00, 610.2},
{0.7800, 5.00, 623.2},
{0.8000, 5.00, 636.3},
{0.8200, 5.00, 649.5},
{0.8400, 5.00, 662.7},
{0.8600, 5.00, 676.1},
{0.8800, 5.00, 721.5},
{0.9000, 5.00, 702.7},
{0.9200, 5.00, 728.3}};

(*------------------------------*)
(*  pl bi g mu sill H2O (liq)  *) 

u5={{0.8400, 5.00, 661.9},
{0.8600, 5.00, 660.3},
{0.8800, 5.00, 658.9}};

(*------------------------------*)
(*  pl bi g mu H2O (sill)  *) 

u6={{0.8000, 5.00, 581.9},
{0.8100, 5.00, 591.8},
{0.8200, 5.00, 601.6},
{0.8300, 5.00, 611.3},
{0.8400, 5.00, 620.8},
{0.8500, 5.00, 630.3},
{0.8600, 5.00, 639.7},
{0.8700, 5.00, 649.0},
{0.8800, 5.00, 658.2},
{0.8900, 5.00, 667.3},
{0.9000, 5.00, 676.3}};

(*------------------------------*)
(*  pl bi g mu H2O (liq)  *) 

u7={{0.8000, 5.00, 662.9},
{0.8100, 5.00, 662.5},
{0.8200, 5.00, 662.0},
{0.8300, 5.00, 661.5},
{0.8400, 5.00, 661.0},
{0.8500, 5.00, 660.5},
{0.8600, 5.00, 660.0},
{0.8700, 5.00, 659.4},
{0.8800, 5.00, 658.9},
{0.8900, 5.00, 658.3},
{0.9000, 5.00, 657.8},
{0.9100, 5.00, 657.2},
{0.9200, 5.00, 656.6},
{0.9300, 5.00, 656.0},
{0.9400, 5.00, 655.4},
{0.9500, 5.00, 654.7},
{0.9600, 5.00, 654.1},
{0.9700, 5.00, 653.4},
{0.9800, 5.00, 652.8},
{0.9900, 5.00, 652.1},
{1.0000, 5.00, 651.5}};

(*------------------------------*)
(*  liq pl bi g mu sill (H2O)  *) 

u8={{0.8400, 5.00, 662.5},
{0.8600, 5.00, 660.8},
{0.8800, 5.00, 659.3}};

(*------------------------------*)
(*  liq pl bi g mu (H2O)  *) 

u11={{0.8000, 5.00, 663.4},
{0.8200, 5.00, 662.5},
{0.8400, 5.00, 661.5},
{0.8600, 5.00, 660.4},
{0.8800, 5.00, 659.3},
{0.9000, 5.00, 658.1},
{0.9200, 5.00, 656.9},
{0.9400, 5.00, 655.7},
{0.9600, 5.00, 654.4},
{0.9800, 5.00, 653.0},
{1.0000, 5.00, 651.5}};

(*------------------------------*)
(*  liq pl bi g mu (sill)  *) 

u12={{0.8000, 5.00, 582.2},
{0.8080, 5.00, 590.1},
{0.8160, 5.00, 598.0},
{0.8240, 5.00, 605.8},
{0.8320, 5.00, 613.5},
{0.8400, 5.00, 621.1},
{0.8480, 5.00, 628.7},
{0.8560, 5.00, 636.2},
{0.8640, 5.00, 643.6},
{0.8720, 5.00, 651.0},
{0.8800, 5.00, 658.3},
{0.8880, 5.00, 665.6},
{0.8960, 5.00, 672.8},
{0.9040, 5.00, 679.9},
{0.9120, 5.00, 687.1}};
(*------------------------------*)
(*  liq pl bi mu sill (g)  *) 

u13={{0.8000, 5.00, 637.1},
{0.8200, 5.00, 650.5},
{0.8400, 5.00, 664.0},
{0.8600, 5.00, 678.0},
{0.8800, 5.00, 693.1}};

(*------------------------------*)
(*  liq pl bi mu sill (cd)  *) 

u14={{0.1000, 5.00, 699.9},
{0.1100, 5.00, 695.1},
{0.1200, 5.00, 692.0},
{0.1300, 5.00, 688.7},
{0.1400, 5.00, 684.9},
{0.1500, 5.00, 680.4},
{0.1600, 5.00, 674.8},
{0.1700, 5.00, 667.3},
{0.1800, 5.00, 653.5}};

(*------------------------------*)
(*  liq pl bi mu sill (ksp)  *) 

u15={{0.0200, 5.00, 677.4},
{0.0400, 5.00, 677.7},
{0.0600, 5.00, 677.9},
{0.0800, 5.00, 678.1},
{0.1000, 5.00, 678.3},
{0.1200, 5.00, 678.5},
{0.1400, 5.00, 678.7},
{0.1600, 5.00, 678.9},
{0.1800, 5.00, 679.2},
{0.2000, 5.00, 679.4},
{0.2200, 5.00, 679.6},
{0.2400, 5.00, 679.8},
{0.2600, 5.00, 680.0},
{0.2800, 5.00, 680.3},
{0.3000, 5.00, 680.5},
{0.3200, 5.00, 680.7},
{0.3400, 5.00, 680.9},
{0.3600, 5.00, 681.1},
{0.3800, 5.00, 681.4},
{0.4000, 5.00, 681.6},
{0.4200, 5.00, 681.8},
{0.4400, 5.00, 682.0},
{0.4600, 5.00, 682.2},
{0.4800, 5.00, 682.3},
{0.5000, 5.00, 682.5},
{0.5200, 5.00, 682.7},
{0.5400, 5.00, 682.9},
{0.5600, 5.00, 683.0},
{0.5800, 5.00, 683.2},
{0.6000, 5.00, 683.4},
{0.6200, 5.00, 683.5},
{0.6400, 5.00, 683.7},
{0.6600, 5.00, 683.8},
{0.6800, 5.00, 683.9},
{0.7000, 5.00, 684.1},
{0.7200, 5.00, 684.2},
{0.7400, 5.00, 684.4},
{0.7600, 5.00, 684.5},
{0.7800, 5.00, 684.6},
{0.8000, 5.00, 684.8},
{0.8200, 5.00, 684.9},
{0.8400, 5.00, 685.0},
{0.8600, 5.00, 685.1},
{0.8800, 5.00, 685.3},
{0.9000, 5.00, 685.4},
{0.9200, 5.00, 685.5},
{0.9400, 5.00, 685.6},
{0.9600, 5.00, 685.8},
{0.9800, 5.00, 685.9}};

(*------------------------------*)
(*  pl bi cd mu H2O (sill)  *) 

u16={{0.0000, 5.00, 588.7},
{0.0200, 5.00, 596.9},
{0.0400, 5.00, 605.3},
{0.0600, 5.00, 613.8},
{0.0800, 5.00, 622.4},
{0.1000, 5.00, 631.2},
{0.1200, 5.00, 640.2},
{0.1400, 5.00, 649.2},
{0.1600, 5.00, 658.4},
{0.1800, 5.00, 667.8},
{0.2000, 5.00, 677.3}};

(*------------------------------*)
(*  pl bi cd mu H2O (liq)  *) 

u17={{0.0000, 5.00, 657.1},
{0.0200, 5.00, 657.2},
{0.0400, 5.00, 657.3},
{0.0600, 5.00, 657.5},
{0.0800, 5.00, 657.7},
{0.1000, 5.00, 657.9},
{0.1200, 5.00, 658.0},
{0.1400, 5.00, 658.2},
{0.1600, 5.00, 658.4},
{0.1800, 5.00, 658.5},
{0.2000, 5.00, 658.7}};







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (21-40)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi sill (cd)  *) 

u21={{0.0500, 5.00, 668.9},
{0.0600, 5.00, 670.0},
{0.0700, 5.00, 671.1},
{0.0800, 5.00, 672.3},
{0.0900, 5.00, 673.4},
{0.1000, 5.00, 674.6},
{0.1100, 5.00, 675.7},
{0.1200, 5.00, 676.9},
{0.1300, 5.00, 678.1},
{0.1500, 5.00, 680.5},
{0.1600, 5.00, 681.7},
{0.1700, 5.00, 682.9},
{0.1800, 5.00, 684.1},
{0.1900, 5.00, 685.3},
{0.2000, 5.00, 686.8},
{0.2200, 5.00, 689.3},
{0.2400, 5.00, 691.8},
{0.2600, 5.00, 694.3},
{0.2800, 5.00, 696.8},
{0.3000, 5.00, 699.4},
{0.3200, 5.00, 701.9},
{0.3400, 5.00, 704.4},
{0.3600, 5.00, 706.8},
{0.3800, 5.00, 709.3},
{0.4000, 5.00, 711.8},
{0.4200, 5.00, 714.2},
{0.4400, 5.00, 716.7},
{0.4600, 5.00, 719.1},
{0.4800, 5.00, 721.6},
{0.5000, 5.00, 724.0},
{0.5200, 5.00, 726.5},
{0.5400, 5.00, 728.9},
{0.5600, 5.00, 731.4},
{0.5800, 5.00, 734.0},
{0.6000, 5.00, 736.5},
{0.6200, 5.00, 739.1},
{0.6400, 5.00, 741.8},
{0.6600, 5.00, 744.5},
{0.6800, 5.00, 747.3},
{0.7000, 5.00, 750.2}};

(*------------------------------*)
(*  liq ksp pl bi sill (mu)  *) 

u22={{0.0200, 5.00, 680.4},
{0.0400, 5.00, 680.6},
{0.0600, 5.00, 680.8},
{0.0800, 5.00, 681.0},
{0.1000, 5.00, 681.3},
{0.1200, 5.00, 681.5},
{0.1400, 5.00, 681.7},
{0.1600, 5.00, 682.0},
{0.1800, 5.00, 682.2},
{0.2000, 5.00, 682.4},
{0.2200, 5.00, 682.7},
{0.2400, 5.00, 682.9},
{0.2600, 5.00, 683.1},
{0.2800, 5.00, 683.3},
{0.3000, 5.00, 683.6},
{0.3200, 5.00, 683.8},
{0.3400, 5.00, 684.0},
{0.3800, 5.00, 684.4},
{0.4000, 5.00, 684.6},
{0.4200, 5.00, 684.8},
{0.4400, 5.00, 685.0},
{0.4600, 5.00, 685.1},
{0.4800, 5.00, 685.3},
{0.5000, 5.00, 685.5},
{0.5200, 5.00, 685.6},
{0.5400, 5.00, 685.8},
{0.5600, 5.00, 685.9},
{0.5800, 5.00, 686.0},
{0.6000, 5.00, 686.1},
{0.6200, 5.00, 686.3},
{0.6400, 5.00, 686.4},
{0.6600, 5.00, 686.5},
{0.6800, 5.00, 686.6},
{0.7000, 5.00, 686.7},
{0.7200, 5.00, 686.8},
{0.7400, 5.00, 686.9},
{0.7600, 5.00, 687.0},
{0.7800, 5.00, 687.1},
{0.8000, 5.00, 687.2},
{0.8200, 5.00, 687.3},
{0.8400, 5.00, 687.4},
{0.8600, 5.00, 687.5},
{0.8800, 5.00, 687.6},
{0.9000, 5.00, 687.7},
{0.9200, 5.00, 687.8},
{0.9400, 5.00, 687.9},
{0.9600, 5.00, 688.0},
{0.9800, 5.00, 688.1}};

(*------------------------------*)
(*  liq ksp pl bi sill (g)  *) 

u23={{0.3000, 5.00, 813.2},
{0.3200, 5.00, 807.8},
{0.3400, 5.00, 802.4},
{0.3600, 5.00, 797.0},
{0.3800, 5.00, 791.6},
{0.4000, 5.00, 786.2},
{0.4200, 5.00, 780.8},
{0.4400, 5.00, 775.5},
{0.4600, 5.00, 770.3},
{0.4800, 5.00, 765.2},
{0.5000, 5.00, 760.2},
{0.5200, 5.00, 755.3},
{0.5400, 5.00, 750.6},
{0.5600, 5.00, 745.9},
{0.5800, 5.00, 741.4},
{0.6000, 5.00, 737.0},
{0.6200, 5.00, 732.7},
{0.6400, 5.00, 728.6},
{0.6600, 5.00, 724.5},
{0.6800, 5.00, 720.5},
{0.7000, 5.00, 716.6},
{0.7200, 5.00, 712.8},
{0.7400, 5.00, 709.0},
{0.7600, 5.00, 705.3},
{0.7800, 5.00, 701.6},
{0.8000, 5.00, 698.0},
{0.8200, 5.00, 694.4},
{0.8400, 5.00, 690.9},
{0.8600, 5.00, 687.5},
{0.8800, 5.00, 684.0},
{0.9000, 5.00, 680.7},
{0.9200, 5.00, 677.3},
{0.9400, 5.00, 673.9},
{0.9600, 5.00, 670.6},
{0.9800, 5.00, 667.3}};

(*------------------------------*)
(*  liq pl bi g mu (ksp)  *) 

u24={{0.8000, 5.00, 701.7},
{0.8200, 5.00, 698.4},
{0.8400, 5.00, 695.0},
{0.8600, 5.00, 691.7},
{0.8800, 5.00, 688.3},
{0.9000, 5.00, 684.9},
{0.9200, 5.00, 681.4},
{0.9400, 5.00, 678.0},
{0.9600, 5.00, 674.4},
{0.9800, 5.00, 670.9},
{0.9850, 5.00, 670.0},
{0.9900, 5.00, 669.1},
{0.9950, 5.00, 668.2},
{1.0000, 5.00, 667.3}};

(*------------------------------*)
(*  liq pl bi cd mu (H2O)  *) 

u25={{0.0000, 5.00, 657.3},
{0.0200, 5.00, 657.6},
{0.0400, 5.00, 657.9},
{0.0600, 5.00, 658.3},
{0.0800, 5.00, 658.6},
{0.1000, 5.00, 659.0},
{0.1200, 5.00, 659.3},
{0.1400, 5.00, 659.6},
{0.1600, 5.00, 660.0},
{0.1800, 5.00, 660.3},
{0.2000, 5.00, 660.6}};

(*------------------------------*)
(*  liq pl bi cd mu (sill)  *) 

u26={{0.1000, 5.00, 698.6},
{0.1100, 5.00, 692.2},
{0.1200, 5.00, 688.6},
{0.1300, 5.00, 684.5},
{0.1400, 5.00, 679.6},
{0.1500, 5.00, 673.4},
{0.1600, 5.00, 664.4},
{0.1610, 5.00, 663.2},
{0.1620, 5.00, 661.9},
{0.1630, 5.00, 660.5},
{0.1640, 5.00, 659.0},
{0.1650, 5.00, 657.2},
{0.1660, 5.00, 655.2},
{0.1670, 5.00, 652.6},
{0.1680, 5.00, 648.9}};

(*------------------------------*)
(*  liq pl bi cd mu (ksp)  *) 

u28={{0.0000, 5.00, 673.4},
{0.0200, 5.00, 673.3},
{0.0400, 5.00, 674.2},
{0.0600, 5.00, 675.0},
{0.0800, 5.00, 675.9},
{0.1000, 5.00, 676.8},
{0.1200, 5.00, 677.7},
{0.1400, 5.00, 678.6},
{0.1600, 5.00, 679.5},
{0.1800, 5.00, 680.4},
{0.2000, 5.00, 681.3}};

(*------------------------------*)
(*  liq ksp pl bi cd (mu)  *) 

u29={{0.0000, 5.00, 677.4},
{0.0200, 5.00, 678.5},
{0.0400, 5.00, 679.5},
{0.0600, 5.00, 680.6},
{0.0800, 5.00, 681.6},
{0.1000, 5.00, 682.7},
{0.1200, 5.00, 683.7},
{0.1400, 5.00, 684.7},
{0.1600, 5.00, 685.8},
{0.1800, 5.00, 686.8},
{0.2000, 5.00, 687.8}};

(*------------------------------*)
(*  liq ksp pl bi cd (sill)  *) 

u30={{0.0200, 5.00, 667.4},
{0.0400, 5.00, 670.2},
{0.0600, 5.00, 673.0},
{0.0800, 5.00, 675.8},
{0.1000, 5.00, 678.6},
{0.1200, 5.00, 681.5},
{0.1400, 5.00, 684.3},
{0.1600, 5.00, 687.2},
{0.1800, 5.00, 690.1},
{0.2000, 5.00, 692.9},
{0.2200, 5.00, 695.8},
{0.2400, 5.00, 698.6},
{0.2600, 5.00, 701.4},
{0.2800, 5.00, 704.2},
{0.3000, 5.00, 707.0},
{0.3200, 5.00, 709.7},
{0.3400, 5.00, 712.4},
{0.3600, 5.00, 715.0},
{0.3800, 5.00, 717.7},
{0.4000, 5.00, 720.3},
{0.4200, 5.00, 722.9},
{0.4400, 5.00, 725.5},
{0.4600, 5.00, 728.1},
{0.4800, 5.00, 730.7},
{0.5000, 5.00, 733.3},
{0.5200, 5.00, 735.9},
{0.5400, 5.00, 738.6},
{0.5600, 5.00, 741.3},
{0.5800, 5.00, 744.0},
{0.6000, 5.00, 746.7}};

(*------------------------------*)
(*  liq ksp bi g sill (pl)  *) 

u35={{0.6000, 5.00, 766.1},
{0.6200, 5.00, 760.9},
{0.6400, 5.00, 755.6},
{0.6600, 5.00, 750.4},
{0.6800, 5.00, 745.1},
{0.7000, 5.00, 739.9},
{0.7200, 5.00, 734.6},
{0.7400, 5.00, 729.4},
{0.7600, 5.00, 724.2},
{0.7800, 5.00, 719.1},
{0.8000, 5.00, 714.0},
{0.8200, 5.00, 708.9},
{0.8400, 5.00, 703.8},
{0.8600, 5.00, 698.7},
{0.8800, 5.00, 693.7},
{0.9000, 5.00, 688.7},
{0.9200, 5.00, 683.7},
{0.9400, 5.00, 678.8},
{0.9600, 5.00, 673.9},
{0.9800, 5.00, 669.0}};

(*------------------------------*)
(*  liq ksp bi g sill (mu)  *) 

u36={{0.8000, 5.00, 682.2},
{0.8200, 5.00, 682.9},
{0.8400, 5.00, 684.1},
{0.8600, 5.00, 685.7},
{0.8800, 5.00, 687.6},
{0.9000, 5.00, 689.8},
{0.9200, 5.00, 692.4},
{0.9400, 5.00, 695.1},
{0.9600, 5.00, 697.9}};

(*------------------------------*)
(*  liq ksp bi g mu sill (pl)  *) 

u37={{0.9000, 5.00, 689.1},
{0.9025, 5.00, 688.7},
{0.9050, 5.00, 688.4},
{0.9075, 5.00, 688.1},
{0.9100, 5.00, 687.8},
{0.9125, 5.00, 687.5},
{0.9150, 5.00, 687.2},
{0.9175, 5.00, 687.0},
{0.9200, 5.00, 686.7},
{0.9225, 5.00, 686.4},
{0.9250, 5.00, 686.2},
{0.9275, 5.00, 685.9},
{0.9300, 5.00, 685.7},
{0.9325, 5.00, 685.5},
{0.9350, 5.00, 685.3},
{0.9375, 5.00, 685.0}};

(*------------------------------*)
(*  liq ksp pl bi g mu (sill)  *) 

u38={{0.9100, 5.00, 683.8},
{0.9125, 5.00, 683.9},
{0.9150, 5.00, 684.0},
{0.9175, 5.00, 684.1},
{0.9200, 5.00, 684.2},
{0.9225, 5.00, 684.2},
{0.9250, 5.00, 684.3},
{0.9275, 5.00, 684.4},
{0.9300, 5.00, 684.5},
{0.9325, 5.00, 684.6},
{0.9350, 5.00, 684.7},
{0.9375, 5.00, 684.8}};

(*------------------------------*)
(*  liq ksp bi g mu (sill)  *) 

u39={{0.9200, 5.00, 680.3},
{0.9300, 5.00, 682.3},
{0.9400, 5.00, 685.2},
{0.9500, 5.00, 688.2}};

(*------------------------------*)
(*  liq ksp bi g mu (pl)  *) 

u40={{0.9000, 5.00, 695.9},
{0.9100, 5.00, 693.1},
{0.9200, 5.00, 690.3},
{0.9300, 5.00, 687.5},
{0.9400, 5.00, 684.7},
{0.9500, 5.00, 681.8},
{0.9600, 5.00, 678.9},
{0.9700, 5.00, 676.0},
{0.9800, 5.00, 673.1},
{0.9900, 5.00, 670.2},
{0.9950, 5.00, 668.7},
{1.0000, 5.00, 667.3}};





\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (41-60)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq ksp pl bi g sill (mu)  *) 

u41={{0.8700, 5.00, 688.5},
{0.8750, 5.00, 688.7},
{0.8800, 5.00, 688.9},
{0.8850, 5.00, 689.0},
{0.8900, 5.00, 689.2},
{0.8950, 5.00, 689.4}};

(*------------------------------*)
(*  liq pl bi g mu sill (ksp)  *) 

u42={{0.8750, 5.00, 685.4},
{0.8800, 5.00, 685.1},
{0.8850, 5.00, 684.9},
{0.8900, 5.00, 684.6},
{0.8950, 5.00, 684.4},
{0.9000, 5.00, 684.2},
{0.9050, 5.00, 683.9}};

(*------------------------------*)
(*  liq ksp g mu (bi)  *) 

u44={{0.9500, 5.00, 694.0},
{0.9550, 5.00, 692.2},
{0.9600, 5.00, 690.3},
{0.9650, 5.00, 688.4},
{0.9700, 5.00, 686.5},
{0.9750, 5.00, 684.6},
{0.9800, 5.00, 682.7},
{0.9850, 5.00, 680.8},
{0.9900, 5.00, 678.8},
{0.9950, 5.00, 676.8},
{1.0000, 5.00, 674.8}};

(*------------------------------*)
(*  liq ksp g mu sill (bi)  *) 

u45={{0.9590, 5.00, 691.4},
{0.9600, 5.00, 693.0},
{0.9610, 5.00, 694.5},
{0.9620, 5.00, 696.0},
{0.9630, 5.00, 697.4}};

(*------------------------------*)
(*  liq ksp g sill (bi)  *) 

u46={{0.7500, 5.00, 783.4},
{0.7700, 5.00, 777.2},
{0.7900, 5.00, 770.6},
{0.8100, 5.00, 763.7},
{0.8300, 5.00, 756.4},
{0.8500, 5.00, 748.7},
{0.8700, 5.00, 740.6},
{0.8900, 5.00, 732.2},
{0.9100, 5.00, 723.4},
{0.9300, 5.00, 714.3},
{0.9500, 5.00, 705.0},
{0.9550, 5.00, 702.7},
{0.9600, 5.00, 700.3},
{0.9650, 5.00, 697.9},
{0.9700, 5.00, 695.5},
{0.9750, 5.00, 693.1},
{0.9800, 5.00, 690.8},
{0.9850, 5.00, 688.4},
{0.9900, 5.00, 686.1},
{0.9950, 5.00, 683.7}};

(*------------------------------*)
(*  liq ksp g sill (mu)  *) 

u47={{0.9500, 5.00, 698.5},
{0.9550, 5.00, 698.5},
{0.9600, 5.00, 698.5},
{0.9650, 5.00, 698.5},
{0.9700, 5.00, 698.4},
{0.9750, 5.00, 698.4},
{0.9800, 5.00, 698.4},
{0.9850, 5.00, 698.4},
{0.9900, 5.00, 698.4},
{0.9950, 5.00, 698.3},
{1.0000, 5.00, 698.3}};

(*------------------------------*)
(*  liq ksp g mu (sill)  *) 

u48={{0.9500, 5.00, 690.9},
{0.9550, 5.00, 690.8},
{0.9600, 5.00, 690.8},
{0.9650, 5.00, 690.8},
{0.9700, 5.00, 690.8},
{0.9750, 5.00, 690.8},
{0.9800, 5.00, 690.8},
{0.9850, 5.00, 690.7},
{0.9900, 5.00, 690.7},
{1.0000, 5.00, 690.7}};

(*------------------------------*)
(*  liq ksp pl bi g sill (cd)  *) 

u49={{0.6200, 5.00, 737.2},
{0.6300, 5.00, 737.4},
{0.6400, 5.00, 737.5},
{0.6500, 5.00, 737.7},
{0.6600, 5.00, 737.9},
{0.6700, 5.00, 738.0},
{0.6800, 5.00, 738.2},
{0.6900, 5.00, 738.4},
{0.7000, 5.00, 738.5}};

(*------------------------------*)
(*  liq ksp pl bi cd sill (g)  *) 

u50={{0.5500, 5.00, 738.7},
{0.5600, 5.00, 738.2},
{0.5700, 5.00, 737.9},
{0.5800, 5.00, 737.6},
{0.5900, 5.00, 737.3},
{0.6000, 5.00, 737.0}};

(*------------------------------*)
(*  liq ksp bi g sill (cd)  *) 

u51={{0.6000, 5.00, 728.2},
{0.6200, 5.00, 730.2},
{0.6400, 5.00, 732.3},
{0.6600, 5.00, 734.3},
{0.6800, 5.00, 736.3},
{0.7000, 5.00, 738.2},
{0.7200, 5.00, 739.9},
{0.7400, 5.00, 741.5},
{0.7600, 5.00, 742.9},
{0.7800, 5.00, 744.3},
{0.8000, 5.00, 745.5},
{0.8200, 5.00, 746.5},
{0.8400, 5.00, 747.5}};

(*------------------------------*)
(*  liq ksp bi cd g (sill)  *) 

u52={{0.5000, 5.00, 727.8},
{0.5200, 5.00, 729.8},
{0.5400, 5.00, 731.7},
{0.5600, 5.00, 733.5},
{0.5800, 5.00, 735.3},
{0.6000, 5.00, 736.9},
{0.6200, 5.00, 738.4},
{0.6400, 5.00, 739.9},
{0.6600, 5.00, 741.2},
{0.6800, 5.00, 742.4},
{0.7000, 5.00, 743.5},
{0.7200, 5.00, 744.5},
{0.7400, 5.00, 745.5},
{0.7600, 5.00, 746.4}};

(*------------------------------*)
(*  liq ksp bi cd g (pl)  *) 

u53={{0.3000, 5.00, 846.7},
{0.3200, 5.00, 840.7},
{0.3400, 5.00, 834.5},
{0.3600, 5.00, 828.3},
{0.3800, 5.00, 822.0},
{0.4000, 5.00, 815.7},
{0.4200, 5.00, 809.2},
{0.4400, 5.00, 802.7},
{0.4600, 5.00, 796.2},
{0.4800, 5.00, 789.6},
{0.5000, 5.00, 783.1},
{0.5200, 5.00, 776.5},
{0.5400, 5.00, 770.0},
{0.5600, 5.00, 763.5},
{0.5800, 5.00, 757.1},
{0.6000, 5.00, 750.8},
{0.6200, 5.00, 744.7},
{0.6400, 5.00, 738.8},
{0.6600, 5.00, 733.0},
{0.6800, 5.00, 727.4},
{0.7000, 5.00, 722.0}};

(*------------------------------*)
(*  liq ksp pl bi cd (g)  *) 

u54={{0.3000, 5.00, 842.8},
{0.3200, 5.00, 832.2},
{0.3400, 5.00, 821.8},
{0.3600, 5.00, 811.7},
{0.3800, 5.00, 801.9},
{0.4000, 5.00, 792.5},
{0.4200, 5.00, 783.4},
{0.4400, 5.00, 774.9},
{0.4600, 5.00, 766.7},
{0.4800, 5.00, 759.1},
{0.5000, 5.00, 751.9},
{0.5200, 5.00, 745.2},
{0.5400, 5.00, 738.9},
{0.5600, 5.00, 733.1},
{0.5800, 5.00, 727.7},
{0.6000, 5.00, 722.6}};

(*------------------------------*)
(*  liq ksp bi cd g sill (pl)  *) 

u55={{0.6400, 5.00, 739.6},
{0.6500, 5.00, 739.5},
{0.6600, 5.00, 739.3},
{0.6700, 5.00, 739.1},
{0.6800, 5.00, 739.0},
{0.6900, 5.00, 738.8},
{0.7000, 5.00, 738.7}};

(*------------------------------*)
(*  liq ksp pl bi cd g (sill)  *) 

u56={{0.5500, 5.00, 738.8},
{0.5600, 5.00, 738.9},
{0.5700, 5.00, 739.0},
{0.5800, 5.00, 739.1},
{0.5900, 5.00, 739.2},
{0.6000, 5.00, 739.3},
{0.6100, 5.00, 739.4},
{0.6200, 5.00, 739.5},
{0.6300, 5.00, 739.6}};

(*------------------------------*)
(*  liq ksp cd g sill (bi)  *) 

u57={{0.7700, 5.00, 746.6},
{0.7800, 5.00, 746.8},
{0.7900, 5.00, 747.0},
{0.8000, 5.00, 747.2},
{0.8100, 5.00, 747.4},
{0.8200, 5.00, 747.5},
{0.8300, 5.00, 747.7},
{0.8400, 5.00, 747.9},
{0.8500, 5.00, 748.0}};

(*------------------------------*)
(*  liq ksp g sill (cd)  *) 

u58={{0.8440, 5.00, 843.0},
{0.8450, 5.00, 835.0},
{0.8460, 5.00, 826.6},
{0.8470, 5.00, 817.6},
{0.8480, 5.00, 807.8},
{0.8490, 5.00, 796.8},
{0.8500, 5.00, 783.6},
{0.8503, 5.00, 779.8},
{0.8505, 5.00, 775.7},
{0.8508, 5.00, 771.2},
{0.8510, 5.00, 766.1},
{0.8513, 5.00, 760.2},
{0.8515, 5.00, 752.9},
{0.8518, 5.00, 742.2}};

(*------------------------------*)
(*  liq ksp cd g (sill)  *) 

u59={{0.7000, 5.00, 582.8},
{0.7100, 5.00, 605.4},
{0.7200, 5.00, 628.8},
{0.7300, 5.00, 653.2},
{0.7400, 5.00, 678.8},
{0.7500, 5.00, 706.2},
{0.7600, 5.00, 735.0},
{0.7700, 5.00, 764.4},
{0.7800, 5.00, 793.2},
{0.7900, 5.00, 819.9},
{0.8000, 5.00, 843.0},
{0.8040, 5.00, 851.1}};

(*------------------------------*)
(*  liq ksp cd g (bi)  *) 

u60={{0.5000, 5.00, 856.8},
{0.5200, 5.00, 850.5},
{0.5400, 5.00, 843.9},
{0.5600, 5.00, 837.1},
{0.5800, 5.00, 830.0},
{0.6000, 5.00, 822.5},
{0.6200, 5.00, 814.7},
{0.6400, 5.00, 806.4},
{0.6600, 5.00, 797.7},
{0.6800, 5.00, 788.6},
{0.7000, 5.00, 779.0},
{0.7200, 5.00, 769.1},
{0.7400, 5.00, 758.9},
{0.7600, 5.00, 748.6},
{0.7800, 5.00, 738.4},
{0.8000, 5.00, 728.6},
{0.8200, 5.00, 719.5},
{0.8400, 5.00, 711.1},
{0.8600, 5.00, 703.7},
{0.8800, 5.00, 697.2},
{0.9000, 5.00, 691.6}};








\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (61-80)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq ksp bi cd g (opx)  *) 

u61={{0.3400, 5.00, 804.9},
{0.3600, 5.00, 804.8},
{0.3800, 5.00, 804.8},
{0.4000, 5.00, 804.9},
{0.4200, 5.00, 805.1},
{0.4400, 5.00, 805.4},
{0.4600, 5.00, 805.7},
{0.4800, 5.00, 806.0},
{0.5000, 5.00, 806.4},
{0.5200, 5.00, 806.8},
{0.5400, 5.00, 807.2},
{0.5600, 5.00, 807.6},
{0.5800, 5.00, 808.0},
{0.6000, 5.00, 808.4},
{0.6200, 5.00, 808.8}};

(*------------------------------*)
(*  liq ksp pl bi cd g (opx)  *) 

u62={{0.3800, 5.00, 804.3},
{0.3900, 5.00, 804.5},
{0.4000, 5.00, 804.7},
{0.4100, 5.00, 804.9},
{0.4200, 5.00, 805.0}};

(*------------------------------*)
(*  liq ksp pl bi cd (opx)  *) 

u63={{0.0000, 5.00, 837.5},
{0.0200, 5.00, 836.6},
{0.0400, 5.00, 835.7},
{0.0600, 5.00, 834.7},
{0.0800, 5.00, 833.6},
{0.1000, 5.00, 832.3},
{0.1200, 5.00, 830.9},
{0.1400, 5.00, 829.4},
{0.1600, 5.00, 827.7},
{0.1800, 5.00, 825.9},
{0.2000, 5.00, 824.0},
{0.2200, 5.00, 822.0},
{0.2400, 5.00, 819.8},
{0.2600, 5.00, 817.6},
{0.2800, 5.00, 815.4},
{0.3000, 5.00, 813.0},
{0.3200, 5.00, 810.7},
{0.3400, 5.00, 808.3},
{0.3600, 5.00, 806.0},
{0.3800, 5.00, 803.7},
{0.4000, 5.00, 801.4}};

(*------------------------------*)
(*  liq ksp cd g opx (bi)  *) 

u64={{0.4400, 5.00, 810.1},
{0.4600, 5.00, 809.8},
{0.4800, 5.00, 809.6},
{0.5000, 5.00, 809.4},
{0.5200, 5.00, 809.3},
{0.5400, 5.00, 809.2},
{0.5600, 5.00, 809.1},
{0.5800, 5.00, 809.0},
{0.6000, 5.00, 809.0},
{0.6200, 5.00, 809.0}};

(*------------------------------*)
(*  liq g sill (ksp)  *) 

u65={{0.8000, 5.00, 847.0},
{0.8200, 5.00, 847.0},
{0.8400, 5.00, 847.0},
{0.8600, 5.00, 847.1},
{0.8800, 5.00, 847.1},
{0.9000, 5.00, 847.1},
{0.9200, 5.00, 847.1},
{0.9400, 5.00, 847.1},
{0.9600, 5.00, 847.2},
{0.9800, 5.00, 847.2},
{1.0000, 5.00, 847.2}};

(*------------------------------*)
(*  liq cd g sill (ksp)  *) 

u66={{0.8100, 5.00, 851.3},
{0.8200, 5.00, 850.1},
{0.8300, 5.00, 848.8},
{0.8400, 5.00, 847.5}};

(*------------------------------*)
(*  liq g sill (cd)  *) 

u67={{0.8000, 5.00, 705.7},
{0.8100, 5.00, 739.7},
{0.8200, 5.00, 772.8},
{0.8300, 5.00, 805.0},
{0.8400, 5.00, 836.3},
{0.8500, 5.00, 867.0},
{0.8600, 5.00, 897.0}};

(*------------------------------*)
(*  liq g sill (sp)  *) 

u68={{0.8000, 5.00, 880.7},
{0.8100, 5.00, 879.4},
{0.8200, 5.00, 878.1},
{0.8300, 5.00, 876.9},
{0.8400, 5.00, 875.6},
{0.8500, 5.00, 874.4},
{0.8600, 5.00, 873.3},
{0.8700, 5.00, 872.1},
{0.8800, 5.00, 871.0},
{0.8900, 5.00, 869.9},
{0.9000, 5.00, 868.8},
{0.9100, 5.00, 867.8},
{0.9200, 5.00, 866.7},
{0.9300, 5.00, 865.7},
{0.9400, 5.00, 864.7},
{0.9500, 5.00, 863.7},
{0.9600, 5.00, 862.8},
{0.9700, 5.00, 861.8},
{0.9800, 5.00, 860.9},
{0.9900, 5.00, 860.0},
{1.0000, 5.00, 859.1}};

(*------------------------------*)
(*  liq cd g sill (sp)  *) 

u69={{0.8275, 5.00, 874.8},
{0.8300, 5.00, 874.7},
{0.8325, 5.00, 874.7},
{0.8350, 5.00, 874.6},
{0.8375, 5.00, 874.5},
{0.8400, 5.00, 874.5},
{0.8425, 5.00, 874.4},
{0.8450, 5.00, 874.4},
{0.8475, 5.00, 874.3},
{0.8500, 5.00, 874.2}};

(*------------------------------*)
(*  liq ksp cd g (opx)  *) 

u70={{0.6150, 5.00, 608.2},
{0.6200, 5.00, 675.9},
{0.6250, 5.00, 745.9},
{0.6300, 5.00, 787.3},
{0.6350, 5.00, 814.4},
{0.6400, 5.00, 834.2},
{0.6410, 5.00, 837.6},
{0.6420, 5.00, 840.8},
{0.6430, 5.00, 843.9},
{0.6440, 5.00, 846.8},
{0.6450, 5.00, 849.6},
{0.6460, 5.00, 852.4},
{0.6470, 5.00, 855.0},
{0.6480, 5.00, 857.5}};

(*------------------------------*)
(*  liq cd g (ksp)  *) 

u71={{0.6000, 5.00, 859.2},
{0.6200, 5.00, 858.7},
{0.6400, 5.00, 858.2},
{0.6600, 5.00, 857.6},
{0.6800, 5.00, 857.0},
{0.7000, 5.00, 856.4},
{0.7200, 5.00, 855.7},
{0.7400, 5.00, 854.9},
{0.7600, 5.00, 854.1},
{0.7800, 5.00, 853.2},
{0.8000, 5.00, 852.3},
{0.8200, 5.00, 851.2},
{0.8400, 5.00, 850.0},
{0.8600, 5.00, 848.7}};

(*------------------------------*)
(*  liq cd g (sill)  *) 

u72={{0.7500, 5.00, 791.5},
{0.7550, 5.00, 797.4},
{0.7600, 5.00, 803.2},
{0.7650, 5.00, 809.0},
{0.7700, 5.00, 814.6},
{0.7750, 5.00, 820.2},
{0.7800, 5.00, 825.8},
{0.7850, 5.00, 831.3},
{0.7900, 5.00, 836.7},
{0.7950, 5.00, 842.0},
{0.8000, 5.00, 847.3},
{0.8050, 5.00, 852.6},
{0.8100, 5.00, 857.7},
{0.8150, 5.00, 862.8},
{0.8200, 5.00, 867.9},
{0.8250, 5.00, 872.9},
{0.8300, 5.00, 877.8},
{0.8350, 5.00, 882.7},
{0.8400, 5.00, 887.6},
{0.8450, 5.00, 892.4},
{0.8500, 5.00, 897.1}};

(*------------------------------*)
(*  liq cd g (opx)  *) 

u73={{0.6000, 5.00, 746.8},
{0.6200, 5.00, 800.0},
{0.6400, 5.00, 842.6},
{0.6600, 5.00, 878.6},
{0.6800, 5.00, 909.7},
{0.7000, 5.00, 936.7},
{0.7200, 5.00, 960.0},
{0.7400, 5.00, 980.0}};

(*------------------------------*)
(*  liq cd g sp (sill)  *) 

u74={{0.8270, 5.00, 874.8},
{0.8280, 5.00, 874.8},
{0.8290, 5.00, 874.8},
{0.8300, 5.00, 874.8},
{0.8310, 5.00, 874.8},
{0.8320, 5.00, 874.8},
{0.8330, 5.00, 874.7},
{0.8340, 5.00, 874.7},
{0.8350, 5.00, 874.7},
{0.8360, 5.00, 874.7},
{0.8370, 5.00, 874.7},
{0.8380, 5.00, 874.7},
{0.8390, 5.00, 874.7},
{0.8400, 5.00, 874.7},
{0.8450, 5.00, 874.6},
{0.8500, 5.00, 874.6}};

(*------------------------------*)
(*  liq g sp (sill)  *) 

u75={{0.7000, 5.00, 895.3},
{0.7100, 5.00, 893.8},
{0.7200, 5.00, 892.3},
{0.7300, 5.00, 890.8},
{0.7400, 5.00, 889.3},
{0.7500, 5.00, 887.9},
{0.7600, 5.00, 886.5},
{0.7700, 5.00, 885.1},
{0.7800, 5.00, 883.8},
{0.7900, 5.00, 882.4},
{0.8000, 5.00, 881.1},
{0.8100, 5.00, 879.8},
{0.8200, 5.00, 878.6},
{0.8300, 5.00, 877.4},
{0.8400, 5.00, 876.1},
{0.8500, 5.00, 875.0},
{0.8600, 5.00, 873.8},
{0.8700, 5.00, 872.7},
{0.8800, 5.00, 871.5},
{0.8900, 5.00, 870.4},
{0.9000, 5.00, 869.4},
{0.9100, 5.00, 868.3},
{0.9200, 5.00, 867.3},
{0.9300, 5.00, 866.3},
{0.9400, 5.00, 865.3},
{0.9500, 5.00, 864.3},
{0.9600, 5.00, 863.3},
{0.9700, 5.00, 862.4},
{0.9800, 5.00, 861.5},
{0.9900, 5.00, 860.6},
{1.0000, 5.00, 859.7}};

(*------------------------------*)
(*  liq g sp (cd)  *) 

u77={{0.8420, 5.00, 957.6},
{0.8440, 5.00, 932.4},
{0.8460, 5.00, 918.5},
{0.8480, 5.00, 906.3},
{0.8500, 5.00, 894.9},
{0.8540, 5.00, 872.9},
{0.8560, 5.00, 861.9},
{0.8580, 5.00, 850.7},
{0.8600, 5.00, 839.2},
{0.8640, 5.00, 815.1},
{0.8660, 5.00, 802.4},
{0.8680, 5.00, 789.1},
{0.8700, 5.00, 775.1},
{0.8720, 5.00, 760.4},
{0.8740, 5.00, 744.9},
{0.8760, 5.00, 728.6},
{0.8780, 5.00, 711.3},
{0.8800, 5.00, 692.8}};

(*------------------------------*)
(*  liq cd g (sp)  *) 

u78={{0.8000, 5.00, 743.4},
{0.8030, 5.00, 756.6},
{0.8060, 5.00, 770.0},
{0.8090, 5.00, 783.4},
{0.8120, 5.00, 797.1},
{0.8150, 5.00, 811.2},
{0.8180, 5.00, 825.7},
{0.8210, 5.00, 840.9},
{0.8240, 5.00, 857.2},
{0.8270, 5.00, 875.3},
{0.8300, 5.00, 896.9},
{0.8330, 5.00, 929.5},
{0.8331, 5.00, 931.2},
{0.8332, 5.00, 933.0},
{0.8333, 5.00, 935.0},
{0.8334, 5.00, 937.1},
{0.8335, 5.00, 939.4},
{0.8336, 5.00, 942.1},
{0.8337, 5.00, 945.3},
{0.8338, 5.00, 949.5},
{0.8339, 5.00, 957.7}};

(*------------------------------*)
(*  liq cd g opx (ksp)  *) 

u79={{0.5200, 5.00, 863.2},
{0.5400, 5.00, 862.5},
{0.5600, 5.00, 861.8},
{0.5800, 5.00, 861.0},
{0.6000, 5.00, 860.2}};

(*------------------------------*)
(*  liq cd opx (g)  *) 

u80={{0.4000, 5.00, 786.7},
{0.4200, 5.00, 802.3},
{0.4400, 5.00, 817.7},
{0.4600, 5.00, 833.0},
{0.4800, 5.00, 847.8},
{0.5000, 5.00, 862.1},
{0.5200, 5.00, 875.9},
{0.5400, 5.00, 889.0},
{0.5600, 5.00, 901.4},
{0.5800, 5.00, 913.1},
{0.6000, 5.00, 924.1},
{0.6200, 5.00, 934.5},
{0.6400, 5.00, 944.2},
{0.6600, 5.00, 953.3},
{0.6800, 5.00, 961.8},
{0.7000, 5.00, 969.8},
{0.7200, 5.00, 977.3},
{0.7400, 5.00, 984.2}};










\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["lines data (81-> )", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->GrayLevel[0]],

Cell["\<\
(*------------------------------*)
(*  liq ksp cd opx (g)  *) 

u81={{0.4000, 5.00, 782.1},
{0.4100, 5.00, 789.7},
{0.4200, 5.00, 797.6},
{0.4300, 5.00, 805.5},
{0.4400, 5.00, 813.6},
{0.4500, 5.00, 821.7},
{0.4600, 5.00, 829.9},
{0.4700, 5.00, 838.1},
{0.4800, 5.00, 846.2},
{0.4900, 5.00, 854.2}};

(*------------------------------*)
(*  liq cd opx (ksp)  *) 

u82={{0.0000, 5.00, 869.7},
{0.0200, 5.00, 869.6},
{0.0400, 5.00, 869.5},
{0.0600, 5.00, 869.3},
{0.0800, 5.00, 869.2},
{0.1000, 5.00, 869.0},
{0.1200, 5.00, 868.8},
{0.1400, 5.00, 868.6},
{0.1600, 5.00, 868.5},
{0.1800, 5.00, 868.3},
{0.2000, 5.00, 868.1},
{0.2200, 5.00, 867.8},
{0.2400, 5.00, 867.6},
{0.2600, 5.00, 867.4},
{0.2800, 5.00, 867.1},
{0.3000, 5.00, 866.9},
{0.3200, 5.00, 866.6},
{0.3400, 5.00, 866.4},
{0.3600, 5.00, 866.1},
{0.3800, 5.00, 865.8},
{0.4000, 5.00, 865.5},
{0.4200, 5.00, 865.2},
{0.4400, 5.00, 864.9},
{0.4600, 5.00, 864.5},
{0.4800, 5.00, 864.2},
{0.5000, 5.00, 863.9},
{0.5200, 5.00, 863.5},
{0.5400, 5.00, 863.1},
{0.5600, 5.00, 862.8},
{0.5800, 5.00, 862.4},
{0.6000, 5.00, 862.0}};

(*------------------------------*)
(*  liq ksp bi cd g opx (pl)  *) 

u83={{0.4272, 5.00, 808.8},
{0.4275, 5.00, 808.4},
{0.4277, 5.00, 808.1},
{0.4280, 5.00, 807.8},
{0.4282, 5.00, 807.6},
{0.4285, 5.00, 807.4},
{0.4287, 5.00, 807.2},
{0.4290, 5.00, 807.0},
{0.4293, 5.00, 806.8},
{0.4295, 5.00, 806.7},
{0.4297, 5.00, 806.5},
{0.4300, 5.00, 806.4},
{0.4302, 5.00, 806.2},
{0.4305, 5.00, 806.1},
{0.4307, 5.00, 806.0},
{0.4310, 5.00, 805.8},
{0.4313, 5.00, 805.7},
{0.4315, 5.00, 805.6},
{0.4317, 5.00, 805.5},
{0.4320, 5.00, 805.4},
{0.4322, 5.00, 805.3}};

(*------------------------------*)
(*  liq ksp pl bi cd opx (g)  *) 

u84={{0.3800, 5.00, 804.9},
{0.3850, 5.00, 805.5},
{0.3900, 5.00, 806.2},
{0.3950, 5.00, 806.7},
{0.4000, 5.00, 807.3},
{0.4050, 5.00, 807.8},
{0.4100, 5.00, 808.3},
{0.4150, 5.00, 808.8},
{0.4200, 5.00, 809.2},
{0.4250, 5.00, 809.6}};

(*------------------------------*)
(*  liq ksp bi cd opx (pl)  *) 

u85={{0.0000, 5.00, 839.8},
{0.0200, 5.00, 839.0},
{0.0400, 5.00, 838.2},
{0.0600, 5.00, 837.4},
{0.0800, 5.00, 836.4},
{0.1000, 5.00, 835.4},
{0.1200, 5.00, 834.3},
{0.1400, 5.00, 833.1},
{0.1600, 5.00, 831.8},
{0.1800, 5.00, 830.5},
{0.2000, 5.00, 829.0},
{0.2200, 5.00, 827.6},
{0.2400, 5.00, 826.0},
{0.2600, 5.00, 824.4},
{0.2800, 5.00, 822.8},
{0.3000, 5.00, 821.1},
{0.3200, 5.00, 819.4},
{0.3400, 5.00, 817.6},
{0.3600, 5.00, 815.8},
{0.3800, 5.00, 814.1},
{0.4000, 5.00, 812.3},
{0.4200, 5.00, 810.4},
{0.4400, 5.00, 808.6},
{0.4600, 5.00, 806.8},
{0.4800, 5.00, 805.0}};

(*------------------------------*)
(*  liq ksp cd opx (bi)  *) 

u86={{0.0000, 5.00, 844.4},
{0.0200, 5.00, 843.6},
{0.0400, 5.00, 842.8},
{0.0600, 5.00, 841.9},
{0.0800, 5.00, 841.0},
{0.1000, 5.00, 839.9},
{0.1200, 5.00, 838.8},
{0.1400, 5.00, 837.6},
{0.1600, 5.00, 836.3},
{0.1800, 5.00, 834.9},
{0.2000, 5.00, 833.4},
{0.2200, 5.00, 831.9},
{0.2400, 5.00, 830.2},
{0.2600, 5.00, 828.5},
{0.2800, 5.00, 826.7},
{0.3000, 5.00, 824.8},
{0.3200, 5.00, 822.8},
{0.3400, 5.00, 820.8},
{0.3600, 5.00, 818.6},
{0.3800, 5.00, 816.4},
{0.4000, 5.00, 814.2},
{0.4200, 5.00, 811.9},
{0.4400, 5.00, 809.6},
{0.4600, 5.00, 807.3},
{0.4800, 5.00, 805.0},
{0.5000, 5.00, 802.7}};

(*------------------------------*)
(*  liq cd (opx)  *) 

u88={{0.6400, 5.00, 1040.1},
{0.6600, 5.00, 1023.1},
{0.6800, 5.00, 1011.2},
{0.7000, 5.00, 1002.0},
{0.7200, 5.00, 994.7},
{0.7400, 5.00, 988.7},
{0.7600, 5.00, 983.9},
{0.7800, 5.00, 980.0},
{0.8000, 5.00, 977.0}};

(*------------------------------*)
(*  liq cd (g)  *) 

u89={{0.6000, 5.00, 964.6},
{0.6200, 5.00, 967.4},
{0.6400, 5.00, 970.2},
{0.6600, 5.00, 973.1},
{0.6800, 5.00, 976.1},
{0.7000, 5.00, 979.2},
{0.7200, 5.00, 982.3},
{0.7400, 5.00, 985.5},
{0.7600, 5.00, 988.8},
{0.7800, 5.00, 992.1},
{0.8000, 5.00, 995.4},
{0.8200, 5.00, 998.8},
{0.8400, 5.00, 1002.2},
{0.8600, 5.00, 1005.6}};

(*------------------------------*)
(*  liq g (cd)  *) 

u90={{0.8480, 5.00, 973.9},
{0.8485, 5.00, 977.3},
{0.8490, 5.00, 980.0},
{0.8495, 5.00, 982.1},
{0.8500, 5.00, 984.1},
{0.8505, 5.00, 985.8},
{0.8510, 5.00, 987.3},
{0.8515, 5.00, 988.8},
{0.8520, 5.00, 990.1},
{0.8525, 5.00, 991.4},
{0.8530, 5.00, 992.6},
{0.8535, 5.00, 993.7},
{0.8540, 5.00, 994.8},
{0.8545, 5.00, 995.9},
{0.8550, 5.00, 996.9},
{0.8555, 5.00, 997.9},
{0.8560, 5.00, 998.8},
{0.8565, 5.00, 999.7},
{0.8570, 5.00, 1000.6},
{0.8575, 5.00, 1001.4},
{0.8580, 5.00, 1002.2},
{0.8585, 5.00, 1003.0},
{0.8590, 5.00, 1003.8},
{0.8595, 5.00, 1004.6},
{0.8600, 5.00, 1005.3}};

(*------------------------------*)
(*  liq g (sp)  *) 

u91={{0.8000, 5.00, 972.6},
{0.8020, 5.00, 980.5},
{0.8040, 5.00, 1001.1},
{0.8060, 5.00, 1009.9}};

(*------------------------------*)
(*  liq cd sp (g)  *) 

u92={{0.8335, 5.00, 1001.0},
{0.8340, 5.00, 1001.0},
{0.8345, 5.00, 1001.0},
{0.8350, 5.00, 1001.0},
{0.8355, 5.00, 1001.0},
{0.8360, 5.00, 1001.0},
{0.8365, 5.00, 1001.0},
{0.8370, 5.00, 1000.9},
{0.8375, 5.00, 1000.9},
{0.8380, 5.00, 1000.9},
{0.8385, 5.00, 1000.9},
{0.8390, 5.00, 1000.9},
{0.8395, 5.00, 1000.9},
{0.8400, 5.00, 1000.9},
{0.8405, 5.00, 1000.9},
{0.8410, 5.00, 1000.9},
{0.8415, 5.00, 1000.8},
{0.8420, 5.00, 1000.8},
{0.8425, 5.00, 1000.8},
{0.8430, 5.00, 1000.8},
{0.8435, 5.00, 1000.8},
{0.8440, 5.00, 1000.8},
{0.8445, 5.00, 1000.8},
{0.8450, 5.00, 1000.8},
{0.8455, 5.00, 1000.8},
{0.8460, 5.00, 1000.7},
{0.8465, 5.00, 1000.7},
{0.8470, 5.00, 1000.7},
{0.8475, 5.00, 1000.7},
{0.8480, 5.00, 1000.7},
{0.8485, 5.00, 1000.7},
{0.8490, 5.00, 1000.7},
{0.8495, 5.00, 1000.7},
{0.8500, 5.00, 1000.7},
{0.8505, 5.00, 1000.6},
{0.8510, 5.00, 1000.6}};

(*------------------------------*)
(*  liq sp (g)  *) 

u93={{0.8400, 5.00, 1002.7},
{0.8500, 5.00, 1000.8},
{0.8600, 5.00, 999.1},
{0.8700, 5.00, 997.6},
{0.8800, 5.00, 996.2},
{0.8900, 5.00, 994.9},
{0.9000, 5.00, 993.9},
{0.9100, 5.00, 992.9},
{0.9200, 5.00, 992.2},
{0.9300, 5.00, 991.5},
{0.9400, 5.00, 991.1},
{0.9500, 5.00, 990.8},
{0.9600, 5.00, 990.8},
{0.9700, 5.00, 991.0},
{0.9800, 5.00, 991.4},
{0.9900, 5.00, 992.3},
{1.0000, 5.00, 993.2}};







\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["draw function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawing",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n  (tlow = 0; thigh = 1000; hlow = 0; hhigh = 1;\n   xycols = \
{1,3};\n   \n  \n  \t\n  \tlu1 = makeline[u1, i1, i2];\n  \tlu2 = \
makeline[u2, i6, i4];\n  \tlu3 = makeline[u3, ll, i1];\n  \tlu4 = \
makeline[u4, ll, i2];\n  \tlu5 = makeline[u5, i3, i2];\n  \tlu6 = \
makeline[u6, ll, i3];\n  \tlu7 = makeline[u7, lr, i3];\n  \tlu8 = \
makeline[u8, i4, i5];\n  \tlu9 = connect[i4, i2];\n  \tlu10 = connect[i3, \
i5];\n  \tlu11 = makeline[u11, lr, i5];\n  \tlu12 = makeline[u12, i11, i5];\n \
 \tlu13 = makeline[u13, i9, i4];\n  \tlu14 = makeline[u14, i7, i6];\n  \tlu15 \
= makeline[u15, i7, i9];\n  \tlu16 = makeline[u16, ll, i8];\n  \tlu17 = \
makeline[u17, i8, ll];\n  \tlu18 = connect[i12, i6];\n  \tlu19 = connect[i8, \
i1];\n  \tlu20 = connect[i1, i6];\n  \tlu21 = makeline[u21, i13, i20];\n  \t\
lu22 = makeline[u22, i13, i10];\n  \tlu23 = makeline[u23, i20, i10];\n  \t\
lu24 = makeline[u24, i11, lr];\n  \tlu25 = makeline[u25, ll, i12];\n  \tlu26 \
= makeline[u26, i14, i12];\n  \tlu27 = connect[i8, i12];\n  \tlu28 = \
makeline[u28, ll, i14];\n  \tlu29 = makeline[u29, ll, i15];\n  \tlu30 = \
makeline[u30, i15, i22];\n  \tlu31 = connect[i14, i7];\n  \tlu32 = \
connect[i13, i7];\n  \tlu33 = connect[i13, i15];\n  \tlu34 = connect[i14, \
i15];\n  \tlu35 = makeline[u35, i21, i16];\n  \tlu36 = makeline[u36, i16, \
i18];\n  \tlu37 = makeline[u37, i16, i17];\n  \tlu38 = makeline[u38, i11, \
i17];\n  \tlu39 = makeline[u39, i17, i19];\n  \tlu40 = makeline[u40, i17, \
lr];\n  \tlu41 = makeline[u41, i10, i16];\n  \tlu42 = makeline[u42, i9, i11];\
\n  \tlu43 = connect[i9, i10];\n  \tlu44 = makeline[u44, i19, lr];\n  \tlu45 \
= makeline[u45, i19, i18];\n  \tlu46 = makeline[u46, i24, i18];\n  \tlu47 = \
makeline[u47, i18, lr];\n  \tlu48 = makeline[u48, i19, lr];\n  \tlu49 = \
makeline[u49, i20, i21];\n  \tlu50 = makeline[u50, i20, i22];\n  \tlu51 = \
makeline[u51, i21, i24];\n  \tlu52 = makeline[u52, i23, i25];\n  \tlu53 = \
makeline[u53, i23, i27];\n  \tlu54 = makeline[u54, i28, i22];\n  \tlu55 = \
makeline[u55, i21, i23];\n  \tlu56 = makeline[u56, i22, i23];\n  \tlu57 = \
makeline[u57, i25, i24];\n  \tlu58 = makeline[u58, i29, i24];\n  \tlu59 = \
makeline[u59, i25, i31];\n  \tlu60 = makeline[u60, i26, i25];\n  \tlu61 = \
makeline[u61, i27, i26];\n  \tlu62 = makeline[u62, i27, i28];\n  \tlu63 = \
makeline[u63, ul, i28];\n  \tlu64 = makeline[u64, i37, i26];\n  \tlu65 = \
makeline[u65, i29, ur];\n  \tlu66 = makeline[u66, i31, i29];\n  \tlu67 = \
makeline[u67, i29, i30];\n  \tlu68 = makeline[u68, i30, lr];\n  \tlu69 = \
makeline[u69, i33, i30];\n  \tlu70 = makeline[u70, i32, i26];\n  \tlu71 = \
makeline[u71, i32, i31];\n  \tlu72 = makeline[u72, i33, i31];\n  \tlu73 = \
makeline[u73, i38, i32];\n  \tlu74 = makeline[u74, i33, i34];\n  \tlu75 = \
makeline[u75, i34, lr];\n  \tlu76 = connect[i30, i34];\n  \tlu77 = \
makeline[u77, i34, i40];\n  \tlu78 = makeline[u78, i33, i39];\n  \tlu79 = \
makeline[u79, i32, i35];\n  \tlu80 = makeline[u80, i35, i38];\n  \tlu81 = \
makeline[u81, i37, i35];\n  \tlu82 = makeline[u82, ul, i35];\n  \tlu83 = \
makeline[u83, i36, i27];\n  \tlu84 = makeline[u84, i28, i36];\n  \tlu85 = \
makeline[u85, ul, i36];\n  \tlu86 = makeline[u86, ul, i37];\n  \tlu87 = \
connect[i36, i37];\n  \tlu88 = makeline[u88, ul, i38];\n  \tlu89 = \
makeline[u89, i39, i38];\n  \n  \tlu92 = makeline[u92, i39, i40];\n  \tlu93 = \
makeline[u93, i40, lr];\n  \t\n  \t\n  \t\n  \n  \t\n  \n  \t\n      \t\t\n   \
     \t\t\n  Show[Graphics[\n         {GrayLevel[0.85],\n          \
area[{lu85, lu84, lu63}],\n          area[{lu64, lu87, lu83, lu61}],\n        \
  area[{lu62, lu54, lu56, lu53}],\n          area[{lu52, lu55, lu51, lu57}],\n\
          area[{lu29, lu34, lu28}],\n          area[{lu25, lu27, lu17}],\n    \
      area[{lu30, lu33, lu21, lu50}],\n          area[{lu23, lu41, lu35, \
lu49}],\n          area[{lu25, lu27, lu17}],\n          area[{lu31, lu26, \
lu18, lu14}],\n          area[{lu16, lu19, lu3}],\n          area[{lu22, \
lu32, lu15, lu43}],\n          area[{lu2, lu20, lu1, lu9}],\n          \
area[{lu4, lu5, lu6}],\n          area[{lu42, lu13, lu8, lu12}],\n          \
area[{lu24, lu38, lu40}],\n          area[{lu36, lu37, lu39, lu45}],\n        \
  area[{lu7, lu10, lu11}],\n          \n         \n          GrayLevel[0.65],\
\n          area[{lu74, lu69, lu76}],\n          area[{lu79, lu81, lu64, \
lu70}],\n          area[{lu66, lu59, lu57, lu58}],\n          area[{lu86, \
lu87, lu85}],\n          area[{lu63, lu54, lu30, lu29}],\n          \
area[{lu61, lu53, lu52, lu60}],\n          area[{lu51, lu35, lu36, lu46}],\n  \
        area[{lu21, lu22, lu23}],\n          area[{lu28, lu26, lu25}],\n      \
    area[{lu17, lu16}],\n          area[{lu15, lu14, lu2, lu13}],\n          \
area[{lu3, lu1, lu4}],\n          area[{lu44, lu39, lu40}],\n          \
area[{lu47, lu45, lu48}],\n          area[{lu24, lu12, lu11}],\n          \
area[{lu7, lu6}],\n          \n         \n          GrayLevel[0.35],\n        \
  area[{lu80, lu79, lu73}],\n          area[{lu78, lu74, lu77}],\n          \
area[{lu75, lu76, lu68}],\n          area[{lu66, lu67, lu69, lu72}], \n       \
   area[{lu82, lu81, lu86}],\n          area[{lu71, lu70, lu60, lu59}],\n     \
     area[{lu65, lu58, lu46, lu47}], \n          area[{lu48, lu44}], \n       \
   \n         \n          \n          GrayLevel[0.15],\n          area[{lu82, \
lu80, lu88}],\n          area[{lu89, lu73, lu71, lu72, lu78}], \n          \
area[{lu93, lu77, lu75}],\n          area[{lu68, lu67, lu65}],\n          \n  \
        \n          \n         \n         \n          \n          GrayLevel[0]\
,\n          area[{lu88, lu89}],\n          area[{lu93}], \n   \n          \
AbsoluteThickness[0.3],\n          drawline[lu1],\n          drawline[lu2],\n \
         drawline[lu3],\n          drawline[lu4],\n          \n          \
drawline[lu5],\n          drawline[lu6],\n          drawline[lu7],\n          \
drawline[lu8],\n          drawline[lu9],\n          drawline[lu10],\n         \
 drawline[lu11],\n          drawline[lu12],\n          drawline[lu13],\n      \
    drawline[lu14],\n          drawline[lu15],\n          drawline[lu16],\n   \
       drawline[lu17],\n          drawline[lu18],\n          drawline[lu19],\n\
          drawline[lu20],\n          drawline[lu21],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu22],\n          drawline[lu23],\n          \
drawline[lu24],\n          drawline[lu25],\n          drawline[lu26],\n       \
   drawline[lu27],\n          drawline[lu28],\n          drawline[lu29],\n    \
      drawline[lu30],\n          drawline[lu31],\n          drawline[lu32],\n \
         drawline[lu33],\n          drawline[lu34],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["drawline[lu35],\n          drawline[lu36],\n          \
drawline[lu37],\n          drawline[lu38],\n          drawline[lu39],\n       \
   drawline[lu40],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu41],\n          drawline[lu42],\n          \
drawline[lu43],\n          drawline[lu44],\n          drawline[lu45],\n       \
   drawline[lu46],\n          drawline[lu47],\n          drawline[lu48],\n    \
      ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu49],\n          drawline[lu50],\n          \
drawline[lu51],\n          drawline[lu52],\n          drawline[lu53],\n       \
   drawline[lu54],\n          drawline[lu55],\n          drawline[lu56],\n    \
      drawline[lu57],\n          drawline[lu58],\n          drawline[lu59],\n \
         ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu60],\n          drawline[lu61],\n          \
drawline[lu62],\n          drawline[lu63],\n          drawline[lu64],\n       \
   drawline[lu65],\n          drawline[lu66],\n          drawline[lu67],\n    \
      drawline[lu68],\n          drawline[lu69],\n          drawline[lu70],\n \
         drawline[lu71],\n          drawline[lu72],\n          ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["drawline[lu73],\n          drawline[lu74],\n          \
drawline[lu75],\n          drawline[lu76],\n          drawline[lu77],\n       \
   drawline[lu78],\n          drawline[lu79],\n          drawline[lu80],\n    \
      drawline[lu81],\n          drawline[lu82],\n          drawline[lu83],\n \
         drawline[lu84],\n          drawline[lu85],\n          \
drawline[lu86],\n          drawline[lu87],\n          drawline[lu88],\n       \
   drawline[lu89],\n         ",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["drawline[lu92],\n          drawline[lu93],\n          \n          \
",
    FontWeight->"Plain"],
  StyleBox["\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n         \n          \n          \n         \n         \n       \
   \n         \n          \n          AbsoluteThickness[0.5], \n         \n   \
       \n          \n          \n           \n          \n          \n        \
  ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[0,1,0],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["\n          \n          ",
    FontWeight->"Plain"],
  StyleBox["RGBColor[1,0,0],\n          ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["RGBColor[0,0,1],",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n           outline}],\n        \t\t",
    FontWeight->"Plain"],
  StyleBox["\n           \n           \n           \n           ",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n          \n               \n         AspectRatio -> 1, Frame \
-> True,\n         PlotRange -> {{xlow, xhigh}, {ylow, yhigh}} ]);",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["drawing", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
xlow = 0; xhigh = 1; ylow = 630; yhigh =1000;
drawing;
\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 -1.7027 0.0027027 [
[(0.2)] .2 0 0 2 Msboxa
[(0.4)] .4 0 0 2 Msboxa
[(0.6)] .6 0 0 2 Msboxa
[(0.8)] .8 0 0 2 Msboxa
[(1)] 1 0 0 2 Msboxa
[(650)] -0.0125 .05405 1 0 Msboxa
[(700)] -0.0125 .18919 1 0 Msboxa
[(750)] -0.0125 .32432 1 0 Msboxa
[(800)] -0.0125 .45946 1 0 Msboxa
[(850)] -0.0125 .59459 1 0 Msboxa
[(900)] -0.0125 .72973 1 0 Msboxa
[(950)] -0.0125 .86486 1 0 Msboxa
[(1000)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(0.2)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(0.4)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(0.6)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(0.8)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(1)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .05405 m
.00625 .05405 L
s
P
[(650)] -0.0125 .05405 1 0 Mshowa
p
.002 w
0 .18919 m
.00625 .18919 L
s
P
[(700)] -0.0125 .18919 1 0 Mshowa
p
.002 w
0 .32432 m
.00625 .32432 L
s
P
[(750)] -0.0125 .32432 1 0 Mshowa
p
.002 w
0 .45946 m
.00625 .45946 L
s
P
[(800)] -0.0125 .45946 1 0 Mshowa
p
.002 w
0 .59459 m
.00625 .59459 L
s
P
[(850)] -0.0125 .59459 1 0 Mshowa
p
.002 w
0 .72973 m
.00625 .72973 L
s
P
[(900)] -0.0125 .72973 1 0 Mshowa
p
.002 w
0 .86486 m
.00625 .86486 L
s
P
[(950)] -0.0125 .86486 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(1000)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .08108 m
.00375 .08108 L
s
P
p
.001 w
0 .10811 m
.00375 .10811 L
s
P
p
.001 w
0 .13514 m
.00375 .13514 L
s
P
p
.001 w
0 .16216 m
.00375 .16216 L
s
P
p
.001 w
0 .21622 m
.00375 .21622 L
s
P
p
.001 w
0 .24324 m
.00375 .24324 L
s
P
p
.001 w
0 .27027 m
.00375 .27027 L
s
P
p
.001 w
0 .2973 m
.00375 .2973 L
s
P
p
.001 w
0 .35135 m
.00375 .35135 L
s
P
p
.001 w
0 .37838 m
.00375 .37838 L
s
P
p
.001 w
0 .40541 m
.00375 .40541 L
s
P
p
.001 w
0 .43243 m
.00375 .43243 L
s
P
p
.001 w
0 .48649 m
.00375 .48649 L
s
P
p
.001 w
0 .51351 m
.00375 .51351 L
s
P
p
.001 w
0 .54054 m
.00375 .54054 L
s
P
p
.001 w
0 .56757 m
.00375 .56757 L
s
P
p
.001 w
0 .62162 m
.00375 .62162 L
s
P
p
.001 w
0 .64865 m
.00375 .64865 L
s
P
p
.001 w
0 .67568 m
.00375 .67568 L
s
P
p
.001 w
0 .7027 m
.00375 .7027 L
s
P
p
.001 w
0 .75676 m
.00375 .75676 L
s
P
p
.001 w
0 .78378 m
.00375 .78378 L
s
P
p
.001 w
0 .81081 m
.00375 .81081 L
s
P
p
.001 w
0 .83784 m
.00375 .83784 L
s
P
p
.001 w
0 .89189 m
.00375 .89189 L
s
P
p
.001 w
0 .91892 m
.00375 .91892 L
s
P
p
.001 w
0 .94595 m
.00375 .94595 L
s
P
p
.001 w
0 .97297 m
.00375 .97297 L
s
P
p
.001 w
0 .02703 m
.00375 .02703 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.2 .99375 m
.2 1 L
s
P
p
.002 w
.4 .99375 m
.4 1 L
s
P
p
.002 w
.6 .99375 m
.6 1 L
s
P
p
.002 w
.8 .99375 m
.8 1 L
s
P
p
.001 w
.04 .99625 m
.04 1 L
s
P
p
.001 w
.08 .99625 m
.08 1 L
s
P
p
.001 w
.12 .99625 m
.12 1 L
s
P
p
.001 w
.16 .99625 m
.16 1 L
s
P
p
.001 w
.24 .99625 m
.24 1 L
s
P
p
.001 w
.28 .99625 m
.28 1 L
s
P
p
.001 w
.32 .99625 m
.32 1 L
s
P
p
.001 w
.36 .99625 m
.36 1 L
s
P
p
.001 w
.44 .99625 m
.44 1 L
s
P
p
.001 w
.48 .99625 m
.48 1 L
s
P
p
.001 w
.52 .99625 m
.52 1 L
s
P
p
.001 w
.56 .99625 m
.56 1 L
s
P
p
.001 w
.64 .99625 m
.64 1 L
s
P
p
.001 w
.68 .99625 m
.68 1 L
s
P
p
.001 w
.72 .99625 m
.72 1 L
s
P
p
.001 w
.76 .99625 m
.76 1 L
s
P
p
.001 w
.84 .99625 m
.84 1 L
s
P
p
.001 w
.88 .99625 m
.88 1 L
s
P
p
.001 w
.92 .99625 m
.92 1 L
s
P
p
.001 w
.96 .99625 m
.96 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .05405 m
1 .05405 L
s
P
p
.002 w
.99375 .18919 m
1 .18919 L
s
P
p
.002 w
.99375 .32432 m
1 .32432 L
s
P
p
.002 w
.99375 .45946 m
1 .45946 L
s
P
p
.002 w
.99375 .59459 m
1 .59459 L
s
P
p
.002 w
.99375 .72973 m
1 .72973 L
s
P
p
.002 w
.99375 .86486 m
1 .86486 L
s
P
p
.001 w
.99625 .08108 m
1 .08108 L
s
P
p
.001 w
.99625 .10811 m
1 .10811 L
s
P
p
.001 w
.99625 .13514 m
1 .13514 L
s
P
p
.001 w
.99625 .16216 m
1 .16216 L
s
P
p
.001 w
.99625 .21622 m
1 .21622 L
s
P
p
.001 w
.99625 .24324 m
1 .24324 L
s
P
p
.001 w
.99625 .27027 m
1 .27027 L
s
P
p
.001 w
.99625 .2973 m
1 .2973 L
s
P
p
.001 w
.99625 .35135 m
1 .35135 L
s
P
p
.001 w
.99625 .37838 m
1 .37838 L
s
P
p
.001 w
.99625 .40541 m
1 .40541 L
s
P
p
.001 w
.99625 .43243 m
1 .43243 L
s
P
p
.001 w
.99625 .48649 m
1 .48649 L
s
P
p
.001 w
.99625 .51351 m
1 .51351 L
s
P
p
.001 w
.99625 .54054 m
1 .54054 L
s
P
p
.001 w
.99625 .56757 m
1 .56757 L
s
P
p
.001 w
.99625 .62162 m
1 .62162 L
s
P
p
.001 w
.99625 .64865 m
1 .64865 L
s
P
p
.001 w
.99625 .67568 m
1 .67568 L
s
P
p
.001 w
.99625 .7027 m
1 .7027 L
s
P
p
.001 w
.99625 .75676 m
1 .75676 L
s
P
p
.001 w
.99625 .78378 m
1 .78378 L
s
P
p
.001 w
.99625 .81081 m
1 .81081 L
s
P
p
.001 w
.99625 .83784 m
1 .83784 L
s
P
p
.001 w
.99625 .89189 m
1 .89189 L
s
P
p
.001 w
.99625 .91892 m
1 .91892 L
s
P
p
.001 w
.99625 .94595 m
1 .94595 L
s
P
p
.001 w
.99625 .97297 m
1 .97297 L
s
P
p
.001 w
.99625 .02703 m
1 .02703 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.85 g
0 .56703 m
.02024 .56484 L
.04048 .56265 L
.06071 .56045 L
.08095 .55771 L
.10119 .55497 L
.12143 .55194 L
.14167 .54863 L
.1619 .54508 L
.18214 .54147 L
.20238 .53739 L
.22262 .53351 L
.24286 .52911 L
.2631 .52474 L
.28333 .52033 L
.30357 .51567 L
.32381 .51098 L
.34405 .50603 L
.36429 .50117 L
.38452 .49651 L
.40476 .49126 L
.425 .48541 L
.425 .48541 L
.41253 .48259 L
.40005 .4792 L
.38758 .47533 L
.3751 .47108 L
.3751 .47108 L
.35536 .4771 L
.33562 .48331 L
.31587 .48967 L
.29613 .49585 L
.27639 .50218 L
.25665 .50802 L
.23691 .51391 L
.21716 .51971 L
.19742 .525 L
.17768 .53004 L
.15794 .53482 L
.13819 .5393 L
.11845 .54328 L
.09871 .54699 L
.07897 .55043 L
.05923 .55335 L
.03948 .55601 L
.01974 .55841 L
0 .56081 L
F
.6305 .48351 m
.61102 .48384 L
.59154 .48377 L
.57206 .48387 L
.55258 .48415 L
.5331 .48442 L
.51362 .48467 L
.49414 .48501 L
.47466 .48555 L
.45518 .48609 L
.4357 .48676 L
.4357 .48676 L
.425 .48541 L
.425 .48541 L
.4321 .47378 L
.4321 .47378 L
.45194 .47456 L
.47178 .47532 L
.49162 .47629 L
.51146 .47738 L
.5313 .47845 L
.55114 .47952 L
.57098 .48059 L
.59082 .48167 L
.61066 .48279 L
.6305 .48351 L
F
.4321 .47378 m
.41785 .47291 L
.4036 .47237 L
.38935 .47159 L
.3751 .47108 L
.3751 .47108 L
.39033 .45141 L
.40594 .43174 L
.42214 .41207 L
.43931 .3924 L
.45696 .37273 L
.47586 .35306 L
.49585 .33339 L
.51712 .31372 L
.545 .29405 L
.545 .29405 L
.5634 .29441 L
.5818 .29491 L
.6002 .29541 L
.6186 .29591 L
.637 .29649 L
.637 .29649 L
.61651 .31283 L
.59602 .32984 L
.57553 .34736 L
.55504 .36515 L
.53455 .38315 L
.51406 .40124 L
.49357 .41944 L
.47308 .43752 L
.45259 .45569 L
.4321 .47378 L
F
.7639 .31486 m
.74275 .31251 L
.7216 .30968 L
.70045 .30682 L
.6793 .30367 L
.65815 .30023 L
.637 .29649 L
.637 .29649 L
.65388 .29574 L
.67075 .29484 L
.68763 .29419 L
.7045 .29351 L
.7045 .29351 L
.72543 .29824 L
.74636 .30259 L
.76729 .30654 L
.78821 .31032 L
.80914 .31343 L
.83007 .31625 L
.851 .31892 L
.851 .31892 L
.82923 .31806 L
.80745 .31717 L
.78568 .31598 L
.7639 .31486 L
F
0 .12811 m
.02064 .13117 L
.04129 .13397 L
.06193 .13702 L
.08257 .13984 L
.10321 .14288 L
.12386 .14563 L
.1445 .14838 L
.1445 .14838 L
.1418 .13162 L
.1418 .13162 L
.12154 .12911 L
.10129 .12664 L
.08103 .12418 L
.06077 .12171 L
.04051 .11952 L
.02026 .11705 L
0 .1173 L
F
0 .07378 m
.02041 .07461 L
.04083 .07545 L
.06124 .07654 L
.08165 .07738 L
.10206 .07847 L
.12248 .07928 L
.14289 .08017 L
.1633 .08135 L
.1633 .08135 L
.16 .07676 L
.16 .07676 L
.14 .07622 L
.12 .07568 L
.1 .07541 L
.08 .07486 L
.06 .07432 L
.04 .07378 L
.02 .07351 L
0 .07324 L
F
.545 .29405 m
.52498 .28768 L
.50495 .28095 L
.48493 .27389 L
.4649 .26686 L
.44488 .25982 L
.42485 .25279 L
.40483 .24575 L
.3848 .23873 L
.36478 .23147 L
.34475 .22438 L
.32473 .21714 L
.3047 .20984 L
.28468 .20232 L
.26465 .19473 L
.24463 .18716 L
.2246 .17959 L
.20458 .17179 L
.18455 .16416 L
.16453 .15639 L
.1445 .14838 L
.1445 .14838 L
.1628 .14076 L
.1628 .14076 L
.18274 .14707 L
.20267 .15449 L
.22261 .16115 L
.24255 .16789 L
.26248 .17462 L
.28242 .18139 L
.30235 .18837 L
.32229 .1951 L
.34223 .20181 L
.36216 .20829 L
.3821 .21504 L
.40204 .22174 L
.42197 .22823 L
.44191 .23495 L
.46185 .24143 L
.48178 .24815 L
.50172 .25463 L
.52165 .26135 L
.54159 .26782 L
.56153 .27459 L
.58146 .28158 L
.6014 .28838 L
.6014 .28838 L
.5873 .29025 L
.5732 .29136 L
.5591 .29251 L
.545 .29405 L
F
.6014 .28838 m
.62129 .27684 L
.64118 .26583 L
.66108 .25482 L
.68097 .24408 L
.70086 .23361 L
.72075 .22339 L
.74065 .21319 L
.76054 .20324 L
.78043 .1933 L
.80032 .18363 L
.82022 .17395 L
.84011 .16454 L
.86 .15541 L
.86 .15541 L
.86925 .158 L
.8785 .15904 L
.88775 .15975 L
.897 .16054 L
.897 .16054 L
.87775 .17368 L
.8585 .1867 L
.83925 .19998 L
.82 .21324 L
.80075 .22651 L
.7815 .23978 L
.76225 .25304 L
.743 .26653 L
.72375 .28007 L
.7045 .29351 L
.7045 .29351 L
.68388 .29265 L
.66326 .29171 L
.64264 .29067 L
.62202 .28986 L
.6014 .28838 L
F
0 .07378 m
.02041 .07461 L
.04083 .07545 L
.06124 .07654 L
.08165 .07738 L
.10206 .07847 L
.12248 .07928 L
.14289 .08017 L
.1633 .08135 L
.1633 .08135 L
.16 .07676 L
.16 .07676 L
.14 .07622 L
.12 .07568 L
.1 .07541 L
.08 .07486 L
.06 .07432 L
.04 .07378 L
.02 .07351 L
0 .07324 L
F
.1531 .13189 m
.1418 .13162 L
.1418 .13162 L
.14911 .11905 L
.15502 .10649 L
.15969 .09392 L
.1633 .08135 L
.1633 .08135 L
.1758 .08216 L
.1758 .08216 L
.17221 .09459 L
.16734 .10703 L
.16094 .11946 L
.1531 .13189 L
F
.0973 0 m
.1 .00324 L
.12 .02757 L
.14 .05189 L
.16 .07676 L
.16 .07676 L
.1747 .08054 L
.1747 .08054 L
.15536 .05752 L
.13603 .03518 L
.11669 .01329 L
.10484 0 L
F
.86 .15541 m
.84008 .15514 L
.82016 .15487 L
.80024 .1546 L
.78032 .15433 L
.7604 .15406 L
.74048 .15379 L
.72056 .15352 L
.70064 .15325 L
.68072 .15298 L
.6608 .15271 L
.64088 .15244 L
.62096 .15218 L
.60104 .15165 L
.58112 .15136 L
.5612 .1511 L
.54128 .15083 L
.52136 .1503 L
.50144 .15002 L
.48152 .1495 L
.4616 .14896 L
.44168 .14867 L
.42176 .14816 L
.40184 .14762 L
.38192 .14708 L
.362 .14654 L
.34208 .146 L
.32216 .14546 L
.30224 .14493 L
.28232 .14414 L
.2624 .14357 L
.24248 .14304 L
.22256 .14251 L
.20264 .14172 L
.18272 .14114 L
.1628 .14076 L
.1628 .14076 L
.1531 .13189 L
.1531 .13189 L
.17301 .13268 L
.19292 .13333 L
.21283 .13386 L
.23273 .1344 L
.25264 .13492 L
.27255 .13565 L
.29246 .1363 L
.31237 .13682 L
.33227 .13736 L
.35218 .13788 L
.37209 .1386 L
.392 .13926 L
.41191 .13978 L
.43182 .14032 L
.45172 .14087 L
.47163 .14124 L
.49154 .14165 L
.51145 .1422 L
.53136 .14276 L
.55127 .14312 L
.57117 .14353 L
.59108 .1441 L
.61099 .14447 L
.6309 .14489 L
.65081 .1453 L
.67072 .14553 L
.69062 .14596 L
.71053 .14636 L
.73044 .14677 L
.75035 .14718 L
.77026 .14742 L
.79017 .14784 L
.81007 .14826 L
.82998 .14851 L
.84989 .1488 L
.8698 .14919 L
.8698 .14919 L
.86 .15541 L
F
.84 .08784 m
.81987 .08811 L
.79975 .08811 L
.77962 .08784 L
.75949 .08783 L
.73936 .08757 L
.71924 .08756 L
.69911 .0873 L
.67898 .08729 L
.65885 .08702 L
.63873 .08701 L
.6186 .08675 L
.59847 .08674 L
.57835 .08648 L
.55822 .08647 L
.53809 .08619 L
.51796 .08594 L
.49784 .08592 L
.47771 .08564 L
.45758 .0854 L
.43745 .08538 L
.41733 .0851 L
.3972 .08483 L
.37707 .08456 L
.35695 .08428 L
.33682 .08405 L
.31669 .08402 L
.29656 .08374 L
.27644 .08347 L
.25631 .08319 L
.23618 .08292 L
.21605 .08265 L
.19593 .08239 L
.1758 .08216 L
.1758 .08216 L
.1747 .08054 L
.1747 .08054 L
.19483 .08076 L
.21495 .08101 L
.23508 .0813 L
.25521 .08135 L
.27534 .08155 L
.29546 .08183 L
.31559 .0821 L
.33572 .08237 L
.35585 .08265 L
.37597 .08292 L
.3961 .0832 L
.41623 .08324 L
.43635 .08346 L
.45648 .08375 L
.47661 .08378 L
.49674 .084 L
.51686 .08429 L
.53699 .08432 L
.55712 .08455 L
.57725 .08484 L
.59737 .08486 L
.6175 .08511 L
.63763 .08513 L
.65775 .08538 L
.67788 .0854 L
.69801 .08565 L
.71814 .08567 L
.73826 .08593 L
.75839 .08594 L
.77852 .0862 L
.79865 .08621 L
.81877 .08647 L
.8389 .08649 L
.8389 .08649 L
.84 .08784 L
F
.7904 0 m
.79927 .01572 L
.81908 .05106 L
.8389 .08649 L
.8389 .08649 L
.84918 .08417 L
.85945 .082 L
.86973 .07998 L
.88 .07811 L
.88 .07811 L
.86 .02622 L
.84968 0 L
F
.908 .14459 m
.89845 .14668 L
.8889 .14774 L
.87935 .14897 L
.8698 .14919 L
.8698 .14919 L
.86209 .13385 L
.85476 .11851 L
.84761 .10318 L
.84 .08784 L
.84 .08784 L
.85 .08547 L
.86 .08324 L
.87 .08115 L
.88 .07919 L
.88 .07919 L
.88768 .09554 L
.89448 .11189 L
.90125 .12824 L
.908 .14459 L
F
1 .10081 m
.9816 .10976 L
.9632 .11849 L
.9448 .12741 L
.9264 .13598 L
.908 .14459 L
.908 .14459 L
.9158 .14603 L
.9236 .14659 L
.9314 .14745 L
.9392 .14838 L
.9392 .14838 L
.9544 .13656 L
.9696 .12464 L
.9848 .11275 L
1 .10081 L
F
.9637 .18514 m
.94703 .1786 L
.93035 .17238 L
.91368 .16633 L
.897 .16054 L
.897 .16054 L
.90755 .15701 L
.9181 .15387 L
.92865 .15082 L
.9392 .14838 L
.9392 .14838 L
.9587 .16432 L
.9587 .16432 L
.9637 .18514 L
F
1 .05811 m
.98 .06162 L
.96 .06514 L
.94 .06865 L
.92 .07189 L
.9 .07514 L
.88 .07811 L
.88 .07811 L
.88 .07919 L
.88 .07919 L
.9 .07595 L
.92 .0727 L
.94 .06946 L
.96 .06595 L
.98 .06216 L
1 .05811 L
F
.65 g
.8537 .66081 m
.827 .66162 L
.827 .66162 L
.8524 .65973 L
.8524 .65973 L
.8537 .66081 L
F
.6481 .61622 m
.6273 .61899 L
.6065 .62144 L
.5857 .62371 L
.5649 .62597 L
.5441 .628 L
.5233 .62995 L
.5025 .63216 L
.5025 .63216 L
.49255 .61139 L
.48289 .59062 L
.47337 .56985 L
.46397 .54907 L
.45461 .5283 L
.44517 .50753 L
.4357 .48676 L
.4357 .48676 L
.45518 .48609 L
.47466 .48555 L
.49414 .48501 L
.51362 .48467 L
.5331 .48442 L
.55258 .48415 L
.57206 .48387 L
.59154 .48377 L
.61102 .48384 L
.6305 .48351 L
.6305 .48351 L
.63584 .50247 L
.63817 .52143 L
.63923 .54039 L
.64081 .55934 L
.64302 .5783 L
.64549 .59726 L
.6481 .61622 L
F
.8435 .58649 m
.83375 .59002 L
.824 .59347 L
.81425 .59687 L
.8045 .60027 L
.8045 .60027 L
.80074 .57988 L
.79723 .5595 L
.79393 .53911 L
.79081 .51873 L
.78783 .49834 L
.78496 .47795 L
.78218 .45757 L
.77948 .43718 L
.77682 .4168 L
.7742 .39641 L
.77161 .37602 L
.76904 .35564 L
.76646 .33525 L
.7639 .31486 L
.7639 .31486 L
.78568 .31598 L
.80745 .31717 L
.82923 .31806 L
.851 .31892 L
.851 .31892 L
.85151 .3395 L
.85115 .36008 L
.85082 .38067 L
.85037 .40125 L
.84981 .42183 L
.84924 .44241 L
.84861 .46299 L
.84789 .48358 L
.84711 .50416 L
.84628 .52474 L
.84539 .54532 L
.84445 .5659 L
.8435 .58649 L
F
0 .57946 m
.0198 .57732 L
.03961 .57518 L
.05941 .57278 L
.07922 .57037 L
.09902 .56745 L
.11883 .5645 L
.13863 .56131 L
.15844 .55785 L
.17824 .55413 L
.19805 .55013 L
.21785 .54613 L
.23765 .54163 L
.25746 .53708 L
.27726 .5323 L
.29707 .52726 L
.31687 .52193 L
.33668 .5166 L
.35648 .51079 L
.37629 .50489 L
.39609 .49901 L
.4159 .4929 L
.4357 .48676 L
.4357 .48676 L
.425 .48541 L
.425 .48541 L
.40476 .49126 L
.38452 .49651 L
.36429 .50117 L
.34405 .50603 L
.32381 .51098 L
.30357 .51567 L
.28333 .52033 L
.2631 .52474 L
.24286 .52911 L
.22262 .53351 L
.20238 .53739 L
.18214 .54147 L
.1619 .54508 L
.14167 .54863 L
.12143 .55194 L
.10119 .55497 L
.08095 .55771 L
.06071 .56045 L
.04048 .56265 L
.02024 .56484 L
0 .56703 L
F
0 .56081 m
.01974 .55841 L
.03948 .55601 L
.05923 .55335 L
.07897 .55043 L
.09871 .54699 L
.11845 .54328 L
.13819 .5393 L
.15794 .53482 L
.17768 .53004 L
.19742 .525 L
.21716 .51971 L
.23691 .51391 L
.25665 .50802 L
.27639 .50218 L
.29613 .49585 L
.31587 .48967 L
.33562 .48331 L
.35536 .4771 L
.3751 .47108 L
.3751 .47108 L
.39033 .45141 L
.40594 .43174 L
.42214 .41207 L
.43931 .3924 L
.45696 .37273 L
.47586 .35306 L
.49585 .33339 L
.51712 .31372 L
.545 .29405 L
.545 .29405 L
.52498 .28768 L
.50495 .28095 L
.48493 .27389 L
.4649 .26686 L
.44488 .25982 L
.42485 .25279 L
.40483 .24575 L
.3848 .23873 L
.36478 .23147 L
.34475 .22438 L
.32473 .21714 L
.3047 .20984 L
.28468 .20232 L
.26465 .19473 L
.24463 .18716 L
.2246 .17959 L
.20458 .17179 L
.18455 .16416 L
.16453 .15639 L
.1445 .14838 L
.1445 .14838 L
.12386 .14563 L
.10321 .14288 L
.08257 .13984 L
.06193 .13702 L
.04129 .13397 L
.02064 .13117 L
0 .12811 L
F
.6305 .48351 m
.61066 .48279 L
.59082 .48167 L
.57098 .48059 L
.55114 .47952 L
.5313 .47845 L
.51146 .47738 L
.49162 .47629 L
.47178 .47532 L
.45194 .47456 L
.4321 .47378 L
.4321 .47378 L
.45259 .45569 L
.47308 .43752 L
.49357 .41944 L
.51406 .40124 L
.53455 .38315 L
.55504 .36515 L
.57553 .34736 L
.59602 .32984 L
.61651 .31283 L
.637 .29649 L
.637 .29649 L
.65815 .30023 L
.6793 .30367 L
.70045 .30682 L
.7216 .30968 L
.74275 .31251 L
.7639 .31486 L
.7639 .31486 L
.74884 .33595 L
.73377 .35703 L
.71841 .37811 L
.70266 .39919 L
.68656 .42027 L
.66979 .44135 L
.65371 .46243 L
.6305 .48351 L
F
.851 .31892 m
.83007 .31625 L
.80914 .31343 L
.78821 .31032 L
.76729 .30654 L
.74636 .30259 L
.72543 .29824 L
.7045 .29351 L
.7045 .29351 L
.72375 .28007 L
.743 .26653 L
.76225 .25304 L
.7815 .23978 L
.80075 .22651 L
.82 .21324 L
.83925 .19998 L
.8585 .1867 L
.87775 .17368 L
.897 .16054 L
.897 .16054 L
.91368 .16633 L
.93035 .17238 L
.94703 .1786 L
.9637 .18514 L
.9637 .18514 L
.94876 .20425 L
.93357 .22336 L
.91817 .24247 L
.9024 .26158 L
.88615 .28069 L
.86917 .29981 L
.851 .31892 L
F
.6014 .28838 m
.58146 .28158 L
.56153 .27459 L
.54159 .26782 L
.52165 .26135 L
.50172 .25463 L
.48178 .24815 L
.46185 .24143 L
.44191 .23495 L
.42197 .22823 L
.40204 .22174 L
.3821 .21504 L
.36216 .20829 L
.34223 .20181 L
.32229 .1951 L
.30235 .18837 L
.28242 .18139 L
.26248 .17462 L
.24255 .16789 L
.22261 .16115 L
.20267 .15449 L
.18274 .14707 L
.1628 .14076 L
.1628 .14076 L
.18272 .14114 L
.20264 .14172 L
.22256 .14251 L
.24248 .14304 L
.2624 .14357 L
.28232 .14414 L
.30224 .14493 L
.32216 .14546 L
.34208 .146 L
.362 .14654 L
.38192 .14708 L
.40184 .14762 L
.42176 .14816 L
.44168 .14867 L
.4616 .14896 L
.48152 .1495 L
.50144 .15002 L
.52136 .1503 L
.54128 .15083 L
.5612 .1511 L
.58112 .15136 L
.60104 .15165 L
.62096 .15218 L
.64088 .15244 L
.6608 .15271 L
.68072 .15298 L
.70064 .15325 L
.72056 .15352 L
.74048 .15379 L
.7604 .15406 L
.78032 .15433 L
.80024 .1546 L
.82016 .15487 L
.84008 .15514 L
.86 .15541 L
.86 .15541 L
.84011 .16454 L
.82022 .17395 L
.80032 .18363 L
.78043 .1933 L
.76054 .20324 L
.74065 .21319 L
.72075 .22339 L
.70086 .23361 L
.68097 .24408 L
.66108 .25482 L
.64118 .26583 L
.62129 .27684 L
.6014 .28838 L
F
0 .1173 m
.02026 .11705 L
.04051 .11952 L
.06077 .12171 L
.08103 .12418 L
.10129 .12664 L
.12154 .12911 L
.1418 .13162 L
.1418 .13162 L
.14911 .11905 L
.15502 .10649 L
.15969 .09392 L
.1633 .08135 L
.1633 .08135 L
.14289 .08017 L
.12248 .07928 L
.10206 .07847 L
.08165 .07738 L
.06124 .07654 L
.04083 .07545 L
.02041 .07461 L
0 .07378 L
F
0 .07324 m
.02 .07351 L
.04 .07378 L
.06 .07432 L
.08 .07486 L
.1 .07541 L
.12 .07568 L
.14 .07622 L
.16 .07676 L
.16 .07676 L
.14 .05189 L
.12 .02757 L
.1 .00324 L
.0973 0 L
0 0 L
F
.8698 .14919 m
.84989 .1488 L
.82998 .14851 L
.81007 .14826 L
.79017 .14784 L
.77026 .14742 L
.75035 .14718 L
.73044 .14677 L
.71053 .14636 L
.69062 .14596 L
.67072 .14553 L
.65081 .1453 L
.6309 .14489 L
.61099 .14447 L
.59108 .1441 L
.57117 .14353 L
.55127 .14312 L
.53136 .14276 L
.51145 .1422 L
.49154 .14165 L
.47163 .14124 L
.45172 .14087 L
.43182 .14032 L
.41191 .13978 L
.392 .13926 L
.37209 .1386 L
.35218 .13788 L
.33227 .13736 L
.31237 .13682 L
.29246 .1363 L
.27255 .13565 L
.25264 .13492 L
.23273 .1344 L
.21283 .13386 L
.19292 .13333 L
.17301 .13268 L
.1531 .13189 L
.1531 .13189 L
.16094 .11946 L
.16734 .10703 L
.17221 .09459 L
.1758 .08216 L
.1758 .08216 L
.19593 .08239 L
.21605 .08265 L
.23618 .08292 L
.25631 .08319 L
.27644 .08347 L
.29656 .08374 L
.31669 .08402 L
.33682 .08405 L
.35695 .08428 L
.37707 .08456 L
.3972 .08483 L
.41733 .0851 L
.43745 .08538 L
.45758 .0854 L
.47771 .08564 L
.49784 .08592 L
.51796 .08594 L
.53809 .08619 L
.55822 .08647 L
.57835 .08648 L
.59847 .08674 L
.6186 .08675 L
.63873 .08701 L
.65885 .08702 L
.67898 .08729 L
.69911 .0873 L
.71924 .08756 L
.73936 .08757 L
.75949 .08783 L
.77962 .08784 L
.79975 .08811 L
.81987 .08811 L
.84 .08784 L
.84 .08784 L
.84761 .10318 L
.85476 .11851 L
.86209 .13385 L
.8698 .14919 L
F
.10484 0 m
.11669 .01329 L
.13603 .03518 L
.15536 .05752 L
.1747 .08054 L
.1747 .08054 L
.19483 .08076 L
.21495 .08101 L
.23508 .0813 L
.25521 .08135 L
.27534 .08155 L
.29546 .08183 L
.31559 .0821 L
.33572 .08237 L
.35585 .08265 L
.37597 .08292 L
.3961 .0832 L
.41623 .08324 L
.43635 .08346 L
.45648 .08375 L
.47661 .08378 L
.49674 .084 L
.51686 .08429 L
.53699 .08432 L
.55712 .08455 L
.57725 .08484 L
.59737 .08486 L
.6175 .08511 L
.63763 .08513 L
.65775 .08538 L
.67788 .0854 L
.69801 .08565 L
.71814 .08567 L
.73826 .08593 L
.75839 .08594 L
.77852 .0862 L
.79865 .08621 L
.81877 .08647 L
.8389 .08649 L
.8389 .08649 L
.81908 .05106 L
.79927 .01572 L
.7904 0 L
F
1 .12108 m
.99 .13189 L
.97974 .1427 L
.96921 .15351 L
.9587 .16432 L
.9587 .16432 L
.9392 .14838 L
.9392 .14838 L
.9544 .13656 L
.9696 .12464 L
.9848 .11275 L
1 .10081 L
F
1 .18459 m
.99092 .18482 L
.98185 .18486 L
.97278 .18485 L
.9637 .18514 L
.9637 .18514 L
.9587 .16432 L
.9587 .16432 L
.96903 .16432 L
.97935 .16433 L
.98968 .16405 L
1 .16405 L
F
1 .10081 m
.9816 .10976 L
.9632 .11849 L
.9448 .12741 L
.9264 .13598 L
.908 .14459 L
.908 .14459 L
.90125 .12824 L
.89448 .11189 L
.88768 .09554 L
.88 .07919 L
.88 .07919 L
.9 .07595 L
.92 .0727 L
.94 .06946 L
.96 .06595 L
.98 .06216 L
1 .05811 L
F
1 .05811 m
.98 .06162 L
.96 .06514 L
.94 .06865 L
.92 .07189 L
.9 .07514 L
.88 .07811 L
.88 .07811 L
.86 .02622 L
.84968 0 L
1 0 L
F
.35 g
.7476 .96405 m
.72615 .94453 L
.70638 .92501 L
.68792 .90548 L
.67044 .88596 L
.65389 .86644 L
.63821 .84692 L
.62328 .82739 L
.60909 .80787 L
.59551 .78835 L
.58242 .76882 L
.56983 .7493 L
.55771 .72978 L
.546 .71025 L
.53466 .69073 L
.52366 .67121 L
.51295 .65169 L
.5025 .63216 L
.5025 .63216 L
.5233 .62995 L
.5441 .628 L
.5649 .62597 L
.5857 .62371 L
.6065 .62144 L
.6273 .61899 L
.6481 .61622 L
.6481 .61622 L
.65234 .63668 L
.65673 .65714 L
.66127 .6776 L
.66593 .69806 L
.67075 .71852 L
.67573 .73898 L
.68089 .75944 L
.68624 .7799 L
.69182 .80037 L
.69763 .82083 L
.70369 .84129 L
.71004 .86175 L
.71672 .88221 L
.72372 .90267 L
.73112 .92313 L
.73905 .94359 L
.7476 .96405 L
F
.83351 1 m
.83358 .9801 L
.83368 .96019 L
.83378 .94029 L
.83387 .92038 L
.83391 .90048 L
.83389 .88057 L
.83378 .86067 L
.83356 .84076 L
.83324 .82086 L
.8328 .80095 L
.83225 .78105 L
.83159 .76114 L
.83084 .74124 L
.83 .72134 L
.82909 .70143 L
.82809 .68153 L
.827 .66162 L
.827 .66162 L
.8537 .66081 L
.8537 .66081 L
.85235 .68076 L
.85101 .70072 L
.84969 .72067 L
.84839 .74062 L
.84714 .76057 L
.84595 .78052 L
.84484 .80048 L
.84385 .82043 L
.84299 .84038 L
.84235 .86033 L
.84203 .88029 L
.84208 .90024 L
.84259 .92019 L
.84363 .94014 L
.84528 .9601 L
.84762 .98005 L
.85071 1 L
F
1 .62081 m
.9791 .62589 L
.9582 .63101 L
.9373 .63668 L
.9164 .64231 L
.8955 .64824 L
.8746 .65445 L
.8537 .66081 L
.8537 .66081 L
.8524 .65973 L
.8524 .65973 L
.87349 .65327 L
.89457 .647 L
.91566 .64102 L
.93674 .6352 L
.95783 .62972 L
.97891 .62431 L
1 .61919 L
F
.8045 .60027 m
.81425 .59687 L
.824 .59347 L
.83375 .59002 L
.8435 .58649 L
.8435 .58649 L
.84569 .6048 L
.84788 .62311 L
.85011 .64142 L
.8524 .65973 L
.8524 .65973 L
.827 .66162 L
.827 .66162 L
.82124 .64628 L
.81563 .63095 L
.81007 .61561 L
.8045 .60027 L
F
0 .64784 m
.0201 .64757 L
.0402 .64729 L
.0603 .64675 L
.0804 .64648 L
.1005 .64593 L
.1206 .64539 L
.1407 .64485 L
.1608 .64458 L
.1809 .64403 L
.201 .64347 L
.2211 .64267 L
.2412 .64213 L
.2613 .64157 L
.2814 .64077 L
.3015 .64021 L
.3216 .63941 L
.3417 .63886 L
.3618 .63804 L
.3819 .63722 L
.402 .63641 L
.4221 .6356 L
.4422 .63475 L
.4623 .63368 L
.4824 .63289 L
.5025 .63216 L
.5025 .63216 L
.49255 .61139 L
.48289 .59062 L
.47337 .56985 L
.46397 .54907 L
.45461 .5283 L
.44517 .50753 L
.4357 .48676 L
.4357 .48676 L
.4159 .4929 L
.39609 .49901 L
.37629 .50489 L
.35648 .51079 L
.33668 .5166 L
.31687 .52193 L
.29707 .52726 L
.27726 .5323 L
.25746 .53708 L
.23765 .54163 L
.21785 .54613 L
.19805 .55013 L
.17824 .55413 L
.15844 .55785 L
.13863 .56131 L
.11883 .5645 L
.09902 .56745 L
.07922 .57037 L
.05941 .57278 L
.03961 .57518 L
.0198 .57732 L
0 .57946 L
F
.8045 .60027 m
.78495 .60268 L
.7654 .60503 L
.74585 .60722 L
.7263 .60934 L
.70675 .61128 L
.6872 .61294 L
.66765 .6145 L
.6481 .61622 L
.6481 .61622 L
.64549 .59726 L
.64302 .5783 L
.64081 .55934 L
.63923 .54039 L
.63817 .52143 L
.63584 .50247 L
.6305 .48351 L
.6305 .48351 L
.65371 .46243 L
.66979 .44135 L
.68656 .42027 L
.70266 .39919 L
.71841 .37811 L
.73377 .35703 L
.74884 .33595 L
.7639 .31486 L
.7639 .31486 L
.76646 .33525 L
.76904 .35564 L
.77161 .37602 L
.7742 .39641 L
.77682 .4168 L
.77948 .43718 L
.78218 .45757 L
.78496 .47795 L
.78783 .49834 L
.79081 .51873 L
.79393 .53911 L
.79723 .5595 L
.80074 .57988 L
.8045 .60027 L
F
1 .58703 m
.98044 .58703 L
.96088 .58703 L
.94131 .58677 L
.92175 .58675 L
.90219 .58676 L
.88263 .58676 L
.86306 .58677 L
.8435 .58649 L
.8435 .58649 L
.84445 .5659 L
.84539 .54532 L
.84628 .52474 L
.84711 .50416 L
.84789 .48358 L
.84861 .46299 L
.84924 .44241 L
.84981 .42183 L
.85037 .40125 L
.85082 .38067 L
.85115 .36008 L
.85151 .3395 L
.851 .31892 L
.851 .31892 L
.86917 .29981 L
.88615 .28069 L
.9024 .26158 L
.91817 .24247 L
.93357 .22336 L
.94876 .20425 L
.9637 .18514 L
.9637 .18514 L
.97278 .18485 L
.98185 .18486 L
.99092 .18482 L
1 .18459 L
F
1 .16405 m
.98968 .16405 L
.97935 .16433 L
.96903 .16432 L
.9587 .16432 L
.9587 .16432 L
.96921 .15351 L
.97974 .1427 L
.99 .13189 L
1 .12108 L
F
.15 g
0 .64784 m
.0201 .64757 L
.0402 .64729 L
.0603 .64675 L
.0804 .64648 L
.1005 .64593 L
.1206 .64539 L
.1407 .64485 L
.1608 .64458 L
.1809 .64403 L
.201 .64347 L
.2211 .64267 L
.2412 .64213 L
.2613 .64157 L
.2814 .64077 L
.3015 .64021 L
.3216 .63941 L
.3417 .63886 L
.3618 .63804 L
.3819 .63722 L
.402 .63641 L
.4221 .6356 L
.4422 .63475 L
.4623 .63368 L
.4824 .63289 L
.5025 .63216 L
.5025 .63216 L
.51295 .65169 L
.52366 .67121 L
.53466 .69073 L
.546 .71025 L
.55771 .72978 L
.56983 .7493 L
.58242 .76882 L
.59551 .78835 L
.60909 .80787 L
.62328 .82739 L
.63821 .84692 L
.65389 .86644 L
.67044 .88596 L
.68792 .90548 L
.70638 .92501 L
.72615 .94453 L
.7476 .96405 L
.7476 .96405 L
.72608 .98035 L
.70505 1 L
0 1 L
F
.82737 1 m
.81203 .99311 L
.79055 .98334 L
.76908 .9738 L
.7476 .96405 L
.7476 .96405 L
.73905 .94359 L
.73112 .92313 L
.72372 .90267 L
.71672 .88221 L
.71004 .86175 L
.70369 .84129 L
.69763 .82083 L
.69182 .80037 L
.68624 .7799 L
.68089 .75944 L
.67573 .73898 L
.67075 .71852 L
.66593 .69806 L
.66127 .6776 L
.65673 .65714 L
.65234 .63668 L
.6481 .61622 L
.6481 .61622 L
.66765 .6145 L
.6872 .61294 L
.70675 .61128 L
.7263 .60934 L
.74585 .60722 L
.7654 .60503 L
.78495 .60268 L
.8045 .60027 L
.8045 .60027 L
.81007 .61561 L
.81563 .63095 L
.82124 .64628 L
.827 .66162 L
.827 .66162 L
.82809 .68153 L
.82909 .70143 L
.83 .72134 L
.83084 .74124 L
.83159 .76114 L
.83225 .78105 L
.8328 .80095 L
.83324 .82086 L
.83356 .84076 L
.83378 .86067 L
.83389 .88057 L
.83391 .90048 L
.83387 .92038 L
.83378 .94029 L
.83368 .96019 L
.83358 .9801 L
.83351 1 L
F
.85448 1 m
.87229 .99262 L
.89357 .9852 L
.91486 .97984 L
.93614 .9763 L
.95743 .97507 L
.97871 .97656 L
1 .98162 L
.85071 1 L
.84762 .98005 L
.84528 .9601 L
.84363 .94014 L
.84259 .92019 L
.84208 .90024 L
.84203 .88029 L
.84235 .86033 L
.84299 .84038 L
.84385 .82043 L
.84484 .80048 L
.84595 .78052 L
.84714 .76057 L
.84839 .74062 L
.84969 .72067 L
.85101 .70072 L
.85235 .68076 L
.8537 .66081 L
.8537 .66081 L
.8746 .65445 L
.8955 .64824 L
.9164 .64231 L
.9373 .63668 L
.9582 .63101 L
.9791 .62589 L
1 .62081 L
1 1 L
F
1 .61919 m
.97891 .62431 L
.95783 .62972 L
.93674 .6352 L
.91566 .64102 L
.89457 .647 L
.87349 .65327 L
.8524 .65973 L
.8524 .65973 L
.85011 .64142 L
.84788 .62311 L
.84569 .6048 L
.8435 .58649 L
.8435 .58649 L
.86306 .58677 L
.88263 .58676 L
.90219 .58676 L
.92175 .58675 L
.94131 .58677 L
.96088 .58703 L
.98044 .58703 L
1 .58703 L
F
0 g
.70505 1 m
.72608 .98035 L
.7476 .96405 L
.7476 .96405 L
.76908 .9738 L
.79055 .98334 L
.81203 .99311 L
.82737 1 L
F
.85448 1 m
.87229 .99262 L
.89357 .9852 L
.91486 .97984 L
.93614 .9763 L
.95743 .97507 L
.97871 .97656 L
1 .98162 L
1 1 L
F
.3 Mabswid
.1747 .08054 m
.19483 .08076 L
.21495 .08101 L
.23508 .0813 L
.25521 .08135 L
.27534 .08155 L
.29546 .08183 L
.31559 .0821 L
.33572 .08237 L
.35585 .08265 L
.37597 .08292 L
.3961 .0832 L
.41623 .08324 L
.43635 .08346 L
.45648 .08375 L
.47661 .08378 L
.49674 .084 L
.51686 .08429 L
.53699 .08432 L
.55712 .08455 L
.57725 .08484 L
.59737 .08486 L
.6175 .08511 L
.63763 .08513 L
.65775 .08538 L
.67788 .0854 L
.69801 .08565 L
.71814 .08567 L
.73826 .08593 L
.75839 .08594 L
.77852 .0862 L
.79865 .08621 L
.81877 .08647 L
.8389 .08649 L
s
.1758 .08216 m
.19593 .08239 L
.21605 .08265 L
.23618 .08292 L
.25631 .08319 L
.27644 .08347 L
.29656 .08374 L
.31669 .08402 L
.33682 .08405 L
.35695 .08428 L
.37707 .08456 L
.3972 .08483 L
.41733 .0851 L
.43745 .08538 L
.45758 .0854 L
.47771 .08564 L
.49784 .08592 L
.51796 .08594 L
.53809 .08619 L
.55822 .08647 L
.57835 .08648 L
.59847 .08674 L
.6186 .08675 L
.63873 .08701 L
.65885 .08702 L
.67898 .08729 L
.69911 .0873 L
.71924 .08756 L
.73936 .08757 L
.75949 .08783 L
.77962 .08784 L
.79975 .08811 L
.81987 .08811 L
.84 .08784 L
s
.10484 0 m
.11669 .01329 L
.13603 .03518 L
.15536 .05752 L
.1747 .08054 L
s
.7904 0 m
.79927 .01572 L
.81908 .05106 L
.8389 .08649 L
s
.8389 .08649 m
.84918 .08417 L
.85945 .082 L
.86973 .07998 L
.88 .07811 L
s
.84968 0 m
.86 .02622 L
.88 .07811 L
s
.88 .07811 m
.9 .07514 L
.92 .07189 L
.94 .06865 L
.96 .06514 L
.98 .06162 L
1 .05811 L
s
.84 .08784 m
.85 .08547 L
.86 .08324 L
.87 .08115 L
.88 .07919 L
s
.84 .08784 m
.8389 .08649 L
s
.88 .07811 m
.88 .07919 L
s
.88 .07919 m
.9 .07595 L
.92 .0727 L
.94 .06946 L
.96 .06595 L
.98 .06216 L
1 .05811 L
s
.88 .07919 m
.88768 .09554 L
.89448 .11189 L
.90125 .12824 L
.908 .14459 L
s
.84 .08784 m
.84761 .10318 L
.85476 .11851 L
.86209 .13385 L
.8698 .14919 L
s
.1758 .08216 m
.17221 .09459 L
.16734 .10703 L
.16094 .11946 L
.1531 .13189 L
s
.1531 .13189 m
.17301 .13268 L
.19292 .13333 L
.21283 .13386 L
.23273 .1344 L
.25264 .13492 L
.27255 .13565 L
.29246 .1363 L
.31237 .13682 L
.33227 .13736 L
.35218 .13788 L
.37209 .1386 L
.392 .13926 L
.41191 .13978 L
.43182 .14032 L
.45172 .14087 L
.47163 .14124 L
.49154 .14165 L
.51145 .1422 L
.53136 .14276 L
.55127 .14312 L
.57117 .14353 L
.59108 .1441 L
.61099 .14447 L
.6309 .14489 L
.65081 .1453 L
.67072 .14553 L
.69062 .14596 L
.71053 .14636 L
.73044 .14677 L
.75035 .14718 L
.77026 .14742 L
.79017 .14784 L
.81007 .14826 L
.82998 .14851 L
.84989 .1488 L
.8698 .14919 L
s
.0973 0 m
.1 .00324 L
.12 .02757 L
.14 .05189 L
.16 .07676 L
s
0 .07324 m
.02 .07351 L
.04 .07378 L
.06 .07432 L
.08 .07486 L
.1 .07541 L
.12 .07568 L
.14 .07622 L
.16 .07676 L
s
.1633 .08135 m
.1758 .08216 L
s
.16 .07676 m
.1747 .08054 L
s
.1747 .08054 m
.1758 .08216 L
s
.1628 .14076 m
.18274 .14707 L
.20267 .15449 L
.22261 .16115 L
.24255 .16789 L
.26248 .17462 L
.28242 .18139 L
.30235 .18837 L
.32229 .1951 L
.34223 .20181 L
.36216 .20829 L
.3821 .21504 L
.40204 .22174 L
.42197 .22823 L
.44191 .23495 L
.46185 .24143 L
.48178 .24815 L
.50172 .25463 L
.52165 .26135 L
.54159 .26782 L
.56153 .27459 L
.58146 .28158 L
.6014 .28838 L
s
.1628 .14076 m
.18272 .14114 L
.20264 .14172 L
.22256 .14251 L
.24248 .14304 L
.2624 .14357 L
.28232 .14414 L
.30224 .14493 L
.32216 .14546 L
.34208 .146 L
.362 .14654 L
.38192 .14708 L
.40184 .14762 L
.42176 .14816 L
.44168 .14867 L
.4616 .14896 L
.48152 .1495 L
.50144 .15002 L
.52136 .1503 L
.54128 .15083 L
.5612 .1511 L
.58112 .15136 L
.60104 .15165 L
.62096 .15218 L
.64088 .15244 L
.6608 .15271 L
.68072 .15298 L
.70064 .15325 L
.72056 .15352 L
.74048 .15379 L
.7604 .15406 L
.78032 .15433 L
.80024 .1546 L
.82016 .15487 L
.84008 .15514 L
.86 .15541 L
s
.6014 .28838 m
.62129 .27684 L
.64118 .26583 L
.66108 .25482 L
.68097 .24408 L
.70086 .23361 L
.72075 .22339 L
.74065 .21319 L
.76054 .20324 L
.78043 .1933 L
.80032 .18363 L
.82022 .17395 L
.84011 .16454 L
.86 .15541 L
s
.908 .14459 m
.9264 .13598 L
.9448 .12741 L
.9632 .11849 L
.9816 .10976 L
1 .10081 L
s
0 .07378 m
.02041 .07461 L
.04083 .07545 L
.06124 .07654 L
.08165 .07738 L
.10206 .07847 L
.12248 .07928 L
.14289 .08017 L
.1633 .08135 L
s
.1633 .08135 m
.15969 .09392 L
.15502 .10649 L
.14911 .11905 L
.1418 .13162 L
s
.16 .07676 m
.1633 .08135 L
s
0 .1173 m
.02026 .11705 L
.04051 .11952 L
.06077 .12171 L
.08103 .12418 L
.10129 .12664 L
.12154 .12911 L
.1418 .13162 L
s
0 .12811 m
.02064 .13117 L
.04129 .13397 L
.06193 .13702 L
.08257 .13984 L
.10321 .14288 L
.12386 .14563 L
.1445 .14838 L
s
.1445 .14838 m
.16453 .15639 L
.18455 .16416 L
.20458 .17179 L
.2246 .17959 L
.24463 .18716 L
.26465 .19473 L
.28468 .20232 L
.3047 .20984 L
.32473 .21714 L
.34475 .22438 L
.36478 .23147 L
.3848 .23873 L
.40483 .24575 L
.42485 .25279 L
.44488 .25982 L
.4649 .26686 L
.48493 .27389 L
.50495 .28095 L
.52498 .28768 L
.545 .29405 L
s
.1418 .13162 m
.1531 .13189 L
s
.1628 .14076 m
.1531 .13189 L
s
.1628 .14076 m
.1445 .14838 L
s
.1418 .13162 m
.1445 .14838 L
s
.7045 .29351 m
.72375 .28007 L
.743 .26653 L
.76225 .25304 L
.7815 .23978 L
.80075 .22651 L
.82 .21324 L
.83925 .19998 L
.8585 .1867 L
.87775 .17368 L
.897 .16054 L
s
.897 .16054 m
.91368 .16633 L
.93035 .17238 L
.94703 .1786 L
.9637 .18514 L
s
.897 .16054 m
.90755 .15701 L
.9181 .15387 L
.92865 .15082 L
.9392 .14838 L
s
.908 .14459 m
.9158 .14603 L
.9236 .14659 L
.9314 .14745 L
.9392 .14838 L
s
.9392 .14838 m
.9587 .16432 L
s
.9392 .14838 m
.9544 .13656 L
.9696 .12464 L
.9848 .11275 L
1 .10081 L
s
.86 .15541 m
.86925 .158 L
.8785 .15904 L
.88775 .15975 L
.897 .16054 L
s
.8698 .14919 m
.87935 .14897 L
.8889 .14774 L
.89845 .14668 L
.908 .14459 L
s
.8698 .14919 m
.86 .15541 L
s
1 .12108 m
.99 .13189 L
.97974 .1427 L
.96921 .15351 L
.9587 .16432 L
s
.9587 .16432 m
.9637 .18514 L
s
.9637 .18514 m
.94876 .20425 L
.93357 .22336 L
.91817 .24247 L
.9024 .26158 L
.88615 .28069 L
.86917 .29981 L
.851 .31892 L
s
.9637 .18514 m
.97278 .18485 L
.98185 .18486 L
.99092 .18482 L
1 .18459 L
s
.9587 .16432 m
.96903 .16432 L
.97935 .16433 L
.98968 .16405 L
1 .16405 L
s
.6014 .28838 m
.62202 .28986 L
.64264 .29067 L
.66326 .29171 L
.68388 .29265 L
.7045 .29351 L
s
.545 .29405 m
.5591 .29251 L
.5732 .29136 L
.5873 .29025 L
.6014 .28838 L
s
.7045 .29351 m
.72543 .29824 L
.74636 .30259 L
.76729 .30654 L
.78821 .31032 L
.80914 .31343 L
.83007 .31625 L
.851 .31892 L
s
.637 .29649 m
.65815 .30023 L
.6793 .30367 L
.70045 .30682 L
.7216 .30968 L
.74275 .31251 L
.7639 .31486 L
s
.4321 .47378 m
.45259 .45569 L
.47308 .43752 L
.49357 .41944 L
.51406 .40124 L
.53455 .38315 L
.55504 .36515 L
.57553 .34736 L
.59602 .32984 L
.61651 .31283 L
.637 .29649 L
s
.545 .29405 m
.51712 .31372 L
.49585 .33339 L
.47586 .35306 L
.45696 .37273 L
.43931 .3924 L
.42214 .41207 L
.40594 .43174 L
.39033 .45141 L
.3751 .47108 L
s
.637 .29649 m
.65388 .29574 L
.67075 .29484 L
.68763 .29419 L
.7045 .29351 L
s
.545 .29405 m
.5634 .29441 L
.5818 .29491 L
.6002 .29541 L
.6186 .29591 L
.637 .29649 L
s
.7639 .31486 m
.78568 .31598 L
.80745 .31717 L
.82923 .31806 L
.851 .31892 L
s
.851 .31892 m
.85151 .3395 L
.85115 .36008 L
.85082 .38067 L
.85037 .40125 L
.84981 .42183 L
.84924 .44241 L
.84861 .46299 L
.84789 .48358 L
.84711 .50416 L
.84628 .52474 L
.84539 .54532 L
.84445 .5659 L
.8435 .58649 L
s
.7639 .31486 m
.76646 .33525 L
.76904 .35564 L
.77161 .37602 L
.7742 .39641 L
.77682 .4168 L
.77948 .43718 L
.78218 .45757 L
.78496 .47795 L
.78783 .49834 L
.79081 .51873 L
.79393 .53911 L
.79723 .5595 L
.80074 .57988 L
.8045 .60027 L
s
.7639 .31486 m
.74884 .33595 L
.73377 .35703 L
.71841 .37811 L
.70266 .39919 L
.68656 .42027 L
.66979 .44135 L
.65371 .46243 L
.6305 .48351 L
s
.4321 .47378 m
.45194 .47456 L
.47178 .47532 L
.49162 .47629 L
.51146 .47738 L
.5313 .47845 L
.55114 .47952 L
.57098 .48059 L
.59082 .48167 L
.61066 .48279 L
.6305 .48351 L
s
.3751 .47108 m
.38935 .47159 L
.4036 .47237 L
.41785 .47291 L
.4321 .47378 L
s
0 .56081 m
.01974 .55841 L
.03948 .55601 L
.05923 .55335 L
.07897 .55043 L
.09871 .54699 L
.11845 .54328 L
.13819 .5393 L
.15794 .53482 L
.17768 .53004 L
.19742 .525 L
.21716 .51971 L
.23691 .51391 L
.25665 .50802 L
.27639 .50218 L
.29613 .49585 L
.31587 .48967 L
.33562 .48331 L
.35536 .4771 L
.3751 .47108 L
s
.4357 .48676 m
.45518 .48609 L
.47466 .48555 L
.49414 .48501 L
.51362 .48467 L
.5331 .48442 L
.55258 .48415 L
.57206 .48387 L
.59154 .48377 L
.61102 .48384 L
.6305 .48351 L
s
.8435 .58649 m
.86306 .58677 L
.88263 .58676 L
.90219 .58676 L
.92175 .58675 L
.94131 .58677 L
.96088 .58703 L
.98044 .58703 L
s
1 .58703 m
.98044 .58703 L
s
s
.8045 .60027 m
.81425 .59687 L
.824 .59347 L
.83375 .59002 L
.8435 .58649 L
s
.8435 .58649 m
.84569 .6048 L
.84788 .62311 L
.85011 .64142 L
.8524 .65973 L
s
.8524 .65973 m
.87349 .65327 L
.89457 .647 L
.91566 .64102 L
.93674 .6352 L
.95783 .62972 L
.97891 .62431 L
1 .61919 L
s
.827 .66162 m
.8524 .65973 L
s
.6305 .48351 m
.63584 .50247 L
.63817 .52143 L
.63923 .54039 L
.64081 .55934 L
.64302 .5783 L
.64549 .59726 L
.6481 .61622 L
s
.6481 .61622 m
.66765 .6145 L
.6872 .61294 L
.70675 .61128 L
.7263 .60934 L
.74585 .60722 L
.7654 .60503 L
.78495 .60268 L
.8045 .60027 L
s
.8045 .60027 m
.81007 .61561 L
.81563 .63095 L
.82124 .64628 L
.827 .66162 L
s
.6481 .61622 m
.65234 .63668 L
.65673 .65714 L
.66127 .6776 L
.66593 .69806 L
.67075 .71852 L
.67573 .73898 L
.68089 .75944 L
.68624 .7799 L
.69182 .80037 L
.69763 .82083 L
.70369 .84129 L
.71004 .86175 L
.71672 .88221 L
.72372 .90267 L
.73112 .92313 L
.73905 .94359 L
.7476 .96405 L
s
.827 .66162 m
.8537 .66081 L
s
.8537 .66081 m
.8746 .65445 L
.8955 .64824 L
.9164 .64231 L
.9373 .63668 L
.9582 .63101 L
.9791 .62589 L
s
1 .62081 m
.9791 .62589 L
s
s
.8524 .65973 m
.8537 .66081 L
s
.8537 .66081 m
.85235 .68076 L
.85101 .70072 L
.84969 .72067 L
.84839 .74062 L
.84714 .76057 L
.84595 .78052 L
.84484 .80048 L
.84385 .82043 L
.84299 .84038 L
.84235 .86033 L
.84203 .88029 L
.84208 .90024 L
.84259 .92019 L
.84363 .94014 L
.84528 .9601 L
.84762 .98005 L
.85071 1 L
s
.827 .66162 m
.82809 .68153 L
.82909 .70143 L
.83 .72134 L
.83084 .74124 L
.83159 .76114 L
.83225 .78105 L
.8328 .80095 L
.83324 .82086 L
.83356 .84076 L
.83378 .86067 L
.83389 .88057 L
.83391 .90048 L
.83387 .92038 L
.83378 .94029 L
.83368 .96019 L
.83358 .9801 L
s
.83351 1 m
.83358 .9801 L
s
s
.5025 .63216 m
.5233 .62995 L
.5441 .628 L
.5649 .62597 L
.5857 .62371 L
.6065 .62144 L
.6273 .61899 L
.6481 .61622 L
s
.5025 .63216 m
.51295 .65169 L
.52366 .67121 L
.53466 .69073 L
.546 .71025 L
.55771 .72978 L
.56983 .7493 L
.58242 .76882 L
.59551 .78835 L
.60909 .80787 L
.62328 .82739 L
.63821 .84692 L
.65389 .86644 L
.67044 .88596 L
.68792 .90548 L
.70638 .92501 L
.72615 .94453 L
.7476 .96405 L
s
.4357 .48676 m
.44517 .50753 L
.45461 .5283 L
.46397 .54907 L
.47337 .56985 L
.48289 .59062 L
.49255 .61139 L
.5025 .63216 L
s
0 .64784 m
.0201 .64757 L
.0402 .64729 L
.0603 .64675 L
.0804 .64648 L
.1005 .64593 L
.1206 .64539 L
.1407 .64485 L
.1608 .64458 L
.1809 .64403 L
.201 .64347 L
.2211 .64267 L
.2412 .64213 L
.2613 .64157 L
.2814 .64077 L
.3015 .64021 L
.3216 .63941 L
.3417 .63886 L
.3618 .63804 L
.3819 .63722 L
.402 .63641 L
.4221 .6356 L
.4422 .63475 L
.4623 .63368 L
.4824 .63289 L
.5025 .63216 L
s
.4321 .47378 m
.425 .48541 L
s
.3751 .47108 m
.38758 .47533 L
.40005 .4792 L
.41253 .48259 L
.425 .48541 L
s
0 .56703 m
.02024 .56484 L
.04048 .56265 L
.06071 .56045 L
.08095 .55771 L
.10119 .55497 L
.12143 .55194 L
.14167 .54863 L
.1619 .54508 L
.18214 .54147 L
.20238 .53739 L
.22262 .53351 L
.24286 .52911 L
.2631 .52474 L
.28333 .52033 L
.30357 .51567 L
.32381 .51098 L
.34405 .50603 L
.36429 .50117 L
.38452 .49651 L
.40476 .49126 L
.425 .48541 L
s
0 .57946 m
.0198 .57732 L
.03961 .57518 L
.05941 .57278 L
.07922 .57037 L
.09902 .56745 L
.11883 .5645 L
.13863 .56131 L
.15844 .55785 L
.17824 .55413 L
.19805 .55013 L
.21785 .54613 L
.23765 .54163 L
.25746 .53708 L
.27726 .5323 L
.29707 .52726 L
.31687 .52193 L
.33668 .5166 L
.35648 .51079 L
.37629 .50489 L
.39609 .49901 L
.4159 .4929 L
.4357 .48676 L
s
.425 .48541 m
.4357 .48676 L
s
.70505 1 m
.72608 .98035 L
.7476 .96405 L
s
.7476 .96405 m
.76908 .9738 L
.79055 .98334 L
.81203 .99311 L
.82737 1 L
s
s
.85448 1 m
.87229 .99262 L
.89357 .9852 L
.91486 .97984 L
.93614 .9763 L
.95743 .97507 L
.97871 .97656 L
1 .98162 L
s
0 1 0 r
1 0 0 r
0 0 1 r
p
0 g
0 0 m
0 1 L
1 1 L
1 0 L
0 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{453, 453},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000750001aA000`40O003h00OogooaWoo003oOoo6
Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`00
JWoo0P0017oo00@007ooOomoo`D004Eoo`8000Aoo`03001oogoo00=oo`<004Eoo`8000Aoo`03001o
ogoo009oo`<004Ioo`8000Aoo`03001oogoo009oo`<004Yoo`<000Aoo`00JGoo00@007ooOol000Qo
o`04001oogoo0014Ool01000Oomoo`002Woo00<007ooOol0@goo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`001goo00D007ooOomoo`0004Yoo`03001oogoo00=oo`00JGoo00@007oo
Ool000Uoo`03001oogoo04Aoo`04001oogoo0007Ool50014Ool01000Oomoo`001goo00D007ooOomo
o`0004Aoo`04001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomo
o`002Woo00<007ooOol0@goo00@007ooOol000Moo`04001oogoo0015Ool01000Oomoo`001goo1000
AGoo00@007ooOol000Qoo`<004]oo`03001oogoo00=oo`00JGoo00@007ooOol000Moo`05001oogoo
Ool00014Ool01000Oomoo`0027oo00<007oo0000AGoo00@007ooOol000Moo`03001oogoo04Ioo`04
001oogoo0007Ool01@00Oomoogoo0000BWoo00<007ooOol00goo001YOol01000Oomoo`001goo00D0
07ooOomoo`0004Aoo`04001oogoo0009Ool20015Ool01000Oomoo`0027oo00<007ooOol0AGoo00@0
07ooOol000Moo`05001oogooOol00019Ool20005Ool006Yoo`8000Uoo`<004Ioo`8000]oo`03001o
ogoo04Aoo`8000Yoo`8004Ioo`8000Uoo`<004]oo`03001oogoo00=oo`00ogooaWoo003oOoo6Ool0
0?moolIoo`00ogooaWoo003oOoo6Ool00?moolIoo`007Gooo`00Y@0017oo000MOol00`00DYABU00W
DY@00`00Kg/0003oDY@PDY@00`00Kg]_N`0EKg/00`00DYABU00lDY@00`00Oomoo`02Ool001eoo`03
001BU5:D02MBU004001_Nfmk003oDY@PDY@00`00Kg]_N`0EKg/00`00DYABU00kDY@00`00Oomoo`02
Ool001eoo`03001BU5:D02QBU004001_Nfmk003oDY@ODY@00`00Kg]_N`0EKg/00`00DYABU00kDY@0
0`00Oomoo`02Ool001eoo`03001BU5:D02UBU004001_Nfmk003oDY@ODY@00`00Kg]_N`0EKg/00`00
DYABU00jDY@00`00Oomoo`02Ool001eoo`03001BU5:D02YBU004001_Nfmk003oDY@NDY@00`00Kg]_
N`0EKg/00`00DYABU00jDY@00`00Oomoo`02Ool001eoo`03001BU5:D02YBU005001_NfmkKg/0003o
DY@MDY@00`00Kg]_N`0FKg/00`00DYABU00iDY@00`00Oomoo`02Ool001eoo`03001BU5:D02]BU004
001_Nfmk003oDY@NDY@00`00Kg]_N`0EKg/00`00DYABU00iDY@00`00Oomoo`02Ool001eoo`03001B
U5:D02aBU004001_Nfmk003oDY@MDY@00`00Kg]_N`0EKg/00`00DYABU00iDY@00`00Oomoo`02Ool0
01eoo`03001BU5:D02aBU005001_NfmkKg/0003oDY@MDY@00`00Kg]_N`0EKg/00`00DYABU00hDY@0
0`00Oomoo`02Ool001eoo`03001BU5:D02eBU005001_NfmkKg/0003oDY@MDY@00`00Kg]_N`0DKg/0
0`00DYABU00hDY@00`00Oomoo`02Ool001eoo`03001BU5:D02iBU005001_NfmkKg/0003oDY@LDY@0
0`00Kg]_N`0EKg/00`00DYABU00gDY@00`00Oomoo`02Ool001eoo`03001BU5:D02mBU005001_Nfmk
Kg/0003oDY@LDY@00`00Kg]_N`0DKg/00`00DYABU00gDY@00`00Oomoo`02Ool001eoo`03001BU5:D
02mBU003001_Nfmk009_N`03001BU5:D0?mBU1UBU003001_Nfmk01E_N`03001BU5:D03IBU003001o
ogoo009oo`007Goo00<005:DDY@0<5:D00<006mkKg/00Vmk00<005:DDY@0oe:D6E:D00<006mkKg/0
56mk00<005:DDY@0=U:D00<007ooOol00Woo000MOol00`00DYABU00aDY@00`00Kg]_N`02Kg/00`00
DYABU03oDY@IDY@00`00Kg]_N`0CKg/00`00DYABU00fDY@00`00Oomoo`02Ool001eoo`03001BU5:D
039BU005001_NfmkKg/0003oDY@KDY@00`00Kg]_N`0DKg/00`00DYABU00eDY@00`00Oomoo`02Ool0
01eoo`03001BU5:D03=BU005001_NfmkKg/0003oDY@KDY@00`00Kg]_N`0CKg/00`00DYABU00eDY@0
0`00Oomoo`02Ool001eoo`03001BU5:D03ABU005001_NfmkKg/0003oDY@JDY@00`00Kg]_N`0CKg/0
0`00DYABU00eDY@00`00Oomoo`02Ool001eoo`03001BU5:D03EBU005001_NfmkKg/0003oDY@JDY@0
0`00Kg]_N`0CKg/00`00DYABU00dDY@00`00Oomoo`02Ool000Moo`<000=oo`<000Aoo`8000Moo`03
001BU5:D03IBU005001_NfmkKg/0003oDY@JDY@00`00Kg]_N`0BKg/00`00DYABU00dDY@00`00Oomo
o`02Ool000Ioo`07001oogooOol007oo00000goo00@007ooOol0009oo`03001oogoo00Aoo`03001B
U5:D03MBU005001_NfmkKg/0003oDY@IDY@00`00Kg]_N`0BKg/00`00DYABU00dDY@00`00Oomoo`02
Ool000Ioo`05001oogooOol00005Ool01000Oomoo`000Woo00<007ooOol017oo00<005:DDY@0>5:D
00D006mkKg]_N`000?mBU1UBU003001_Nfmk019_N`03001BU5:D03=BU003001oogoo009oo`001Woo
10001Woo00@007ooOol0009oo`03001oogoo00Aoo`03001BU5:D03QBU003001_Nfmk009_N`03001B
U5:D0?mBU1IBU003001_Nfmk019_N`03001BU5:D03=BU003001oogoo009oo`001Woo00<007ooOol0
0goo10000goo00@007ooOol000Ioo`03001BU5:D03UBU003001_Nfmk009_N`03001BU5:D0?mBU1IB
U003001_Nfmk019_N`03001BU5:D039BU003001oogoo009oo`001goo00<007ooOol00Woo00<007oo
Ool017oo00@007ooOol000Ioo`03001BU5:D03YBU005001_NfmkKg/0003oDY@HDY@00`00Kg]_N`0B
Kg/00`00DYABU00^DY@50004Ool000Qoo`80009oo`D000=oo`8000Moo`03001BU5:D03]BU005001_
NfmkKg/0003oDY@HDY@00`00Kg]_N`0AKg/00`00DYABU00VDY@80004DY@00`00Oomoo`02Ool001eo
o`03001BU5:D03aBU005001_NfmkKg/0003oDY@HDY@00`00Kg]_N`0AKg/00`00DYABU00ODY@8000:
DY@00`00Oomoo`02Ool001eoo`03001BU5:D03aBU003001_Nfmk009_N`03001BU5:D0?mBU1EBU003
001_Nfmk015_N`03001BU5:D01YBU0T000iBU003001oogoo009oo`007Goo00<005:DDY@0?E:D00<0
06mkKg/00Vmk00<005:DDY@0oe:D5E:D00<006mkKg/046mk00<005:DDY@055:D2@0055:D00<007oo
Ool00Woo000MOol00`00DYABU00nDY@01@00Kg]_Nfmk0000oe:D5e:D00<006mkKg/04Fmk00<005:D
DY@03E:D20006e:D00<007ooOol00Woo000MOolN000TDY@01@00Kg]_Nfmk0000oe:D5e:D00<006mk
Kg/046mk00<005:DDY@02E:D20007e:D00<007ooOol00Woo000MOol00`00DYABU00;DY@h00000fmk
001BU03oDY@EDY@00`00Kg]_N`0@Kg/00`00DYABU003DY@8000UDY@00`00Oomoo`02Ool001eoo`03
001BU5:D01aBU1X000Y_N`03001oogoo00<00?mBU1IBU003001_Nfmk00i_N`L002eBU003001oogoo
009oo`007Goo00<005:DDY@0=U:D3`0000=oo`000000=P00gU:D00<006mkKg/02Fmk10000Vmk00<0
05:DDY@0;e:D00<007ooOol00Woo000MOol00`00DYABU011DY@01000Kg]_NfmkSP00RE:D00<006mk
Kg/02@001fmk00<005:DDY@0;U:D00<007ooOol00Woo000MOol00`00DYABU011DY@00`00Kg]_N`03
Kg/00`00DYABU016DYC?00000goo00000002000;Kg/00`00DYABU00^DY@00`00Oomoo`02Ool001eo
o`03001BU5:D045BU003001_Nfmk009_N`03001BU5:D0:aBU6/0011_N`03001BU5:D02eBU003001o
ogoo009oo`007Goo00<005:DDY@0@5:D00<006mkKg/00fmk00<005:DDY@0oe:D5E:D00<006mkKg/0
46mk00<005:DDY@0;E:D00<007ooOol00Woo000MOol00`00DYABU010DY@00`00Kg]_N`03Kg/00`00
DYABU03oDY@FDY@00`00Kg]_N`0?Kg/00`00DYABU00]DY@00`00Oomoo`02Ool001eoo`03001BU5:D
041BU003001_Nfmk009_N`03001BU5:D0?mBU1QBU003001_Nfmk00m_N`03001BU5:D02aBU003001o
ogoo009oo`007Goo00<005:DDY@0@5:D00<006mkKg/00Vmk00<005:DDY@0oe:D65:D00<006mkKg/0
3fmk00<005:DDY@0;5:D00<007ooOol00Woo000MOol00`00DYABU00oDY@00`00Kg]_N`02Kg/00`00
DYABU03oDY@JDY@00`00Kg]_N`0?Kg/00`00DYABU00ZDY@20004Ool001eoo`03001BU5:D03mBU003
001_Nfmk009_N`03001BU5:D0?mBU1]BU003001_Nfmk00i_N`03001BU5:D02QBU0800003DY@007oo
00=oo`007Goo00<005:DDY@0?e:D00<006mkKg/00Vmk00<005:DDY@0oe:D6e:D00<006mkKg/03fmk
00<005:DDY@09U:D0P000U:D00<007ooOol00Woo000MOol00`00DYABU00nDY@00`00Kg]_N`02Kg/0
0`00DYABU03oDY@MDY@00`00Kg]_N`0>Kg/00`00DYABU00TDY@30003DY@00`00Oomoo`02Ool001eo
o`03001BU5:D03iBU003001_Nfmk009_N`03001BU5:D0?mBU1eBU003001_Nfmk00i_N`03001BU5:D
029BU0800003Kg/005:D00=BU003001oogoo009oo`007Goo00<005:DDY@0?E:D00<006mkKg/00Vmk
00<005:DDY@0oe:D7e:D00<006mkKg/03Vmk00<005:DDY@07e:D0P0000=_N`0000001E:D00<007oo
Ool00Woo000MOol00`00DYABU00lDY@00`00Kg]_N`02Kg/00`00DYABU03oDY@PDY@00`00Kg]_N`0>
Kg/00`00DYABU00MDY@20002Kg/00`00DYABU005DY@00`00Oomoo`02Ool001eoo`h0035BU003001_
Nfmk009_N`03001BU5:D0?mBU21BU003001_Nfmk00m_N`03001BU5:D01YBU08000=_N`03001BU5:D
00IBU003001oogoo009oo`007Goo00<006mkKg/02fmk2000:5:D00<006mkKg/00Vmk00<005:DDY@0
oe:D8U:D00<006mkKg/03Vmk00<005:DDY@065:D0P0016mk00<005:DDY@01e:D00<007ooOol00Woo
000MOol00`00Kg]_N`0CKg/9000ODY@00`00Kg]_N`02Kg/00`00DYABU03oDY@RDY@00`00Kg]_N`0?
Kg/00`00DYABU00EDY@20005Kg/00`00DYABU008DY@00`00Oomoo`02Ool001eoo`03001_Nfmk01a_
N`P001IBU003001_Nfmk009_N`03001BU5:D0?mBU2ABU003001_Nfmk00i_N`03001BU5:D01=BU080
00E_N`8000YBU08000Aoo`007Goo00<006mkKg/096mk2@0035:D00<006mkKg/00Vmk00<005:DDY@0
oe:D9E:D00<006mkKg/03Vmk00<005:DDY@04E:D0P001Vmk00<005:DDY@02E:D00<002e[000017oo
000MOol5000[Kg/80004DY@00`00Kg]_N`02Kg/00`00DYABU03oDY@VDY@00`00Kg]_N`0>Kg/00`00
DYABU00>DY@20006Kg/2000;DY@01000;F/]J`0017oo000MOol00`00DYABU002DY@9000ZKg/=003o
DY@UDY@00`00Kg]_N`0>Kg/00`00DYABU00;DY@30007Kg/00`00DYABU00:DY@01@00;F/]Jbe[0000
17oo000MOol00`00DYABU00;DY@6000WKg/00`00Oomoo`03Ool01000Kg]_Nfmk6@00oe:D3E:D00<0
06mkKg/03Vmk00<005:DDY@025:D0P002Fmk00<005:DDY@02e:D00D002e[;F/]J`0000Aoo`007Goo
00<005:DDY@04E:D1@008Vmk00<007ooOol017oo00<006mkKg/06Fmk8P00jU:D00<006mkKg/03Vmk
00<005:DDY@01U:D0P002Fmk0P003E:D00<002e[;F/00Re[00<007ooOol00Woo000MOol00`00DYAB
U00FDY@6000LKg/00`00Oomoo`05Ool00`00Kg]_N`0jKg/Q003:DY@00`00Kg]_N`0>Kg/00`00DYAB
U003DY@2000:Kg/00`00DYABU00<DY@00`00;F/]J`03;F/00`00Oomoo`02Ool001eoo`03001BU5:D
01aBU0T001A_N`03001oogoo00Aoo`l004m_NbX00:1BU003001_Nfmk00i_N`04001BU5:DDY@2000;
Kg/00`00DYABU00<DY@00`00;F/]J`04;F/00`00Oomoo`02Ool001eoo`03001BU5:D02EBU0T000]_
N`04001oogooOol30003Kg/30009DY@Q001HKg/Z001gDY@00`00Kg]_N`0=Kg/01000DY@0000036mk
00<005:DDY@035:D00<002e[;F/01Be[00<007ooOol00Woo000MOol00`00DYABU00^DY@80003Kg/4
0009Kg/3000WDY@R001PKg/b0015DY@00`00Kg]_N`0<Kg/80008Kg/00`00DYABU00=DY@00`00;F/]
J`05;F/00`00Oomoo`02Ool001eoo`03001BU5:D03IBU0D000i_N`<004IBU240075_NcX000]BU003
001_Nfmk00A_N`P000Qoo`T000iBU003000]Jbe[00H]J`03001oogoo009oo`007Goo00<005:DDY@0
>e:D0P003fmk0`00I5:D<P00NFmk4P004Woo0`0016mk00<005:DDY@02U:D00<002e[;F/01be[00<0
07ooOol00Woo000MOol00`00DYABU00mDY@3000?Kg/3002CDYA3000oKg/2000FOol30008Kg/00`00
DYABU008DY@00`00;F/]J`08;F/00`00Oomoo`02Ool001eoo`03001BU5:D041BU080011_N`800=AB
U44001=oo`<000a_N`03001BU5:D00EBU08000/]J`03001oogoo009oo`007Goo00<005:DDY@0@U:D
0P0046mk0`00oe:D3E:D0P0016mk100037oo0`0046mk00<005:DDY@00e:D00<002e[;F/02be[00<0
07ooOol00Woo000MOol00`00DYABU014DY@3000@Kg/3003oDY@7DY@3000:Kg/70002Ool3000DKg/0
1@00DYABU5:D00003Re[00<007ooOol00Woo000MOol00`00DYABU017DY@3000@Kg/3003oDY@2DY@2
000DKg/4000FKg/00`00DY@0000?;F/00`00Oomoo`02Ool001eoo`03001BU5:D04YBU0<0011_N`<0
0?aBU08001E_N`03001BU5:D009BU0<001A_Na8000Aoo`007Goo00<005:DDY@0CE:D0`0046mk0`00
me:D0P005Fmk0P0025:D100046mk00<005:DDY@03U:D00<007ooOol00Woo000MOol00`00DYABU01@
DY@3000@Kg/3003bDY@2000EKg/2000>DY@3000=Kg/00`00DYABU00>DY@00`00Oomoo`02Ool001eo
o`03001BU5:D05=BU080015_N`@00>aBU08001I_N`03001BU5:D015BU0<000]_N`03001BU5:D00eB
U003001oogoo009oo`007Goo00<005:DDY@0EE:D0P004fmk0`00ie:D0P005Vmk0P005e:D0`0026mk
00<005:DDY@03E:D00<007ooOol00Woo000MOol00`00DYABU01GDY@2000DKg/3003RDY@2000GKg/0
0`00DYABU00JDY@20006Kg/00`00DYABU00=DY@00`00Oomoo`02Ool001eoo`03001BU5:D05UBU080
01E_N`<00=eBU08001M_N`8001mBU08000A_N`03001BU5:D00eBU003001oogoo009oo`007Goo00<0
05:DDY@0Fe:D0P005Vmk0`00f5:D0P005fmk0P008e:D0`0000=_N`00DY@03U:D00<007ooOol00Woo
0008Ool00`00Oomoo`03Ool20004Ool20007Ool00`00DYABU01MDY@3000FKg/3003CDY@2000HKg/0
0`00DYABU00VDY@3000>DY@00`00Oomoo`02Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`001Woo00<005:DDY@0H5:D0`005Vmk0`00cU:D0P0066mk0P00:e:D400017oo0009Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00Aoo`03001BU5:D06=BU0<001I_N`80
0<UBU0<001U_N`03001BU5:D02]BU003000]Jbe[00`]J`03001oogoo009oo`002Goo00D007ooOomo
o`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU01VDY@3000EKg/30034DY@2000K
Kg/00`00DYABU00[DY@00`00;F/]J`0=;F/00`00Oomoo`02Ool000Yoo`04001oogoo0002Ool01000
Oomoo`000Woo00<007ooOol017oo00<005:DDY@0JE:D0`005Fmk0`00_e:D0P006fmk0P00;E:D00<0
02e[;F/03Re[00<007ooOol00Woo0006Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001o
ogoo0006Ool00`00DYABU01/DY@2000FKg/2002kDY@2000LKg/00`00DYABU00/DY@00`00;F/]J`0?
;F/00`00Oomoo`02Ool000Ioo`D000=oo`8000Aoo`8000Moo`03001BU5:D06iBU0<001E_N`<00;IB
U08001e_N`03001BU5:D02eBU003000]Jbe[00l]J`03001oogoo009oo`007Goo00<005:DDY@0LE:D
0`005Fmk0`00/E:D0P007Fmk0P00;e:D00<002e[;F/042e[00<007ooOol00Woo000MOol00`00DYAB
U01dDY@3000EKg/3002/DY@2000NKg/00`00DYABU00^DY@00`00;F/]J`0A;F/00`00Oomoo`02Ool0
01eoo`03001BU5:D07MBU0<001E_N`<00:QBU003001_Nfmk01e_N`03001BU5:D02iBU003000]Jbe[
018]J`03001oogoo009oo`007Goo00<005:DDY@0NU:D0`005Fmk0`00Xe:D0P007Vmk0P00<E:D00<0
02e[;F/04Re[00<007ooOol00Woo000MOol00`00DYABU01mDY@2000FKg/3002NDY@2000OKg/00`00
DYABU00`DY@00`00;F/]J`0C;F/00`00Oomoo`02Ool001eoo`03001BU5:D07mBU0<001I_N`@009UB
U003001_Nfmk01i_N`03001BU5:D031BU003000]Jbe[01@]J`03001oogoo009oo`007Goo00<005:D
DY@0PU:D0`005fmk1000Te:D0P007fmk0P00<U:D00<002e[;F/05Be[00<007ooOol00Woo000MOol0
0`00DYABU025DY@2000IKg/3002>DY@2000PKg/00`00DYABU00bDY@00`00;F/]J`0E;F/00`00Oomo
o`02Ool001eoo`03001BU5:D08MBU0<001U_N`<008QBU0<0021_N`8003ABU003000]Jbe[01H]J`03
001oogoo009oo`007Goo00<005:DDY@0RU:D0`006Fmk0P00Q5:D0P008Fmk0P00=E:D00<002e[;F/0
5be[00<007ooOol00Woo000MOol00`00DYABU02=DY@3000HKg/3001oDY@2000RKg/00`00DYABU00d
DY@00`00;F/]J`0H;F/00`00Oomoo`02Ool001eoo`03001BU5:D091BU0<001Q_N`<007YBU080029_
N`8003MBU003000]Jbe[01P]J`03001oogoo009oo`007Goo00<005:DDY@0Te:D0`0066mk0P00MU:D
0P008fmk00<005:DDY@0=U:D00<002e[;F/06Be[00<007ooOol00Woo000MOol00`00DYABU02FDY@2
000HKg/3001aDY@2000TKg/00`00DYABU00fDY@00`00;F/]J`0J;F/00`00Oomoo`02Ool001eoo`03
001BU5:D09QBU0<001Q_N`<006aBU08002A_N`8003QBU003000]Jbe[01/]J`03001oogoo009oo`00
7Goo00<005:DDY@0Ve:D0`0066mk0`00J5:D00<006mkKg/08fmk00<005:DDY@0=e:D00<002e[;F/0
72e[00<007ooOol00Woo000MOol00`00DYABU02NDY@3000HKg/5001QDY@2000UKg/00`00DYABU00g
DY@00`00;F/]J`0M;F/00`00Oomoo`02Ool001eoo`03001BU5:D0:5BU0<001Y_N`<005aBU08002E_
N`8003UBU003000]Jbe[01h]J`03001oogoo009oo`007Goo00<005:DDY@0Y5:D0`006Vmk0`00F5:D
00<006mkKg/096mk00<005:DDY@0>5:D00<002e[;F/07be[00<007ooOol00Woo000MOol00`00DYAB
U02WDY@2000KKg/3001CDY@2000UKg/2000kDY@00`00;F/]J`0O;F/00`00Oomoo`02Ool001eoo`03
001BU5:D0:UBU0<001]_N`8004mBU08002E_N`8003aBU003000]Jbe[020]J`03001oogoo009oo`00
7Goo00<005:DDY@0[5:D0`006Vmk0`00BE:D0`009Vmk00<005:DDY@0>e:D00<002e[;F/08Be[00<0
07ooOol00Woo000MOol00`00DYABU02_DY@2000KKg/30014DY@2000WKg/2000mDY@00`00;F/]J`0R
;F/00`00Oomoo`02Ool001eoo`03001BU5:D0;5BU0<001]_N`<003mBU08002Q_N`03001BU5:D03eB
U003000]Jbe[028]J`03001oogoo009oo`007Goo00<005:DDY@0]5:D0`006fmk0`00>e:D00<006mk
Kg/09fmk00<005:DDY@0?E:D00<002e[;F/08be[00<007ooOol00Woo000MOol00`00DYABU02gDY@3
000KKg/3000fDY@2000XKg/2000oDY@00`00;F/]J`0T;F/00`00Oomoo`02Ool001eoo`03001BU5:D
0;YBU0<001]_N`80039BU08002U_N`03001BU5:D03iBU003000]Jbe[02D]J`03001oogoo009oo`00
7Goo00<005:DDY@0_E:D0`006Vmk0`00;U:D00<006mkKg/0:6mk00<005:DDY@0?e:D00<002e[;F/0
9Be[00<007ooOol00Woo000MOol00`00DYABU030DY@2000KKg/3000YDY@2000YKg/20011DY@00`00
;F/]J`0V;F/00`00Oomoo`02Ool001eoo`03001BU5:D0<9BU0<001]_N`<002ABU08002Y_N`03001B
U5:D041BU003000]Jbe[02L]J`03001oogoo009oo`007Goo00<005:DDY@0aE:D0`006fmk10007U:D
0P00:fmk00<005:DDY@0@5:D00<002e[;F/0:2e[00<007ooOol00Woo000MOol00`00DYABU038DY@3
000LKg/4000HDY@2000[Kg/20012DY@00`00;F/]J`0Y;F/00`00Oomoo`02Ool001eoo`03001BU5:D
0<]BU0<001e_N`<001=BU08002a_N`03001BU5:D045BU003000]Jbe[02X]J`03001oogoo009oo`00
7Goo00<005:DDY@0cU:D0`007Fmk0`003U:D0P00;Fmk00<005:DDY@0@E:D00<002e[;F/0:be[00<0
07ooOol00Woo000MOol00`00DYABU03ADY@2000NKg/2000:DY@2000]Kg/20013DY@00`00;F/]J`0/
;F/00`00Oomoo`02Ool001eoo`03001BU5:D0==BU0<001e_N`<000IBU003001_Nfmk02]_N`8004EB
U003000]Jbe[02`]J`03001oogoo009oo`007Goo00<005:DDY@0eU:D0`007Fmk0`0000=BU0000000
;6mk0P00AU:D00<002e[;F/0;Be[00<007ooOol00Woo000MOol00`00DYABU03IDY@3000JKg/9000X
Kg/00`00DYABU015DY@00`00;F/]J`0^;F/00`00Oomoo`02Ool001eoo`03001BU5:D0=aBU0<000]_
N``000Uooa4001E_N`8004MBU003000]Jbe[02l]J`03001oogoo009oo`007Goo00<005:DDY@0ge:D
0`000fmk1@009Woo5`00AU:D00<002e[;F/0<2e[00<007ooOol00Woo000MOol00`00DYABU03QDY@T
0007OolE0006Kg/50010DY@00`00;F/]J`0a;F/00`00Oomoo`02Ool001eoo`03001BU5:D0>1BU003
001_Nfmk029_N`T001i_N`@003]BU003000]Jbe[038]J`03001oogoo009oo`007Goo00<005:DDY@0
gU:D0P009Vmk00<005:DDY@01E:D1P0076mk1@00=E:D00<002e[;F/0<be[00<007ooOol00Woo000M
Ool00`00DYABU03MDY@00`00Kg]_N`0UKg/00`00DYABU00<DY@5000LKg/4000`DY@00`00;F/]J`0d
;F/00`00Oomoo`02Ool001eoo`03001BU5:D0=]BU08002I_N`8001ABU0L001U_N`D002YBU003000]
Jbe[03D]J`03001oogoo009oo`007Goo00<005:DDY@0fU:D00<006mkKg/09Fmk00<005:DDY@06e:D
2@005Fmk1`008U:D00<002e[;F/0=Re[00<007ooOol00Woo000MOol00`00DYABU03HDY@2000WKg/0
0`00DYABU00UDY@9000CKg/6000KDY@00`00;F/]J`0g;F/00`00Oomoo`02Ool001eoo`03001BU5:D
0=MBU003001_Nfmk02E_N`80035BU0P0015_N`@001IBU003000]Jbe[03P]J`03001oogoo009oo`00
7Goo00<005:DDY@0eE:D0P009fmk00<005:DDY@0>E:D2@0036mk1`003U:D00<002e[;F/0>Be[00<0
07ooOol00Woo000MOol00`00DYABU03DDY@00`00Kg]_N`0VKg/00`00DYABU00mDY@00`00DYABU003
DY@L0004DY@00`00;F/]J`0j;F/00`00Oomoo`02Ool000Qoo`03001oogoo009oo`<000Aoo`8000Mo
o`03001BU5:D0==BU003001_Nfmk02I_N`03001BU5:D03eBU08001QBU0d003d]J`03001oogoo009o
o`0027oo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU03BDY@0
0`00Kg]_N`0VKg/00`00DYABU00mDY@00`00;F/0000TDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool0
00Uoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU03ADY@00`00Kg]_
N`0VKg/00`00DYABU00nDY@00`00;F/0000TDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool000Uoo`03
001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00DYABU03@DY@00`00Kg]_N`0VKg/0
0`00DYABU00nDY@01@00;F/]Jbe[00008e:D00<002e[;F/0>be[00<007ooOol00Woo000:Ool00`00
Ool000030003Ool01000Oomoo`001Woo00<005:DDY@0ce:D00<006mkKg/09Vmk00<005:DDY@0?U:D
00<002e[;F/00Re[00<005:DDY@08E:D00<002e[;F/0>be[00<007ooOol00Woo0006Ool01`00Oomo
ogoo001oo`0000Ioo`04001oogoo0006Ool00`00DYABU03>DY@00`00Kg]_N`0UKg/20011DY@00`00
;F/]J`02;F/00`00DYABU00QDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool000Ioo`D00003Ool00000
00<000=oo`8000Moo`03001BU5:D0<aBU08002M_N`03001BU5:D041BU003000]Jbe[00<]J`03001B
U5:D025BU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:DDY@0be:D00<006mkKg/09Vmk
00<005:DDY@0@5:D00<002e[;F/012e[00<005:DDY@08E:D00<002e[;F/0>be[00<007ooOol00Woo
000MOol00`00DYABU03:DY@00`00Kg]_N`0UKg/20013DY@00`00;F/]J`04;F/00`00DYABU00QDY@0
0`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D0<UBU003001_Nfmk02E_N`03001BU5:D
049BU003000]Jbe[00D]J`03001BU5:D025BU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<0
05:DDY@0b5:D00<006mkKg/09Fmk00<005:DDY@0@U:D00<002e[;F/01be[00<005:DDY@085:D00<0
02e[;F/0>be[00<007ooOol00Woo000MOol00`00DYABU037DY@00`00Kg]_N`0UKg/00`00DYABU013
DY@00`00;F/]J`07;F/00`00DYABU00PDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001B
U5:D0<IBU003001_Nfmk02A_N`8004EBU003000]Jbe[00P]J`03001BU5:D021BU003000]Jbe[03/]
J`03001oogoo009oo`007Goo00<005:DDY@0aE:D00<006mkKg/096mk00<005:DDY@0A5:D00<002e[
;F/02Be[00<005:DDY@085:D00<002e[;F/0>be[00<007ooOol00Woo000MOol00`00DYABU034DY@0
0`00Kg]_N`0TKg/00`00DYABU015DY@00`00;F/]J`0:;F/00`00DYABU00ODY@00`00;F/]J`0k;F/0
0`00Oomoo`02Ool001eoo`03001BU5:D0<ABU003001_Nfmk02=_N`03001BU5:D04EBU003000]Jbe[
00/]J`03001BU5:D01mBU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:DDY@0`e:D00<0
06mkKg/08fmk00<005:DDY@0AE:D00<002e[;F/032e[00<005:DDY@07e:D00<002e[;F/0>be[00<0
07ooOol00Woo000MOol00`00DYABU032DY@00`00Kg]_N`0SKg/00`00DYABU016DY@00`00;F/]J`0<
;F/00`00DYABU00ODY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D0<5BU003001_
Nfmk02=_N`03001BU5:D04IBU003000]Jbe[00d]J`03001BU5:D01mBU003000]Jbe[03/]J`03001o
ogoo009oo`007Goo00<005:DDY@0`5:D00<006mkKg/08Vmk0P00B5:D00<002e[;F/03Re[00<005:D
DY@07e:D00<002e[;F/0>be[00<007ooOol00Woo000MOol00`00DYABU030DY@00`00Kg]_N`0QKg/0
0`00DYABU017DY@00`00;F/]J`0@;F/00`00DYABU00NDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool0
01eoo`03001BU5:D0;mBU003001_Nfmk025_N`03001BU5:D04MBU003000]Jbe[014]J`03001BU5:D
01iBU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:DDY@0_U:D00<006mkKg/08Fmk00<0
05:DDY@0B5:D00<002e[;F/04Be[00<005:DDY@07U:D00<002e[;F/0>be[00<007ooOol00Woo000M
Ool00`00DYABU02mDY@00`00Kg]_N`0QKg/00`00DYABU018DY@00`00;F/]J`0B;F/00`00DYABU00N
DY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D0;aBU003001_Nfmk025_N`03001B
U5:D04QBU003000]Jbe[01<]J`03001BU5:D01iBU003000]Jbe[03/]J`03001oogoo009oo`007Goo
00<005:DDY@0^e:D00<006mkKg/08Fmk00<005:DDY@0B5:D00<002e[;F/052e[00<005:DDY@07U:D
00<002e[;F/0>be[00<007ooOol00Woo000MOol00`00DYABU02jDY@00`00Kg]_N`0QKg/00`00DYAB
U019DY@00`00;F/]J`0D;F/00`00DYABU00NDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03
001BU5:D0;UBU003001_Nfmk025_N`03001BU5:D04UBU003000]Jbe[01D]J`03001BU5:D01iBU003
000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:DDY@0^5:D00<006mkKg/08Fmk00<005:DDY@0
BE:D00<002e[;F/05Re[00<005:DDY@07U:D00<002e[;F/0>be[00<007ooOol00Woo000MOol00`00
DYABU02gDY@00`00Kg]_N`0QKg/00`00DYABU01:DY@00`00;F/]J`0G;F/00`00DYABU00MDY@00`00
;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D0;IBU003001_Nfmk025_N`03001BU5:D04YB
U003000]Jbe[01P]J`03001BU5:D01eBU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:D
DY@0]E:D00<006mkKg/08Fmk00<005:DDY@0BU:D00<002e[;F/06Be[00<005:DDY@07E:D00<002e[
;F/0>be[00<007ooOol00Woo000MOol00`00DYABU02eDY@00`00Kg]_N`0PKg/00`00DYABU01;DY@0
0`00;F/]J`0I;F/00`00DYABU00MDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D
0;ABU003001_Nfmk021_N`03001BU5:D04]BU003000]Jbe[01X]J`03001BU5:D01eBU003000]Jbe[
03/]J`03001oogoo009oo`007Goo00<005:DDY@0/e:D00<006mkKg/086mk00<005:DDY@0Be:D00<0
02e[;F/06be[00<005:DDY@07E:D00<002e[;F/0>be[00<007ooOol00Woo000MOol00`00DYABU02b
DY@00`00Kg]_N`0OKg/2001>DY@00`00;F/]J`0K;F/00`00DYABU00MDY@00`00;F/]J`0k;F/00`00
Oomoo`02Ool001eoo`03001BU5:D0;5BU003001_Nfmk01m_N`03001BU5:D04eBU003000]Jbe[01`]
J`03001BU5:D01eBU003000]Jbe[03/]J`03001oogoo009oo`007Goo00<005:DDY@0/5:D00<006mk
Kg/07fmk00<005:DDY@0CE:D00<002e[;F/07Be[00<005:DDY@07E:D00<002e[;F/0>be[00<007oo
Ool00Woo000MOol00`00DYABU02_DY@00`00Kg]_N`0NKg/2001?DY@00`00;F/]J`0O;F/00`00DYAB
U00LDY@00`00;F/]J`0k;F/00`00Oomoo`02Ool001eoo`03001BU5:D0:iBU003001_Nfmk01i_N`03
001BU5:D04iBU003000]Jbe[020]J`03001BU5:D01aBU003000]Jbe[03/]J`03001oogoo009oo`00
7Goo00<005:DDY@0[U:D00<006mkKg/07Fmk00<005:DDY@0Ce:D00<002e[;F/082e[00<005:DDY@0
6e:D00<002e[;F/0?2e[00<007ooOol00Woo000MOol00`00DYABU02]DY@00`00Kg]_N`0MKg/00`00
DYABU01?DY@00`00;F/]J`0Q;F/00`00DYABU00KDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool001eo
o`03001BU5:D0:aBU003001_Nfmk01a_N`80055BU003000]Jbe[028]J`03001BU5:D01]BU003000]
Jbe[03`]J`03001oogoo009oo`007Goo00<005:DDY@0Ze:D00<006mkKg/076mk00<005:DDY@0D5:D
00<002e[;F/08be[00<005:DDY@06e:D00<002e[;F/0?2e[00<007ooOol00Woo000MOol00`00DYAB
U02ZDY@00`00Kg]_N`0LKg/00`00DYABU01ADY@00`00;F/]J`0S;F/00`00DYABU00KDY@00`00;F/]
J`0l;F/00`00Oomoo`02Ool001eoo`03001BU5:D0:UBU003001_Nfmk01a_N`03001BU5:D055BU003
000]Jbe[02@]J`03001BU5:D01]BU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<005:DDY@0
Z5:D00<006mkKg/076mk00<005:DDY@0DE:D00<002e[;F/09Re[00<005:DDY@06U:D00<002e[;F/0
?2e[00<007ooOol00Woo000MOol00`00DYABU02WDY@00`00Kg]_N`0LKg/00`00DYABU01ADY@00`00
;F/]J`0W;F/00`00DYABU00JDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool001eoo`03001BU5:D0:MB
U003001_Nfmk01]_N`03001BU5:D055BU003000]Jbe[02P]J`03001BU5:D01YBU003000]Jbe[03`]
J`03001oogoo009oo`007Goo00<005:DDY@0YU:D00<006mkKg/06fmk00<005:DDY@0DE:D00<002e[
;F/0:Be[00<005:DDY@06U:D00<002e[;F/0?2e[00<007ooOol00Woo000MOol00`00DYABU02UDY@0
0`00Kg]_N`0JKg/2001CDY@00`00;F/]J`0Z;F/00`00DYABU00JDY@00`00;F/]J`0l;F/00`00Oomo
o`02Ool001eoo`03001BU5:D0:EBU003001_Nfmk01U_N`03001BU5:D059BU003000]Jbe[02/]J`03
001BU5:D01YBU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<005:DDY@0Y5:D00<006mkKg/0
6Fmk00<005:DDY@0De:D00<002e[;F/0:be[00<005:DDY@06U:D00<002e[;F/0?2e[00<007ooOol0
0Woo000MOol00`00DYABU02SDY@00`00Kg]_N`0IKg/00`00DYABU01CDY@00`00;F/]J`0/;F/00`00
DYABU00JDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool001eoo`03001BU5:D0:=BU003001_Nfmk01Q_
N`03001BU5:D05=BU003000]Jbe[02d]J`03001BU5:D01YBU003000]Jbe[03`]J`03001oogoo009o
o`007Goo00<005:DDY@0XU:D00<006mkKg/066mk00<005:DDY@0De:D00<002e[;F/0;be[00<005:D
DY@06E:D00<002e[;F/0?2e[00<007ooOol00Woo0007Ool30004Ool20004Ool20007Ool00`00DYAB
U02QDY@00`00Kg]_N`0HKg/00`00DYABU01CDY@00`00;F/]J`0`;F/00`00DYABU00IDY@00`00;F/]
J`0l;F/00`00Oomoo`02Ool000Ioo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
00Ioo`03001BU5:D0:5BU003001_Nfmk01I_N`8005IBU003000]Jbe[030]J`03001BU5:D01UBU003
000]Jbe[03`]J`03001oogoo009oo`001Woo00D007ooOomoo`00009oo`04001oogoo0002Ool01000
Oomoo`001Woo00<005:DDY@0X5:D00<006mkKg/05Vmk00<005:DDY@0EE:D00<002e[;F/0<Be[00<0
05:DDY@06E:D00<002e[;F/0?2e[00<007ooOol00Woo0007Ool30003Ool01000Oomoo`000Woo00@0
07ooOol000Ioo`03001BU5:D09mBU003001_Nfmk01I_N`03001BU5:D05EBU003000]Jbe[038]J`03
001BU5:D01UBU003000]Jbe[03`]J`03001oogoo009oo`001Woo00D007ooOomoo`00009oo`04001o
ogoo0002Ool01000Oomoo`001Woo00<005:DDY@0WU:D00<006mkKg/05Vmk00<005:DDY@0E5:D0P00
=Be[00<005:DDY@06E:D00<002e[;F/0?2e[00<007ooOol00Woo0006Ool01@00Oomoogoo00000Woo
00@007ooOol0009oo`04001oogoo0006Ool00`00DYABU02MDY@00`00Kg]_N`0FKg/00`00DYABU01D
DY@00`00;F/]J`0e;F/00`00DYABU00IDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool000Moo`<000Ao
o`8000Aoo`8000Moo`03001BU5:D09aBU003001_Nfmk01I_N`03001BU5:D05ABU003000]Jbe[03H]
J`03001BU5:D01UBU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<005:DDY@0Ve:D00<006mk
Kg/05Vmk00<005:DDY@0E5:D00<002e[;F/0>2e[00<005:DDY@065:D00<002e[;F/0?2e[00<007oo
Ool00Woo000MOol00`00DYABU02HDY@B0009Kg/00`00DYABU01DDY@00`00;F/]J`0i;F/00`00DYAB
U00HDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool001eoo`03001BU5:D09ABU0@000A_N`<000]ooaH0
04UBU003000]Jbe[03X]J`03001BU5:D01QBU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<0
05:DDY@0TE:D0`002fmk10003goo00<006mkKg/02fmk4000>5:D00<002e[;F/0>be[00<005:DDY@0
65:D00<002e[;F/0?2e[00<007ooOol00Woo000MOol00`00DYABU02>DY@3000BKg/4000:Ool00`00
Kg]_N`0LKg/I000NDY@00`00;F/]J`0l;F/00`00DYABU00HDY@00`00;F/]J`0l;F/00`00Oomoo`02
Ool001eoo`03001BU5:D08]BU0<001U_N`<000Ioo`03001_Nfmk03I_Na4000aBU003000]Jbe[03d]
J`03001BU5:D01QBU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<005:DDY@0RE:D0P007fmk
10000Woo00<006mkKg/09Vmk;@00@2e[00<005:DDY@065:D00<002e[;F/0?2e[00<007ooOol00Woo
000MOol00`00DYABU026DY@3000TKg//000/DY@00`00;F/]J`0n;F/00`00DYABU00HDY@00`00;F/]
J`0l;F/00`00Oomoo`02Ool001eoo`03001BU5:D08=BU0<002=_N`@000=BU0<00003;F/005:D051B
U003000]Jbe[03d]J`03001BU5:D01QBU003000]Jbe[03`]J`03001oogoo009oo`007Goo00<005:D
DY@0Oe:D10008fmk0`0015:D0`001Be[00<005:DDY@0CU:D00<002e[;F/0?Re[00<005:DDY@05e:D
00<002e[;F/0?2e[00<007ooOol00Woo000MOol00`00DYABU01kDY@4000TKg/30004DY@30008;F/0
0`00DYABU01>DY@00`00;F/]J`0n;F/00`00DYABU00GDY@00`00;F/]J`0l;F/00`00Oomoo`02Ool0
01eoo`03001BU5:D07QBU0<002E_N`<000ABU0<000`]J`03001BU5:D04iBU003000]Jbe[03d]J`03
001BU5:D01IBU003000]Jbe[03d]J`03001oogoo009oo`007Goo00<005:DDY@0ME:D0`008Vmk1P00
15:D0`003be[00<005:DDY@0CU:D00<002e[;F/0?Be[00<005:DDY@05U:D00<002e[;F/0?Be[00<0
07ooOol00Woo000MOol00`00DYABU01bDY@3000PKg/50007DY@3000B;F/00`00DYABU01>DY@00`00
;F/]J`0m;F/00`00DYABU00FDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool001eoo`03001BU5:D06mB
U0<0021_N`<000QBU0@001H]J`03001BU5:D04iBU003000]Jbe[03`]J`03001BU5:D01IBU003000]
Jbe[03d]J`03001oogoo009oo`007Goo00<005:DDY@0JU:D1@0086mk0`0025:D0`006Re[00<005:D
DY@0CU:D00<002e[;F/0?Be[00<005:DDY@05E:D00<002e[;F/0?Be[00<007ooOol00Woo000MOol0
0`00DYABU01WDY@3000QKg/40008DY@3000N;F/00`00DYABU01=DY@00`00;F/]J`0m;F/00`00DYAB
U00EDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool001eoo`03001BU5:D06ABU0<0021_N`@000UBU0<0
024]J`03001BU5:D04eBU003000]Jbe[03d]J`03001BU5:D01EBU003000]Jbe[03d]J`03001oogoo
009oo`007Goo00<005:DDY@0HE:D0`007fmk10002E:D10009Be[00<005:DDY@0C5:D00<002e[;F/0
?Be[00<005:DDY@05E:D00<002e[;F/0?Be[00<007ooOol00Woo000MOol00`00DYABU01NDY@3000M
Kg/50009DY@4000Y;F/00`00DYABU01=DY@00`00;F/]J`0l;F/00`00DYABU00EDY@00`00;F/]J`0m
;F/00`00Oomoo`02Ool001eoo`03001BU5:D05YBU0@001a_N`@000YBU0@002h]J`03001BU5:D04aB
U003000]Jbe[03d]J`03001BU5:D01ABU003000]Jbe[03d]J`03001oogoo009oo`007Goo00<005:D
DY@0EU:D100076mk10002U:D1000<Re[00<005:DDY@0C5:D00<002e[;F/0?Be[00<005:DDY@055:D
00<002e[;F/0?Be[00<007ooOol00Woo000MOol00`00DYABU01BDY@4000JKg/6000:DY@4000f;F/0
0`00DYABU01<DY@00`00;F/]J`0m;F/00`00DYABU00DDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool0
01eoo`03001BU5:D04mBU0<001M_N`L000]BU0D003/]J`03001BU5:D04]BU003000]Jbe[03d]J`03
001BU5:D01ABU003000]Jbe[03d]J`03001oogoo009oo`007Goo00<005:DDY@0C5:D0`005Vmk1000
3e:D0`00@2e[00<005:DDY@0Be:D00<002e[;F/0?Be[00<005:DDY@055:D00<002e[;F/0?Be[00<0
07ooOol00Woo000MOol00`00DYABU019DY@3000EKg/4000@DY@30014;F/00`00DYABU01:DY@00`00
;F/]J`0m;F/00`00DYABU00DDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool001eoo`03001BU5:D04EB
U0@001=_N`D0015BU0<004L]J`03001BU5:D04YBU003000]Jbe[03h]J`03001BU5:D01=BU003000]
Jbe[03d]J`03001oogoo009oo`007Goo00<005:DDY@0@E:D10004fmk10004e:D0`00Bbe[00<005:D
DY@0BE:D00<002e[;F/0?Re[00<005:DDY@04e:D00<002e[;F/0?Be[00<007ooOol00Woo000MOol0
0`00DYABU00kDY@6000CKg/4000CDY@4001>;F/00`00DYABU019DY@00`00;F/]J`0n;F/00`00DYAB
U00CDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool001eoo`03001BU5:D03EBU0H001=_N`H0015BU0H0
05<]J`03001BU5:D04QBU003000]Jbe[03h]J`03001BU5:D01=BU003000]Jbe[03d]J`03001oogoo
009oo`007Goo00<005:DDY@0<5:D1@004Vmk1`004E:D1P00FBe[00<005:DDY@0B5:D00<002e[;F/0
?Re[00<005:DDY@04e:D00<002e[;F/0?Be[00<007ooOol00Woo000MOol00`00DYABU00/DY@4000C
Kg/4000CDY@5001O;F/00`00DYABU018DY@00`00;F/]J`0n;F/00`00DYABU00CDY@00`00;F/]J`0m
;F/00`00Oomoo`02Ool001eoo`03001BU5:D02QBU0@0015_N`H001=BU0@006D]J`03001BU5:D04MB
U003000]Jbe[03h]J`03001BU5:D01=BU003000]Jbe[03d]J`03001oogoo009oo`007Goo00<005:D
DY@08U:D1P003Vmk1`005E:D1000JBe[00<005:DDY@0Ae:D00<002e[;F/0?Re[00<005:DDY@04e:D
00<002e[;F/0?Be[00<007ooOol00Woo000MOol00`00DYABU00JDY@8000@Kg/4000HDY@4001^;F/0
0`00DYABU016DY@00`00;F/]J`0o;F/00`00DYABU00BDY@00`00;F/]J`0m;F/00`00Oomoo`02Ool0
01eoo`03001BU5:D01ABU0H0019_N`H001QBU0@0078]J`03001BU5:D04MBU003000]Jbe[03h]J`03
001BU5:D019BU003000]Jbe[03d]J`03001oogoo009oo`007Goo00<005:DDY@03e:D1@003fmk2@00
65:D1P00Mbe[00<005:DDY@0AU:D00<002e[;F/0?Re[00<005:DDY@04U:D00<002e[;F/0?Be[00<0
07ooOol00Woo000MOol00`00DYABU009DY@6000<Kg/8000JDY@7001m;F/00`00DYABU016DY@00`00
;F/]J`0n;F/00`00DYABU00ADY@00`00;F/]J`0n;F/00`00Oomoo`02Ool001eoo`04001BU5:DDY@8
0009Kg/9000NDY@40024;F/00`00DYABU016DY@00`00;F/]J`0n;F/00`00DYABU00ADY@00`00;F/]
J`0n;F/00`00Oomoo`02Ool001eoo`@000U_N`P0025BU0H008T]J`03001BU5:D04EBU003000]Jbe[
03h]J`03001BU5:D015BU003000]Jbe[03h]J`03001oogoo009oo`007Goo00@006mkKg]_N`T0025B
U0P008l]J`03001BU5:D04EBU003000]Jbe[03h]J`03001BU5:D015BU003000]Jbe[03h]J`03001o
ogoo009oo`007Goo10008e:D1`00Ube[00<005:DDY@0AE:D00<002e[;F/0?be[00<005:DDY@045:D
00<002e[;F/0?Re[00<007ooOol00Woo000MOol00`00DYABU00PDY@4002O;F/00`00DYABU014DY@0
0`00;F/]J`0o;F/00`00DYABU00@DY@00`00;F/]J`0n;F/00`00Oomoo`02Ool001eoo`03001BU5:D
01YBU0H00:<]J`03001BU5:D04EBU003000]Jbe[03h]J`03001BU5:D011BU003000]Jbe[03h]J`03
001oogoo009oo`007Goo00<005:DDY@04U:D2000ZRe[00<005:DDY@0A5:D00<002e[;F/0?Re[00<0
05:DDY@045:D00<002e[;F/0?Re[00<007ooOol00Woo000MOol01000DYABU5:D4@00/Re[00<005:D
DY@0A5:D00<002e[;F/0?Re[00<005:DDY@045:D00<002e[;F/0?Re[00<007ooOol00Woo000MOol4
0034;F/00`00DYABU013DY@00`00;F/]J`0o;F/00`00DYABU00?DY@00`00;F/]J`0n;F/00`00Oomo
o`02Ool001eoo`03000]Jbe[0<D]J`03001BU5:D04=BU003000]Jbe[03l]J`03001BU5:D00mBU003
000]Jbe[03h]J`03001oogoo009oo`007Goo00<002e[;F/0aBe[00<005:DDY@0@e:D00<002e[;F/0
?be[00<005:DDY@03e:D00<002e[;F/0?Re[00<007ooOol00Woo000MOol00`00;F/]J`36;F/00`00
DYABU012DY@00`00;F/]J`0o;F/00`00DYABU00>DY@_000C;F/00`00Oomoo`02Ool000Moo`<000=o
o`<000Aoo`8000Moo`03000]Jbe[0<H]J`03001BU5:D049BU003000]Jbe[03l]J`03001BU5:D00aB
U0800003;F/0012402`@Q1@000Aoo`001Woo00L007ooOomoo`00Ool00003Ool01000Oomoo`000Woo
00<007ooOol017oo00<002e[;F/0abe[00<005:DDY@0@U:D00<002e[;F/0?Re[00<005:DDY@02E:D
0`000be[00<0012448@0?Q2400<007ooOol00Woo0006Ool01@00Oomoogoo00001Goo00@007ooOol0
009oo`03001oogoo00Aoo`03000]Jbe[0<L]J`03001BU5:D049BU003000]Jbe[03l]J`03001BU5:D
00EBU0<000H]J`03000@Q12403h@Q003001oogoo009oo`001goo0`001Woo00@007ooOol0009oo`03
001oogoo00Aoo`03000]Jbe[0<P]J`03001BU5:D045BU003000]Jbe[03l]J`03001BU5:D00=BU080
00T]J`03000@Q12403h@Q003001oogoo009oo`001Woo00H007ooOomoo`00Ool40003Ool01000Oomo
o`001Woo00<002e[;F/0b2e[00<005:DDY@0@E:D00<002e[;F/0?be[00<005:DDY@00`0032e[00<0
012448@0?A2400<007ooOol00Woo0006Ool01`00Oomoogoo001oo`0000Ioo`04001oogoo0006Ool0
0`00;F/]J`39;F/00`00DYABU010DY@00`00;F/]J`0k;F/7000?;F/00`0048@@Q00m48@00`00Oomo
o`02Ool000Moo`<0009oo`D000=oo`8000Moo`03000]Jbe[0<T]J`03001BU5:D041BU003000]Jbe[
03<]J`P000@@Q003000]Jbe[00l]J`03000@Q12403d@Q003001oogoo009oo`007Goo00<002e[;F/0
bBe[00<005:DDY@0@5:D00<002e[;F/0:be[20003A2400<002e[;F/03Re[00<0012448@0?A2400<0
07ooOol00Woo000MOol00`00;F/]J`3:;F/00`00DYABU00oDY@00`00;F/]J`0S;F/8000E48@00`00
;F/]J`0>;F/00`0048@@Q00m48@00`00Oomoo`02Ool001eoo`03000]Jbe[0<X]J`03001BU5:D041B
U003000]Jbe[01X]J`P001h@Q003000]Jbe[00d]J`03000@Q12403d@Q003001oogoo009oo`007Goo
00<002e[;F/0bbe[00<005:DDY@0?e:D00<002e[;F/02Be[4@009Q2400<002e[;F/03Be[00<00124
48@0?A2400<007ooOol00Woo000MOol00`00;F/]J`3;;F/00`00DYABU00oDY@01000;F/]Jbe[2000
=a2400<002e[;F/03Be[00<0012448@0?A2400<007ooOol00Woo000MOol00`00;F/]J`3<;F/00`00
DYABU00jDY@8001048@00`00;F/]J`0=;F/00`0048@@Q00l48@00`00Oomoo`02Ool001eoo`03000]
Jbe[0<d]J`03001BU5:D031BU0T000@]J`03000@Q124044@Q003000]Jbe[00d]J`03000@Q12403X@
Q0<000Aoo`007Goo00<002e[;F/0cBe[00<005:DDY@09e:D2@003Be[00<0012448@0@Q2400<002e[
;F/032e[00<0012448@0=Q241`0017oo000MOol00`00;F/]J`3>;F/00`00DYABU00NDY@8000G;F/0
0`0048@@Q01148@00`00;F/]J`0<;F/00`0048@@Q00b48@8000248@00`00Oomoo`02Ool001eoo`03
000]Jbe[0<h]J`03001BU5:D01EBU0T001l]J`03000@Q124044@Q003000]Jbe[00`]J`03000@Q124
02d@Q0T000H@Q003001oogoo009oo`007Goo00<002e[;F/0cbe[00<005:DDY@02e:D2@00:2e[00<0
012448@0@Q2400<002e[;F/02be[00<0012448@0:Q2420002Q2400<007ooOol00Woo000MOol00`00
;F/]J`3<;F/A000a;F/00`0048@@Q01248@00`00;F/]J`0;;F/00`0048@@Q00W48@6000?48@00`00
Oomoo`02Ool001eoo`03000]Jbe[0;/]Ja4000@@Q003000]Jbe[03`]J`03000@Q124044@Q003000]
Jbe[00`]J`03000@Q12402<@Q0D001<@Q003001oogoo009oo`007Goo00<002e[;F/0XBe[6P005Q24
00<002e[;F/0>be[00<0012448@0@Q2400<002e[;F/02be[00<0012448@07a241000612400<007oo
Ool00Woo000MOol00`00;F/]J`28;F/I000`48@00`00;F/]J`0k;F/00`0048@@Q01248@00`00;F/]
J`0;;F/00`0048@@Q00J48@6000K48@00`00Oomoo`02Ool001eoo`03000]Jbe[06H]Jb8004X@Q003
000]Jbe[03X]J`03000@Q124048@Q003000]Jbe[00/]J`03000@Q12401L@Q0H001h@Q003001oogoo
009oo`007Goo00<002e[;F/0ABe[8@00K12400<002e[;F/0>Re[00<0012448@0@a2400<002e[;F/0
2Re[00<0012448@051241P008A2400<007ooOol00Woo000MOol00`00;F/]J`0J;F/[002=48@00`00
;F/]J`0j;F/00`0048@@Q01348@00`00;F/]J`0:;F/00`0048@@Q00A48@5000U48@00`00Oomoo`02
Ool001eooad00;T@Q003000]Jbe[03X]J`03000@Q124048@Q003000]Jbe[00X]J`03000@Q12400d@
Q0D002T@Q003001oogoo009oo`007Goo00<0012448@0da2400<002e[;F/0>Re[00<0012448@0@a24
00<002e[;F/02Be[00<0012448@021241`00;12400<007ooOol00Woo000MOol00`0048@@Q03D48@0
0`00;F/]J`0i;F/00`0048@@Q01348@00`00;F/]J`0:;F/00`0048@@Q00448@3000012e[00000000
;a2400<007ooOol00Woo000MOol00`0048@@Q03D48@00`00;F/]J`0i;F/00`0048@@Q01448@00`00
;F/]J`09;F/0100048@@Q1241`00<Q2400<007ooOol00Woo000MOol00`0048@@Q03E48@00`00;F/]
J`0h;F/00`0048@@Q01448@00`00;F/]J`09;F/7000f48@00`00Oomoo`02Ool001eoo`03000@Q124
0=H@Q003000]Jbe[03L]J`03000@Q12404@@Q003000]Jbe[00@]J`L003/@Q003001oogoo009oo`00
7Goo00<0012448@0eQ2400<002e[;F/0=be[00<0012448@0AA241P001Be[00<0012448@0>Q2400<0
07ooOol00Woo000MOol00`0048@@Q03G48@00`00;F/]J`0g;F/00`0048@@Q01448@00`00;F/]J`08
;F/00`0048@@Q00j48@00`00Oomoo`02Ool001eoo`03000@Q1240=L@Q003000]Jbe[03L]J`03000@
Q12404@@Q003000]Jbe[00P]J`03000@Q12403X@Q003001oogoo009oo`007Goo00<0012448@0f124
00<002e[;F/0=Re[00<0012448@0A12400<002e[;F/022e[00<0012448@0>Q2400<007ooOol00Woo
000MOol00`0048@@Q03I48@00`00;F/]J`0e;F/00`0048@@Q01448@00`00;F/]J`08;F/00`0048@@
Q00j48@00`00Oomoo`02Ool001eoo`03000@Q1240=T@Q003000]Jbe[03D]J`03000@Q12404@@Q003
000]Jbe[00P]J`03000@Q12403X@Q003001oogoo009oo`007Goo00<0012448@0fQ2400<002e[;F/0
=Be[00<0012448@0@a2400<002e[;F/022e[00<0012448@0>Q2400<007ooOol00Woo000MOol00`00
48@@Q03J48@00`00;F/]J`0e;F/00`0048@@Q01348@00`00;F/]J`08;F/00`0048@@Q00j48@00`00
Oomoo`02Ool001eoo`03000@Q1240=/@Q003000]Jbe[03@]J`03000@Q12404<@Q003000]Jbe[00P]
J`03000@Q12403X@Q003001oogoo009oo`007Goo00<0012448@0fa2400<002e[;F/0=2e[00<00124
48@0@a2400<002e[;F/022e[00<0012448@0>Q2400<007ooOol00Woo000MOol00`0048@@Q03L48@0
0`00;F/]J`0d;F/00`0048@@Q01248@00`00;F/]J`08;F/00`0048@@Q00j48@00`00Oomoo`02Ool0
01eoo`03000@Q1240=`@Q003000]Jbe[03@]J`03000@Q124048@Q003000]Jbe[00P]J`03000@Q124
03X@Q003001oogoo009oo`007Goo00<0012448@0gA2400<002e[;F/0<be[00<0012448@0@Q2400<0
02e[;F/022e[00<0012448@0>Q2400<007ooOol00Woo000MOol00`0048@@Q03M48@00`00;F/]J`0c
;F/00`0048@@Q01348@00`00;F/]J`06;F/00`0048@@Q00k48@00`00Oomoo`02Ool001eoo`03000@
Q1240=h@Q003000]Jbe[03<]J`03000@Q124048@Q003000]Jbe[00H]J`03000@Q12403/@Q003001o
ogoo009oo`007Goo00<0012448@0ga2400<002e[;F/0<Re[00<0012448@0@Q2400<002e[;F/01Re[
00<0012448@0>a2400<007ooOol00Woo000MOol00`0048@@Q03O48@00`00;F/]J`0b;F/00`0048@@
Q01248@00`00;F/]J`06;F/00`0048@@Q00k48@00`00Oomoo`02Ool001eoo`03000@Q1240>0@Q003
000]Jbe[034]J`03000@Q124048@Q003000]Jbe[00H]J`03000@Q12403/@Q003001oogoo009oo`00
7Goo00<0012448@0h12400<002e[;F/0<Re[00<0012448@0@A2400<002e[;F/01Re[00<0012448@0
>a2400<007ooOol00Woo000MOol00`0048@@Q03Q48@00`00;F/]J`0a;F/00`0048@@Q01148@00`00
;F/]J`06;F/00`0048@@Q00k48@00`00Oomoo`02Ool001eoo`03000@Q1240>8@Q003000]Jbe[030]
J`03000@Q124044@Q003000]Jbe[00H]J`03000@Q12403/@Q003001oogoo009oo`007Goo00<00124
48@0hQ2400<002e[;F/0<2e[00<0012448@0@A2400<002e[;F/01Be[00<0012448@0?12400<007oo
Ool00Woo000MOol00`0048@@Q03S48@00`00;F/]J`0_;F/00`0048@@Q01148@00`00;F/]J`05;F/0
0`0048@@Q00l48@00`00Oomoo`02Ool001eoo`03000@Q1240>@@Q003000]Jbe[02l]J`03000@Q124
040@Q003000]Jbe[00D]J`03000@Q12403`@Q003001oogoo009oo`007Goo00<0012448@0i12400<0
02e[;F/0;be[00<0012448@0@12400<002e[;F/01Be[00<0012448@0?12400<007ooOol00Woo000M
Ool00`0048@@Q03U48@00`00;F/]J`0^;F/00`0048@@Q01048@00`00;F/]J`05;F/00`0048@@Q00l
48@00`00Oomoo`02Ool000Moo`8000Eoo`8000Aoo`8000Moo`03000@Q1240>D@Q003000]Jbe[02h]
J`03000@Q124040@Q003000]Jbe[00D]J`03000@Q12403`@Q003001oogoo009oo`002Goo00D007oo
Oomoo`00009oo`04001oogoo0002Ool00`00Oomoo`04Ool00`0048@@Q03V48@00`00;F/]J`0^;F/0
0`0048@@Q00o48@00`00;F/]J`05;F/00`0048@@Q00l48@00`00Oomoo`02Ool000Yoo`04001oogoo
0002Ool01000Oomoo`000Woo00<007ooOol017oo00<0012448@0ia2400<002e[;F/0;Be[00<00124
48@0?a2400<002e[;F/01Be[00<0012448@0?12400<007ooOol00Woo0007Ool40002Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03000@Q1240>L@Q003000]Jbe[02d]J`03000@Q12403l@Q003000]
Jbe[00D]J`03000@Q12403`@Q003001oogoo009oo`001Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool01000Oomoo`001Woo00<0012448@0j12400<002e[;F/0;2e[00<0012448@0?a2400<002e[
;F/01Be[00<0012448@0?12400<007ooOol00Woo0006Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0006Ool00`0048@@Q03X48@00`00;F/]J`0];F/00`0048@@Q00n48@00`00;F/]
J`05;F/00`0048@@Q00l48@00`00Oomoo`02Ool000Moo`<000Aoo`8000Aoo`8000Moo`03000@Q124
0>T@Q003000]Jbe[02`]J`03000@Q12403h@Q003000]Jbe[00D]J`03000@Q12403`@Q003001oogoo
009oo`007Goo00<0012448@0jQ2400<002e[;F/0:be[00<0012448@0?Q2400<002e[;F/01Be[00<0
012448@0?12400<007ooOol00Woo000MOol00`0048@@Q03Z48@00`00;F/]J`0/;F/00`0048@@Q00m
48@00`00;F/]J`05;F/00`0048@@Q00l48@00`00Oomoo`02Ool001eoo`03000@Q1240>/@Q003000]
Jbe[02/]J`03000@Q12403d@Q003000]Jbe[00D]J`03000@Q12403`@Q003001oogoo009oo`007Goo
00<0012448@0ja2400<002e[;F/0:be[00<0012448@0?A2400<002e[;F/01Be[00<0012448@0?124
00<007ooOol00Woo000MOol00`0048@@Q03/48@00`00;F/]J`0[;F/00`0048@@Q00l48@00`00;F/]
J`05;F/00`0048@@Q00l48@00`00Oomoo`02Ool001eoo`03000@Q1240>`@Q003000]Jbe[02/]J`03
000@Q12403d@Q003000]Jbe[00<]J`03000@Q12403d@Q003001oogoo009oo`007Goo00<0012448@0
kA2400<002e[;F/0:Re[00<0012448@0?A2400<002e[;F/00be[00<0012448@0?A2400<007ooOol0
0Woo000MOol00`0048@@Q03^48@00`00;F/]J`0Z;F/00`0048@@Q00l48@00`00;F/]J`03;F/00`00
48@@Q00m48@00`00Oomoo`02Ool001eoo`03000@Q1240>h@Q003000]Jbe[02X]J`03000@Q12403`@
Q003000]Jbe[00<]J`03000@Q12403d@Q003001oogoo009oo`007Goo00<0012448@0ka2400<002e[
;F/0:Be[00<0012448@0?12400<002e[;F/00be[00<0012448@0?A2400<007ooOol00Woo000MOol0
0`0048@@Q03_48@00`00;F/]J`0Y;F/00`0048@@Q00l48@00`00;F/]J`03;F/00`0048@@Q00m48@0
0`00Oomoo`02Ool001eoo`03000@Q1240?0@Q003000]Jbe[02T]J`03000@Q12403/@Q003000]Jbe[
00<]J`03000@Q12403d@Q003001oogoo009oo`007Goo00<0012448@0lA2400<002e[;F/0:2e[00<0
012448@0>a2400<002e[;F/00be[00<0012448@0?A2400<007ooOol00Woo000MOol00`0048@@Q03a
48@00`00;F/]J`0X;F/00`0048@@Q00k48@00`00;F/]J`03;F/00`0048@@Q00m48@00`00Oomoo`02
Ool001eoo`03000@Q1240?8@Q003000]Jbe[02L]J`03000@Q12403/@Q003000]Jbe[00<]J`03000@
Q12403d@Q003001oogoo009oo`007Goo00<0012448@0la2400<002e[;F/09be[00<0012448@0>Q24
00<002e[;F/00be[00<0012448@0?A2400<007ooOol00Woo000MOol00`0048@@Q03d48@00`00;F/]
J`0V;F/00`0048@@Q00j48@00`00;F/]J`03;F/00`0048@@Q00m48@00`00Oomoo`02Ool001eoo`03
000@Q1240?@@Q003000]Jbe[02H]J`03000@Q12403X@Q003000]Jbe[00<]J`03000@Q12403d@Q003
001oogoo009oo`007Goo00<0012448@0mA2400<002e[;F/09Be[00<0012448@0>Q2400<002e[;F/0
0be[00<0012448@0?A2400<007ooOol00Woo000MOol00`0048@@Q03f48@00`00;F/]J`0U;F/00`00
48@@Q00i48@00`00;F/]J`03;F/00`0048@@Q00m48@00`00Oomoo`02Ool001eoo`03000@Q1240?L@
Q003000]Jbe[02@]J`03000@Q12403T@Q003000]Jbe[00<]J`03000@Q12403d@Q003001oogoo009o
o`007Goo00<0012448@0ma2400<002e[;F/092e[00<0012448@0>A2400<002e[;F/00be[00<00124
48@0?A2400<007ooOol00Woo000MOol00`0048@@Q03h48@00`00;F/]J`0S;F/00`0048@@Q00i48@0
0`00;F/]J`02;F/00`0048@@Q00n48@00`00Oomoo`02Ool001eoo`03000@Q1240?T@Q003000]Jbe[
028]J`03000@Q12403T@Q003000]Jbe[008]J`03000@Q12403h@Q003001oogoo009oo`007Goo00<0
012448@0nA2400<002e[;F/08be[00<0012448@0>12400<002e[;F/00Re[00<0012448@0?Q2400<0
07ooOol00Woo000MOol00`0048@@Q03j48@00`00;F/]J`0R;F/00`0048@@Q00h48@00`00;F/]J`02
;F/00`0048@@Q00n48@00`00Oomoo`02Ool001eoo`03000@Q1240?X@Q003000]Jbe[028]J`03000@
Q12403P@Q003000]Jbe[008]J`03000@Q12403h@Q003001oogoo009oo`007Goo00<0012448@0na24
00<002e[;F/08Re[00<0012448@0=a2400<002e[;F/00Re[00<0012448@0?Q2400<007ooOol00Woo
000MOol00`0048@@Q03l48@00`00;F/]J`0Q;F/00`0048@@Q00g48@00`00;F/]J`02;F/00`0048@@
Q00n48@00`00Oomoo`02Ool001eoo`03000@Q1240?`@Q003000]Jbe[024]J`03000@Q12403L@Q003
000]Jbe[008]J`03000@Q12403h@Q003001oogoo009oo`007Goo00<0012448@0oA2400<002e[;F/0
8Be[00<0012448@0=a2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oQ24
00<002e[;F/082e[00<0012448@0=a2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0
012448@0oa2400<002e[;F/07be[00<0012448@0=a2400D002e[;F/]J`00040@Q003001oogoo009o
o`007Goo00<0012448@0oa2400<002e[;F/082e[00<0012448@0=Q2400D002e[;F/]J`00040@Q003
001oogoo009oo`007Goo00<0012448@0oa240A2400<002e[;F/07be[00<0012448@0=Q2400D002e[
;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa240Q2400<002e[;F/07Re[00<00124
48@0=Q2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa240a2400<002e[
;F/07Be[00<0012448@0=Q2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0
oa240a2400<002e[;F/07Re[00<0012448@0=A2400D002e[;F/]J`00040@Q003001oogoo009oo`00
7Goo00<0012448@0oa24112400<002e[;F/07Be[00<0012448@0=A2400D002e[;F/]J`00040@Q003
001oogoo009oo`007Goo00<0012448@0oa241A2400<002e[;F/072e[00<0012448@0=A2400D002e[
;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa241Q2400<002e[;F/06be[00<00124
48@0=A2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa241a2400<002e[
;F/06be[00<0012448@0=12400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0
oa241a2400<002e[;F/06be[00<0012448@0=12400D002e[;F/]J`00040@Q003001oogoo009oo`00
7Goo00<0012448@0oa24212400<002e[;F/06Re[00<0012448@0=12400D002e[;F/]J`00040@Q003
001oogoo009oo`007Goo00<0012448@0oa242A2400<002e[;F/06Re[00<0012448@0<a2400D002e[
;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa242Q2400<002e[;F/06Be[00<00124
48@0<a2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa242Q2400<002e[
;F/06Be[00<0012448@0<a2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0
oa242a2400<002e[;F/06Be[00<0012448@0<Q2400@002e[;F/0044@Q003001oogoo009oo`007Goo
00<0012448@0oa24312400<002e[;F/062e[00<0012448@0<Q2400@002e[;F/0044@Q003001oogoo
009oo`007Goo00<0012448@0oa243A2400<002e[;F/05be[00<0012448@0<Q2400@002e[;F/0044@
Q003001oogoo009oo`001goo0P0017oo0`0017oo0P001goo00<0012448@0oa243A2400<002e[;F/0
62e[00<0012448@0<A2400@002e[;F/0044@Q003001oogoo009oo`002Goo00@007ooOol000=oo`04
001oogoo0002Ool00`00Oomoo`04Ool00`0048@@Q03o48@>48@00`00;F/]J`0G;F/00`0048@@Q00a
48@01000;F/]J`00@A2400<007ooOol00Woo000:Ool00`00Oomoo`03Ool01000Oomoo`000Woo00<0
07ooOol017oo00<0012448@0oa243a2400<002e[;F/05Re[00<0012448@0<A2400@002e[;F/0044@
Q003001oogoo009oo`001goo10001Goo00@007ooOol0009oo`03001oogoo00Aoo`03000@Q1240?l@
Q10@Q003000]Jbe[01H]J`03000@Q124030@Q004000]Jbe[001148@00`00Oomoo`02Ool000Ioo`06
001oogooOol007oo10000goo00@007ooOol000Ioo`03000@Q1240?l@Q10@Q003000]Jbe[01H]J`03
000@Q124030@Q004000]Jbe[001148@00`00Oomoo`02Ool000Ioo`07001oogooOol007oo00001Woo
00@007ooOol000Ioo`03000@Q1240?l@Q14@Q003000]Jbe[01D]J`03000@Q124030@Q004000]Jbe[
001148@00`00Oomoo`02Ool000Moo`<0009oo`D000=oo`8000Moo`03000@Q1240?l@Q18@Q003000]
Jbe[01D]J`03000@Q12402l@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@
Q1<@Q003000]Jbe[01@]J`03000@Q12402l@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03
000@Q1240?l@Q1@@Q003000]Jbe[01<]J`03000@Q12402l@Q004000]Jbe[001148@00`00Oomoo`02
Ool001eoo`03000@Q1240?l@Q1D@Q003000]Jbe[01<]J`03000@Q12402h@Q004000]Jbe[001148@0
0`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1H@Q003000]Jbe[018]J`03000@Q12402h@Q004000]
Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1L@Q003000]Jbe[018]J`03000@Q124
02d@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1P@Q003000]Jbe[014]
J`03000@Q12402d@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1T@Q003
000]Jbe[010]J`03000@Q12402d@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q124
0?l@Q1X@Q003000]Jbe[010]J`03000@Q12402`@Q004000]Jbe[001148@00`00Oomoo`02Ool001eo
o`03000@Q1240?l@Q1/@Q003000]Jbe[00l]J`03000@Q12402`@Q004000]Jbe[001148@00`00Oomo
o`02Ool001eoo`03000@Q1240?l@Q1`@Q003000]Jbe[00h]J`03000@Q12402`@Q004000]Jbe[0011
48@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1d@Q003000]Jbe[00h]J`03000@Q12402/@Q004
000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1h@Q003000]Jbe[00d]J`03000@
Q12402/@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1l@Q003000]Jbe[
00`]J`03000@Q12402/@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q1l@
Q003000]Jbe[00d]J`03000@Q12402X@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@
Q1240?l@Q20@Q003000]Jbe[00`]J`03000@Q12402X@Q004000]Jbe[001148@00`00Oomoo`02Ool0
01eoo`03000@Q1240?l@Q24@Q003000]Jbe[00/]J`03000@Q12402X@Q004000]Jbe[001148@00`00
Oomoo`02Ool001eoo`03000@Q1240?l@Q28@Q003000]Jbe[00/]J`03000@Q12402T@Q004000]Jbe[
001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2<@Q003000]Jbe[00X]J`03000@Q12402T@
Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2@@Q003000]Jbe[00T]J`03
000@Q12402T@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2D@Q003000]
Jbe[00T]J`03000@Q12402P@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03000@Q1240?l@
Q2H@Q003000]Jbe[00P]J`03000@Q12402P@Q004000]Jbe[001148@00`00Oomoo`02Ool001eoo`03
000@Q1240?l@Q2L@Q003000]Jbe[00L]J`03000@Q12402P@Q004000]Jbe[001148@00`00Oomoo`02
Ool001eoo`03000@Q1240?l@Q2P@Q003000]Jbe[00L]J`03000@Q12402L@Q004000]Jbe[001148@0
0`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2T@Q003000]Jbe[00H]J`03000@Q12402L@Q005000]
Jbe[;F/0001048@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2X@Q003000]Jbe[00D]J`03000@
Q12402L@Q005000]Jbe[;F/0001048@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2/@Q003000]
Jbe[00D]J`03000@Q12402H@Q005000]Jbe[;F/0001048@00`00Oomoo`02Ool001eoo`03000@Q124
0?l@Q2`@Q003000]Jbe[00@]J`03000@Q12402H@Q005000]Jbe[;F/0001048@00`00Oomoo`02Ool0
01eoo`03000@Q1240?l@Q2d@Q003000]Jbe[00<]J`03000@Q12402H@Q005000]Jbe[;F/0001048@0
0`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2h@Q003000]Jbe[00<]J`03000@Q12402D@Q005000]
Jbe[;F/0001048@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q2l@Q08000<]J`03000@Q12402D@
Q005000]Jbe[;F/0001048@00`00Oomoo`02Ool001eoo`03000@Q1240?l@Q34@Q005000]Jbe[;F/0
000V48@01@00;F/]Jbe[0000@12400<007ooOol00Woo000MOol00`0048@@Q03o48@b48@01000;F/]
J`009Q2400D002e[;F/]J`00040@Q003001oogoo009oo`007Goo00<0012448@0oa24<a2400@002e[
;F/002D@Q003000]Jbe[008]J`03000@Q12403d@Q003001oogoo009oo`007Goo00<0012448@0oa24
=12400<002e[00009A2400<002e[;F/00Re[00<0012448@0?A2400<007ooOol00Woo000MOol00`00
48@@Q03o48@e48@2000U48@00`00;F/]J`02;F/00`0048@@Q00m48@00`00Oomoo`02Ool001eoo`03
000@Q1240?l@Q3H@Q08002@@Q003000]Jbe[008]J`03000@Q12403d@Q003001oogoo009oo`007Goo
00<0012448@0oa24=a2400<0012448@08Q2400<002e[;F/00Re[00<0012448@0?A2400<007ooOol0
0Woo000MOol00`0048@@Q03o48@g48@3000R48@00`00;F/]J`02;F/00`0048@@Q00m48@00`00Oomo
o`02Ool001eoo`03000@Q1240?l@Q3H@Q0H0020@Q003000]Jbe[008]J`03000@Q12403d@Q003001o
ogoo009oo`007Goo00<0012448@0oa24=A242P007A2400<002e[;F/00Re[00<0012448@0?A2400<0
07ooOol00Woo000MOol00`0048@@Q03o48@c48@>000K48@00`00;F/]J`03;F/00`0048@@Q00l48@0
0`00Oomoo`02Ool001eoo`03000@Q1240?l@Q38@Q14001T@Q003000]Jbe[00<]J`03000@Q12402L@
Q0X000/@Q003001oogoo009oo`007Goo00<0012448@0oa24<A2450005a2400<002e[;F/00be[00<0
012448@07Q246@001A2400<007ooOol00Woo000MOol00`0048@@Q03o48@`48@H000D48@00`00;F/]
J`03;F/00`0048@@Q00H48@S00000a24001oo`03Ool001eoo`03000@Q1240?l@Q2h@Q1`0018@Q003
000]Jbe[00<]J`03000@Q12401D@Q2P000Aoo`007Goo00<0012448@0oa24;A247`00412400<002e[
;F/00be[00<0012448@04Q24:`0017oo000MOol00`0048@@Q03o48@/48@R000>48@00`00;F/]J`03
;F/00`0048@@Q00?48@^0004Ool001eoo`03000@Q1240?l@Q2/@Q2H000/@Q003000]Jbe[00<]J`03
000@Q12400`@Q34000Aoo`007Goo00<0012448@0oa24:Q24:@002A2400<002e[;F/012e[00<00124
48@02124=00017oo000017oo0000000017oo0P0017oo0P0017oo0P001goo00<0012448@0oa24:A24
;0001a2400<002e[;F/012e[00<0012448@01A24=`0017oo0002Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo0006Ool00`0048@@Q03o48@X48@_000548@00`00;F/]
J`04;F/00`0048@@Q00248@j0004Ool0009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`000Woo00@007ooOol000Ioo`03000@Q1240?l@Q2L@Q38000<@Q003000]Jbe[00@]J`03000@Q000
03`000Aoo`000Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`00
1Wooo`00Y@0017oo0002Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo003oOon_Ool00003Ool0000000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
0?moojmoo`000Woo00<007ooOol00goo0P0017oo0P0017oo0P00ogoo/7oo003oOoo6Ool00?moolIo
o`00ogooaWoo003oOoo6Ool00?moolIoo`00ogooaWoo003oOoo6Ool00001\
\>"],
  ImageRangeCache->{{{0, 452}, {452, 0}} -> {-0.0696821, 610.937, 0.00238238, \
0.88148}}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{676, 753},
WindowMargins->{{9, Automatic}, {Automatic, 21}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000cP2>?ogoo<3@@960dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000008000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 133, 3, 114, "Title"],
Cell[1863, 57, 224, 8, 63, "Text"],
Cell[2090, 67, 83, 1, 44, "SmallText"],

Cell[CellGroupData[{
Cell[2198, 72, 65, 1, 67, "Section"],

Cell[CellGroupData[{
Cell[2288, 77, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[2372, 82, 67, 1, 70, "Subsubsection"],
Cell[2442, 85, 208, 9, 70, "Input"],
Cell[2653, 96, 227, 7, 70, "Input"],
Cell[2883, 105, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3085, 115, 112, 2, 70, "Subsubsection"],
Cell[3200, 119, 1901, 93, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5138, 217, 119, 2, 70, "Subsubsection"],
Cell[5260, 221, 799, 25, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6096, 251, 121, 2, 70, "Subsubsection"],
Cell[6220, 255, 710, 30, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6967, 290, 123, 2, 70, "Subsubsection"],
Cell[7093, 294, 13838, 879, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20968, 1178, 125, 2, 70, "Subsubsection"],
Cell[21096, 1182, 16765, 1066, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37898, 2253, 120, 2, 70, "Subsubsection"],
Cell[38021, 2257, 1133, 50, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39191, 2312, 121, 2, 70, "Subsubsection"],
Cell[39315, 2316, 166, 7, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39518, 2328, 122, 2, 70, "Subsubsection"],
Cell[39643, 2332, 3954, 240, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[43646, 2578, 68, 1, 47, "Subsection"],
Cell[43717, 2581, 9280, 149, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[53034, 2735, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[53121, 2740, 163, 6, 51, "Input"],
Cell[53287, 2748, 124625, 3328, 491, 22508, 2063, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[177973, 6083, 79, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[178077, 6088, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[178161, 6093, 93, 2, 70, "Subsubsection"],
Cell[178257, 6097, 208, 9, 70, "Input"],
Cell[178468, 6108, 227, 7, 70, "Input"],
Cell[178698, 6117, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[178900, 6127, 111, 2, 70, "Subsubsection"],
Cell[179014, 6131, 4666, 247, 70, "Input"],

Cell[CellGroupData[{
Cell[183705, 6382, 97, 5, 70, "Input"],
Cell[183805, 6389, 127, 6, 70, "Output"],
Cell[183935, 6397, 469, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184441, 6417, 63, 1, 70, "Input"],
Cell[184507, 6420, 128, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184672, 6431, 64, 1, 70, "Input"],
Cell[184739, 6434, 115, 6, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[184903, 6446, 85, 1, 70, "Subsubsection"],
Cell[184991, 6449, 10433, 655, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[195461, 7109, 86, 1, 70, "Subsubsection"],
Cell[195550, 7112, 10506, 668, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[206093, 7785, 86, 1, 70, "Subsubsection"],
Cell[206182, 7788, 5645, 359, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[211876, 8153, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[211963, 8158, 71, 1, 61, "Subsubsection"],
Cell[212037, 8161, 10722, 153, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[222796, 8319, 65, 1, 47, "Subsubsection"],

Cell[CellGroupData[{
Cell[222886, 8324, 165, 6, 51, "Input"],
Cell[223054, 8332, 108816, 4111, 491, 41787, 3279, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[331931, 12450, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[332023, 12455, 62, 1, 70, "Subsubsection"],
Cell[332088, 12458, 4681, 269, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[336806, 12732, 76, 1, 70, "Subsubsection"],
Cell[336885, 12735, 1432, 66, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[338366, 12807, 70, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[338461, 12812, 71, 1, 70, "Subsubsection"],
Cell[338535, 12815, 10890, 156, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[349462, 12976, 65, 1, 70, "Subsubsection"],

Cell[CellGroupData[{
Cell[349552, 12981, 164, 5, 70, "Input"],
Cell[349719, 12988, 42747, 3347, 70, 42604, 3343, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[392539, 16343, 77, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[392641, 16348, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[392725, 16353, 93, 2, 70, "Subsubsection"],
Cell[392821, 16357, 208, 9, 70, "Input"],
Cell[393032, 16368, 227, 7, 70, "Input"],
Cell[393262, 16377, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[393464, 16387, 109, 2, 70, "Subsubsection"],
Cell[393576, 16391, 4105, 195, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[397718, 16591, 115, 2, 70, "Subsubsection"],
Cell[397836, 16595, 8098, 516, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[405971, 17116, 116, 2, 70, "Subsubsection"],
Cell[406090, 17120, 6139, 399, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[412266, 17524, 116, 2, 70, "Subsubsection"],
Cell[412385, 17528, 8951, 575, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[421385, 18109, 68, 1, 47, "Subsection"],
Cell[421456, 18112, 7381, 118, 70, "Input"],
Cell[428840, 18232, 50, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[428927, 18238, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[429014, 18243, 166, 6, 51, "Input"],
Cell[429183, 18251, 89450, 3229, 491, 29873, 2489, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[518694, 21487, 72, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[518791, 21492, 62, 1, 61, "Subsubsection"],
Cell[518856, 21495, 3478, 51, 70, "Input"],
Cell[522337, 21548, 74, 4, 70, "Input"],
Cell[522414, 21554, 63, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[522502, 21559, 101, 4, 70, "Input"],
Cell[522606, 21565, 146, 6, 70, "Output"],
Cell[522755, 21573, 141, 6, 70, "Output"]
}, Open  ]],
Cell[522911, 21582, 1676, 78, 70, "Input"],

Cell[CellGroupData[{
Cell[524612, 21664, 73, 1, 70, "Input"],
Cell[524688, 21667, 149, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[524874, 21678, 71, 1, 70, "Input"],
Cell[524948, 21681, 145, 6, 70, "Output"]
}, Open  ]],
Cell[525108, 21690, 268, 11, 70, "Input"],
Cell[525379, 21703, 3079, 138, 70, "Input"],

Cell[CellGroupData[{
Cell[528483, 21845, 73, 1, 70, "Input"],
Cell[528559, 21848, 149, 6, 70, "Output"]
}, Open  ]],
Cell[528723, 21857, 486, 22, 70, "Input"],

Cell[CellGroupData[{
Cell[529234, 21883, 73, 1, 70, "Input"],
Cell[529310, 21886, 146, 6, 70, "Output"]
}, Open  ]],
Cell[529471, 21895, 1035, 47, 70, "Input"],

Cell[CellGroupData[{
Cell[530531, 21946, 73, 1, 70, "Input"],
Cell[530607, 21949, 148, 6, 70, "Output"]
}, Open  ]],
Cell[530770, 21958, 102, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[530897, 21966, 776, 35, 70, "Input"],
Cell[531676, 22003, 145, 6, 70, "Output"]
}, Open  ]],
Cell[531836, 22012, 957, 42, 70, "Input"],
Cell[532796, 22056, 72, 1, 70, "Input"],
Cell[532871, 22059, 1539, 70, 70, "Input"],

Cell[CellGroupData[{
Cell[534435, 22133, 107, 4, 70, "Input"],
Cell[534545, 22139, 147, 6, 70, "Output"],
Cell[534695, 22147, 147, 6, 70, "Output"]
}, Open  ]],
Cell[534857, 22156, 2008, 90, 70, "Input"],

Cell[CellGroupData[{
Cell[536890, 22250, 74, 1, 70, "Input"],
Cell[536967, 22253, 147, 6, 70, "Output"]
}, Open  ]],
Cell[537129, 22262, 916, 40, 70, "Input"],

Cell[CellGroupData[{
Cell[538070, 22306, 107, 4, 70, "Input"],
Cell[538180, 22312, 147, 6, 70, "Output"],
Cell[538330, 22320, 144, 6, 70, "Output"]
}, Open  ]],
Cell[538489, 22329, 248, 10, 70, "Input"],
Cell[538740, 22341, 240, 10, 70, "Input"],
Cell[538983, 22353, 99, 4, 70, "Input"],
Cell[539085, 22359, 777, 36, 70, "Input"],

Cell[CellGroupData[{
Cell[539887, 22399, 74, 1, 70, "Input"],
Cell[539964, 22402, 141, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[540142, 22413, 65, 1, 70, "Input"],
Cell[540210, 22416, 107, 5, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[540366, 22427, 66, 1, 47, "Subsubsection"],
Cell[540435, 22430, 635, 17, 70, "Input"],
Cell[541073, 22449, 3655, 52, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[544765, 22506, 65, 1, 47, "Subsubsection"],

Cell[CellGroupData[{
Cell[544855, 22511, 136, 5, 51, "Input"],
Cell[544994, 22518, 106602, 4768, 552, 54301, 4118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[651633, 27291, 142, 5, 51, "Input"],
Cell[651778, 27298, 88, 1, 25, "Print"],
Cell[651869, 27301, 45895, 3577, 408, 45752, 3573, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[697825, 30885, 71, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[697921, 30890, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[698005, 30895, 100, 2, 70, "Subsubsection"],
Cell[698108, 30899, 59, 4, 70, "Input"],
Cell[698170, 30905, 208, 9, 70, "Input"],
Cell[698381, 30916, 167, 6, 70, "Input"],
Cell[698551, 30924, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[698753, 30934, 97, 2, 70, "Subsubsection"],
Cell[698853, 30938, 322, 16, 70, "Input"],

Cell[CellGroupData[{
Cell[699200, 30958, 69, 1, 70, "Input"],
Cell[699272, 30961, 127, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[699436, 30972, 65, 1, 70, "Input"],
Cell[699504, 30975, 119, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[699660, 30986, 65, 1, 70, "Input"],
Cell[699728, 30989, 119, 6, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[699896, 31001, 102, 2, 70, "Subsubsection"],
Cell[700001, 31005, 13226, 607, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[713264, 31617, 103, 2, 70, "Subsubsection"],
Cell[713370, 31621, 6103, 275, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[719522, 31902, 68, 1, 47, "Subsection"],
Cell[719593, 31905, 5701, 107, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[725331, 32017, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[725418, 32022, 163, 6, 51, "Input"],
Cell[725584, 32030, 74543, 3171, 461, 32608, 2649, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[800176, 35207, 67, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[800268, 35212, 66, 1, 70, "Subsubsection"],
Cell[800337, 35215, 3768, 193, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[804142, 35413, 72, 1, 70, "Subsubsection"],
Cell[804217, 35416, 4621, 209, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[808887, 35631, 77, 1, 47, "Subsection"],
Cell[808967, 35634, 5963, 122, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[814967, 35761, 71, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[815063, 35766, 163, 6, 70, "Input"],
Cell[815229, 35774, 34215, 2784, 70, 34073, 2780, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[849505, 38565, 74, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[849604, 38570, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[849688, 38575, 100, 2, 70, "Subsubsection"],
Cell[849791, 38579, 59, 4, 70, "Input"],
Cell[849853, 38585, 208, 9, 70, "Input"],
Cell[850064, 38596, 167, 6, 70, "Input"],
Cell[850234, 38604, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[850436, 38614, 97, 2, 70, "Subsubsection"],
Cell[850536, 38618, 909, 43, 70, "Input"],
Cell[851448, 38663, 68, 1, 70, "Input"],
Cell[851519, 38666, 65, 1, 70, "Input"],
Cell[851587, 38669, 65, 1, 70, "Input"],
Cell[851655, 38672, 65, 1, 70, "Input"],
Cell[851723, 38675, 65, 1, 70, "Input"],

Cell[CellGroupData[{
Cell[851813, 38680, 65, 1, 70, "Input"],
Cell[851881, 38683, 119, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[852037, 38694, 65, 1, 70, "Input"],
Cell[852105, 38697, 119, 6, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[852273, 38709, 102, 2, 70, "Subsubsection"],
Cell[852378, 38713, 11839, 533, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[864254, 39251, 103, 2, 70, "Subsubsection"],
Cell[864360, 39255, 5267, 251, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[869664, 39511, 103, 2, 70, "Subsubsection"],
Cell[869770, 39515, 8527, 387, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[878334, 39907, 103, 2, 70, "Subsubsection"],
Cell[878440, 39911, 7365, 342, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[885842, 40258, 103, 2, 70, "Subsubsection"],
Cell[885948, 40262, 2974, 139, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[888971, 40407, 68, 1, 47, "Subsection"],
Cell[889042, 40410, 9591, 157, 70, "Input"],
Cell[898636, 40569, 50, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[898723, 40575, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[898810, 40580, 161, 6, 51, "Input"],
Cell[898974, 40588, 85415, 3968, 461, 44403, 3457, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[984450, 44563, 74, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[984549, 44568, 59, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[984633, 44573, 100, 2, 70, "Subsubsection"],
Cell[984736, 44577, 59, 4, 70, "Input"],
Cell[984798, 44583, 208, 9, 70, "Input"],
Cell[985009, 44594, 167, 6, 70, "Input"],
Cell[985179, 44602, 165, 5, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[985381, 44612, 97, 2, 70, "Subsubsection"],
Cell[985481, 44616, 893, 44, 70, "Input"],

Cell[CellGroupData[{
Cell[986399, 44664, 97, 4, 70, "Input"],
Cell[986499, 44670, 127, 6, 70, "Output"],
Cell[986629, 44678, 127, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[986793, 44689, 65, 1, 70, "Input"],
Cell[986861, 44692, 131, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[987029, 44703, 65, 1, 70, "Input"],
Cell[987097, 44706, 119, 6, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[987265, 44718, 102, 2, 70, "Subsubsection"],
Cell[987370, 44722, 7459, 341, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[994866, 45068, 103, 2, 70, "Subsubsection"],
Cell[994972, 45072, 7813, 355, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1002822, 45432, 103, 2, 70, "Subsubsection"],
Cell[1002928, 45436, 6562, 307, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1009527, 45748, 103, 2, 70, "Subsubsection"],
Cell[1009633, 45752, 7607, 358, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1017277, 46115, 103, 2, 70, "Subsubsection"],
Cell[1017383, 46119, 6185, 285, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1023617, 46410, 68, 1, 47, "Subsection"],
Cell[1023688, 46413, 10480, 177, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1034205, 46595, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[1034292, 46600, 161, 6, 51, "Input"],
Cell[1034456, 46608, 89721, 3887, 461, 41209, 3284, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

