(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    124880,       3292]*)
(*NotebookOutlinePosition[    125935,       3325]*)
(*  CellTagsIndexPosition[    125891,       3321]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["plot functions", "Title",
  ImageRegion->{{0, 1}, {0, 1}},
  FontFamily->"Palatino",
  FontColor->RGBColor[1, 0, 0],
  Background->GrayLevel[1]],

Cell["as is...", "Text"],

Cell["\[Copyright] rp 2001", "Text"],

Cell[CellGroupData[{

Cell["general functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Off[General::spell]; Off[General::spell1];
Off[InterpolatingFunction::dmwarn];
Off[Interpolation::inhr];
Off[Syntax::com];
SetOptions[Position, Heads -> False];Syntax::com\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \($Off[]\)], "Output"]
}, Open  ]],

Cell["R = 0.0083144;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["layout", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["formatting output ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["format",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ, n_Integer,_?TrueQ] :=\n\t   \
Module[{m=N[10^n]},Round[m x]/m];\n\t   \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["format",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_?NumberQ, n_Integer,___] := N[x,n];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["format",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_,___] := x;\n\nSetAttributes[format,{Listable}];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["graph colours", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["        ",
    FontFamily->"Monaco",
    FontSize->10,
    FontWeight->"Plain"],
  StyleBox["pink = \t\t{1,      0.94,    0.94};\n        blue =\t \t{0.88,    \
  1,       1};\n        green =  {0.91,      1,    0.87};",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["",
    FontFamily->"Monaco",
    FontSize->10,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
graphColour =  Background->RGBColor[0.88,1,1];

SetOptions[ListPlot, graphColour];
SetOptions[Plot, graphColour];
SetOptions[ParametricPlot, graphColour];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["etc", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["old code to help with simplification of expressions", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[simplifyTerm]; Clear[simplifyTerms];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["simplifyTerm",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[y_, n_Integer] := y-y[[n]]+Simplify[y[[n]]] /; n!=0 && \
Abs[n]<=Length[y];\nsimplifyTerm[y_, n_Integer] := y;\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["simplifyTerms",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[y_,n_List] := Map[simplifyTerm[y, #]&, n];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
old code to help with finding the position in vectors/matrices that \
have a particular property, via a pure function\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[rpos]; Clear[ipos]; Clear[colrpos]; Clear[colipos];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["rpos",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_List, f_Function] := Flatten[Position[x,_Real?(f)]];\n     \n",
    
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ipos",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_List, f_Function]:= Flatten[Position[x,_Integer?(f)]];\n     \n\
",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["colrpos",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_List, col_Integer, f_Function] := \n             \
Flatten[Position[Map[#[[col]]&,x],_Real?(f)]];\n     \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["colipos",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_List, col_Integer, f_Function] := \n             \
Flatten[Position[Map[#[[col]]&,x],_Integer?(f)]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
allNumbers returns True if the object passed to it involves
only numbers, False otherwise.

One way it can be used is in parameter lists to functions :
    
    Clear[f];
    f[x_List?(allNumbers[#]&)] := 0;
    f[___]:=\"inappropriate input : list is not all numbers\"\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[allNumbers];\n\nallNumbers[x_Integer]:=True;\n\
allNumbers[x_Real]:=True;\n",
    FontSize->10,
    FontWeight->"Plain"],
  StyleBox["allNumbers",
    FontSize->10,
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[x_List]:=Length[Complement[Union[Map[Head[#]&,Flatten[x]]],\n    \
                                  {Real,Integer}]]==0;\n\
allNumbers[x_]:=False;",
    FontSize->10,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["combinations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["used in generating combinations", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["gray",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["} /; n < m || m <= 0;  \n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := gray[n,n] = {Range[n]};\n  \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,1] := gray[n,1] = Partition[Range[n],1];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,2] := gray[n,2] =\n    Flatten[Table[Table[{i,j}, \
{j,i+1,n}], {i,1,n}],1];\n    \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["gray",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    gray[n,m] = \
Partition[Flatten[{gray[n-1,m],Map[Append[#,n]&,\n                 \
gray[n-1,m-1]]}],m];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["generating a random combination", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["randomCombination",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,n_Integer] := Range[n];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["randomCombination",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer] :=\n    Module[{k,q,qk,rc},\n           \
q=Range[n];\n           Sort[Array[(k=Random[Integer,{1,n-#+1}];\n            \
           qk=q[[k]];\n                       q=Drop[q,{k}];\n                \
       qk)&, m]] ] /; n>m;",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
generating all combinations (using gray), otherwise a random \
selection of combinations\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["combinations",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[n_Integer,m_Integer,max_Integer:50]:=\n  Module[{b,u,lu},\n      \
  b=Binomial[n,m];\n        If[b>max,\n           \
u=Union[Table[randomCombination[n,m],\n                         \
{Round[max(1+0.6 max/b)]}]];\n           lu=Length[u];\n           \
If[lu>max,Drop[u,lu-max],u],\n           gray[n,m] ] ] /; n>m;",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["phase diagram functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["makeline/drawline ", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["as of end of November 1998 (info added feb 99)", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "these are globals that you would normally reset to values specific to your \
plot:\n   ",
  StyleBox["xlow,xhigh,ylow,yhigh",
    FontColor->RGBColor[0, 0, 1]],
  ": x,y plot ranges\n   ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  ": columns in the info produced by THERMOCALC to be used \n           for \
the x and y coordinates\n   ",
  StyleBox["nop",
    FontColor->RGBColor[0, 0, 1]],
  ": number of interpolating points (this need not be reset)"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
xlow = 0; xhigh = 1; ylow = 400; yhigh = 500;
xycols = {1,2};
nop = 50;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "generic {x,y} limits for use in makeline, meaning upper left (",
  StyleBox["ul",
    FontColor->RGBColor[0, 0, 1]],
  "), upper right (",
  StyleBox["ur",
    FontColor->RGBColor[0, 0, 1]],
  ") etc"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["ul",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {xlow,yhigh};",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox[" \nur",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {xhigh,yhigh};\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ll",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {xlow,ylow};  \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["lr",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {xhigh,ylow};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "does a correspond to ",
  StyleBox["ul, ur, ll ",
    FontColor->RGBColor[0, 0, 1]],
  "or ",
  StyleBox["lr",
    FontColor->RGBColor[0, 0, 1]],
  ""
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["atlimit",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[a_] := (a[[1]]==xlow || a[[1]]==xhigh) && \n               \
(a[[2]]==ylow || a[[2]]==yhigh);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "are numbers in ",
  StyleBox["a",
    FontColor->RGBColor[0, 0, 1]],
  " changing monotonically"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["monotonic",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[a_] := Intersection[Chop[a - Sort[a]]] == {0} || \n              \
   Intersection[Chop[Reverse[a] - Sort[a]]] == {0}",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "generates a list of interpolated {x,y} coordinates from ",
  StyleBox["info",
    FontColor->RGBColor[0, 0, 1]],
  " (using the global ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  ") for showing with ",
  StyleBox["drawline. s ",
    FontColor->RGBColor[0, 0, 1]],
  "and",
  StyleBox[" e ",
    FontColor->RGBColor[0, 0, 1]],
  "are the start and finish {x,y} coordinates of the line to be drawn; they \
may be specified {x,y}, eg for an invariant, or they be the generaic \
ccoordinates ",
  StyleBox["ul, ur, ll ",
    FontColor->RGBColor[0, 0, 1]],
  "or ",
  StyleBox["lr.",
    FontColor->RGBColor[0, 0, 1]],
  " (in the latter case, the line is drawn to the end of the info, or the \
edge of the diagram, whichever is sooner). In the interpolation, the limits \
on the line are added into the info, so the line will go through the points, \
whatever scale the diagram is drawn at. (Given that\ninterpolation is \
involved odd lines can be drawn if these points are off the line, if the \
points defining the line are too widely spaced, etc)"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["makeline",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_, s_,e_] :=\n\n  Module[{near = 0.25, inc, incx,incy, \
limstart,limend, ii, xinfo,yinfo,\n          qq,mins,ks,mine,ke, x,y, \
rx1,rx2, ry1,ry2, xs,xe,ys,ye, \n          xx1,xx2,yy1,yy2,x1,x2,y1,y2, \
o,v,olow,ohigh,vlow,vhigh,\n          o1,o2,inco, dupl, n, osub,vsub, \
klow,khigh,\n          oa,va,ob,vb, ck, osub1,vsub1, res },\n\n    inc = \
{incx,incy} = {(xhigh - xlow)/nop, (yhigh - ylow)/nop};\n    limstart = \
atlimit[s]; limend = atlimit[e];\n   \n    ii = Map[#[[xycols]]&,info];\n    \
xinfo = monotonic[Transpose[ii][[1]]]; \n    yinfo = \
monotonic[Transpose[ii][[2]]];  \n    \n    If[xinfo || yinfo, \
,Print[\"stuffed: curves back both ways!\"]]; \n\n    If[!limstart,\n       \
qq = Array[{Apply[Plus,((ii[[#]] - s)/inc)^2],#}&,Length[ii]];\n       \
{mins,ks} = Sort[qq][[1]];\n       If[mins < near, ii[[ks]] := s, \
AppendTo[ii,s]] ];\n    If[!limend,\n       qq = Array[{Apply[Plus,((ii[[#]] \
- e)/inc)^2],#}&,Length[ii]];\n       {mine,ke} = Sort[qq][[1]];\n       \
If[mine < near, ii[[ke]] := e, AppendTo[ii,e]] ];\n       \n    {x,y} = \
Transpose[ii];\n               \n    If[xinfo,{rx1,rx2} = {Min[x],Max[x]};\n  \
           {xs,xe} = If[e[[1]]>s[[1]],{s[[1]],e[[1]]},{e[[1]],s[[1]]}];\n     \
        {xx1,xx2} = {If[xs > rx1, xs, rx1], If[xe < rx2, xe, rx2]};\n         \
    {x1,x2} = {If[xx1 > xlow,  xx1, xlow], \n                        If[xx2 < \
xhigh, xx2, xhigh]}];\n    If[yinfo,{ry1,ry2} = {Min[y],Max[y]};\n            \
 {ys,ye} = If[e[[2]]>s[[2]],{s[[2]],e[[2]]},{e[[2]],s[[2]]}];\n             \
{yy1,yy2} = {If[ys > ry1, ys, ry1], If[ye < ry2, ye, ry2]};\n             \
{y1,y2} = {If[yy1 > ylow,  yy1, ylow], \n                        If[yy2 < \
yhigh, yy2, yhigh]}];\n                        \n    If[xinfo && yinfo, xinfo \
= (x2 - x1)/incx > (y2 - y1)/incy];\n    \n    If[xinfo, \n       {o,v} = \
Transpose[Sort[ii]]; \n       {olow,ohigh} = {xlow,xhigh}; {vlow,vhigh} = \
{ylow,yhigh};\n       {o1,o2} = {x1,x2}; inco = incx, \n       {o,v} = \
Transpose[Sort[Map[Reverse,ii]]]; \n       {olow,ohigh} = {ylow,yhigh}; \
{vlow,vhigh} = {xlow,xhigh};\n       {o1,o2} = {y1,y2}; inco = incy];\n       \
\n    dupl = o1 == o2;\n    If[!dupl,if = Interpolation[Transpose[{o,v}]]];\n \
          \n    Which[o1 >= o2 || dupl, {},\n       o2 - o1 < 1.5 inco,\n     \
  If[xinfo,connect[{o1,if[o1]},{o2,if[o2]}],\n                \
connect[{if[o1],o1},{if[o2],o2}]],\n       True,\n       n = Round[(o2 - \
o1)/inco]; If[n < 4, n = 4];\n       inc = (o2 - o1)/n;\n       osub = \
Range[o1,o2,inc]; vsub = Map[if[#]&,osub];\n       \n       klow = \
Flatten[Position[vsub,_?((# < vlow)&)]];\n       khigh = \
Flatten[Position[vsub,_?((# > vhigh)&)]];\n       \n       If[Length[klow] == \
Length[osub] || Length[khigh] == Length[osub], {},\n          {oa,va} = \
{{},{}}; {ob,vb} = {{},{}};\n          Which[Length[klow] == 0, ,\n           \
     klow[[1]] == 1, \n                {oa,va} = {{osol /. FindRoot[if[osol] \
- vlow, \n                   {osol,osub[[klow[[-1]]]],osub[[1 + \
klow[[-1]]]]}]},{vlow}},\n                True,\n                {ob,vb} = \
{{osol /. FindRoot[if[osol] - vlow, \n                   \
{osol,osub[[klow[[1]]]],osub[[klow[[1]] - 1]]}]},{vlow}}];\n          \
Which[Length[khigh] == 0, ,\n                khigh[[1]] == 1, \n              \
  {oa,va} = {{osol /. FindRoot[if[osol] - vhigh, \n                   \
{osol,osub[[khigh[[-1]]]],osub[[1 + khigh[[-1]]]]}]},{vhigh}},\n              \
  True,\n                {ob,vb} = {{osol /. FindRoot[if[osol] - vhigh, \n    \
               {osol,osub[[khigh[[1]]]],osub[[khigh[[1]] - 1]]}]},{vhigh}}];\n\
          ck = Complement[Range[Length[osub]],klow,khigh];\n          \n      \
    osub1 = Join[oa,osub[[ck]],ob];\n          vsub1 = \
Join[va,vsub[[ck]],vb];\n          res = Transpose[If[xinfo, {osub1,vsub1}, \
{vsub1,osub1}]];\n          Partition[Flatten[res],2] ] ]\n    ] /; \
Length[Dimensions[info]]==2 && Dimensions[info][[2]]>1;",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "provides the coordinates of a straight line between ",
  StyleBox["s ",
    FontColor->RGBColor[0, 0, 1]],
  "and",
  StyleBox[" e, ",
    FontColor->RGBColor[0, 0, 1]],
  "where it intersects the diagram"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["connect",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_,e_] :=\n   Module[{x1,y1, x2,y2, onein,twoin, \
x1in,y1in,x2in,y2in, bothout,\n           te,le,be,re, teok,reok,leok,beok, \
u,v, cut,g,i},\n           \n    Which[atlimit[s] || atlimit[e], \n          \
Print[\"connect problem: not both points\"];\n          Print[{s,e}]; \
Print[\" \"]; ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{},",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n       {x1,y1} = s; {x2,y2} = e;\n       \n       x1in = x1 >= \
xlow && x1 <= xhigh; \n       y1in = y1 >= ylow && y1 <= yhigh;\n       onein \
= x1in && y1in;\n       \n       x2in = x2 >= xlow && x2 <= xhigh;\n       \
y2in = y2 >= ylow && y2 <= yhigh;\n       twoin = x2in && y2in;\n       \n    \
   onein && twoin,\n         ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{x1,y1},{x2,y2}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n       True,\n       bothout = (!onein) && (!twoin);\n       \
If[bothout, \n          Which[\n             (x1<xlow && x2<xlow) || \
(x1>xhigh && x2>xhigh) ||\n             (y1<ylow && y2<ylow) || (y1>yhigh && \
y2>yhigh),\n               {},\n          \n             (x1<xlow && x2<xlow) \
|| (x1>xhigh && x2>xhigh) ||\n             (y1<ylow && y2<ylow) || (y1>yhigh \
&& y2>yhigh),\n               {},\n\n             x2 == x1,\n               \
If[y1<ylow && y2>yhigh || y2<ylow && y1>yhigh,\n                  ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{x2,ylow},{x2,yhigh}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",{}],\n                  \n             y2 == y1,\n               \
If[x1<xlow && x2>xhigh || x2<xlow && x1>xhigh,\n                  ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xlow,y2},{xhigh,y2}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",{}],\n                  \n             g = (y2 - y1)/(x2 - x1); \
i = y1 - x1 g;\n\n             te = (yhigh - i)/g;  be = (ylow - i)/g;\n      \
       le = i + xlow g;   re = i + xhigh g;\n             \n             teok \
= te>=xlow && te<=xhigh; \n             beok = be>=xlow && be<=xhigh;\n       \
      \n             leok = le>=ylow && le<=yhigh; \n             reok = \
re>=ylow && re<=yhigh; \n             \n             leok && reok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xlow,le},{xhigh,re}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             leok && teok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xlow,le},{te,yhigh}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             leok && beok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xlow,le},{be,ylow}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             reok && teok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xhigh,re},{te,yhigh}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             reok && beok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{xhigh,re},{be,ylow}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             teok && beok, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{{te,yhigh},{be,ylow}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[",\n             True, {} ],  (* end of out == True *)\n           \
  \n          If[onein,  (* one in is {x2,y2} *)\n             {u,v} = \
{x1,y1}; {x1,y1} = {x2,y2}; {x2,y2} = {u,v}];\n             \n          cut = \
Which[x2 == x1,\n                        If[y2>y1,{x2,ylow},{x2,yhigh}],\n    \
                  y2 == y1,\n                        \
If[x2>x1,{xlow,y2},{xhigh,y2}],\n                        \n                   \
   g = (y2 - y1)/(x2 - x1); i = y1 - x1 g;\n                      \n          \
            g > 0 && x2 > x1,\n                        \
If[i>=ylow,{xlow,i+xlow g}, {(ylow-i)/g,ylow}],\n                      g > 0, \
\n                        If[i<=yhigh,{xhigh,i+xhigh g},{(yhigh-i)/g,yhigh}],\
\n                      g < 0 && x2 > x1,\n                        \
If[i<=yhigh,{xlow,i+xlow g},{(yhigh-i)/g,yhigh}],\n                      g < \
0, \n                        If[i>=ylow,{xhigh,i+xhigh g},{(ylow-i)/g,ylow}],\
\n                      True, \n                        Print[\"connect \
problem: not found (inside+outside)\"];\n                        \
Print[{s,e}]; Print[\" \"]; {} ];\n          ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{cut, {x2,y2}}",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" ] ] ];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws the info generated by makeline", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["drawline",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[line_List] := Line[line];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
given a list of info generated by makeline, in order surrounding an \
area (bar possibly the sides of the diagram), it shades the area(!)\
\>", \
"Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["area",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_List] := \n  Module[{qq,q,k,kq,qk,qk1, qs,qe, add},\n    qq \
= info[[Flatten[Position[Map[Length,info],_?((#>0)&)]]]];\n    q = \
qq[[Flatten[Position[Map[#[[1]]&,qq],_?((!atlimit[#])&),1]]]];\n    \n    \
If[Length[q] == 0, {},\n       Array[(k = #; k1 = # + 1; qk = q[[k]]; qk1 = \
q[[k1]];\n              Which[qk[[-1]] == qk1[[1]], ,\n                    \
qk[[1]] == qk1[[1]],   q[[k]] = Reverse[qk],\n                    qk[[-1]] == \
qk1[[-1]], q[[k1]] = Reverse[qk1],\n                    qk[[1]] == qk1[[-1]], \
 q[[k]] = Reverse[qk]; \n                                           q[[k1]] = \
Reverse[qk1],\n                    True, Print[\"area problem: lines do not \
connect up?\"] ]\n             )&, Length[q] - 1];\n             \n       add \
= Which[qs = q[[1]][[1]]; qe = q[[-1]][[-1]];\n       \n              \
qs[[2]]==yhigh && qe[[1]]==xhigh ||\n              qe[[2]]==yhigh && \
qs[[1]]==xhigh,    {ur},\n              qs[[2]]==yhigh && qe[[1]]==xlow ||\n  \
            qe[[2]]==yhigh && qs[[1]]==xlow,     {ul},\n              \n      \
        qs[[2]]==ylow && qe[[1]]==xhigh ||\n              qe[[2]]==ylow && \
qs[[1]]==xhigh,     {lr},\n              qs[[2]]==ylow && qe[[1]]==xlow ||\n  \
            qe[[2]]==ylow && qs[[1]]==xlow,      {ll},\n              \n      \
        qs[[2]]==ylow && qe[[2]]==yhigh,\n                If[qs[[1]] + \
qe[[1]] < xlow + xhigh,{ul,ll},{ur,lr}],\n              qe[[2]]==ylow && \
qs[[2]]==yhigh,\n                If[qs[[1]] + qe[[1]] < xlow + \
xhigh,{ll,ul},{lr,ur}],\n                \n              qs[[1]]==xlow && \
qe[[1]]==xhigh,\n                If[qs[[2]] + qe[[2]] < ylow + \
yhigh,{lr,ll},{ur,ul}],\n              qe[[1]]==xlow && qs[[1]]==xhigh,\n     \
           If[qs[[2]] + qe[[2]] < ylow + yhigh,{ll,lr},{ul,ur}],\n            \
  True, {}];\n        AppendTo[q,add];\n        ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["Polygon[",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["Apply[Join,q]]] ];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws rhe boundary of the diagram", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["outline",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {AbsoluteThickness [0.3], GrayLevel[0], \n           \
Line[{{xlow, ylow},{xlow, yhigh},\n                  {xhigh, yhigh},{xhigh, \
ylow},{xlow, ylow}}]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
makeline[___] := (Print[\"bad input to makeline\"]; {});
connect[___] := (Print[\"bad input to connect\"]; {});
drawline[___] := (Print[\"bad input to drawline\"]; Line[{}]);
area[___] :=     (Print[\"bad input to area\"];     Line[{}]);\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "given two sets of line info, ",
  StyleBox["a",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["b",
    FontColor->RGBColor[0, 0, 1]],
  ", it returns the {x,y} coordinates where the lines cross (uses global ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  ")"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["crossover",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[a_List, b_List] :=\n  Module[{iia,xia,yia,iib,xib,yib, cando, \
oa,va,ob,vb,\n          mina,minb,maxa,maxb, lim1,lim2, ifa,ifb, osol},\n    \
iia = Map[#[[xycols]]&,a]; \n    \n    xia = monotonic[Transpose[iia][[1]]]; \
\n    yia = monotonic[Transpose[iia][[2]]];  \n    \n    iib = \
Map[#[[xycols]]&,b];\n    xib = monotonic[Transpose[iib][[1]]]; \n    yib = \
monotonic[Transpose[iib][[2]]];\n    \n    cando = True;\n    Which[xia && \
xib,\n          If[Min[Transpose[iia][[1]]] > Min[Transpose[iib][[1]]],\n     \
        ii = iia; iia = iib; iib = ii];\n          {oa,va} = Transpose[iia]; \
{ob,vb} = Transpose[iib],\n          yia && yib, \n          \
If[Min[Transpose[iia][[2]]] > Min[Transpose[iib][[2]]],\n             ii = \
iia; iia = iib; iib = ii];\n          {va,oa} = Transpose[iia]; {vb,ob} = \
Transpose[iib],\n          True, Print[\"not implemented\"]; cando = False];\n\
       \n    If[cando,\n       {mina,maxa} = {Min[oa],Max[oa]};\n       \
{minb,maxb} = {Min[ob],Max[ob]};\n       If[maxa>minb,\n          lim1 = \
minb;\n          lim2 = If[maxa>maxb,maxb,maxa];\n          ifa = \
Interpolation[Transpose[{oa,va}]];\n          ifb = \
Interpolation[Transpose[{ob,vb}]];\n          osol = oo /. FindRoot[ifa[oo] - \
ifb[oo], {oo,lim1,lim2}];\n          If[xia, {osol,ifa[osol]}, \
{ifa[osol],osol}],\n          Print[\"no solution: curves don't overlap\"]; \
{}], {}] ];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "interpolates the info in ",
  StyleBox["info",
    FontColor->RGBColor[0, 0, 1]],
  ", at ",
  StyleBox["v",
    FontColor->RGBColor[0, 0, 1]],
  " in the column which is not\nin ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  " . (So if ",
  StyleBox["info",
    FontColor->RGBColor[0, 0, 1]],
  " is a series of triplets (x,P,T}, and a T-x pseudosection is being drawn - \
so xycols = {1,3} - then interp[info,5] will find the {x,T} corresponding to \
P = 5."
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["interp",
    FontFamily->"Monaco",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_List, v_] :=\n   Module[{ck,ii},\n      ck = \
Complement[Range[3],xycols][[1]];\n      Map[(ii = \
Transpose[Transpose[info][[{ck,#}]]];\n          \
Interpolation[ii][v])&,xycols]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "returns whatever is in ",
  StyleBox["line",
    FontColor->RGBColor[0, 0, 1]],
  " as a list of pairs of things"
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["clearup",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[line_] :=\n   Partition[Flatten[line],2];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "returns minimum and maximum of info in ",
  StyleBox["list",
    FontColor->RGBColor[0, 0, 1]],
  ""
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["minimax",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[list_] :=\n   Module[{plx,ply},\n     {plx,ply} = \
Transpose[Partition[Flatten[list],2]];\n     \
{{Min[plx],Max[plx]},{Min[ply],Max[ply]}} ];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "displays info in ",
  StyleBox["list",
    FontColor->RGBColor[0, 0, 1]],
  ""
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["display",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[list_] :=\n    Array[ {#, list[[#]]}&, Length[list] \
]//TableForm",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "for scalar ",
  StyleBox["y",
    FontColor->RGBColor[0, 0, 1]],
  ", returns ",
  StyleBox["{x,y}",
    FontColor->RGBColor[0, 0, 1]],
  ", with ",
  StyleBox["x",
    FontColor->RGBColor[0, 0, 1]],
  " being the coordinate found by interpolating in info ",
  StyleBox["m",
    FontColor->RGBColor[0, 0, 1]],
  " (using global ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  ") at ",
  StyleBox["y",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["cutx",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[m_, y_] :=\n  \
{Interpolation[Transpose[Transpose[m][[Reverse[xycols]]]]][y],y}",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "for scalar ",
  StyleBox["x",
    FontColor->RGBColor[0, 0, 1]],
  ", returns ",
  StyleBox["{x,y}",
    FontColor->RGBColor[0, 0, 1]],
  ", with ",
  StyleBox["y",
    FontColor->RGBColor[0, 0, 1]],
  " being the coordinate found by interpolating in info ",
  StyleBox["m",
    FontColor->RGBColor[0, 0, 1]],
  " (using global ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  ") at ",
  StyleBox["x",
    FontColor->RGBColor[0, 0, 1]]
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["cuty",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[m_, x_] :=\n  \
{x,Interpolation[Transpose[Transpose[m][[xycols]]]][x]}",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "adds a zero column to ",
  StyleBox["q",
    FontColor->RGBColor[0, 0, 1]],
  " at position ",
  StyleBox["posi",
    FontColor->RGBColor[0, 0, 1]],
  ""
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["addcol",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_, posi_] := Map[Insert[#,0,posi]&,q];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "just takes the ",
  StyleBox["xycols",
    FontColor->RGBColor[0, 0, 1]],
  " columns (a global) from ",
  StyleBox["q",
    FontColor->RGBColor[0, 0, 1]],
  ""
}], "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["killcol",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_, posi_] := Map[#[[xycols]]&,q];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["checks lu for duff lines", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
checker[lu_] :=
    Transpose[{Range[Length[lu]],
           Map[If[Length[#]==0, \"no line\", 
                  If[Head[#[[1,1]]]===ReplaceAll,\"====stuffed====\",#[[1]]]]&\
, lu]}]//ColumnForm\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["compatibility diagrams", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["as in Powell et al ( 1998)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["rsqrt3 = 1/Sqrt[3];  lla = 1.36 rsqrt3; \n\nClear[conv];  \
Clear[tri];  Clear[close];  Clear[one];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["conv",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_] := N[{rsqrt3(s[[4]] - s[[3]]), -(s[[4]] + s[[3]])}];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["close",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] := Line[Join[p,{p[[1]]}]];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["tri",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[t_] := close[Map[conv, t[[2]]]];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["one",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[w_] := close[Map[(conv[#[[1,2,#[[2]]]]])&, w]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["phase diagram movie functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["tutorial drawline", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["name change and Module added at end Nov98", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
(* xlow = 0; xhigh = 1; ylow = 400; yhigh = 500;    nop = 50; \
*)\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tdrawline];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["tdrawline",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_, xcol_,ycol_, xinfo_, start_,end_] :=\n   \
Module[{os,oe,ii,x,y,o,v,olow,ohigh,if,r1,r2,oo1,oo2,\n           \
o1,o2,inca,n,inc,osub,vsub},\n    os = \
If[Length[start]==0,start,start[[If[xinfo,1,2]]]];\n    oe = \
If[Length[end]==0,end,end[[If[xinfo,1,2]]]];\n    \n    ii = \
Map[#[[{xcol,ycol}]]&,info];\n    If[Length[start] == 2, AppendTo[ii,start]];\
\n    If[Length[end] == 2, AppendTo[ii,end]];       \n    {x,y} = \
Transpose[Sort[ii]];   \n               \n    If[xinfo, {o,v} = {x,y}; \
{olow,ohigh} = {xlow,xhigh}, \n              {v,o} = {x,y}; {olow,ohigh} = \
{ylow,yhigh}];\n       \n    if = Interpolation[Transpose[{o,v}]]; \n    \
{r1,r2} = Flatten[Apply[List,if][[1]]];\n           \n    {oo1,oo2} = If[oe > \
os,{If[os > r1, os, r1],If[oe < r2, oe, r2]},\n                           \
{If[oe > r1, oe, r1],If[os < r2, os, r2]}];\n    {o1,o2} = {If[oo1 > olow,  \
oo1, olow], If[oo2 < ohigh, oo2, ohigh]};\n           \n    If[o2 < o1,  \
Line[{}],\n       inca = (ohigh - olow)/nop;\n       n = Round[(o2 - \
o1)/inca]; If[n < 4, n = 4];\n       inc = (o2 - o1)/n;\n    \n       osub = \
Range[o1,o2,inc]; vsub = Map[if[#]&,osub];\n\n       Line[Transpose[If[xinfo, \
{osub,vsub}, {vsub,osub}]]] ]\n\n    ] /; Length[Dimensions[info]]==2 && \
Dimensions[info][[2]]>1;\n   \ntdrawline[___] := (Print[\"bad input\"];{});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[toutline]; \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["toutline",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0], \n           Line",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[{{xlow, ylow},{xlow, yhigh},\n                  {xhigh, \
yhigh},{xhigh, ylow},{xlow, ylow}}]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["auxiliary functions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["linecuts", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[linecuts];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["linecuts",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{slope_,intercept_},{{xlow_,xhigh_},{ylow_,yhigh_}}]:=\n  \
(y1=intercept+slope xlow; y2=intercept+slope xhigh;\n      {If[slope>0,\n     \
   If[y1<ylow, {(ylow-intercept)/slope,ylow},  {xlow,y1}],\n        \
If[y1>yhigh,{(yhigh-intercept)/slope,yhigh},{xlow,y1}]],\n       If[slope>0,\n\
        If[y2>yhigh,{(yhigh-intercept)/slope,yhigh},{xhigh,y2}],\n        \
If[y2<ylow, {(ylow-intercept)/slope,ylow},  {xhigh,y2}] ]});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["number of strings in common between two strings", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["T-x/P-x functions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["default values, normally overridden", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
left = 0; right = 1; bottom = 400; top = 800;
delv = 5; addx = addy = 0;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
varyTatP = True;
debugit = False;\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["labelling[p_]:={};", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["differentiating an interpolation function", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[dif];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["dif",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifr_,v_] := \n    ({r1,r2} = ifr;\n     Which[v > \
r2-difdelv,\n             (if[r2]-if[r2-difdelv])/difdelv,\n           v < \
r1,\n             (if[r1+difdelv]-if[r1])/difdelv,\n           True,\n        \
     (if[v+difdelv]-if[v])/difdelv]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
substitute into interpolation function in value (T or P) range v1 \
<-> v2\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[subsif];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["subsif",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,v1_,v2_] :=\n    (dv = Abs[v2-v1];\n     If[dv <= 2 delv,\n  \
      {{if[v1],v1},{if[v2],v2}},\n        kd = Floor[dv/delv]; \n        \
Map[{if[#],#}&, v1 + dv/kd Range[0,kd]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
make a boundary of the a divariant using the interpolation fn, if;  \
(note that vs < ve  OR  vs > ve)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makeboundary];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["makeboundary",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[if_,ifrange_,vs_,ve_] :=\n    (\n     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["va <-> vb is maximum substitution range, with vb > va ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     If[ve > vs, {va,vb} = {vs,ve}, {va,vb} = {ve,vs}];\
\n   \n     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["va <-> vb adjusted to be consistent with interpolation function ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n     {vr1,vr2} = ifrange;\n     If[va<vr1, va=vr1];  \
If[vb>vr2, vb=vr2];\n     \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["     If[debugit, Print[\"    \",if]; Print[\"  \",ifrange,\"  \", \
{vs,ve},\"  \",{va,vb}]];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["xa <-> xb corresponds to va <-> vb ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)     \n     \n     z = Which[(va > top  || vb < bottom) || \
(va>=vb),\n     \n               (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["boundary doesn't appear within diagram ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 {{}},\n                 \n     \
          {xa,xb} = {if[va],if[vb]};  xb > xa,\n     \n               (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["positive slope in v-x ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n                 Which[xa >= left && xb <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xa > right && xb  >right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[{{left,va}},subsif[if,vsol,vb]],\n                       True,   (* \
ie xb > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[subsif[if,va,vsol],{{right,vb}}] ],\n               True,\n              \
      \n               (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["negative slope in v-x",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *) \n             \n                 Which[xb >= left && xa <= \
right,\n                         subsif[if,va,vb],\n                       xa \
< left && xb < left,  \n                         {{left,va},{left,vb}},\n     \
                  xb > right && xb > right,  \n                         \
{{right,va},{right,vb}},\n                       xa < left,\n                 \
        vsol = vv /. FindRoot[if[vv]==left,{vv,va,vb}];\n                     \
    Join[subsif[if,va,vsol], {{left,vb}}],\n                       True,   (* \
ie xa > right *)\n                         vsol = vv /. \
FindRoot[if[vv]==right,{vv,va,vb}];\n                         \
Join[{{right,va}}, subsif[if,vsol,vb]] ]  ];   \n                             \
  \n     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["reverse info if ve < vs ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n  \n     If[ve > vs, z, Reverse[z]]  );",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["no of strings in common between two strings", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[incommon];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["incommon",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s1_,s2_] := \n      \
Length[Intersection[If[Head[s1]===List,s1,{s1}],\n                          \
If[Head[s2]===List,s2,{s2}]]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["positions in an integer vector where value is n", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[nposi];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["nposi",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ii_,n_] := Flatten[Position[ii,_?((#==n)&)]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[diwhich];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["diwhich",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List, doprint_] :=\n   (\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points which see s",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = nposi[Map[incommon[s,#]&,plines],3];\n    \
muni = nposi[Map[incommon[s,#]&,puni]-Map[Length,puni],-1];\n    mpoints = \
nposi[Map[incommon[s,#]&,ppoints],3];\n\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["which univariants, if any, are in range",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       ipuni = \
Flatten[Position[uni[[muni]],\n                          \
_?((#[[vuposi]]>bottom && #[[vuposi]]<top)&),{1}]];\n       muni = \
muni[[ipuni]] ];\n            \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["duni = degenerate univariants; cduni are the others",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    If[Length[muni] > 0,\n       duni = \
muni[[nposi[Map[Length,puni[[muni]]],2]]];  \n       cduni = \
Complement[muni,duni],\n       duni = {}; cduni = {}];\n           \n    (* ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["removing degenerate univariant(s) not relevant to this divariant \
",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[Length[cduni]>0 && Length[duni] > 0,  \n       \
idel = Map[({v,{react,prod}} = uni[[#,{vuposi,5}]];  \n       ph = \
Flatten[{react,prod}];\n       If[incommon[prod,s] == Length[prod],\n         \
     Position[uni[[duni]],\n                  _?((#[[vuposi]] < v && \
incommon[ph,#[[5,2]]] == 1)&),{1}],\n              Position[uni[[duni]],\n    \
              _?((#[[vuposi]] > v && incommon[ph,#[[5,1]]] == \
1)&),{1}]])&,cduni];\n       muni = \
Complement[muni,duni[[Union[Flatten[idel]]]]]];\n       \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
{\",plines[[#,{1,2}]],\", \",plines[[#,3]],\"}\"]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no univariants\"],\n             \
Print[\"  univariants\"];\n             Map[Print[\"    \", #,\": \
\",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["does a T-x / P-x divariant field", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doadi];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["doadi",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_List] :=\n   (\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["positions in lines, univariants and points relevant to s",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = diwhich[s,False];\n        \
\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["using any univariants to get the value (ie T or P) range",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n\n    Switch[Length[muni],\n       2, {va,vb} = \
uni[[muni,vuposi]]; \n          If[vb>va, {v1,v2} = {va,vb}, {v2,v1} = \
{va,vb}],\n       1, {vuni,{react,prod}} = uni[[muni[[1]],{vuposi,5}]];\n     \
     If[incommon[react,s]==Length[react],\n             v1 = bottom; v2 = \
vuni,\n             v1 = vuni; v2 = top],\n       _, v1 = bottom; v2 = top];\n\
            \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the divariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iff[[mlines]]; ifrange = iffrange[[mlines]];\n\
\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = plines[[mlines,{1,2}]];\n    pp = Map[(ppk = \
#; \n              pos = Position[pm, _?((#==ppk)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,1]]];\n    cpp = \
Complement[Range[Length[mlines]],Flatten[pp]];\n    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["lc = no of lines; lpp = no of points; pcpp = no not connected to \
points",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; luni = Length[muni];\n  \n   ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp,\"  \",luni]];",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n    \n    p = Which[lc == 1,\n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a divariant ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2], \n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && luni == 1, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries, one point, and one univariant ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            vuni = uni[[muni]][[1,vuposi]];\n                {p1,p2} = \
pp[[1]];                \n                If[vuni>vp, vw = v2, vw = v1];      \
          \n                Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp],\n\
                     makeboundary[if[[p2]],ifrange[[p2]],vp,vw]],\n           \
   \n              lc == 2, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point - ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["logic not complete",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n               ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[{d1,d2},\"  \",{vp,vw1,vw2}]];",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["from here down, three boundaries (ie max for 3 phase divariants) \
",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n              lpp == 1,\n              \n              (* ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                      \n               ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox[" If[debugit, Print[ifrange[[{pp1,pp2}]],\"  \",{d1,d2},\"  \
\",{vp,vc,vw1,vw2}]];",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n                \n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lpp == 2 \
&& luni == 1,\n              \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two points: boundaries connected through points, and to a \
univariant ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                vuni = \
uni[[muni]][[1,vuposi]];\n                {pp1,pp2}=pp;\n                p2 = \
Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
If[vuni>vp1, vw = v2, vw = v1];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],vw,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,vw]],\n              \n              \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** \
geometry for \",s,\" not implemented yet **\"]; {{}} ];\n    Join[p,{p[[1]]}] \
 );",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
finds lines, points etc in a particular (divariant) \
assemblage\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadriwhich];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["quadriwhich",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_, doprint_] :=\n   (\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["positions in lines, points, and degenerate univariants which see \
s",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    mlines = \
Flatten[Position[Map[#[[1]]&,pqlines],_?((#==s)&)]];\n    mpoints = \
Flatten[Position[Map[#[[1]]&,ppoints],_?((#==s)&)]];        \n    muni = \
Flatten[Position[puni,_?((Length[#]==2 && incommon[#,s]==1)&),{1}]];\n       \
\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["printout if doprint is True, otherwise mlines, etc returned as \
result ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    If[TrueQ[doprint],\n       If[Length[mlines]==0,\n  \
        Print[\"nothing matching \", s],\n          Print[\"matching \",s];\n \
         Print[\"  lines\"];\n          Map[Print[\"    \", #,\": \
\",{pqlines[[#,1]]},\", \",pqlines[[#,2]]]&,mlines];\n          \
If[Length[muni]==0,\n             Print[\"  no degenerate univariants\"],\n   \
          Print[\"  degenerate univariants\"];\n             Map[Print[\"    \
\", #,\": \",uni[[#,5,1]],\" = \",uni[[#,5,2]]]&,muni]];\n          \
If[Length[mpoints]>0,\n             Print[\"  quadrivariant -> divariant \
points\"];\n             Map[Print[\"    \", #,\": \
\",points[[#,{6,7,8}]]]&,mpoints]]]; ,\n        \n       \
{mlines,muni,mpoints}]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[doaquadri];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["doaquadri",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_]:=\n   (\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["qline, points and degenerate univariants for this quadrivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    {mlines,muni,mpoints} = quadriwhich[s,False];",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["\n    ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["\n    v1 = bottom; v2 = top;           \n            \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for the boundaries of the quadrivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    if = iffq[[mlines]];  ifrange = \
iffqrange[[mlines]];\n\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["pp are the boundaries either side of points; cpp are the simple \
ones ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pm = pqlines[[mlines,2]];\n    pp = Map[(ppk = #; \n\
              pos = Position[pm, _?((incommon[#,ppk]==1)&)];\n              \
If[Length[pos]==0,{},Map[#[[1]]&,pos]] )&, ppoints[[mpoints,{2,3}]]];\n    \
cpp = Complement[Range[Length[mlines]],Flatten[pp]];\n  \n    ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[s,\"  \",pp,\"  \", cpp]];",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["\n",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["    \n    lc = Length[mlines]; lpp = Length[pp]; lcpp = \
Length[cpp]; lu = Length[muni];\n\n    p = Which[lc == 1,\n    \n             \
 (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["just one boundary, so one side of a quadrivariant ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                \n              lc \
== 2 && lpp == 0 && lu == 0, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["- assumes lines have same slope",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                \
Join[makeboundary[if[[1]],ifrange[[1]],v1,v2],\n                     \
makeboundary[if[[2]],ifrange[[2]],v2,v1]],\n              \n              lc \
== 2 && lpp == 0 && lu == 1, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries and no points, but one degenerate univariant *)",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\n    \n                vuni = uni[[muni,vuposi]][[1]];\n         \
       If[{s} == puni[[muni]][[1]], vw = v1, vw = v2];\n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw,vuni],\n                     \
makeboundary[if[[2]],ifrange[[2]],vuni,vw]],\n              \n              \
lc == 2 && lpp == 1, \n    \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two boundaries and one point ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n\n                vp = points[[mpoints]][[1,vposi]];\n        \
        d1 = dif[if[[1]],ifrange[[1]],vp]; \n                d2 = \
dif[if[[2]],ifrange[[2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2,\n                      d1>0, vw1 = v1; \
vw2 = v1,\n                      True, vw1 = v2; vw2 = v2];\n                 \
     \n                ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["If[debugit, Print[{d1,d2},\" \",{vp,vw1,vw2}]]",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[";       \n                      \n                \
Join[makeboundary[if[[1]],ifrange[[1]],vw1,vp], \n                     \
makeboundary[if[[2]],ifrange[[2]],vp,vw2]],\n                     \n          \
    lc == 3 && lpp == 1 && lu == 0,\n              \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, two either side of the point ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp = points[[mpoints]][[1,vposi]];\n    \
            {pp1,pp2} = pp[[1]]; cpp1 = cpp[[1]];\n                d1 = \
dif[if[[pp1]],ifrange[[pp1]],vp]; \n                d2 = \
dif[if[[pp2]],ifrange[[pp2]],vp];\n                Which[(d1>=0 && d2>=0) || \
(d1<=0 && d2<=0), vw1 = v1; vw2 = v2; vc = v1,\n                      d1>0, \
vw1 = v1; vw2 = v1; vc = v2,\n                      True, vw1 = v2; vw2 = v2; \
vc = v1];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],vw1,vp], \n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vw2],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vw2,vc]],\n  \n              lc == 3 \
&& lpp == 1 && lu == 1,\n              \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["one point: one separate boundary, one degenerate univariant ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vuni = uni[[muni,vuposi]][[1]];\n       \
         vp = points[[mpoints]][[1,vposi]];\n                {pp1,pp2} = \
pp[[1]]; cpp1 = cpp[[1]];\n                \
Join[makeboundary[if[[pp1]],ifrange[[pp1]],v1,vp],  (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to ky",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[pp2]],ifrange[[pp2]],vp,vuni],\n                     \
makeboundary[if[[cpp1]],ifrange[[cpp1]],vuni,v1]],\n  \n              lc == 3 \
&& lpp == 2,\n              \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2}=pp;\n              \
  p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                \
Join[makeboundary[if[[p1]],ifrange[[p1]],v1,vp1], (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to chl",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v1]],\n  \n              lc == 4 && \
lpp == 2,\n              \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["two points with three boundaries, plus one separate boundary ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n                vp1 = points[[mpoints]][[1,vposi]]; vp2 \
= points[[mpoints]][[2,vposi]];\n                {pp1,pp2} = pp;\n            \
    p2 = Intersection[pp1,pp2][[1]];\n                {p1,p3} = \
Flatten[{Complement[pp1,{p2}],Complement[pp2,{p2}]}];\n                p4 = \
Complement[Range[4],{p1,p2,p3}][[1]];\n                \
Join[makeboundary[if[[p4]],ifrange[[p4]],v2,v1], (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["SPECIFIC to bi",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" *)\n                     \
makeboundary[if[[p1]],ifrange[[p1]],v1,vp1],\n                     \
makeboundary[if[[p2]],ifrange[[p2]],vp1,vp2],\n                     \
makeboundary[if[[p3]],ifrange[[p3]],vp2,v2]],\n  \n              (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["other cases haven't been implemented yet ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n              True,\n                Print[\"** not \
implemented yet **\"]; {{}} ];\n    If[p[[1]]=={}, \n       \
Join[Drop[p,1],{p[[2]]}], \n       Join[p,{p[[1]]}]]",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["   ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[");",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw all the quadrivariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[quadrvariant];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["quadrivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = \
Map[doaquadri,Intersection[Map[#[[1]]&,pqlines]]];\n      ipoly = \
Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > 0)&)]];\n      \
{Hue[1,0.45,1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]\
});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw all the divariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[divariant];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["divariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (poly = Map[doadi,Intersection[Map[Sort,plines]]];\n    \
  ipoly = Flatten[Position[Map[Apply[Plus,Map[Length,#]]&,poly],_?((# > \
0)&)]];\n      \
{GrayLevel[1],Map[Polygon,poly[[ipoly]]],GrayLevel[0],Map[Line,poly[[ipoly]]]}\
);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["makes horizontal lines for degenerate univariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makehor];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["makehor",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["pluni is position of degenerate reactions in uni ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pluni = nposi[Map[Length[Flatten[#[[5]]]]&,uni],2];\
\n    If[Length[pluni]==0, Line[{{0,top+1},{1,top+1}}], (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["dummy line",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n       Map[(            \n            (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ph is phases involved in A=B; vuni is T/P  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            ph = Flatten[uni[[#,5]]]; vuni = \
uni[[#,vuposi]];\n            \n            (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["dl2 is positions in lines which involve A or B disappearing  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            dl = plines; (* \
Map[#[[1]][[{6,7}]]&,lines]; *)\n            dl2 = \
Flatten[Position[dl,_?((#[[-1]]==ph[[1]] || #[[-1]]==ph[[2]])&),{1}]];\n      \
      \n            (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ii locates which of the dl2 involve A and B disappearing at A=B ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            gg = gray[Length[dl2],2];\n         \
   dl1 = Map[Drop[#,-1]&,dl[[dl2]]];\n            ii = \
Flatten[Position[Map[incommon[dl1[[#[[1]]]],dl1[[#[[2]]]]]&,gg],\n            \
                       _?((#==2)&)]];\n                                   \n  \
          If[debugit, ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["Print[ph,\"  \",dl2,\"  \",Map[gg[[#]]&,ii]]]; ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n            \n            (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["draws horizontal line, length depends on length of ii ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n            Switch[Length[ii],\n                \
   0, Line[{{left,vuni},{right,vuni}}],\n                   1, ig = \
dl2[[gg[[ii[[1]],1]]]];\n                      {r1,r2} = \
Apply[List,iff[[ig]]][[1]];\n                      If[vuni<=r1 || vuni>=r2,\n \
                        Line[{{left,vuni},{right,vuni}}],\n                   \
      Line[{{iff[[ig]][vuni],vuni},{right,vuni}}]],\n                   2, \
ig1 = dl2[[gg[[ii[[1]],1]]]];               \n                      {r11,r12} \
= Apply[List,iff[[ig1]]][[1]];\n                      ig2 = \
dl2[[gg[[ii[[2]],1]]]];\n                      {r21,r22} = \
Apply[List,iff[[ig2]]][[1]];\n                      Which[(vuni<=r11 || \
vuni>=r12) && (vuni<=r21 || vuni>=r22),\n                              \
Line[{{left,vuni},{right,vuni}}],\n                            vuni<=r11 || \
vuni>=r12,\n                              \
Line[{{iff[[ig2]][vuni],vuni},{right,vuni}}],\n                            \
vuni<=r21 || vuni>=r22,\n                              \
Line[{{iff[[ig1]][vuni],vuni},{right,vuni}}],\n                            \
True,\n                              Line[{{iff[[ig1]][vuni],vuni},\n         \
                           {iff[[ig2]][vuni],vuni}}]] ] )&,pluni] ] );",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["generate the outlines of the diagram", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background]; Clear[outline]; Clear[box];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["box",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {{left, bottom},{left, top},{right, top},{right, \
bottom},{left, bottom}};\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["background",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[1,0.3,1], Polygon[box]};\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["outline",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0], Line",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[box]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["                                    ",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["setting up ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setupvx];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["setupvx",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n   (If[TrueQ[varyTatP], \n       vposi = 5; oposi = 4; \
vuposi = 4; ouposi = 3; delv =   5; difdelv =   0.01, \n       vposi = 4; \
oposi = 5; vuposi = 3; ouposi = 4; delv = 0.2; difdelv = 0.0001];\n        \n \
   (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for lines",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    rolines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,alllines];\n    alliff = Array[(ak = \
alllines[[#]]; ro = rolines[[#]];\n                    Map[(rok = #;\n        \
                 ii = Flatten[Position[Map[#[[oposi]]&,ak],\n                 \
                              _?((#==rok)&),{1}]];\n                         \
Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                        \
)&,ro])&,Length[alllines]];\n    alliffrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliff];\n                        \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for qlines",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    roqlines = \
Map[Intersection[Map[#[[oposi]]&,#]]&,allqlines];\n    alliffq = Array[(ak = \
allqlines[[#]]; ro = roqlines[[#]];\n                     Map[(rok = #;\n     \
                     ii = Flatten[Position[Map[#[[oposi]]&,ak],\n             \
                                   _?((#==rok)&),{1}]];\n                     \
     Interpolation[Map[#[[{vposi,3}]]&,ak[[ii]]]]\n                         \
)&,ro])&,Length[allqlines]]; \n    alliffqrange = \
Map[Map[Apply[List,#][[1]]&,#]&,alliffq];\n                            \n    \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for univariants",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffuni = \
Map[Interpolation[Map[#[[{ouposi,vuposi}]]&,#]]&,alluni];\n    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolation functions for points",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    iffpoints = \
Map[Interpolation[Map[#[[{oposi,vposi}]]&,#]]&,allpoints];\n    iffpointsx = \
Map[Interpolation[Map[#[[{oposi,3}]]&,#]]&,allpoints];  );",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[assemblevx];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["assemblevx",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := \n   (    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["forming uni (ie univariants) at ok ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    iuni = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffuni],\n                           \
 _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    uni = Map[(if = iffuni[[#]];\n   \
            If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = ok; pp = if[tt]];\n  \
             {0,2,pp,tt,alluni[[#]][[1,5]]})&,iuni];       \n    puni =  \
Map[Flatten[#[[5]]]&,uni];\n    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["removes univariants excluded by out of range univariants",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)    \n    \n    dels1 = Map[(sp = #[[5]];\n                 \
If[#[[vuposi]]>top,\n                    If[Length[sp[[1]]]==1, {sp[[2]]},\n  \
                     {Flatten[{sp[[1,1]],sp[[2]]}],Flatten[{sp[[1,2]],sp[[2]]}\
]}],\n                    {{\"junk\"}}])&,uni];\n    dels2 = Map[(sp = \
#[[5]];\n                 If[#[[vuposi]]<bottom,\n                    \
If[Length[sp[[2]]]==1, {sp[[1]]},\n                       \
{Flatten[{sp[[1]],sp[[2,1]]}],Flatten[{sp[[1]],sp[[2,1]]}]}],\n               \
     {{\"junk\"}}])&,uni];\n    dels = Flatten[Union[dels1,dels2],1];\n       \
                         \n    cjuni =  Map[(dsk = #; ll = Length[dsk];\n     \
             Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,puni],\n   \
                                _?((#==0)&)]])&, dels];\n    juni = \
Complement[Range[Length[puni]],Intersection[Flatten[cjuni]]];\n               \
                  \n    uni = uni[[juni]];\n    puni =  puni[[juni]];         \
                   \n                                    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["removes univariants that are excluded by degenerate univariants",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ie does Schreinemakers in this special case",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" *)\n    \n    dlu = \
Flatten[Position[Map[Length,puni],_?((#==2)&)]];\n    cdlu = \
Complement[Range[Length[puni]],dlu];\n    idel1 = Map[(v = uni[[#,vuposi]]; p \
= puni[[#]];\n                Position[uni[[cdlu]],\n                     \
_?((ll1 = incommon[{p[[1]]},Flatten[#[[5]]]];\n                         \
#[[vuposi]] > v && ll1 == 1)&),{1}])&,dlu];\n    idel2 = Map[(v = \
uni[[#,vuposi]]; p = puni[[#]];\n                Position[uni[[cdlu]],\n      \
               _?((ll2 = incommon[{p[[2]]},Flatten[#[[5]]]];\n                \
         #[[vuposi]] < v && ll2 == 1)&),{1}])&,dlu];\n    idel1 = \
Union[Flatten[idel1]]; idel2 = Union[Flatten[idel2]];\n    \n    udel1 = \
Map[{#[[{1,3,4}]],#[[{2,3,4}]]}&,puni[[idel1]]];\n    udel2 = \
Map[{#[[{1,2,3}]],#[[{1,2,4}]]}&,puni[[idel2]]];\n    udel = \
Partition[Flatten[{udel1,udel2}],3];\n    \n    iuni = \
Complement[Range[Length[puni]],Union[Flatten[{idel1,idel2}]]];\n    uni = \
uni[[iuni]];\n    puni =  puni[[iuni]];\n\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["forming points at ok ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    ip = \
Flatten[Position[Map[Apply[List,#][[1]]&,iffpoints],\n                        \
    _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    points = Map[(if = \
iffpoints[[#]];\n               If[TrueQ[varyTatP],pp = ok; tt = if[pp],tt = \
ok; pp = if[tt]];\n               \
{1,2,iffpointsx[[#]][ok],pp,tt,allpoints[[#]][[1,6]],\n                \
allpoints[[#]][[1,7]],allpoints[[#]][[1,8]]})&,ip];       \n    \n    ppoints \
= Map[Flatten[#[[{6,7,8}]]]&,points];\n    \n    cipoints =  Map[(dsk = #; ll \
= Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,ppoints],\n             \
                         _?((#==0)&)]])&, dels];\n    ipoints = \
Complement[Range[Length[ppoints]],Intersection[Flatten[cipoints]]];\n    \
points = points[[ipoints]];\n    ppoints = ppoints[[ipoints]];\n\n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["forming lines at ok ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    plines = Map[Flatten[#[[1,{6,7}]]]&,alllines];\n    \
ilines1 = Flatten[Position[Map[#[[{1,-1}]]&,rolines],\n                       \
       _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    cilines2 = \
Flatten[Map[(udelk = #;\n                            Flatten[Position[plines,\
\n                                             _?((Length[Intersection[#,\
udelk]]==3)&),\n                                             {1}]])&,udel]];\n\
    ilines2 = Complement[Range[Length[rolines]],cilines2];\n    cilines3 =  \
Map[(dsk = #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,plines],\n              \
                        _?((#==0)&)]])&, dels];\n    ilines3 = \
Complement[Range[Length[plines]],Intersection[Flatten[cilines3]]];\n    \
ilines = Intersection[ilines1,ilines2,ilines3];                          \n   \
                           \n    iff = Map[(ii = #; rok = rolines[[ii]];\n    \
           kkm = Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n           \
    If[Length[kkm] == 1,\n                  alliff[[ii,kkm[[1]]]],\n          \
        kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  \
k1 = kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {f1,f2} = alliff[[ii,{k1,k2}]]; \n                  \
{fr1,fr2} = alliffrange[[ii,{k1,k2}]];\n                  diff1 = \
(fr1[[2]]-fr1[[1]]-2del)/ni;\n                  v1 = Map[{#,f1[#]}&, \
Range[fr1[[1]]+del,fr1[[2]]-del,diff1]];\n                  diff2 = \
(fr2[[2]]-fr2[[1]]-2del)/ni;\n                  v2 = Map[{#,f2[#]}&, \
Range[fr2[[1]]+del,fr2[[2]]-del,diff2]];\n                  \
Interpolation[v1(1-prop) + v2 prop]]\n              )&, ilines];            \n\
              \n    iffrange = Map[Apply[List,#][[1]]&, iff];    \n           \
        \n    plines = plines[[ilines]];\n                 \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["forming qlines at ok ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n    \n    pqlines = Map[Flatten[#[[1,{6,7}]]]&,allqlines];\n  \
  iqlines1 = Flatten[Position[Map[#[[{1,-1}]]&,roqlines],\n                   \
           _?((ok>=#[[1]] && ok<=#[[2]])&),{1}]];\n    ciqlines2 =  Map[(dsk \
= #; ll = Length[dsk];\n                     \
Flatten[Position[Map[Length[Intersection[#,dsk]]-ll &,pqlines],\n             \
                         _?((#==0)&)]])&, dels];\n    iqlines2 = \
Complement[Range[Length[pqlines]],Intersection[Flatten[ciqlines2]]];\n    \
iqlines = Intersection[iqlines1,iqlines2];\n              \n    iffq = \
Map[(ii = #; rok = roqlines[[ii]];\n               kkm = \
Flatten[Position[rok, _?((Abs[ok-#]<0.0001)&)]];\n               \
If[Length[kkm] == 1,\n                  alliffq[[ii,kkm[[1]]]],\n             \
     kk0 = Flatten[Position[rok, _?((ok < #)&)]][[1]];\n                  k1 \
= kk0-1;  k2 = kk0;\n                  prop = (ok - \
rok[[k1]])/(rok[[k2]]-rok[[k1]]);\n                  ni = 10; del = 0.00001;\n\
                  {fq1,fq2} = alliffq[[ii,{k1,k2}]]; \n                  \
{fqr1,fqr2} = alliffqrange[[ii,{k1,k2}]];\n                  diffq1 = \
(fqr1[[2]]-fqr1[[1]]-2del)/ni;\n                  vq1 = Map[{#,fq1[#]}&, \
Range[fqr1[[1]]+del,fqr1[[2]]-del,diffq1]];\n                  diffq2 = \
(fqr2[[2]]-fqr2[[1]]-2del)/ni;\n                  vq2 = Map[{#,fq2[#]}&, \
Range[fqr2[[1]]+del,fqr2[[2]]-del,diffq2]];\n                  \
Interpolation[vq1(1-prop) + vq2 prop]]\n               )&, iqlines];          \
  \n              \n    iffqrange = Map[Apply[List,#][[1]]&, iffq];          \
\n           \n    pqlines = pqlines[[iqlines]]   );\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["make graphic", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[makevx];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["makevx",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[ok_] := (assemblevx[ok];\n                \
Show[Graphics[{background,\n                               quadrivariant,\n   \
                            divariant,\n                               \
makehor,\n                               outline,\n                           \
    labelling[ok]}],\n                     AspectRatio -> 1, Frame -> True,\n \
                    PlotRange -> {{left, right}, {bottom, top}},\n            \
         PlotRegion-> {{addx,1-addx},{addy,1-addy}}])",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["compatibility diagram functions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["default values, normally overridden", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["creates slider", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[slider];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["slider",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v1_, v2_, dv1_, dv2_] := \n    \
{Line[{{x1,y},{x2,y},{x2,y-dy},{x1,y-dy},{x1,y}}],\n          Map[Line[{{x1 + \
(#-v1)(x2-x1)/(v2-v1),y},\n                    {x1 + \
(#-v1)(x2-x1)/(v2-v1),y-dy}}]&, Range[v1,v2,dv1]],\n                    \n    \
      Map[Line[{{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.4},\n                    \
{x1 + (#-v1)(x2-x1)/(v2-v1),y-dy 0.6}}]&, Range[v1,v2,dv2]],\n                \
    \n          If[TrueQ[varyTatP],\n             \
Text[FontForm[\"T(\[Degree]C)\",  {\"Helvetica\",fontsize1}], {x1,y+yplus}],\n\
             Text[FontForm[\"P(kbar)\",{\"Helvetica\",fontsize1}], \
{x1,y+yplus}]],\n          \n          \
Text[FontForm[Round[v1],{\"Helvetica\",fontsize1}], {x1,y+yminus}],\n         \
 Text[FontForm[Round[v2],{\"Helvetica\",fontsize1}], {x2,y+yminus}] };",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["creates bar on slider", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bar];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["bar",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[v_, v1_, v2_] := \n           Line[{{x1 + (v-v1)(x2-x1)/(v2-v1), \
y-dy-dy1},\n                 {x1 + (v-v1)(x2-x1)/(v2-v1), y+dy1}}];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws background to phase relationships", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[background];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["background",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[0,0.45,1], Polygon[shape], GrayLevel[0], Line[shape]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws labels", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[labelling];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["labelling",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[p_] := {};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws all the tie triangles", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tietriangle];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["tietriangle",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_]:=\n     {GrayLevel[1], Map[conv[Polygon,#]&, q], \n      \
GrayLevel[0], Map[conv[Line,#]&, q]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["interpolation of divariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[interpolatedi];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolatedi",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_, info_, v_] :=\n   (    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["info2 is same as info but with names->codes and phases ordered  ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    info1 = Fold[(k = #2; pn = phase[[k]];\n    \
              pp = Position[#1,_?((#==pn)&)];\n                  MapAt[k&, \
#1, pp])&, info, Range[Length[phase]]];\n    info2 = Map[{#[[1]],Map[Sort[#, \
(#1[[1]]<#2[[1]])&]&, Drop[#,1]]}&,info1];\n    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["vv is vector of T (or P)  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t   vv = Map[#[[1,vposi]]&, info];\n    \n    \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["kki is position in vv if there is exact match with v  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    kki = Flatten[Position[vv, _?((Abs[v - \
#]<diffv)&)]]; \n    If[Length[kki] == 1,  \n        \n       (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["returns divariant coordinates from info2 if there is an exact \
match ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       info2[[kki[[1]],2]],\n        \n       \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["no exact match; {k1,k2} positions in vv bracket v ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       k2 = Flatten[Position[vv, _?((v < \
#)&)]][[1]]; k1 = k2 - 1;\n       \n       If[k1 == 0, \n           \n        \
  (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["if v cannot be bracketed, empty list returned ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n          {},\n           \n          (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["bracketed; vprop is prop position in bracket ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t         vprop = (v - vv[[k1]])/(vv[[k2]] - \
vv[[k1]]);\n\t\n          (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["dic are divariants in {k1,k2} in common ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         di1 = Map[Transpose[#][[1]]&, \
Drop[info2[[k1]],1][[1]]];\n\t         di2 = Map[Transpose[#][[1]]&, \
Drop[info2[[k2]],1][[1]]];\n\t         dic = Intersection[di1,di2];\n\t\n     \
     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolating the divariants in common ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         Map[(idik = #;\n            \t  pk1 = \
Position[di1, _?((#==idik)&)][[1,1]];\n      \t        pk2 = Position[di2, \
_?((#==idik)&)][[1,1]];\n      \t        q1 = info2[[k1,2,pk1]]; q2 = \
info2[[k2,2,pk2]];\n               q1 + vprop (q2 - q1) )&, dic]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["drawing trivariants - no curvature assumed", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[tri];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["tri",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (\t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["using divariant info in allinfo, ic is all phases involved ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n      af = Fold[({equiv1,equiv2} = #2;\n          \
        MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n     \t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["looks at the phases pairwise, with a being the divariant \
coordinates ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];                       \
        \n      a = Map[({k1,k2} = #; \n                 plc = \
Flatten[Position[Map[Length,Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\n\
                 cc = Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n     \
                                    Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\n\
                 occ = Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n   \
              cocc = Map[Map[conv,#]&,occ];\n                 \
Map[Join[cocc[[#[[1]]]],Reverse[cocc[[#[[2]]]]],{cocc[[#[[1]],1]]}]&, \n      \
               Partition[Range[Length[plc]],2]] )&, Map[ic[[#]]&,gr]];        \
             \n     \t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["drawing the trivariant info in a ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      {Hue[0,0.15,1], \n       \
Map[Map[Polygon[#]&,#]&, a], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, a], \n       GrayLevel[0]});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["setting up trivariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setuptri];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["setuptri",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     (     \t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["ic is list of phases involved in trivariants ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      triinfo1 = Fold[(k = #2; pn = phasef[[k]];\n   \
                    pp = Position[#1,_?((#==pn)&)];\n                       \
MapAt[k&, #1, pp])&, triinfo, Range[Length[phase]]];\n      triinfo2 = \
Map[{#[[1]],Map[Sort[#, (#1[[1]]<#2[[1]])&]&, \
Drop[Drop[#,-1],1]][[1]]}&,triinfo1];\n      pr = \
Map[{{#[[1,1]],#[[2,1]]},Map[conv,#]}&,Map[Drop[#,1][[1]]&,triinfo2]];\n      \
vr = Map[#[[1,vposi]]&,triinfo2];      \n      c = Map[#[[1]]&,pr];  ic = \
Intersection[Flatten[c]];\n      \n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["calculates all the interpolation functions for the trivariant \
boundaries ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      gr = gray[Length[ic],2];         \n      \
Map[({k1,k2} = #; \n           pp = Flatten[Position[c, _?((#=={k1,k2})&)]];\n\
           pr1 = Map[Drop[#,1][[1]]&,pr[[pp]]];\n           vr1 = vr[[pp]];\n \
          ivv = Intersection[vr1];\n           {#, Map[(ivvk = #;\n           \
         pr2 = pr1[[Flatten[Position[vr1,_?((#==ivvk)&)]]]];\n                \
    {ivvk,\n                     \
Interpolation[Map[Reverse,Transpose[pr2][[1]]],\n                             \
      InterpolationOrder->2], \n                     \
Interpolation[Map[Reverse,Transpose[pr2][[2]]],\n                             \
      InterpolationOrder->2]})&,ivv]})&, \n           Map[ic[[#]]&,gr]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["accessing trivariant info", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[getf];\t\t\t\t(* 1,2 are different limbs; a,b are \
interpolants *)\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["getf",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[{k1_,k2_}, vk_] :=\n      (pp = \
Flatten[Position[Map[#[[1]]&,iff], _?((#=={k1,k2})&)]];\n       If[Length[pp] \
== 0, {0,{}}, \n          pp1 = pp[[1]];   \n          ip = iff[[pp1,2]];\n   \
       If[ip === {}, {0,{}}, \n             vv = Transpose[ip][[1]];\n        \
     kkm = Flatten[Position[vv, _?((Abs[vk-#]<0.01)&)]]; \n             \n    \
         If[Length[kkm] == 1,  \n                {ff1,ff2} = \
ip[[kkm[[1]],{2,3}]]; \n                {1,{ {ff1, Apply[List,ff1][[1]]}, \
{ff2, Apply[List,ff2][[1]]} }},\n             \n                kk0 = \
Flatten[Position[vv, _?((vk < #)&)]]; \n                \n                \
If[kk0 == {} || kk0[[1]] == 1, {0,{}},\n                   kk2 = kk0[[1]];  \
kk1 = kk2 - 1;\n                   prop = (vk - vv[[kk1]])/(vv[[kk2]] - \
vv[[kk1]]);\n                   \n                   (* Print[{k1,k2} /. sub, \
{kk1,kk2}]; *)\n             \n                   ff1a = ip[[kk1,2]]; ff1b = \
ip[[kk2,2]];  \n                   {is1a,ie1a} = Apply[List,ff1a][[1]];\n     \
              {is1b,ie1b} = Apply[List,ff1b][[1]];\n                   is1 = \
If[is1a>is1b, is1a, is1b]; ie1 = If[ie1a<ie1b, ie1a, ie1b];\n             \n  \
                 ff2a = ip[[kk1,3]]; ff2b = ip[[kk2,3]];\n                   \
{is2a,ie2a} = Apply[List,ff2a][[1]];\n                   {is2b,ie2b} = \
Apply[List,ff2b][[1]];\n                   is2 = If[is2a>is2b, is2a, is2b]; \
ie2 = If[ie2a<ie2b, ie2a, ie2b];\n             \n                   {2,{ \
{{ff1a,ff1b}, {is1,ie1}}, {{ff2a,ff2b}, {is2,ie2}}, prop}}]]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["drawing proper trivariant", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["del = 0.001;\n\nClear[btri]; Clear[f1]; Clear[f2]; \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["btri",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_]:=\n     (af = Fold[({equiv1,equiv2} = #2;\n                 \
 MapAt[equiv1&, #1, Position[#1,_?((#==equiv2)&)]])&,\n                \
allinfo, equivalence];\n      c = Map[Transpose[#][[1]]&,af]; ic = \
Intersection[Flatten[c]];\n      gr = gray[Length[ic],2];   icgr = \
Map[ic[[#]]&,gr];  z=.;    \n                      \n      atri = Array[(k = \
#;  {k1,k2} = icgr[[k]];\n                 plc = \
Flatten[Position[Map[Length,Map[Intersection[{k1,k2},#]&,c]], _?((#==2)&)]];\n\
                 cc = Map[af[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n     \
                                    Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\n\
                 occ = Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n   \
              cocc = Map[Map[conv,#]&,occ];\n                 \n              \
   {code,f} = getf[{k1,k2},vk];\n                 \n                 simple = \
code == 0; match = code == 1;\n                 \n                 If[simple, \
(* do nothing *) ,\n                    If[match,\n                       \
{{f1, {is1,ie1}},{f2, {is2,ie2}}} = f,\n                       {{{f1a,f1b}, \
{is1,ie1}}, {{f2a,f2b}, {is2,ie2}}, prop} = f]];\n                       \n   \
              If[OddQ[Length[plc]], \n                    d = \
Abs[Join[cocc,{{{0,0},{0,0}}}] - Join[{{{0,0},{0,0}}},cocc]];\n               \
     pd = Flatten[Position[Map[Apply[Plus,Flatten[#]]&,d],_?((#<0.01)&)]];\n  \
                  cocc = Drop[cocc,pd];\n                    \
If[OddQ[Length[cocc]],\n                       Print[\"no of tie lines for \
\",{k1,k2} /. sub,\" is still odd \"],\n                       (* \
Print[\"duplicate removed in \",{k1,k2} /. sub] *)   ]];\n                    \
   \n                 Map[(c1 = cocc[[#[[1]]]];\n                      c2 = \
cocc[[#[[2]]]];\n                      \n                      If[simple,  p1 \
= {{}}; p2 = {{}},\n\n                         cy12 = c2[[1,2]]; cy11 = \
c1[[1,2]]; \n                         s1 =  If[is1>cy11+del, is1, cy11+del];  \
\n                         e1 = If[ie1<cy12-del, ie1, cy12-del];\n            \
             dy1 = e1 - s1;\n                         p1 = If[dy1 <= \
2del,{{}},\n                                 kd1 = Floor[dy1/del]; dd = \
dy1/kd1;\n                                 rr1 = s1 + dd Range[0,kd1];\n      \
                           If[match,\n                                    \
Map[{f1[#],#}&, rr1],\n                                    \
Map[{(1-prop)f1a[#]+prop f1b[#],#}&, rr1]]];\n                                \
 \n                         cy22 = c2[[2,2]]; cy21 = c1[[2,2]]; \n            \
             s2 =  If[is2>cy21+del, is2, cy21+del];  \n                       \
  e2 = If[ie2<cy22-del, ie2, cy22-del];\n                         dy2 = e2 - \
s2;\n                         p2 = If[dy2 <= 2del,{{}},\n                     \
            kd2 = Floor[dy2/del]; dd = dy2/kd2;\n                             \
    rr2 = s2 + dd Range[0,kd2];\n                                 If[match,\n \
                                   Map[{f2[#],#}&, rr2],\n                    \
                Map[{(1-prop)f2a[#]+prop f2b[#],#}&, rr2]]] ];\n              \
                      \n                       Which[Dimensions[p1]=={1,0} && \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p1]=={1,0},\n                               \
Join[c1,p2,Reverse[c2],{c1[[1]]}],\n                             \
Dimensions[p2]=={1,0},\n                               \
Join[c1,Reverse[c2],Reverse[p1],{c1[[1]]}],\n                             \
True,\n                               \
Join[c1,p2,Reverse[c2],Reverse[p1],{c1[[1]]}]])&, \n                     \
Partition[Range[Length[cocc]],2]])&, Length[icgr]];\n      {Hue[0,0.15,1], \n \
      Map[Map[Polygon[#]&,#]&, atri], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, atri], \n       GrayLevel[0]});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["looking at the divariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[show];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["show",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := Print[N[allinfo /. sub,3] //ColumnForm]",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["checking data shape", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[datashape]; Clear[datacheck];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["datashape",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_] := Map[Map[Dimensions,#]&,info];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["datacheck",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[info_, k_] :=\n  (dc = datashape[info];\n   ldc = \
Length[Position[Map[Transpose[Drop[#,1]][[2]]&, dc], _?((#!=k)&)]];\n   \
If[TrueQ[ldc==0],\"data shape OK\",\"data shape stuffed\"])",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram with slider etc", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["fullmake",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
tri, \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nfullmake[___] := If[TrueQ[varyTatP],\n        \
            Print[\"T outside range (or T inc on slider not supplied)\"],\n   \
                 Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[make];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["make",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   tri, \n                     tietriangle[infok],\n          \
           labelling[vstring],\n                     plotvscale[vk]}],\n      \
               AspectRatio->Automatic,\n                     \
PlotRange->plotrange]) /; vk >= vlow && vk <= vhigh;\n     \nmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
draw compatibility diagram with proper trivariants and with slider \
etc\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bfullmake];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["bfullmake",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, vinc1_,vinc2_] :=\n    (assemble[vk];\n     Show[Graphics[ \
{background,\n                     slider[vlow, vhigh, vinc1,vinc2], bar[vk, \
vlow, vhigh],\n                     labelling[vstring],\n                     \
btri[vk], \n                     tietriangle[infok]}],\n                     \
AspectRatio->Automatic, \n                     PlotRange->plotrangef]) /; vk \
>= vlow && vk <= vhigh;\n     \nbfullmake[___] := If[TrueQ[varyTatP],\n       \
             Print[\"T outside range (or T inc on slider not supplied)\"],\n  \
                  Print[\"P outside range (or P inc on slider not \
supplied)\"]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[bmake];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["bmake",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {background,\n  \
                   btri[vk], \n                     tietriangle[infok],\n     \
                plotvscale[vk]}],\n          AspectRatio->Automatic,\n        \
  PlotRange->plotrange]) /; vk <= vhigh;\n     \nbmake[___] := \
If[TrueQ[varyTatP],\n                Print[\"T outside range\"],\n            \
    Print[\"P outside range\"]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[fullmake];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["partmake",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_, plotrangep_] :=\n    (assemble[vk]; \n     Show[Graphics[ \
{background,\n                     tri,\n                     \
tietriangle[infok]}],\n                    AspectRatio->Automatic, \n         \
           PlotRange->plotrangep])",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setup];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["setup",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_] :=\n   (vstring = s;\n    If[TrueQ[varyTatP],\n       diffv \
= 0.01;    vposi = 2; vlow = info[[1,1,2]]; vhigh = info[[-1,1,2]],\n       \
diffv = 0.0001;; vposi = 1; vlow = info[[1,1,1]]; vhigh = info[[-1,1,1]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["brenton's T-x code", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[univariant]; Clear[divariant]; Clear[quadrivariant];\n\
Clear[background]; Clear[outline];\n\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["univariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[infou_] := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [1], GrayLevel[0],\n                    \
Map[Line[#]&, infou]};\n                    \n",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["divariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[infod_] := ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["{GrayLevel[1], Map[Polygon[#]&, infod], \n                 \
AbsoluteThickness [0.3], GrayLevel[0],\n                 Map[Line[#]&, \
infod]};\n                 \n",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["quadrivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[infoq_] := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["Hue[",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["1,0.45,1",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["], Map[Polygon[#]&, infoq]};\n\n",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["background",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {Hue[1,0.3,1],\n        Polygon[{{0, 550},{0, 620},{1.0, \
620},{1.0, 550}}]};\n        \n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["txoutline",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" := {",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["AbsoluteThickness [0.3], GrayLevel[0],\n       Line",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"],
  StyleBox["[{{0, 550},{0, 620},{1.0, 620},{1.0, 550},{0, 550}}]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["                                    ",
    FontFamily->"Monaco",
    FontSize->11,
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["cut-down compatibility diagram function code", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["varyTatP = True;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["interpolation of divariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[interpolatedivariant];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolatedivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[phase_, info_, v_] :=\n   (    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["info2 is same as info but with names->codes and phases ordered  ",
    
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    info1 = Fold[(k = #2; pn = phase[[k]]; pp = \
Position[#1,_?((#==pn)&)];\n                  MapAt[k&, #1, pp])&, info, \
Range[Length[phase]]];\n    info2 = Map[{#[[1]],Map[Sort[#, \
(#1[[1]]<#2[[1]])&]&, Drop[#,1]]}&,info1];\n    \n    (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["vv is vector of T (or P)  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t   vv = Map[#[[1,vposi]]&, info];\n    \n    \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["kki is position in vv if there is exact match with v  ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n    kki = Flatten[Position[vv, _?((Abs[v - \
#]<diffv)&)]]; \n    If[Length[kki] == 1,  \n        \n       (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["returns divariant coordinates from info2 if there is an exact \
match ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       info2[[kki[[1]],2]],\n        \n       \
(* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["no exact match; {k1,k2} positions in vv bracket v ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n       k2 = Flatten[Position[vv, _?((v < \
#)&)]][[1]]; k1 = k2 - 1;\n       \n       If[k1 == 0, \n           \n        \
  (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["if v cannot be bracketed, empty list returned ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n          {},\n           \n          (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["bracketed; vprop is prop position in bracket ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n            \n\t         vprop = (v - vv[[k1]])/(vv[[k2]] - \
vv[[k1]]);\n\t\n          (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["dic are divariants in {k1,k2} in common ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         di1 = Map[Transpose[#][[1]]&, \
Drop[info2[[k1]],1][[1]]];\n\t         di2 = Map[Transpose[#][[1]]&, \
Drop[info2[[k2]],1][[1]]];\n\t         dic = Intersection[di1,di2];\n\t\n     \
     (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["interpolating the divariants in common ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n\t         Map[(idik = #;\n            \t  pk1 = \
Position[di1, _?((#==idik)&)][[1,1]];\n      \t        pk2 = Position[di2, \
_?((#==idik)&)][[1,1]];\n      \t        q1 = info2[[k1,2,pk1]]; q2 = \
info2[[k2,2,pk2]];\n               q1 + vprop (q2 - q1) )&, dic]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["drawing trivariants (between divariants)", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[drawtrivariant];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["drawtrivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" :=\n     ((* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["using divariant info in allinfo, ic is all phases involved ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n          \n      c = Map[Transpose[#][[1]]&,allinfo]; ic = \
Intersection[Flatten[c]];\n     \t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["looks at the phases pairwise, with a being the divariant \
coordinates ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      lic = Length[ic];\n      gr = Flatten[Map[(k = \
#; Map[{k,#}&, Range[k+1,lic]])&,Range[lic-1]],1];\n\n      a = Map[({k1,k2} \
= #; \n                 plc = \
Flatten[Position[Map[Length,Map[Intersection[{k1,k2},#]&,c]], \n              \
                          _?((#==2)&)]];\n                 cc = \
Map[allinfo[[#,Flatten[{Position[c[[#]],_?((#==k1)&)],\n                      \
                        Position[c[[#]],_?((#==k2)&)]}]]]&,plc];\n            \
     occ = Map[Drop[#,1][[1]]&,Sort[Map[{#[[1,2]],#}&, cc]]];\n               \
  cocc = Map[Map[conv,#]&,occ];\n                 \
Map[Join[cocc[[#[[1]]]],Reverse[cocc[[#[[2]]]]],{cocc[[#[[1]],1]]}]&, \n      \
               Partition[Range[Length[plc]],2]] )&, Map[ic[[#]]&,gr]];        \
             \n     \t\n      (* ",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["drawing the trivariant info in a ",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["*)\n       \n      {Hue[0,0.15,1], \n       \
Map[Map[Polygon[#]&,#]&, a], \n       GrayLevel[0],\n       \
Map[Map[Line[#]&,#]&, a], \n       GrayLevel[0]});",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draws all the tie triangles", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[drawdivariant];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["drawdivariant",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[q_]:=\n     {GrayLevel[1], Map[conv[Polygon,#]&, q], \n      \
GrayLevel[0], Map[conv[Line,#]&, q]};",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram with proper trivariants", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[setup];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["setup",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[s_] :=\n   (vstring = s;\n    If[TrueQ[varyTatP],\n       diffv \
= 0.01;    vposi = 2; vlow = info[[1,1,2]]; vhigh = info[[-1,1,2]],\n       \
diffv = 0.0001;; vposi = 1; vlow = info[[1,1,1]]; vhigh = info[[-1,1,1]]]);",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["draw compatibility diagram", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["Clear[compatibilitytriangle];\n",
    FontFamily->"Monaco",
    FontWeight->"Plain"],
  StyleBox["compatibilitytriangle",
    FontFamily->"Monaco",
    FontWeight->"Plain",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["[vk_] :=\n    (assemble[vk];\n     Show[Graphics[ {Hue[0,0.45,1], \
Polygon[shape], GrayLevel[0], Line[shape],\n                     \
labelling[vk],\n                     drawtrivariant, \n                     \
drawdivariant[infok]}],\n                     AspectRatio->Automatic,\n       \
              PlotRange->plotrange]) /; vk >= vlow && vk <= vhigh;\n     \n\
compatibilitytriangle[___] := \n       If[TrueQ[varyTatP],Print[\"T outside \
range\"],Print[\"P outside range\"]];",
    FontFamily->"Monaco",
    FontWeight->"Plain"]
}], "Input",
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{692, 703},
WindowMargins->{{9, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "myst.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]X2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000000`<300000BL?00400@00000000000000060<01T1T000000<2000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 150, 4, 102, "Title"],
Cell[1880, 58, 24, 0, 46, "Text"],
Cell[1907, 60, 36, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[1968, 64, 69, 1, 67, "Section"],

Cell[CellGroupData[{
Cell[2062, 69, 229, 7, 77, "Input"],
Cell[2294, 78, 40, 1, 24, "Output"]
}, Open  ]],
Cell[2349, 82, 64, 1, 25, "Input"],

Cell[CellGroupData[{
Cell[2438, 87, 61, 1, 63, "Subsection"],
Cell[2502, 90, 67, 1, 46, "Text"],
Cell[2572, 93, 685, 21, 116, "Input"],
Cell[3260, 116, 62, 1, 46, "Text"],
Cell[3325, 119, 430, 14, 53, "Input"],
Cell[3758, 135, 212, 7, 77, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4007, 147, 58, 1, 47, "Subsection"],
Cell[4068, 150, 100, 1, 46, "Text"],
Cell[4171, 153, 644, 18, 103, "Input"],
Cell[4818, 173, 174, 4, 62, "Text"],
Cell[4995, 179, 1131, 33, 155, "Input"],
Cell[6129, 214, 326, 10, 158, "Text"],
Cell[6458, 226, 485, 14, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6980, 245, 67, 1, 47, "Subsection"],
Cell[7050, 248, 80, 1, 46, "Text"],
Cell[7133, 251, 1355, 42, 168, "Input"],
Cell[8491, 295, 80, 1, 46, "Text"],
Cell[8574, 298, 668, 17, 129, "Input"],
Cell[9245, 317, 145, 4, 62, "Text"],
Cell[9393, 323, 532, 12, 129, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9974, 341, 75, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[10074, 346, 73, 1, 63, "Subsection"],
Cell[10150, 349, 100, 1, 44, "SmallText"],
Cell[10253, 352, 532, 14, 126, "Text"],
Cell[10788, 368, 129, 5, 51, "Input"],
Cell[10920, 375, 264, 9, 62, "Text"],
Cell[11187, 386, 817, 30, 64, "Input"],
Cell[12007, 418, 214, 9, 46, "Text"],
Cell[12224, 429, 329, 10, 38, "Input"],
Cell[12556, 441, 160, 6, 46, "Text"],
Cell[12719, 449, 355, 10, 38, "Input"],
Cell[13077, 461, 1128, 28, 222, "Text"],
Cell[14208, 491, 4194, 61, 1143, "Input"],
Cell[18405, 554, 269, 9, 62, "Text"],
Cell[18677, 565, 5300, 120, 1052, "Input"],
Cell[23980, 687, 85, 1, 46, "Text"],
Cell[24068, 690, 237, 8, 25, "Input"],
Cell[24308, 700, 196, 5, 62, "Text"],
Cell[24507, 707, 2253, 39, 522, "Input"],
Cell[26763, 748, 82, 1, 46, "Text"],
Cell[26848, 751, 394, 11, 51, "Input"],
Cell[27245, 764, 295, 6, 64, "Input"],
Cell[27543, 772, 346, 12, 62, "Text"],
Cell[27892, 786, 1615, 27, 454, "Input"],
Cell[29510, 815, 538, 17, 94, "Text"],
Cell[30051, 834, 398, 11, 77, "Input"],
Cell[30452, 847, 177, 6, 46, "Text"],
Cell[30632, 855, 277, 9, 38, "Input"],
Cell[30912, 866, 164, 6, 46, "Text"],
Cell[31079, 874, 379, 11, 64, "Input"],
Cell[31461, 887, 142, 6, 46, "Text"],
Cell[31606, 895, 302, 10, 38, "Input"],
Cell[31911, 907, 511, 20, 62, "Text"],
Cell[32425, 929, 313, 10, 38, "Input"],
Cell[32741, 941, 511, 20, 62, "Text"],
Cell[33255, 963, 304, 10, 38, "Input"],
Cell[33562, 975, 217, 9, 46, "Text"],
Cell[33782, 986, 274, 9, 25, "Input"],
Cell[34059, 997, 224, 9, 46, "Text"],
Cell[34286, 1008, 270, 9, 25, "Input"],
Cell[34559, 1019, 73, 1, 46, "Text"],
Cell[34635, 1022, 253, 7, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34925, 1034, 77, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[35027, 1039, 84, 1, 61, "Subsubsection"],
Cell[35114, 1042, 1092, 34, 116, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36267, 1083, 81, 1, 47, "Section"],

Cell[CellGroupData[{
Cell[36373, 1088, 72, 1, 63, "Subsection"],
Cell[36448, 1091, 90, 1, 46, "Text"],
Cell[36541, 1094, 124, 4, 25, "Input"],
Cell[36668, 1100, 1670, 30, 454, "Input"],
Cell[38341, 1132, 631, 20, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39009, 1157, 74, 1, 47, "Subsection"],
Cell[39086, 1160, 57, 1, 46, "Text"],
Cell[39146, 1163, 750, 17, 142, "Input"],
Cell[39899, 1182, 96, 1, 46, "Text"],
Cell[39998, 1185, 452, 14, 64, "Input"],
Cell[40453, 1201, 96, 1, 46, "Text"],
Cell[40552, 1204, 361, 12, 38, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40950, 1221, 72, 1, 47, "Subsection"],
Cell[41025, 1224, 84, 1, 70, "Text"],
Cell[41112, 1227, 130, 4, 70, "Input"],
Cell[41245, 1233, 91, 4, 70, "Input"],
Cell[41339, 1239, 68, 1, 70, "Input"],
Cell[41410, 1242, 90, 1, 70, "Text"],
Cell[41503, 1245, 562, 15, 70, "Input"],
Cell[42068, 1262, 131, 4, 70, "Text"],
Cell[42202, 1268, 502, 14, 70, "Input"],
Cell[42707, 1284, 159, 4, 70, "Text"],
Cell[42869, 1290, 4060, 94, 70, "Input"],
Cell[46932, 1386, 92, 1, 70, "Text"],
Cell[47027, 1389, 452, 14, 70, "Input"],
Cell[47482, 1405, 96, 1, 70, "Text"],
Cell[47581, 1408, 361, 12, 70, "Input"],
Cell[47945, 1422, 121, 4, 70, "Text"],
Cell[48069, 1428, 3329, 74, 70, "Input"],
Cell[51401, 1504, 81, 1, 70, "Text"],
Cell[51485, 1507, 8150, 188, 70, "Input"],
Cell[59638, 1697, 121, 4, 70, "Text"],
Cell[59762, 1703, 1816, 42, 70, "Input"],
Cell[61581, 1747, 9334, 217, 70, "Input"],
Cell[70918, 1966, 76, 1, 70, "Text"],
Cell[70997, 1969, 580, 16, 70, "Input"],
Cell[71580, 1987, 72, 1, 70, "Text"],
Cell[71655, 1990, 564, 16, 70, "Input"],
Cell[72222, 2008, 98, 1, 70, "Text"],
Cell[72323, 2011, 3939, 88, 70, "Input"],
Cell[76265, 2101, 85, 1, 70, "Text"],
Cell[76353, 2104, 1143, 38, 70, "Input"],
Cell[77499, 2144, 60, 1, 70, "Text"],
Cell[77562, 2147, 2733, 61, 70, "Input"],
Cell[80298, 2210, 61, 1, 70, "Text"],
Cell[80362, 2213, 8688, 153, 70, "Input"],
Cell[89053, 2368, 61, 1, 70, "Text"],
Cell[89117, 2371, 808, 18, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[89962, 2394, 86, 1, 47, "Subsection"],
Cell[90051, 2397, 84, 1, 70, "Text"],
Cell[90138, 2400, 66, 1, 70, "Input"],
Cell[90207, 2403, 63, 1, 70, "Text"],
Cell[90273, 2406, 1116, 23, 70, "Input"],
Cell[91392, 2431, 70, 1, 70, "Text"],
Cell[91465, 2434, 446, 13, 70, "Input"],
Cell[91914, 2449, 88, 1, 70, "Text"],
Cell[92005, 2452, 388, 12, 70, "Input"],
Cell[92396, 2466, 61, 1, 70, "Text"],
Cell[92460, 2469, 334, 12, 70, "Input"],
Cell[92797, 2483, 76, 1, 70, "Text"],
Cell[92876, 2486, 428, 13, 70, "Input"],
Cell[93307, 2501, 76, 1, 70, "Text"],
Cell[93386, 2504, 3673, 92, 70, "Input"],
Cell[97062, 2598, 91, 1, 70, "Text"],
Cell[97156, 2601, 2132, 48, 70, "Input"],
Cell[99291, 2651, 71, 1, 70, "Text"],
Cell[99365, 2654, 2030, 43, 70, "Input"],
Cell[101398, 2699, 74, 1, 70, "Text"],
Cell[101475, 2702, 1935, 33, 70, "Input"],
Cell[103413, 2737, 74, 1, 70, "Text"],
Cell[103490, 2740, 4317, 65, 70, "Input"],
Cell[107810, 2807, 74, 1, 70, "Text"],
Cell[107887, 2810, 356, 12, 70, "Input"],
Cell[108246, 2824, 68, 1, 70, "Text"],
Cell[108317, 2827, 750, 21, 70, "Input"],
Cell[109070, 2850, 91, 1, 70, "Text"],
Cell[109164, 2853, 941, 20, 70, "Input"],
Cell[110108, 2875, 75, 1, 70, "Text"],
Cell[110186, 2878, 792, 18, 70, "Input"],
Cell[110981, 2898, 129, 4, 70, "Text"],
Cell[111113, 2904, 949, 20, 70, "Input"],
Cell[112065, 2926, 99, 1, 70, "Text"],
Cell[112167, 2929, 720, 17, 70, "Input"],
Cell[112890, 2948, 565, 15, 70, "Input"],
Cell[113458, 2965, 99, 1, 70, "Text"],
Cell[113560, 2968, 535, 14, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[114132, 2987, 73, 1, 47, "Subsection"],
Cell[114208, 2990, 2422, 78, 279, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[116667, 3073, 99, 1, 47, "Subsection"],
Cell[116769, 3076, 66, 1, 25, "Input"],
Cell[116838, 3079, 76, 1, 46, "Text"],
Cell[116917, 3082, 3668, 92, 649, "Input"],
Cell[120588, 3176, 89, 1, 46, "Text"],
Cell[120680, 3179, 2093, 48, 376, "Input"],
Cell[122776, 3229, 76, 1, 46, "Text"],
Cell[122855, 3232, 432, 13, 64, "Input"],
Cell[123290, 3247, 99, 1, 46, "Text"],
Cell[123392, 3250, 535, 14, 90, "Input"],
Cell[123930, 3266, 75, 1, 46, "Text"],
Cell[124008, 3269, 832, 18, 168, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

